import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html } from 'lit';
import { property } from 'lit/decorators.js';
import ArrowDown20 from '@carbon/web-components/es/icons/arrow--down/20.js';
import ArrowLeft20 from '@carbon/web-components/es/icons/arrow--left/20.js';
import ArrowRight20 from '@carbon/web-components/es/icons/arrow--right/20.js';
import Download20 from '@carbon/web-components/es/icons/download/20.js';
import KalturaPlayerAPI from '@carbon/ibmdotcom-services/es/services/KalturaPlayer/KalturaPlayer.js';
import Launch20 from '@carbon/web-components/es/icons/launch/20.js';
import PlayFilledAlt20 from '@carbon/web-components/es/icons/play--filled--alt/20.js';
import Blog20 from '@carbon/web-components/es/icons/blog/20.js';
import DocumentPDF20 from '@carbon/web-components/es/icons/document--pdf/20.js';
import NewTab20 from '@carbon/web-components/es/icons/new-tab/20.js';
import Phone20 from '@carbon/web-components/es/icons/phone/20.js';
import Calendar20 from '@carbon/web-components/es/icons/calendar/20.js';
import Email20 from '@carbon/web-components/es/icons/email/20.js';
import Chat20 from '@carbon/web-components/es/icons/chat/20.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import { CTA_TYPE } from "../../components/cta/defs.js";
import { formatVideoCaption, formatVideoDuration } from '@carbon/ibmdotcom-utilities/es/utilities/formatVideoCaption/formatVideoCaption.js';
import root from 'window-or-global';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Icons to use, keyed by CTA type.
 */
export const icons = {
  [CTA_TYPE.LOCAL]: ArrowRight20,
  [`${CTA_TYPE.LOCAL}-rtl`]: ArrowLeft20,
  [CTA_TYPE.DOWNLOAD]: Download20,
  [CTA_TYPE.EXTERNAL]: Launch20,
  [CTA_TYPE.NEW_TAB]: NewTab20,
  [CTA_TYPE.JUMP]: ArrowDown20,
  [CTA_TYPE.VIDEO]: PlayFilledAlt20,
  [CTA_TYPE.PDF]: DocumentPDF20,
  [CTA_TYPE.BLOG]: Blog20,
  [CTA_TYPE.EMAIL]: Email20,
  [CTA_TYPE.SCHEDULE]: Calendar20,
  [CTA_TYPE.CHAT]: Chat20,
  [CTA_TYPE.CALL]: Phone20
};

/**
 * Aria Labels to use, keyed by CTA type.
 */
export const ariaLabels = {
  [CTA_TYPE.LOCAL]: '',
  [CTA_TYPE.DOWNLOAD]: ' - This link downloads a file',
  [CTA_TYPE.EXTERNAL]: ' - This link opens in a new tab',
  [CTA_TYPE.NEW_TAB]: ' - This link opens in a new tab',
  [CTA_TYPE.JUMP]: '',
  [CTA_TYPE.VIDEO]: ' - This link plays a video',
  [CTA_TYPE.PDF]: ' - This link downloads a pdf',
  [CTA_TYPE.BLOG]: ''
};
export const types = CTA_TYPE;

/**
 * @param Base The base class.
 * @returns A mix-in implementing the logic of handling link for CTA.
 * @csspart icon-visually-hidden - The cta icon element for screen readers. Usage: `c4d-left-nav-name::part(icon-visually-hidden)`
 */
const CTAMixin = Base => {
  let CTAMixinImpl = _decorate(null, function (_initialize, _Base) {
    class CTAMixinImpl extends _Base {
      constructor(...args) {
        super(...args);
        _initialize(this);
      }
    }
    return {
      F: CTAMixinImpl,
      d: [{
        kind: "method",
        key: "_handleClick",
        value:
        /**
         * The `<a>`.
         *
         * @internal
         */

        /**
         * Handles `click` event on the `<a>.
         *
         * @param event The event.
         */
        function _handleClick(event) {
          const {
            ctaType,
            disabled,
            href,
            videoDescription,
            videoName
          } = this;
          if (ctaType === CTA_TYPE.VIDEO) {
            event.preventDefault(); // Stop following the link
          }
          if (!disabled) {
            const {
              eventRunAction
            } = this.constructor;
            this.dispatchEvent(new CustomEvent(eventRunAction, {
              bubbles: true,
              cancelable: true,
              composed: true,
              detail: {
                href,
                ctaType,
                videoName,
                videoDescription
              }
            }));
          } else {
            event.preventDefault(); // Stop following the link
            event.stopPropagation(); // Stop firing `onClick`
          }
        }

        /**
         * The CTA type.
         */
      }, {
        kind: "field",
        decorators: [property({
          attribute: 'cta-type',
          type: String,
          reflect: true
        })],
        key: "ctaType",
        value() {
          return CTA_TYPE.REGULAR;
        }
      }, {
        kind: "field",
        decorators: [property({
          type: Boolean
        })],
        key: "disabled",
        value: void 0
      }, {
        kind: "field",
        decorators: [property()],
        key: "download",
        value: void 0
      }, {
        kind: "field",
        decorators: [property()],
        key: "href",
        value: void 0
      }, {
        kind: "field",
        decorators: [property()],
        key: "target",
        value: void 0
      }, {
        kind: "field",
        decorators: [property({
          attribute: false
        })],
        key: "formatVideoCaption",
        value() {
          return formatVideoCaption;
        }
      }, {
        kind: "field",
        decorators: [property({
          attribute: false
        })],
        key: "formatVideoDuration",
        value() {
          return formatVideoDuration;
        }
      }, {
        kind: "field",
        decorators: [property({
          type: Number,
          attribute: 'video-duration',
          reflect: true
        })],
        key: "videoDuration",
        value: void 0
      }, {
        kind: "field",
        decorators: [property({
          attribute: 'video-name',
          reflect: true
        })],
        key: "videoName",
        value: void 0
      }, {
        kind: "field",
        decorators: [property({
          attribute: 'video-description',
          reflect: true
        })],
        key: "videoDescription",
        value: void 0
      }, {
        kind: "field",
        decorators: [property()],
        key: "videoTitle",
        value: void 0
      }, {
        kind: "method",
        key: "_renderIcon",
        value:
        /**
         * `true` if the button should be disabled.
         */
        /**
         * The default file name.
         */
        /**
         * Link `href`.
         */
        /**
         * The link target.
         */
        /**
         * The formatter for the video caption, composed with the video name and the video duration.
         * Should be changed upon the locale the UI is rendered with.
         */
        /**
         * The formatter for the video duration.
         * Should be changed upon the locale the UI is rendered with.
         */
        /**
         * The video duration.
         */
        /**
         * The video name.
         */
        /**
         * The video description.
         */
        /**
         * The full formatted video title with duration
         */
        /**
         * The video thumbnail URL.
         * Text CTA does not support video thumbnail, and this property should never be set.
         */
        /**
         * @returns The template for the icon.
         */
        function _renderIcon() {
          var _icons;
          const {
            ctaType
          } = this;
          const icon = (_icons = icons[`${ctaType}-${document.dir}`]) !== null && _icons !== void 0 ? _icons : icons[ctaType];
          return html(_t || (_t = _`
        <slot name="icon">
          <span class="${0}--visually-hidden" part="icon-visually-hidden"
            >${0}</span
          >
          ${0}
        </slot>
      `), prefix, ariaLabels[ctaType], icon === null || icon === void 0 ? void 0 : icon({
            class: `${c4dPrefix}--card__cta ${c4dPrefix}-ce--cta__icon`
          }));
        }
      }, {
        kind: "method",
        key: "firstUpdated",
        value: function firstUpdated() {
          const {
            ctaType,
            href
          } = this;
          // Check for the URL trigger meant to fire eventRunAction.
          if (ctaType === CTA_TYPE.VIDEO && href) {
            this._checkUrlVideoTrigger();
          }
        }

        /**
         * Handles `.updated()` method of `lit-element`.
         */
      }, {
        kind: "method",
        key: "updated",
        value: function updated(changedProperties) {
          var _this$shadowRoot;
          // Declaring this mixin as it extends `LitElement` seems to cause a TS error
          // @ts-ignore
          _superPropGet(CTAMixinImpl, "updated", this, 3)([changedProperties]);
          const {
            ctaType,
            _linkNode: linkNode,
            videoName,
            videoDescription,
            href,
            videoDuration
          } = this;
          if (changedProperties.has('ctaType') || changedProperties.has('download')) {
            const {
              download
            } = this;
            const downloadTypes = [CTA_TYPE.DOWNLOAD, CTA_TYPE.PDF];
            if (!downloadTypes.includes(ctaType) && download) {
              // eslint-disable-next-line no-console
              console.warn(`\`download\` property used with a CTA data item besides \`type: download|pdf\` (\`type: ${ctaType}\`).`);
            }
            const contactMethods = {
              [CTA_TYPE.EMAIL]: 'email-link',
              [CTA_TYPE.SCHEDULE]: 'scheduler-link',
              [CTA_TYPE.CHAT]: 'chat-link',
              [CTA_TYPE.CALL]: 'phone-link'
            };
            if (Object.keys(contactMethods).includes(ctaType)) {
              linkNode.dataset.ibmContact = contactMethods[ctaType];
            }
          }
          // TODO: See why `linkNode` can possibly be `null`
          if (linkNode && linkNode.nodeName === 'A') {
            if (changedProperties.has('ctaType') || changedProperties.has('href')) {
              const {
                href: _href
              } = this;
              const hrefValue = ctaType !== CTA_TYPE.VIDEO ? _href : '#';
              // If this CTA is of video, uses the link as the action button
              if (hrefValue == null) {
                linkNode.removeAttribute('href');
              } else {
                linkNode.setAttribute('href', hrefValue);
              }
            }
            if (changedProperties.has('ctaType') || changedProperties.has('target')) {
              // Default the target to `_blank` if this CTA is an external link and
              // target is not already set
              const {
                target
              } = this;
              const newTabTypes = [CTA_TYPE.EXTERNAL, CTA_TYPE.NEW_TAB];
              const targetInEffect = newTabTypes.includes(ctaType) && !target ? '_blank' : target;
              if (!targetInEffect) {
                linkNode.removeAttribute('target');
              } else {
                linkNode.setAttribute('target', targetInEffect);
              }
            }
            if (linkNode.hasAttribute('aria-label')) {
              linkNode.setAttribute('aria-label', linkNode.getAttribute('aria-label') + (ctaType ? ariaLabels[ctaType] : ''));
            }
          }
          const {
            eventRequestVideoData
          } = this.constructor;
          if (changedProperties.has('ctaType') && ctaType === CTA_TYPE.VIDEO) {
            if (typeof videoDuration === 'undefined') {
              // Wait for the container to be ready without blocking.
              customElements.whenDefined(`${c4dPrefix}-video-cta-container`).then(() => {
                this.dispatchEvent(new CustomEvent(eventRequestVideoData, {
                  bubbles: true,
                  cancelable: true,
                  composed: true,
                  detail: {
                    href,
                    videoName,
                    videoDescription
                  }
                }));
              });
            }
          }
          if (changedProperties.has('videoName') && (videoName === null || videoName === 'null') || changedProperties.has('videoDescription')) {
            if (typeof videoDuration === 'undefined') {
              // Wait for the container to be ready without blocking.
              customElements.whenDefined(`${c4dPrefix}-video-cta-container`).then(() => {
                this.dispatchEvent(new CustomEvent(eventRequestVideoData, {
                  bubbles: true,
                  cancelable: true,
                  composed: true,
                  detail: {
                    videoName,
                    videoDescription,
                    href
                  }
                }));
              });
            }
          }
          const firstChild = this === null || this === void 0 || (_this$shadowRoot = this.shadowRoot) === null || _this$shadowRoot === void 0 ? void 0 : _this$shadowRoot.querySelector(':first-child');
          if (ctaType === CTA_TYPE.VIDEO && firstChild && firstChild.offsetWidth > 0) {
            this._updateVideoThumbnailUrl(String(firstChild.offsetWidth));
          }
        }

        /**
         * Check the URL for a fragment including the video id.
         *
         * If we find a URL fragment that includes the video id, we trigger the
         * eventRunAction event, which for video will open the video and start
         * playback in a lightbox. This is the same thing that happens when the user
         * clicks on the CTA.
         */
      }, {
        kind: "method",
        key: "_checkUrlVideoTrigger",
        value: function _checkUrlVideoTrigger() {
          const {
            ctaType,
            disabled,
            href,
            videoDescription,
            videoName
          } = this;
          // Without a video id, or if the button is disabled, there is nothing to
          // do here.
          if (ctaType !== CTA_TYPE.VIDEO || !href || disabled) {
            return;
          }
          // Only trigger for the first CTA with the video id in the page.
          if (this.ownerDocument.querySelector(`[href='${href}']`) !== this) {
            return;
          }
          const {
            eventRunAction
          } = this.constructor;
          const hash = root.location.hash;
          const urlTrigger = `cta-video-${href}`;
          if (hash === `#${urlTrigger}`) {
            this.dispatchEvent(new CustomEvent(eventRunAction, {
              bubbles: true,
              cancelable: true,
              composed: true,
              detail: {
                href,
                ctaType,
                videoName,
                videoDescription
              }
            }));
          }
        }

        /**
         * Updates video thumbnail url to match card width.
         */
      }, {
        kind: "method",
        key: "_updateVideoThumbnailUrl",
        value: function _updateVideoThumbnailUrl(width) {
          this.videoThumbnailUrl = KalturaPlayerAPI.getThumbnailUrl({
            mediaId: this.href,
            width: width !== null && width !== void 0 ? width : '340'
          });
        }

        /**
         * The name of the custom event fired when there is a user gesture to run the action.
         */
      }, {
        kind: "get",
        static: true,
        key: "eventRequestVideoData",
        value: function () {
          return `${c4dPrefix}-cta-request-video-data`;
        }

        /**
         * The name of the custom event fired when there is a user gesture to run the action.
         */
      }, {
        kind: "get",
        static: true,
        key: "eventRunAction",
        value: function () {
          return `${c4dPrefix}-cta-run-action`;
        }
      }]
    };
  }, Base);
  return CTAMixinImpl;
};
export default CTAMixin;
//# sourceMappingURL=cta.js.map
