/**
 * @license
 *
 * Copyright IBM Corp. 2022, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import C4DTab from "../../components/tabs-extended/tab.js";
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * @param Base The base class.
 * @returns A mix-in implementing the logic for handling elements that need to
 *   respond when a potential parent element becomes visible.
 * @deprecated This mixin will be removed in a future release.
 */
const ParentVisibilityMixin = Base => {
  class ParentVisibilityMixinImpl extends Base {
    /**
     * The method that is invoked when a parent becomes visible.
     */

    /**
     * Handles `.connectedCallback()` method of `lit-element`.
     */
    connectedCallback() {
      // @ts-ignore
      super.connectedCallback();
      const {
        parentsThatHide
      } = this.constructor;
      Object.entries(parentsThatHide).forEach(([component, event]) => {
        let target = this.closest(component);
        while (target) {
          var _target;
          target.addEventListener(event, this._onParentVisible.bind(this));
          target = (_target = target) === null || _target === void 0 || (_target = _target.parentElement) === null || _target === void 0 ? void 0 : _target.closest(component);
        }
      });
    }

    /**
     * A list of potential parent components that may be hide their content on
     * first render. Lists event names that indicate the parent element
     * visibility has changed keyed by component selector strings.
     */
    static get parentsThatHide() {
      return {
        [`${c4dPrefix}-tab`]: C4DTab.eventTabSelected
      };
    }
  }
  return ParentVisibilityMixinImpl;
};
export default ParentVisibilityMixin;
//# sourceMappingURL=parent-visibility.js.map
