/**
 * @license
 *
 * Copyright IBM Corp. 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { Component } from 'react';
export interface ComponentProps {
  /**
   * The event handler for the custom event fired when there is a user gesture to run the action.
   */
  onRequestAdditionalVideoData?: (event: CustomEvent) => void;
  /**
   * The event handler for the custom event fired when the video title is updated
   */
  onVideoTitleUpdated?: (event: CustomEvent) => void;
  [prop: string]: unknown;
}
/**
 * Card.
 *
 * @element c4d-card
 * @slot eyebrow - The eyebrow content.
 * @slot heading - The heading content.
 * @slot image - The image content.
 * @slot footer - The footer content.
 * @csspart caption - The Caption (default heading). Usage: `c4d-card::part(caption)`
 * @csspart copy - The Copy. Usage: `c4d-card::part(copy)`
 * @csspart container - The Inner content container. Usage: `c4d-card::part(container)`
 * @csspart video-thumbnail - The video thumbnail. Usage: `c4d-card::part(video-thumbnail)`
 * @csspart disabled-link - . Disabled link. Usage: `c4d-card::part(disabled-link)`
 * @csspart wrapper - The component wrapper. Usage: `c4d-card::part(wrapper)`
 * @csspart content - The content container. Usage: `c4d-card::part(content)`
 * @csspart link - Active link. Usage: `c4d-card::part(link)`
 */
declare class C4DCard extends Component<ComponentProps> {}
export default C4DCard;
