/**
 * @license
 *
 * Copyright IBM Corp. 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { Component } from 'react';
export interface ComponentProps {
  /**
   * The event handler for the custom event fired before this modal is being closed upon a user gesture.
   * Cancellation of this event stops the user-initiated action of closing this modal.
   */
  onBeforeClose?: (event: CustomEvent) => void;
  /**
   * The event handler for the custom event fired after this modal is closed upon a user gesture.
   */
  onClose?: (event: CustomEvent) => void;
  [prop: string]: unknown;
}
/**
 * Expressive modal.
 *
 * @element c4d-expressive-modal
 * @fires c4d-expressive-modal-beingclosed
 *   The custom event fired before this modal is being closed upon a user gesture.
 *   Cancellation of this event stops the user-initiated action of closing this modal.
 * @fires c4d-expressive-modal-closed - The custom event fired after this modal is closed upon a user gesture.
 * @slot header - The header content.
 * @slot footer - The footer content.
 * @csspart modal-header - The modal header. Usage: `c4d-expressive-modal::part(modal-header)`
 * @csspart modal-body - The modal body. Usage: `c4d-expressive-modal::part(modal-body)`
 * @csspart sentinel-button - Taget all Sentinels buttons Usage: `c4d-expressive-modal::part(sentinel-button)`
 * @csspart sentinel-button--start - Button labled START. Usage: `c4d-expressive-modal::part(sentinel-button--start)`
 * @csspart sentinel-button--end - Button labled END. Usage: `c4d-expressive-modal::part(sentinel-button--end)`
 * @csspart modal-container - The modal container. Usage: `c4d-expressive-modal::part(modal-container)`
 * @csspart footer-container - The footer container. Usage: `c4d-expressive-modal::part(footer-container)`
 */
declare class C4DExpressiveModal extends Component<ComponentProps> {}
export default C4DExpressiveModal;
