/**
 * @license
 *
 * Copyright IBM Corp. 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { Component } from 'react';
export interface ComponentProps {
  /**
   * The event handler for the custom event captured upon selecting a checkbox
   */
  onCheckboxSelect?: (event: CustomEvent) => void;
  /**
   * The event handler for the custom event captured upon selecting an input select item.
   */
  onInputSelectItem?: (event: CustomEvent) => void;
  /**
   * The event handler for the custom event captured upon activating "view all" button in
   * a filter group item
   */
  onFilterGroupViewAllToggle?: (event: CustomEvent) => void;
  /**
   * The event handler for the custom event captured upon closing the modal
   */
  onModalClose?: (event: CustomEvent) => void;
  /**
   * The event handler for the custom event capture upon selecting an input select item
   */
  onInputSelect?: (event: CustomEvent) => void;
  /**
   * The event handler for the custom event fired to clear selections
   */
  onSelectionClear?: (event: CustomEvent) => void;
  /**
   * The event handler for the custom event capture when the heading changes
   */
  onHeadingChange?: (event: CustomEvent) => void;
  [prop: string]: unknown;
}
/**
 * Filter panel composite
 *
 * @element c4d-filter-panel-composite
 * @csspart panel-modal - The panel modal. Usage: `c4d-filter-panel::part(panel-modal)`
 * @csspart button - The button. Usage: `c4d-filter-panel::part(button)`
 * @csspart filter-panel - The filter panel. Usage: `c4d-filter-panel::part(filter-panel)`
 */
declare class C4DFilterPanelComposite extends Component<ComponentProps> {}
export default C4DFilterPanelComposite;
