/**
 * @license
 *
 * Copyright IBM Corp. 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
export { default as CustomElement } from '../../components/filter-panel/filter-panel-composite.js';
import createReactCustomElementType from '@carbon/web-components/es/globals/wrappers/createReactCustomElementType.js';
import PropTypes from 'prop-types';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
var prefix = settings.prefix;
var c4dPrefix = settings.stablePrefix;
export var descriptor = {
  onCheckboxSelect: {
    event: ''.concat(c4dPrefix, '-checkbox-select'),
  },
  onInputSelectItem: {
    event: ''.concat(c4dPrefix, '-filter-panel-input-select'),
  },
  onFilterGroupViewAllToggle: {
    event: ''.concat(c4dPrefix, '-filter-group-view-all-toggle'),
  },
  onModalClose: {
    event: ''.concat(prefix, '-modal-beingclosed'),
  },
  onInputSelect: {
    event: ''.concat(c4dPrefix, '-filter-panel-input-select-title'),
  },
  onSelectionClear: {
    event: ''.concat(c4dPrefix, '-selection-clear'),
  },
  onHeadingChange: {
    event: ''.concat(c4dPrefix, '-filter-panel-heading-change'),
  },
};
export var propTypes = {
  /**
   * The name of the custom event captured upon selecting a checkbox
   */
  onCheckboxSelect: PropTypes.func,
  /**
   * The name of the custom event captured upon selecting an input select item.
   */
  onInputSelectItem: PropTypes.func,
  /**
   * The name of the custom event captured upon activating "view all" button in
   * a filter group item
   */
  onFilterGroupViewAllToggle: PropTypes.func,
  /**
   * The name of the custom event captured upon closing the modal
   */
  onModalClose: PropTypes.func,
  /**
   * The name of the custom event capture upon selecting an input select item
   */
  onInputSelect: PropTypes.func,
  /**
   * The name of the custom event fired to clear selections
   */
  onSelectionClear: PropTypes.func,
  /**
   * The name of the custom event capture when the heading changes
   */
  onHeadingChange: PropTypes.func,
};
const Component = createReactCustomElementType(
  ''.concat(c4dPrefix, '-filter-panel-composite'),
  descriptor
);
Component.propTypes = propTypes;
export default Component;
