/**
 * @license
 *
 * Copyright IBM Corp. 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { Component } from 'react';
export interface ComponentProps {
  /**
   * The event handler for the custom event fired after the modal is closed upon a user gesture.
   */
  onCloseModal?: (event: CustomEvent) => void;
  [prop: string]: unknown;
}
/**
 * Image.
 *
 * @element c4d-image
 * @slot long-description - The long description content.
 * @slot icon - The icon content.
 * @csspart image - The image. Usage: `c4d-image::part(image)`
 * @csspart picture - The picture tag. Usage:` c4d-image::part(picture)`
 * @csspart long-description - The wrapper around the long description slot. Usage: `c4d-image::part(long-description)`
 * @csspart lightbox-button - The button element for the lightbox when used. Usage: `c4d-image::part(lightbox-button)`
 * @csspart zoom-button - The wrapper around the zoom button to trigger the lightbox when used. Usage: `c4d-image::part(zoom-button)`
 * @csspart zoom-icon - The zoom icon used for the lightbox. Usage: `c4d-image::part(zoom-icon)`
 * @csspart caption - The caption for the image. Usage: `c4d-image::part(caption)`
 * @csspart expressive-modal - The expressive modal content. Usage: `c4d-image::part(expressive-modal)`
 * @csspart expressive-modal-close-button - The expressive modal content close button. Usage: `c4d-image::part(expressive-modal-close-button)`
 * @csspart lightbox-image-viewer - The lightbox image viewer component. Usage: `c4d-image::part(lightbox-image-viewer)`
 */
declare class C4DImage extends Component<ComponentProps> {}
export default C4DImage;
