/**
 * @license
 *
 * Copyright IBM Corp. 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { Component } from 'react';
export interface ComponentProps {
  [prop: string]: unknown;
}
/**
 * The LeadSpace component.
 *
 * @element c4d-leadspace
 * @slot action The action (CTA) content.
 * @slot image The image content.
 * @csspart content - The content. Usage: `c4d-leadspace::part(content)`
 * @csspart content-item - The subheading paragraph. Usage: `c4d-leadspace::part(content-item)`
 * @csspart row - Row wrappers. Usage: `c4d-leadspace::part(row)`
 * @csspart row--description - Row wrapper for the description. Usage: `c4d-leadspace::part(row--description)`
 * @csspart row--content - Row wrapper for the navigation and heading. Usage: `c4d-leadspace::part(row--content)`
 * @csspart description - The description. Usage`c4d-leadspace::part(description)`
 * @csspart section - The first DOM node inside the shadow-root. Usage: `c4d-leadspace::part(section)`
 * @csspart container - The container around the whole leadspace. Usage: `c4d-leadspace::part(container)`
 * @csspart content-container - The container around just the content of the leadspace. Usage: `c4d-leadspace::part(content-container)`
 * @csspart overlay - The leadspace overlay wrapping all contents and optional gradient. Usage: `c4d-leadspace::part(overlay)`
 * @csspart gradient - The SVG gradient. Usage: `c4d-leadspace::part(gradient)`
 * @csspart action - The action. Usage: `c4d-leadspace::part(action)`
 */
declare class C4DLeadSpace extends Component<ComponentProps> {}
export default C4DLeadSpace;
