/**
 * @license
 *
 * Copyright IBM Corp. 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { Component } from 'react';
export interface ComponentProps {
  /**
   * The event handler for the custom event fired after video content state is changed upon a user gesture.
   */
  onContentStateChange?: (event: CustomEvent) => void;
  /**
   * The event handler for the custom event fired requesting playback state change.
   */
  onPlaybackStateChange?: (event: CustomEvent) => void;
  /**
   * The event handler for the custom event fired requesting to toggle playback.
   */
  onTogglePlayback?: (event: CustomEvent) => void;
  [prop: string]: unknown;
}
/**
 * Component that renders video player from its metadata, etc.
 *
 * @element c4d-video-player-composite
 * @csspart video-player - The video player. Usage `c4d-video-player-composite::part(video-player)`
 */
declare class C4DVideoPlayerComposite extends Component<ComponentProps> {}
export default C4DVideoPlayerComposite;
