/**
 * @license
 *
 * Copyright IBM Corp. 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { Component } from 'react';
export interface ComponentProps {
  /**
   * The event handler for the custom event fired after video content state is changed upon a user gesture.
   */
  onContentStateChange?: (event: CustomEvent) => void;
  /**
   * The event handler for the custom event fired requesting playback state change.
   */
  onPlaybackStateChange?: (event: CustomEvent) => void;
  /**
   * The event handler for the custom event fired when a user action toggles playback.
   */
  onTogglePlayback?: (event: CustomEvent) => void;
  [prop: string]: unknown;
}
/**
 * Video player.
 *
 * @element c4d-video-player
 * @csspart video - The video. Usage `c4d-video-player::part(video)`
 * @csspart button - The play button. Usage `c4d-video-player::part(button)`
 * @csspart image - The thumbnail image. Usage `c4d-video-player::part(image)`
 * @csspart play-video - The play video icon. Usage `c4d-video-player::part(play-video)`
 * @csspart video-container - The video container. Usage `c4d-video-player::part(video-container)`
 * @csspart caption - The caption. Usage `c4d-video-player::part(caption)`
 */
declare class C4DVideoPlayer extends Component<ComponentProps> {}
export default C4DVideoPlayer;
