import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2021, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import HostListener from '@carbon/web-components/es/globals/decorators/host-listener.js';
import HostListenerMixin from '@carbon/web-components/es/globals/mixins/host-listener.js';
import throttle from 'lodash-es/throttle.js';
import UpToTop20 from '@carbon/web-components/es/icons/up-to-top/20.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././back-to-top.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;
/**
 * Back to top
 *
 * @element c4d-back-to-top
 * @csspart button - The button. Usage: `c4d-back-to-top::part(button)`
 */
let C4DBackToTop = _decorate([customElement(`${c4dPrefix}-back-to-top`)], function (_initialize, _HostListenerMixin) {
  class C4DBackToTop extends _HostListenerMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DBackToTop,
    d: [{
      kind: "field",
      key: "_observerResizeBody",
      value() {
        return null;
      }
    }, {
      kind: "field",
      key: "_throttleScroll",
      value() {
        return null;
      }
    }, {
      kind: "method",
      key: "_handleOnClick",
      value:
      /**
       * The observer for the resize of the document body.
       */
      // TODO: Wait for `.d.ts` update to support `ResizeObserver`

      /**
       * The document height
       */

      /**
       * The viewport height
       */

      /**
       * The handler for throttled scrolling
       */

      /**
       * Button click scrolls to top
       */
      function _handleOnClick() {
        this.ownerDocument.defaultView.scrollTo({
          top: 0,
          behavior: 'smooth'
        });
        this.ownerDocument.body.tabIndex = 0;
        this.ownerDocument.body.focus({
          preventScroll: true
        });
        this.ownerDocument.body.removeAttribute('tabindex');
      }

      /**
       * Manage the visibility of the back to top button taking into consideration
       * whether it's needed at all for the page, as well as the current scroll
       * position. We show the button when needed and when the one full page
       * length is scrolled.
       */
    }, {
      kind: "method",
      key: "_manageVisibility",
      value: function _manageVisibility() {
        if (this._isBackToTopNeededForPage()) {
          this.hidden = this.ownerDocument.scrollingElement.scrollTop <= this._viewportHeight;
        } else {
          this.hidden = true;
        }
      }

      /**
       * Scroll handler to manage visibility.
       */
    }, {
      kind: "method",
      key: "_handleOnScroll",
      value: function _handleOnScroll() {
        this._manageVisibility();
      }

      /**
       * Cleans-up and creats the resize observer for the scrolling container.
       *
       * @param [options] The options.
       * @param [options.create] `true` to create the new resize observer.
       */
    }, {
      kind: "method",
      key: "_cleanAndCreateObserverResize",
      value: function _cleanAndCreateObserverResize({
        create
      } = {}) {
        if (this._observerResizeBody) {
          this._observerResizeBody.disconnect();
          this._observerResizeBody = null;
        }
        if (create) {
          // TODO: Wait for `.d.ts` update to support `ResizeObserver`
          // @ts-ignore
          this._observerResizeBody = new ResizeObserver(this._handleBodyResize);
          this._observerResizeBody.observe(this.ownerDocument.body);
        }
      }

      /**
       * ResizeObserver callback function.
       *
       * We only observe the body element, therefore entries will typically only
       * have a single item corresponding to changes in the size of the body
       * element.
       */
    }, {
      kind: "field",
      key: "_handleBodyResize",
      value() {
        return entries => {
          this._bodyHeight = entries[entries.length - 1].target.scrollHeight;
          // Body height changes may require adjustment to the current visibility
          // of the back to top button.
          this._manageVisibility();
        };
      }
    }, {
      kind: "method",
      key: "_isBackToTopNeededForPage",
      value:
      /**
       * The back to top button is only necessary when the document height
       * is 3x greater than the viewport.
       */
      function _isBackToTopNeededForPage() {
        var _this$ownerDocument$d;
        // @ts-ignore
        this._viewportHeight = (_this$ownerDocument$d = this.ownerDocument.defaultView) === null || _this$ownerDocument$d === void 0 ? void 0 : _this$ownerDocument$d.innerHeight;
        return this._bodyHeight > this._viewportHeight * 3;
      }

      /**
       * `false` if the button should be visible
       */
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true
      })],
      key: "hidden",
      value() {
        return true;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'back-to-top-assistive-text'
      })],
      key: "backToTopAssistiveText",
      value() {
        return 'Back to top';
      }
    }, {
      kind: "field",
      decorators: [HostListener('window:scroll')],
      key: "_handleScroll",
      value() {
        return event => {
          this._throttleScroll(event);
        };
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value:
      /**
       * Assistive text for back to top button.
       */
      function connectedCallback() {
        _superPropGet(C4DBackToTop, "connectedCallback", this, 3)([]);
        this._cleanAndCreateObserverResize({
          create: true
        });
        if (!this._throttleScroll) {
          this._throttleScroll = throttle(this._handleOnScroll, 250);
        }
      }
    }, {
      kind: "method",
      key: "disconnectedCallback",
      value: function disconnectedCallback() {
        _superPropGet(C4DBackToTop, "disconnectedCallback", this, 3)([]);
        this._cleanAndCreateObserverResize();
        if (this._throttleScroll) {
          this._throttleScroll.cancel();
          this._throttleScroll = null;
        }
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        this._cleanAndCreateObserverResize({
          create: true
        });
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          backToTopAssistiveText,
          _handleOnClick: handleOnClick
        } = this;
        return html(_t || (_t = _`
      <button
        part="button"
        class="${0}--btn ${0}--btn--secondary ${0}--btn--icon-only ${0}--back-to-top__btn"
        aria-label="${0}"
        @click="${0}">
        ${0}
      </button>
    `), prefix, prefix, prefix, prefix, backToTopAssistiveText, handleOnClick, UpToTop20());
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--back-to-top`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, HostListenerMixin(StableSelectorMixin(LitElement)));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DBackToTop;
//# sourceMappingURL=back-to-top.js.map
