/**
 * @license
 *
 * Copyright IBM Corp. 2021, 2025
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { GRADIENT_DIRECTION, MOBILE_POSITION } from './defs';
import C4DImage from '../image/image';
import C4DVideoPlayerContainer from '../video-player/video-player-container';
/**
 * Background media.
 *
 * @element c4d-background-media
 * @csspart controls - The video player controls. Usage: `c4d-background-media::part(controls)`
 * @csspart gradient - The gradient covering the image. Usage: `c4d-background-media::part(gradient)`
 * @csspart container - The component's container. Usage: `c4d-background-media::part(container)`
 * @csspart item - The image container. Usage: `c4d-background-media::part(item)`
 */
declare class C4DBackgroundMedia extends C4DImage {
    /**
     * Returns a class-name based on the Gradient Direction type
     */
    protected _getGradientClass(): import("lit-html/directive").DirectiveResult<typeof import("lit-html/directives/class-map").ClassMapDirective>;
    /**
     * Returns a class-name based on the Mobile Position type
     */
    protected _getMobilePositionClass(): import("lit-html/directive").DirectiveResult<typeof import("lit-html/directives/class-map").ClassMapDirective>;
    /**
     * The opacity of the background image or video. 100 is fully visible, 0 is fully transparent.
     */
    backgroundOpacity: number;
    /**
     * Set to true in _handleBackgroundMedia if all children are `c4d-image-item`
     */
    containsOnlyImages: boolean;
    /**
     * Gradient Direction (left-to-right (default) | top-to-bottom)
     */
    gradientDirection: GRADIENT_DIRECTION;
    /**
     * Option to hide gradient. Automatically set to yes if parent is c4d-leadspace
     */
    gradientHidden: boolean;
    /**
     *  Determines if the direction is right-to-left
     */
    isRTL: boolean;
    /**
     * @deprecated
     *
     * Mobile Position (bottom (default) | top)
     */
    mobilePosition: MOBILE_POSITION;
    /**
     * Query selector to get the child video player container
     */
    protected get videoPlayerContainer(): C4DVideoPlayerContainer | null;
    /**
     * Conditionally runs super.render() if all children are `c4d-image-item`
     */
    private _handleBackgroundMedia;
    toggleVideoState(): void;
    renderVideoControls(): import("lit-html").TemplateResult<1>;
    renderGradient(): import("lit-html").TemplateResult<1>;
    _getMediaOpacity(): string;
    _handleIsRTL(): void;
    /**
     * Append the c4d-background-media to the parent element where this component is being used.
     */
    updated(): void;
    firstUpdated(): void;
    render(): import("lit-html").TemplateResult<1>;
    static get stableSelector(): string;
    static styles: any;
}
export default C4DBackgroundMedia;

//# sourceMappingURL=background-media.d.ts.map
