import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2,
  _t3;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2021, 2025
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html } from 'lit';
import { property } from 'lit/decorators.js';
import { classMap } from 'lit/directives/class-map.js';
import pauseIcon from '@carbon/web-components/es/icons/pause--outline--filled/32.js';
import playIcon from '@carbon/web-components/es/icons/play--filled/32.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././background-media.css.js";
import { GRADIENT_DIRECTION, MOBILE_POSITION } from "./defs.js";
import C4DImage from "../image/image.js";
import C4DLeadSpace from "../leadspace/leadspace.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Background media.
 *
 * @element c4d-background-media
 * @csspart controls - The video player controls. Usage: `c4d-background-media::part(controls)`
 * @csspart gradient - The gradient covering the image. Usage: `c4d-background-media::part(gradient)`
 * @csspart container - The component's container. Usage: `c4d-background-media::part(container)`
 * @csspart item - The image container. Usage: `c4d-background-media::part(item)`
 */
let C4DBackgroundMedia = _decorate([customElement(`${c4dPrefix}-background-media`)], function (_initialize, _C4DImage) {
  class C4DBackgroundMedia extends _C4DImage {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DBackgroundMedia,
    d: [{
      kind: "method",
      key: "_getGradientClass",
      value:
      /**
       * Returns a class-name based on the Gradient Direction type
       */
      function _getGradientClass() {
        return classMap({
          [`${prefix}--background-media--gradient`]: true,
          [`${prefix}--background-media--gradient--${this.gradientDirection}`]: this.gradientDirection
        });
      }

      /**
       * Returns a class-name based on the Mobile Position type
       */
    }, {
      kind: "method",
      key: "_getMobilePositionClass",
      value: function _getMobilePositionClass() {
        const {
          videoPlayerContainer: video
        } = this;
        return classMap({
          [`${prefix}--background-media--container`]: true,
          [`${prefix}--background-media--mobile-position`]: true,
          [`${prefix}--background-media--mobile-position--${this.mobilePosition}`]: this.mobilePosition,
          [`${prefix}--background-media--image`]: video === null,
          [`${prefix}--background-media--video`]: video !== null
        });
      }

      /**
       * The opacity of the background image or video. 100 is fully visible, 0 is fully transparent.
       */
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'opacity',
        reflect: true
      })],
      key: "backgroundOpacity",
      value() {
        return 100;
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "containsOnlyImages",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'gradient-direction',
        reflect: true
      })],
      key: "gradientDirection",
      value() {
        return GRADIENT_DIRECTION.LEFT_TO_RIGHT;
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "gradientHidden",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean
      })],
      key: "isRTL",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'mobile-position',
        reflect: true
      })],
      key: "mobilePosition",
      value() {
        return MOBILE_POSITION.BOTTOM;
      }
    }, {
      kind: "get",
      key: "videoPlayerContainer",
      value:
      /**
       * Set to true in _handleBackgroundMedia if all children are `c4d-image-item`
       */
      /**
       * Gradient Direction (left-to-right (default) | top-to-bottom)
       */
      /**
       * Option to hide gradient. Automatically set to yes if parent is c4d-leadspace
       */
      /**
       *  Determines if the direction is right-to-left
       */
      /**
       * @deprecated
       *
       * Mobile Position (bottom (default) | top)
       */
      /**
       * Query selector to get the child video player container
       */
      function () {
        return this.querySelector(`${c4dPrefix}-video-player-container`);
      }

      /**
       * Conditionally runs super.render() if all children are `c4d-image-item`
       */
    }, {
      kind: "method",
      key: "_handleBackgroundMedia",
      value: function _handleBackgroundMedia(event) {
        var _event$target;
        const assignedElements = (_event$target = event.target) === null || _event$target === void 0 ? void 0 : _event$target.assignedElements();
        const assignedImages = assignedElements.filter(el => el.tagName === `${c4dPrefix}-image-item`.toUpperCase());
        const assignedVideos = assignedElements.filter(el => el.tagName === `${c4dPrefix}-video-player-container`.toUpperCase());
        if (assignedImages.length && !assignedVideos.length) {
          this.containsOnlyImages = true;
        }
      }
    }, {
      kind: "method",
      key: "toggleVideoState",
      value: function toggleVideoState() {
        const {
          videoPlayerContainer: video
        } = this;
        if (video !== null && video !== void 0 && video.isPlaying) {
          video.pauseAllVideos();
        } else {
          video === null || video === void 0 || video.playAllVideos();
        }
        this.requestUpdate();
      }
    }, {
      kind: "method",
      key: "renderVideoControls",
      value: function renderVideoControls() {
        const {
          toggleVideoState,
          videoPlayerContainer
        } = this;
        const {
          isPlaying
        } = videoPlayerContainer !== null && videoPlayerContainer !== void 0 ? videoPlayerContainer : {};
        return html(_t || (_t = _`
      <button
        part="controls"
        @click=${0}
        class="${0}--video-player__controls"
        aria-pressed="${0}"
        aria-label="${0}"
        hasTooltip>
        ${0}
      </button>
    `), toggleVideoState, prefix, !isPlaying, isPlaying ? 'Pause the video' : 'Play the video', isPlaying ? pauseIcon() : playIcon());
      }
    }, {
      kind: "method",
      key: "renderGradient",
      value: function renderGradient() {
        return html(_t2 || (_t2 = _`
      <div part="gradient" class="${0}"></div>
    `), this._getGradientClass());
      }
    }, {
      kind: "method",
      key: "_getMediaOpacity",
      value: function _getMediaOpacity() {
        if (this.backgroundOpacity <= 100 && this.backgroundOpacity >= 0) {
          return `opacity:${this.backgroundOpacity / 100}`;
        }
        return '';
      }
    }, {
      kind: "method",
      key: "_handleIsRTL",
      value: function _handleIsRTL() {
        this.isRTL = this.dir === 'rtl' || getComputedStyle(this).direction === 'rtl';
        if (this.isRTL) {
          this.gradientDirection = GRADIENT_DIRECTION.RIGHT_TO_LEFT;
        }
        console.log(this.isRTL);
      }

      /**
       * Append the c4d-background-media to the parent element where this component is being used.
       */
    }, {
      kind: "method",
      key: "updated",
      value: function updated() {
        // mobilePosition attribute deprecated
        if (this.mobilePosition === MOBILE_POSITION.TOP) {
          var _this$parentElement;
          (_this$parentElement = this.parentElement) === null || _this$parentElement === void 0 || (_this$parentElement = _this$parentElement.shadowRoot) === null || _this$parentElement === void 0 || _this$parentElement.prepend(this);
        }
        if (this.parentElement instanceof C4DLeadSpace) {
          this.gradientHidden = true;
        }
        if (this.hasAttribute('default-src') && !this.videoPlayerContainer) {
          this.containsOnlyImages = true;
        }
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        this._handleIsRTL();
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t3 || (_t3 = _`
      <div part="container" class="${0}">
        ${0}
        <div
          part="item"
          class="${0}--background-media--item"
          style="${0}">
          ${0}
          <slot @slotchange="${0}"></slot>
        </div>
      </div>
      ${0}
    `), this._getMobilePositionClass(), this.gradientHidden ? '' : this.renderGradient(), prefix, this._getMediaOpacity(), this.containsOnlyImages ? _superPropGet(C4DBackgroundMedia, "render", this, 3)([]) : '', this._handleBackgroundMedia, this.videoPlayerContainer ? this.renderVideoControls() : '');
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--background-media`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, C4DImage);
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DBackgroundMedia;
//# sourceMappingURL=background-media.js.map
