import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { BUTTON_KIND } from '@carbon/web-components/es/components/button/defs.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././button-group.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Button group.
 *
 * @element c4d-button-group
 */
let C4DButtonGroup = _decorate([customElement(`${c4dPrefix}-button-group`)], function (_initialize, _StableSelectorMixin) {
  class C4DButtonGroup extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DButtonGroup,
    d: [{
      kind: "method",
      key: "_handleSlotChange",
      value:
      /**
       * Handler for @slotchange, set the first button-group-item to kind tertiary and primary for the remaining ones
       *
       * @private
       */
      function _handleSlotChange(event) {
        const childItems = event.target.assignedNodes().filter(elem => elem.matches !== undefined ? elem.matches(this.constructor.selectorItem) || elem.matches(this.constructor.selectorItemCTA) || elem.matches(this.constructor.selectorItemDefaultCTA) : false);
        childItems.forEach((elem, index) => {
          elem.setAttribute('kind', index === 0 ? BUTTON_KIND.PRIMARY : BUTTON_KIND.TERTIARY);
        });
        const {
          customPropertyItemCount
        } = this.constructor;
        this.style.setProperty(customPropertyItemCount, String(childItems.length));
        const update = new CustomEvent(`${c4dPrefix}-button-group-update`, {
          bubbles: true,
          cancelable: true,
          composed: true
        });
        this.dispatchEvent(update);
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t || (_t = _` <slot @slotchange="${0}"></slot> `), this._handleSlotChange);
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value: function connectedCallback() {
        _superPropGet(C4DButtonGroup, "connectedCallback", this, 3)([]);
        this.setAttribute('role', 'list');
      }

      /**
       * The CSS custom property name for the live button group item count.
       */
    }, {
      kind: "get",
      static: true,
      key: "customPropertyItemCount",
      value: function () {
        return `--${c4dPrefix}--button-group--item-count`;
      }

      /**
       * A selector that will return the child items.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItem",
      value: function () {
        return `${c4dPrefix}-button-group-item`;
      }

      /**
       * A selector that will return the child items.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItemDefaultCTA",
      value: function () {
        return `${c4dPrefix}-cta`;
      }

      /**
       * A selector that will return the child items.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItemCTA",
      value: function () {
        return `${c4dPrefix}-button-cta`;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--button-group`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DButtonGroup;
//# sourceMappingURL=button-group.js.map
