import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4;
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { classMap } from 'lit/directives/class-map.js';
import { LitElement, html } from 'lit';
import { property, state } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import { ifDefined } from 'lit/directives/if-defined.js';
import FocusMixin from '@carbon/web-components/es/globals/mixins/focus.js';
import { BUTTON_ICON_LAYOUT, BUTTON_KIND, BUTTON_SIZE } from "./defs.js";
import styles from "././button.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
export { BUTTON_KIND, BUTTON_SIZE };
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Expressive button.
 *
 * @element c4d-button-expressive
 * @csspart button - The button. Usage `c4d-button-expressive::part(button)`
 * @csspart hidden-paragraph - The hidden paragraph that contains the link. Usage `c4d-button-expressive::part(hidden-paragraph)`
 * @csspart hidden-span - The span inside of the hidden paragraph. Usage `c4d-button-expressive::part(hidden-span)`
 */
let C4DButtonExpressive = _decorate([customElement(`${c4dPrefix}-button-expressive`)], function (_initialize, _FocusMixin) {
  class C4DButtonExpressive extends _FocusMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DButtonExpressive,
    d: [{
      kind: "field",
      decorators: [state()],
      key: "_hasIcon",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasMainContent",
      value() {
        return false;
      }
    }, {
      kind: "get",
      key: "_classes",
      value:
      /**
       * `true` if there is an icon.
       */

      /**
       * `true` if there is a non-icon content.
       */

      /**
       * The CSS class list for the button/link node.
       */
      function () {
        const {
          disabled,
          kind,
          size,
          _hasIcon: hasIcon,
          _hasMainContent: hasMainContent
        } = this;
        return classMap({
          [`${prefix}--btn`]: true,
          [`${prefix}--btn--${kind}`]: kind,
          [`${prefix}--btn--disabled`]: disabled,
          [`${prefix}--btn--icon-only`]: hasIcon && !hasMainContent,
          [`${prefix}--btn--expressive`]: true,
          [`${prefix}--btn--${size}`]: size,
          [`${prefix}-ce--btn--has-icon`]: hasIcon
        });
      }

      /**
       * Handles `click` event on the button.
       */
    }, {
      kind: "method",
      key: "_handleClick",
      value: function _handleClick() {} // eslint-disable-line class-methods-use-this

      /**
       * Handles `slotchange` event.
       */
    }, {
      kind: "method",
      key: "_handleSlotChange",
      value: function _handleSlotChange({
        target
      }) {
        const {
          name
        } = target;
        const hasContent = target.assignedNodes().some(node => node.nodeType !== Node.TEXT_NODE || node.textContent.trim());
        this[name === 'icon' ? '_hasIcon' : '_hasMainContent'] = hasContent;
        this.requestUpdate();
      }

      /**
       * @returns The disabled link content.
       */
    }, {
      kind: "method",
      key: "_renderDisabledLink",
      value: function _renderDisabledLink() {
        const {
          _classes: classes
        } = this;
        return html(_t || (_t = _`
      <p id="button" part="button" class="${0}">${0}</p>
    `), classes, this._renderInner());
      }

      /**
       * @returns The inner content.
       */
    }, {
      kind: "method",
      key: "_renderInner",
      value: function _renderInner() {
        const {
          _handleSlotChange: handleSlotChange
        } = this;
        return html(_t2 || (_t2 = _`
      <slot @slotchange="${0}"></slot>
      <p
        class="${0}--btn--hidden"
        aria-hidden="true"
        part="hidden-paragraph">
        <span part="hidden-span">:</span> ${0}
      </p>
      <slot name="icon" @slotchange="${0}"></slot>
    `), handleSlotChange, prefix, this.href, handleSlotChange);
      }

      /**
       * `true` if the button should have input focus when the page loads.
       */
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true
      })],
      key: "autofocus",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true
      })],
      key: "disabled",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "download",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "href",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "hreflang",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        reflect: true,
        attribute: 'icon-layout'
      })],
      key: "iconLayout",
      value() {
        return BUTTON_ICON_LAYOUT.REGULAR;
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "kind",
      value() {
        return BUTTON_KIND.PRIMARY;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'link-role'
      })],
      key: "linkRole",
      value() {
        return 'button';
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "ping",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "rel",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "size",
      value() {
        return BUTTON_SIZE.REGULAR;
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "target",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "type",
      value: void 0
    }, {
      kind: "method",
      key: "render",
      value:
      /**
       * `true` if the button should be disabled.
       */
      /**
       * The default file name, used if this button is rendered as `<a>`.
       */
      /**
       * Link `href`. If present, this button is rendered as `<a>`.
       */
      /**
       * The language of what `href` points to, if this button is rendered as `<a>`.
       */
      /**
       * Button icon layout.
       */
      /**
       * Button kind.
       */
      /**
       * The a11y role for `<a>`.
       */
      /**
       * URLs to ping, if this button is rendered as `<a>`.
       */
      /**
       * The link type, if this button is rendered as `<a>`.
       */
      /**
       * Button size.
       */
      /**
       * The link target, if this button is rendered as `<a>`.
       */
      /**
       * The default behavior if the button is rendered as `<button>`. MIME type of the `target`if this button is rendered as `<a>`.
       */
      function render() {
        const {
          autofocus,
          disabled,
          download,
          href,
          hreflang,
          linkRole,
          ping,
          rel,
          target,
          type,
          _classes: classes,
          _handleClick: handleClick
        } = this;
        if (href) {
          return disabled ? this._renderDisabledLink() : html(_t3 || (_t3 = _`
            <a
              id="button"
              part="button"
              role="${0}"
              class="${0}"
              download="${0}"
              href="${0}"
              hreflang="${0}"
              ping="${0}"
              rel="${0}"
              target="${0}"
              type="${0}"
              @click="${0}">
              ${0}
            </a>
          `), ifDefined(linkRole), classes, ifDefined(download), ifDefined(href), ifDefined(hreflang), ifDefined(ping), ifDefined(rel), ifDefined(target), ifDefined(type), handleClick, this._renderInner());
        }
        return html(_t4 || (_t4 = _`
      <button
        id="button"
        part="button"
        class="${0}"
        ?autofocus="${0}"
        ?disabled="${0}"
        type="${0}"
        @click="${0}">
        ${0}
      </button>
    `), classes, autofocus, disabled, ifDefined(type), handleClick, this._renderInner());
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--button-expressive`;
      }
    }, {
      kind: "field",
      static: true,
      key: "shadowRootOptions",
      value() {
        return _objectSpread(_objectSpread({}, LitElement.shadowRootOptions), {}, {
          delegatesFocus: true
        });
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, FocusMixin(StableSelectorMixin(LitElement)));
console.warn(`The c4d-button-expressive component has been deprecated in favor of the c4d-button component.
	See migration guide for more information.`);

/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DButtonExpressive;
//# sourceMappingURL=button-expressive.js.map
