import _decorate from "@babel/runtime/helpers/esm/decorate";
/**
 * @license
 *
 * Copyright IBM Corp. 2019, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { property } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././callout-with-media.css.js";
import C4DImage from "../image/image.js";
import { COLOR_SCHEME } from "../../component-mixins/callout/defs.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Callout with media image.
 *
 * @element c4d-callout-with-media-image
 */
let C4DCalloutWithMediaImage = _decorate([customElement(`${c4dPrefix}-callout-with-media-image`)], function (_initialize, _C4DImage) {
  class C4DCalloutWithMediaImage extends _C4DImage {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DCalloutWithMediaImage,
    d: [{
      kind: "field",
      decorators: [property({
        reflect: true,
        attribute: 'color-scheme'
      })],
      key: "colorScheme",
      value() {
        return COLOR_SCHEME.REGULAR;
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "slot",
      value() {
        return 'media';
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, C4DImage);
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DCalloutWithMediaImage;
//# sourceMappingURL=callout-with-media-image.js.map
