import _decorate from "@babel/runtime/helpers/esm/decorate";
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { property } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
import C4DCardLinkCTA from "../cta/card-link-cta.js";
import styles from "././card-group.css.js";
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Card Group Card Link item.
 *
 * @element c4d-card-group-card-link-item
 */
let C4DCardGroupCardLinkItem = _decorate([customElement(`${c4dPrefix}-card-group-card-link-item`)], function (_initialize, _C4DCardLinkCTA) {
  class C4DCardGroupCardLinkItem extends _C4DCardLinkCTA {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DCardGroupCardLinkItem,
    d: [{
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true
      })],
      key: "border",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true
      })],
      key: "empty",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true
      })],
      key: "patternBackground",
      value() {
        return false;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value:
      /**
       * `true` if the card group is using border.
       */

      /**
       * `true` if the card group item is empty.
       */

      /**
       * `true` if the card group item has the same background color as the pattern container.
       */

      function () {
        return `${c4dPrefix}--card-group-card-link-item`;
      }

      /**
       * A selector that will return the child footer.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorFooter",
      value: function () {
        return `${c4dPrefix}-card-cta-footer`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, C4DCardLinkCTA);
console.warn('The card-group-card-link-item component has been deprecated in favor of default card or with content-item. ' + 'See card-group documentation for more information.');
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DCardGroupCardLinkItem;
//# sourceMappingURL=card-group-card-link-item.js.map
