import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2025
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property, state } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import { GRID_MODE } from "./defs.js";
import styles from "././card-group.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
import HostListenerMixin from '@carbon/web-components/es/globals/mixins/host-listener.js';
import MediaQueryMixin, { MQBreakpoints, MQDirs } from "../../component-mixins/media-query/media-query.js";
export { GRID_MODE };
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Card Group.
 *
 * @element c4d-card-group
 */
let C4DCardGroup = _decorate([customElement(`${c4dPrefix}-card-group`)], function (_initialize, _MediaQueryMixin) {
  class C4DCardGroup extends _MediaQueryMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DCardGroup,
    d: [{
      kind: "field",
      key: "_childItems",
      value() {
        return [];
      }
    }, {
      kind: "method",
      key: "_handleSlotChange",
      value:
      /**
       * Array to hold the card-heading elements within child items.
       */

      /**
       * Handler for @slotchange, set the height of all headings to the tallest height.
       *
       * @private
       */
      function _handleSlotChange(event) {
        this._childItems = event.target.assignedNodes().filter(elem => {
          var _matches, _ref;
          return (_matches = (_ref = elem).matches) === null || _matches === void 0 ? void 0 : _matches.call(_ref, this.constructor.selectorItem);
        });

        // Retrieve item heading, eyebrows, and footers to set same height.
        if (this._childItems) {
          this._childItems.forEach(e => {
            if (!e.hasAttribute('href') && this.gridMode === GRID_MODE.CONDENSED) {
              this.gridMode = GRID_MODE.DEFAULT;
            }
          });
          const {
            customPropertyCardsPerRow
          } = this.constructor;
          this.style.setProperty(customPropertyCardsPerRow, String(this.cardsPerRow));
        }
      }

      /**
       * The number of columns per row. Min 2, max 4, default 3. Applies to >=`lg` breakpoint only.
       */
    }, {
      kind: "field",
      decorators: [state()],
      key: "_cardsPerRow",
      value: void 0
    }, {
      kind: "field",
      decorators: [state()],
      key: "_cardsPerRowAuto",
      value() {
        return 3;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_isMediumOrGreater",
      value() {
        return this.carbonBreakpoints.md.matches;
      }
    }, {
      kind: "method",
      key: "mediaQueryCallbackMD",
      value:
      /**
       * Default number of cards per row. Applies to >=`lg` breakpoint only.
       */
      function mediaQueryCallbackMD() {
        this._isMediumOrGreater = this.carbonBreakpoints.md.matches;
      }

      /**
       * Number of cards per column.
       * If `--c4d--card-group--cards-in-row` CSS custom property is set to `<c4d-card-group>`.
       */
    }, {
      kind: "get",
      decorators: [property({
        type: Number,
        attribute: 'cards-per-row'
      })],
      key: "cardsPerRow",
      value: function () {
        const {
          _cardsPerRow: cardsPerRow,
          _cardsPerRowAuto: cardsPerRowAuto
        } = this;
        return cardsPerRow !== null && cardsPerRow !== void 0 ? cardsPerRow : cardsPerRowAuto;
      }
    }, {
      kind: "set",
      key: "cardsPerRow",
      value: function (value) {
        this._cardsPerRow = value;
        // Don't call `.requestUpdate()` here given we track updates via `_cardsPerRow` and `_cardsPerRowAuto`
      }

      /**
       * The Grid Mode for the component layout.
       * Condensed (1px) | Narrow (16px) | Default(32px).
       */
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'grid-mode',
        reflect: true
      })],
      key: "gridMode",
      value() {
        return GRID_MODE.DEFAULT;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true
      })],
      key: "pictograms",
      value() {
        return false;
      }
    }, {
      kind: "method",
      key: "isInsideBlockCards",
      value:
      /**
       * If using cards with pictogram.
       */
      // necessary to avoid using sameHeight utility
      // Adding a class that will identify that c4d-card-group is inside c4d-content-block-cards for special treatment.
      function isInsideBlockCards() {
        const cardGroupParentEl = this.parentElement;
        console.log(cardGroupParentEl);
        if ((cardGroupParentEl === null || cardGroupParentEl === void 0 ? void 0 : cardGroupParentEl.tagName.toLowerCase()) === `${c4dPrefix}-content-block-cards`) {
          this.classList.add('inside-block-cards');
        }
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        var _this$previousElement, _this$previousElement2;
        _superPropGet(C4DCardGroup, "connectedCallback", this, 3)([]);
        if ((_this$previousElement = this.previousElementSibling) !== null && _this$previousElement !== void 0 && (_this$previousElement2 = _this$previousElement.matches) !== null && _this$previousElement2 !== void 0 && _this$previousElement2.call(_this$previousElement, this.constructor.selectorCardInCard)) {
          this.setAttribute('with-card-in-card', '');
        }

        // Check if the component is living in a Full Width or Table of Contents template.
        const isFullWidthTemplate = document.body.getAttribute('data-fullwidthtemplate') === 'true';
        //Adds a class if true, for better css treatment in mobile for FW pages.
        this.classList.toggle('is-full-width-template', isFullWidthTemplate);
        this.isInsideBlockCards();
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated(changedProperties) {
        _superPropGet(C4DCardGroup, "updated", this, 3)([changedProperties]);
        if (changedProperties.has('gridMode')) {
          this._childItems.forEach(e => e.gridMode = this.gridMode);
        }

        //Setting grid mode to condensed in mobile in favor of scroll snap behavior
        if (!this._isMediumOrGreater) {
          this.gridMode = GRID_MODE.CONDENSED;
        }
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t || (_t = _` <slot @slotchange="${0}"></slot> `), this._handleSlotChange);
      }

      /**
       * The CSS custom property name for the live button group item cout.
       */
    }, {
      kind: "get",
      static: true,
      key: "customPropertyCardsPerRow",
      value: function () {
        return `--${c4dPrefix}--card-group--cards-in-row`;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--card-group`;
      }

      /**
       * A selector that will return the card-in-card selector
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorCardInCard",
      value: function () {
        return `${c4dPrefix}-card-in-card`;
      }

      /**
       * A selector that will return the card item.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItem",
      value: function () {
        return `${c4dPrefix}-card-group-item`;
      }

      /**
       * A selector that will return the card item's eyebrow
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItemEyebrow",
      value: function () {
        return `${c4dPrefix}-card-eyebrow`;
      }

      /**
       * A selector that will return the card item's tag group
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItemTagGroup",
      value: function () {
        return `div`;
      }

      /**
       * A selector that will return the card item's tag group
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItemParagraph",
      value: function () {
        return `p`;
      }

      /**
       * A selector that will return the card item's heading
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItemHeading",
      value: function () {
        return `${c4dPrefix}-card-heading`;
      }

      /**
       * A selector that will return the card item's footer
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItemFooter",
      value: function () {
        return `${c4dPrefix}-card-cta-footer`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, MediaQueryMixin(HostListenerMixin(StableSelectorMixin(LitElement)), {
  [MQBreakpoints.MD]: MQDirs.MIN
}));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DCardGroup;
//# sourceMappingURL=card-group.js.map
