/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import C4DLinkWithIcon from '../link-with-icon/link-with-icon';
/**
 * Card footer.
 *
 * @element c4d-card-footer
 * @csspart copy - The Copy. Usage: `c4d-card-footer::part(copy)`
 */
declare class C4DCardFooter extends C4DLinkWithIcon {
    /**
     * The non-link container node, used when the link of parent `<c4d-card>` should be used.
     */
    private _staticNode?;
    /**
     * `true` if there is copy content.
     */
    protected _hasCopy: boolean;
    /**
     * `true` if the link of parent `<c4d-card>` should be used.
     */
    protected get _shouldUseParentLink(): boolean;
    /**
     * Handles `slotchange` event on the default `<slot>`.
     */
    protected _handleSlotChange({ target }: Event): void;
    /**
     * @returns The main content.
     */
    _renderContent(): import("lit-html").TemplateResult<1>;
    _renderInner(): import("lit-html").TemplateResult<1>;
    /**
     * Alternative aria label if no text in footer.
     */
    altAriaLabel?: string | null;
    /**
     * The color scheme.
     */
    colorScheme: string;
    /**
     * The `href` in parent `<c4d-card>`.
     * `<c4d-card>` sets this automatically.
     */
    parentHref?: string;
    /**
     * Positions the icon inline with text when `true`
     */
    iconInline: boolean;
    /**
     * The slot in parent `<c4d-card>`.
     */
    slot: string;
    updated(changedProperties: any): void;
    static get stableSelector(): string;
    static styles: any;
}
export default C4DCardFooter;

//# sourceMappingURL=card-footer.d.ts.map
