import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4,
  _t5,
  _t6,
  _t7,
  _t8,
  _t9,
  _t10,
  _t11,
  _t12;
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2019, 2025
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html, LitElement } from 'lit';
import { property, query, state } from 'lit/decorators.js';
import { ifDefined } from 'lit/directives/if-defined.js';
import ArrowRight20 from '@carbon/web-components/es/icons/arrow--right/20.js';
import ArrowLeft20 from '@carbon/web-components/es/icons/arrow--left/20.js';
import CDSLink from '@carbon/web-components/es/components/link/link.js';
import markdownToHtml from '@carbon/ibmdotcom-utilities/es/utilities/markdownToHtml/markdownToHtml.js';
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import { BASIC_COLOR_SCHEME } from "../../globals/defs.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././card.css.js";
import { PICTOGRAM_PLACEMENT } from "./defs.js";
import { CTA_TYPE } from "../cta/defs.js";
import CTAMixin from "../../component-mixins/cta/cta.js";
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * The table mapping slot name with the private property name that indicates the
 * existence of the slot content.
 */
const slotExistencePropertyNames = {
  image: '_hasImage',
  pictogram: '_hasPictogram',
  eyebrow: '_hasEyebrow'
};

/**
 * Card.
 *
 * @element c4d-card
 * @slot eyebrow - The eyebrow content.
 * @slot heading - The heading content.
 * @slot image - The image content.
 * @slot footer - The footer content.
 * @csspart caption - The Caption (default heading). Usage: `c4d-card::part(caption)`
 * @csspart copy - The Copy. Usage: `c4d-card::part(copy)`
 * @csspart container - The Inner content container. Usage: `c4d-card::part(container)`
 * @csspart video-thumbnail - The video thumbnail. Usage: `c4d-card::part(video-thumbnail)`
 * @csspart disabled-link - . Disabled link. Usage: `c4d-card::part(disabled-link)`
 * @csspart wrapper - The component wrapper. Usage: `c4d-card::part(wrapper)`
 * @csspart content - The content container. Usage: `c4d-card::part(content)`
 * @csspart link - Active link. Usage: `c4d-card::part(link)`
 */
let C4DCard = _decorate([customElement(`${c4dPrefix}-card`)], function (_initialize, _CTAMixin) {
  class C4DCard extends _CTAMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DCard,
    d: [{
      kind: "field",
      decorators: [property({
        attribute: 'cta-type'
      })],
      key: "ctaType",
      value: void 0
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasImage",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasCopy",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasPictogram",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasEyebrow",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'no-poster',
        type: Boolean
      })],
      key: "noPoster",
      value: void 0
    }, {
      kind: "method",
      key: "_handleSlotChange",
      value:
      /**
       * `true` if there is copy content.
       */

      /**
       * `true` if there is image content.
       */

      /**
       * `true` if there is copy content.
       */

      /**
       * `true` if there is a pictogram.
       */

      /**
       * `true` if there is eyebrow content.
       */

      /**
       * Handles `slotchange` event for slots other than the copy slot.
       */
      function _handleSlotChange({
        target
      }) {
        const {
          name
        } = target;
        this[slotExistencePropertyNames[name]] = target.assignedNodes().some(node => node.nodeType !== Node.TEXT_NODE || node.textContent.trim());
      }

      /**
       * Handles `slotchange` event for the copy slot.
       */
    }, {
      kind: "method",
      key: "_handleCopySlotChange",
      value: function _handleCopySlotChange({
        target
      }) {
        this._hasCopy = target.assignedNodes().some(node => node.nodeType !== Node.TEXT_NODE || node.textContent.trim());
      }

      /**
       * @returns The heading content.
       */
      // eslint-disable-next-line class-methods-use-this
    }, {
      kind: "method",
      key: "_renderHeading",
      value: function _renderHeading() {
        const {
          ctaType,
          videoName,
          formatVideoCaption: formatVideoCaptionInEffect
        } = this;
        if (ctaType !== CTA_TYPE.VIDEO) {
          return html(_t || (_t = _`<div part="heading-wrapper">
        <slot name="heading"></slot>
      </div>`));
        }
        const formattedVideoName = formatVideoCaptionInEffect({
          name: videoName
        });
        this.dispatchEvent(new CustomEvent(this.constructor.eventVideoTitleUpdated, {
          bubbles: true,
          composed: true
        }));
        return html(_t2 || (_t2 = _`
      <div part="heading-wrapper">
        <slot name="heading">
          <c4d-card-heading>${0}</c4d-card-heading>
        </slot>
      </div>
    `), formattedVideoName);
      }

      /**
       * @returns The copy content.
       */
    }, {
      kind: "method",
      key: "_renderCopy",
      value: function _renderCopy() {
        const {
          _hasCopy: hasCopy
        } = this;
        return html(_t3 || (_t3 = _`
      <div ?hidden="${0}" class="${0}--card__copy" part="copy">
        <slot @slotchange="${0}"></slot>
      </div>
    `), !hasCopy, prefix, this._handleCopySlotChange);
      }
    }, {
      kind: "method",
      key: "_renderImage",
      value: function _renderImage() {
        const {
          ctaType,
          videoName,
          videoThumbnailUrl,
          _hasImage: hasImage,
          noPoster
        } = this;
        const image = hasImage || ctaType !== CTA_TYPE.VIDEO || noPoster ? undefined : html(_t4 || (_t4 = _`
            <c4d-image
              class="${0}--card__video-thumbnail"
              part="video-thumbnail"
              alt="${0}"
              default-src="${0}">
            </c4d-image>
          `), prefix, videoName, videoThumbnailUrl);
        return html(_t5 || (_t5 = _`
      <div part="image-wrapper" class="${0}--card__image-wrapper">
        <slot name="image" @slotchange="${0}">
          ${0}
        </slot>
      </div>
    `), prefix, this._handleSlotChange, image);
      }

      /**
       * @returns The disabled link content.
       */
    }, {
      kind: "method",
      key: "_renderDisabledLink",
      value: function _renderDisabledLink() {
        const {
          _classes: classes
        } = this;
        return html(_t6 || (_t6 = _`
      <div id="link" class="${0}" part="disabled-link">
        ${0}
      </div>
    `), classes, this._renderInner());
      }
    }, {
      kind: "method",
      key: "_renderPictogramSlot",
      value: function _renderPictogramSlot(placement) {
        const {
          _handleSlotChange: handleSlotChange,
          _hasPictogram: hasPictogram
        } = this;
        return html(_t7 || (_t7 = _`
      <div
        part="pictogram-wrapper"
        class="${0}--card__pictogram-wrapper ${0}">
        <slot
          name="pictogram"
          data-pictogram-placement="${0}"
          @slotchange="${0}"></slot>
      </div>
    `), prefix, !hasPictogram ? `${prefix}--card__pictogram-wrapper--empty` : '', placement, handleSlotChange);
      }
    }, {
      kind: "method",
      key: "_renderEyebrowSlot",
      value: function _renderEyebrowSlot() {
        const {
          _hasEyebrow: hasEyebrow
        } = this;
        return html(_t8 || (_t8 = _`<div
      part="eyebrow-wrapper"
      class="${0}--card__eyebrow-wrapper ${0}">
      <slot name="eyebrow" @slotchange="${0}"></slot>
    </div>`), prefix, !hasEyebrow ? `${prefix}--card__eyebrow-wrapper--empty` : '', this._handleSlotChange);
      }

      /**
       * @returns The inner content.
       */
    }, {
      kind: "method",
      key: "_renderInner",
      value: function _renderInner() {
        const {
          _hasPictogram: hasPictogram,
          _hasCopy: hasCopy
        } = this;
        return html(_t9 || (_t9 = _`
      ${0}
      <div
        class="${0}--card__wrapper ${0} ${0}"
        part="wrapper">
        <div class="${0}--card__content" part="content">
          ${0}
          ${0}
          ${0}
          ${0}
          ${0}
          ${0}
          ${0}
          <div part="footer-wrapper" class="${0}--card__footer-wrapper">
            <slot name="footer"></slot>
          </div>
        </div>
      </div>
    `), this._renderImage(), prefix, hasPictogram ? `${prefix}--card__pictogram` : '', hasPictogram && hasCopy ? `${prefix}--card__motion` : '', prefix, this._renderEyebrowSlot(), this.pictogramPlacement === PICTOGRAM_PLACEMENT.TOP ? this._renderPictogramSlot(PICTOGRAM_PLACEMENT.TOP) : '', this.pictogramPlacement !== PICTOGRAM_PLACEMENT.TOP || !hasPictogram ? this._renderHeading() : null, this.pictogramPlacement === PICTOGRAM_PLACEMENT.BOTTOM || !hasPictogram ? this._renderCopy() : '', this.pictogramPlacement === PICTOGRAM_PLACEMENT.BOTTOM ? this._renderPictogramSlot(PICTOGRAM_PLACEMENT.BOTTOM) : '', hasPictogram && this.pictogramPlacement === PICTOGRAM_PLACEMENT.TOP ? this._renderHeading() : null, hasPictogram && this.pictogramPlacement === PICTOGRAM_PLACEMENT.TOP ? this._renderCopy() : '', prefix);
      }

      /**
       * @returns The CTA arrow.
       *
       */
    }, {
      kind: "method",
      key: "_renderArrow",
      value: function _renderArrow() {
        var _this$querySelector;
        const isLTR = window.getComputedStyle(this).direction.toUpperCase() === 'LTR';
        return html(_t10 || (_t10 = _`
      <a
        class="${0}"
        part="link"
        href="${0}"
        aria-label="${0}"
        >${0}</a
      >
    `), `${prefix}--card__link`, ifDefined(this.href), ((_this$querySelector = this.querySelector(`${c4dPrefix}-card-heading`)) === null || _this$querySelector === void 0 ? void 0 : _this$querySelector.textContent) || '', isLTR ? ArrowRight20() : ArrowLeft20());
      }
      /**
       * The color scheme.
       * A typical use case of using another color scheme of card is having a "CTA" purpose of card at the last in card group.
       *
       * Color scheme options are: "inverse" and "regular"
       */
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'color-scheme',
        reflect: true
      })],
      key: "colorScheme",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "href",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'pictogram-placement',
        reflect: true
      })],
      key: "pictogramPlacement",
      value() {
        return PICTOGRAM_PLACEMENT.BOTTOM;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true
      })],
      key: "link",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true
      })],
      key: "logo",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [query('div')],
      key: "_linkNode",
      value: void 0
    }, {
      kind: "method",
      key: "updated",
      value:
      /**
       * Link `href`.
       */
      /**
       * Pictogram placement
       */
      /**
       * Whether or not to apply the link style.
       */
      /**
       * Whether or not to apply the logo style.
       */
      function updated(changedProperties) {
        _superPropGet(C4DCard, "updated", this, 3)([changedProperties]);
        const {
          colorScheme,
          disabled,
          href,
          _linkNode: linkNode,
          ctaType
        } = this;
        if (changedProperties.has('ctaType') || changedProperties.has('disabled') || changedProperties.has('formatCaption') || changedProperties.has('formatDuration') || changedProperties.has('videoDuration') || changedProperties.has('videoName')) {
          var _this$querySelector2;
          const {
            ctaType: _ctaType,
            videoDuration,
            videoName,
            videoDescription,
            formatVideoCaption: formatVideoCaptionInEffect,
            formatVideoDuration: formatVideoDurationInEffect
          } = this;
          const footer = this.querySelector(this.constructor.selectorFooter);
          const headingText = (_this$querySelector2 = this.querySelector(`${c4dPrefix}-card-heading`)) === null || _this$querySelector2 === void 0 ? void 0 : _this$querySelector2.textContent;
          const copyText = this.textContent;
          if (footer) {
            const ariaTitle = videoName || headingText || copyText;
            let ariaDuration = '';
            if (videoDuration !== undefined) {
              ariaDuration = `, DURATION ${videoDuration}`;
            }
            footer.disabled = disabled;
            footer.altAriaLabel = `${ariaTitle}${ariaDuration}`;
            footer.ctaType = _ctaType;
            footer.videoDuration = videoDuration;
            footer.videoName = videoName;
            footer.videoDescription = videoDescription;
            if (formatVideoCaptionInEffect) {
              footer.formatVideoCaption = formatVideoCaptionInEffect;
            }
            if (formatVideoDurationInEffect) {
              footer.formatVideoDuration = formatVideoDurationInEffect;
            }
          }
        }
        if (changedProperties.has('colorScheme') || changedProperties.has('href')) {
          var _this$querySelector3;
          const headingText = (_this$querySelector3 = this.querySelector(`${c4dPrefix}-card-heading`)) === null || _this$querySelector3 === void 0 ? void 0 : _this$querySelector3.textContent;
          const copyText = this.textContent;
          const footer = this.querySelector(this.constructor.selectorFooter);
          if (footer && href) {
            footer.colorScheme = colorScheme;
            footer.parentHref = href;
            footer.ctaType = ctaType;
            footer.href = href;
            footer.altAriaLabel = headingText || copyText;
          }
        }
        if (linkNode) {
          linkNode.classList.add(`${prefix}--tile`);
          linkNode.classList.add(`${prefix}--card`);
          linkNode.classList.toggle(`${prefix}--tile--clickable`, Boolean(href));
          linkNode.classList.toggle(`${prefix}--card--link`, Boolean(href));
          linkNode.classList.toggle(`${prefix}--card--inverse`, colorScheme === BASIC_COLOR_SCHEME.INVERSE);
          linkNode.classList.toggle(`${prefix}--link--disabled`, Boolean(this.disabled));
        }
        if (this._hasPictogram) {
          this.setAttribute('pictogram', '');
        } else {
          this.removeAttribute('pictogram');
        }
        const copyElement = this.querySelector('p');
        if (this._hasCopy && copyElement !== null && copyElement !== void 0 && copyElement.innerText) {
          var _copyElement$firstEle;
          copyElement.innerHTML = `${markdownToHtml(copyElement === null || copyElement === void 0 ? void 0 : copyElement.innerText, {
            bold: false
          })}`;
          (_copyElement$firstEle = copyElement.firstElementChild) === null || _copyElement$firstEle === void 0 || _copyElement$firstEle.setAttribute('style', 'all:unset;');
        }
      }

      /**
       * Handles card with video heading and applies the set same height function.
       *
       * @param event The event.
       */
      // @ts-ignore: The decorator refers to this method but TS thinks this method is not referred to
    }, {
      kind: "field",
      key: "_handleVideoTitleUpdate",
      value() {
        return async event => {
          const {
            videoId
          } = event.detail || {};
          if (event && this.ctaType === CTA_TYPE.VIDEO && this.href === videoId) {
            var _heading$textContent, _footer$textContent;
            const {
              videoDuration,
              videoName
            } = event.detail;
            const {
              formatVideoDuration,
              formatVideoCaption
            } = this;
            const formattedVideoDuration = formatVideoDuration({
              duration: !videoDuration ? videoDuration : videoDuration * 1000
            });
            this.videoDuration ? null : this.videoDuration = formattedVideoDuration;
            this.videoTitle = formatVideoCaption({
              name: videoName
            });
            const heading = this.querySelector(`${c4dPrefix}-card-heading`);
            const footer = this.querySelector(`${c4dPrefix}-card-footer`);
            if ((heading === null || heading === void 0 || (_heading$textContent = heading.textContent) === null || _heading$textContent === void 0 ? void 0 : _heading$textContent.trim()) === '') {
              const title = document.createTextNode(this.videoTitle);
              heading === null || heading === void 0 || heading.appendChild(title);
            }
            if ((footer === null || footer === void 0 || (_footer$textContent = footer.textContent) === null || _footer$textContent === void 0 ? void 0 : _footer$textContent.trim()) === '') {
              const title = document.createTextNode(formattedVideoDuration);
              footer === null || footer === void 0 || footer.appendChild(title);
            }
          }
        };
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value: function connectedCallback() {
        _superPropGet(C4DCard, "connectedCallback", this, 3)([]);
        const {
          eventRequestAdditionalVideoData
        } = this.constructor;
        document.addEventListener(eventRequestAdditionalVideoData, this._handleVideoTitleUpdate);
      }
    }, {
      kind: "method",
      key: "disconnectedCallback",
      value: function disconnectedCallback() {
        _superPropGet(C4DCard, "disconnectedCallback", this, 3)([]);
        const {
          eventRequestAdditionalVideoData
        } = this.constructor;
        document.removeEventListener(eventRequestAdditionalVideoData, this._handleVideoTitleUpdate);
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return this._hasPictogram ? html(_t11 || (_t11 = _`
          <div part="container">
            ${0} ${0}
          </div>
        `), this._renderInner(), this._renderArrow()) : html(_t12 || (_t12 = _` <div part="container">${0}</div> `), this._renderInner());
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--card`;
      }

      /**
       * A selector that will return the child footer.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorFooter",
      value: function () {
        return `${c4dPrefix}-card-footer`;
      }

      /**
       * The name of the custom event fired when there is a user gesture to run the action.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventRequestAdditionalVideoData",
      value: function () {
        return `${c4dPrefix}-cta-request-additional-video-data`;
      }

      /**
       * The name of the custom event fired when the video title is updated
       */
    }, {
      kind: "get",
      static: true,
      key: "eventVideoTitleUpdated",
      value: function () {
        return `${c4dPrefix}-card-video-title-updated`;
      }
    }, {
      kind: "field",
      static: true,
      key: "shadowRootOptions",
      value() {
        return _objectSpread(_objectSpread({}, LitElement.shadowRootOptions), {}, {
          delegatesFocus: true
        });
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, CTAMixin(StableSelectorMixin(CDSLink)));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DCard;
//# sourceMappingURL=card.js.map
