import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { LitElement, html } from 'lit';
import { customElement, property, query, state } from 'lit/decorators.js';
import { slow01 } from '@carbon/motion';
import { classMap } from 'lit/directives/class-map.js';
import CaretLeft20 from '@carbon/web-components/es/icons/caret--left/20.js';
import CaretRight20 from '@carbon/web-components/es/icons/caret--right/20.js';
import HostListener from '@carbon/web-components/es/globals/decorators/host-listener.js';
import HostListenerMixin from '@carbon/web-components/es/globals/mixins/host-listener.js';
import { selectorTabbable } from '@carbon/web-components/es/globals/settings.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import sameHeight from '@carbon/ibmdotcom-utilities/es/utilities/sameHeight/sameHeight.js';
import styles from "././carousel.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { ifDefined } from 'lit/directives/if-defined.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;
const MAX_GESTURE_DURATION = 600; // max time allowed to do swipe
const MIN_DISTANCE_TRAVELLED = 25; // min distance traveled to be considered swipe
const headingBottomMargin = 64; // tag constants used for same height calculations

/**
 * Minimum percentage of a slide being visible for it to be interactable.
 */
const minIntersectionRatio = 0.75;

/**
 * Carousel.
 *
 * @element c4d-carousel
 * @csspart prev-button - The button to go to the previous page. Usage: `c4d-carousel::part(prev-button)`
 * @csspart next-button - The button to go to the next page. Usage: `c4d-carousel::part(next-button)`
 * @csspart region - The component container. Usage: `c4d-carousel::part(region)`
 * @csspart title - The title. Usage `c4d-carousel::part(title)`
 * @csspart scroll-container - Container for the scrolling elements. Usage: `c4d-carousel::part(scroll-container)`
 * @csspart contents - The scrolling elements. Usage: `c4d-carousel::part(contents)`
 * @csspart navigation - The navigation controls. Usage: `c4d-carousel::part(navigation)`
 * @csspart status - The navigation status. Usage: `c4d-carousel::part(status)`
 * @csspart visually-hidden - The span element used to hide content from view and keep it accessible for assistive technologies. Usage: `c4d-button::part(visually-hidden)`
 */
let C4DCarousel = _decorate([customElement(`${c4dPrefix}-carousel`)], function (_initialize, _HostListenerMixin) {
  class C4DCarousel extends _HostListenerMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DCarousel,
    d: [{
      kind: "field",
      decorators: [query(`.${prefix}--carousel__scroll-container`)],
      key: "_containerNode",
      value: void 0
    }, {
      kind: "field",
      decorators: [query(`.${prefix}--carousel__scroll-contents`)],
      key: "_contentsNode",
      value: void 0
    }, {
      kind: "field",
      decorators: [query('[aria-live]')],
      key: "_announcementNode",
      value: void 0
    }, {
      kind: "field",
      decorators: [state()],
      key: "_contentsBaseWidth",
      value() {
        return 0;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_gap",
      value() {
        return 0;
      }
    }, {
      kind: "field",
      key: "_childItems",
      value() {
        return [];
      }
    }, {
      kind: "field",
      key: "_childItemHeadings",
      value() {
        return [];
      }
    }, {
      kind: "field",
      key: "_childItemEyebrows",
      value() {
        return [];
      }
    }, {
      kind: "field",
      key: "_childItemTagGroup",
      value() {
        return [];
      }
    }, {
      kind: "field",
      key: "_childItemParagraphs",
      value() {
        return [];
      }
    }, {
      kind: "field",
      key: "_childItemFooters",
      value() {
        return [];
      }
    }, {
      kind: "field",
      key: "_observerResizeContainer",
      value() {
        return null;
      }
    }, {
      kind: "field",
      key: "_observerResizeRoot",
      value() {
        return null;
      }
    }, {
      kind: "field",
      key: "_intersectionThresholdDifference",
      value() {
        return Math.max(0.5, minIntersectionRatio) - Math.min(0.5, minIntersectionRatio);
      }
    }, {
      kind: "field",
      key: "_intersectionObserver",
      value() {
        return null;
      }
    }, {
      kind: "method",
      key: "_onIntersect",
      value:
      /**
       * The scrolling container node.
       */

      /**
       * The scrolling contents node.
       */

      /**
       * The node whose text content is announced to screen readers on change.
       */

      /**
       * The width of the scroll contents area node, excluding one of overflowed contents.
       */

      /**
       * The gap width between each card.
       */

      /**
       * Array to hold the card-heading elements within child items.
       */

      /**
       * Array to hold the card-heading elements within child items.
       */

      /**
       * Array to hold the card-eyebrow elements within child items.
       */

      /**
       * Array to hold the tag-group elements within child items.
       */

      /**
       * Array to hold the paragraph elements within child items.
       */

      /**
       * Array to hold the card-cta-footer elements within child items.
       */

      /**
       * The observer for the resize of the scroll container.
       */
      // TODO: Wait for `.d.ts` update to support `ResizeObserver`

      /**
       * The observer for the resize of the viewport.
       */
      // TODO: Wait for `.d.ts` update to support `ResizeObserver`

      /**
       *  IntersectionObserver to watch carousel contents.
       *
       *  @see connectedCallback()
       */

      /**
       * IntersectionObserver callback.
       * Carousel items with more than `minIntersectionRatio` visible will interactable.
       *
       * @param {IntersectionObserverEntry[]} entries Array of observed intersections.
       */
      function _onIntersect(entries) {
        const {
          _announcementNode: announcementNode,
          formatAnnouncement,
          _getStatus: status,
          _intersectionTimeout: timeout
        } = this;

        // Mark off-screen slides as [inert]
        entries.forEach(entry => {
          const {
            target,
            isIntersecting,
            intersectionRatio
          } = entry;
          if (isIntersecting && intersectionRatio > minIntersectionRatio) {
            target.inert = false;
            target.setAttribute('aria-hidden', false);
          } else {
            target.inert = true;
            target.setAttribute('aria-hidden', true);
          }
        });

        // Wait for slide action to finish, then announce slide information
        clearTimeout(timeout);

        // Delay should equal the design token in the carousel's styles.
        const delay = parseInt(slow01, 10);
        this._intersectionTimeout = setTimeout(() => {
          announcementNode.innerText = formatAnnouncement(status);
        }, delay);
      }

      /**
       * The page size that is explicitly set.
       */
    }, {
      kind: "field",
      decorators: [state()],
      key: "_pageSize",
      value: void 0
    }, {
      kind: "field",
      decorators: [state()],
      key: "_pageSizeAuto",
      value() {
        return 1;
      }
    }, {
      kind: "field",
      decorators: [query('slot:not([name])')],
      key: "_slotNode",
      value: void 0
    }, {
      kind: "field",
      decorators: [state()],
      key: "_total",
      value() {
        return 0;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_startPos",
      value() {
        return 0;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_startTime",
      value() {
        return 0;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_isScrolling",
      value() {
        return false;
      }
    }, {
      kind: "method",
      key: "_cleanAndCreateObserverResize",
      value:
      /**
       * The page size that is automatically calculated upon viewport size
       * via `--c4d--carousel--page-size` CSS custom property.
       * If `page-size` attribute is set, this value is ignored.
       */
      /**
       * The default slot.
       */
      /**
       * The number of total items.
       */
      /**
       * Initial touch position (used to detect swipe gesture)
       */
      /**
       * Initial touch time (used to detect swipe gesture)
       */
      /**
       * Whether the carousel is scrolling
       */
      /**
       * Cleans-up and creates the resize observer for the scrolling container.
       *
       * @param [options] The options.
       * @param [options.create] `true` to create the new resize observer.
       */
      function _cleanAndCreateObserverResize({
        create
      } = {}) {
        const {
          _contentsNode: contentsNode
        } = this;
        if (contentsNode) {
          if (this._observerResizeContainer) {
            this._observerResizeContainer.disconnect();
            this._observerResizeContainer = null;
          }
          if (this._observerResizeRoot) {
            this._observerResizeRoot.disconnect();
            this._observerResizeRoot = null;
          }
          if (create) {
            // TODO: Wait for `.d.ts` update to support `ResizeObserver`
            // @ts-ignore
            this._observerResizeRoot = new ResizeObserver(this._observeResizeRoot);
            this._observerResizeRoot.observe(this.ownerDocument.documentElement);
            // TODO: Wait for `.d.ts` update to support `ResizeObserver`
            // @ts-ignore
            this._observerResizeContainer = new ResizeObserver(this._observeResizeContainer);
            this._observerResizeContainer.observe(contentsNode);
          }
        }
      }

      /**
       * Cleans-up and creates the intersection observer for the scrolling container.
       *
       * @param [options] The options.
       * @param [options.create] `true` to create the new intersection observer.
       */
    }, {
      kind: "method",
      key: "_cleanAndCreateObserverIntersection",
      value: function _cleanAndCreateObserverIntersection({
        create
      } = {}) {
        const {
          _containerNode: containerNode
        } = this;
        // Avoid creating the intersection observer prematurely by checking that
        // this._containerNode has been set.
        if (containerNode) {
          if (this._intersectionObserver) {
            this._intersectionObserver.disconnect();
            this._intersectionObserver = null;
          }
          if (create) {
            // As items cross the minIntersectionRatio `inert` and `aria-hidden` are
            // toggled.
            this._intersectionObserver = new IntersectionObserver(this._onIntersect.bind(this), {
              root: containerNode,
              threshold: [0.5 + this._intersectionThresholdDifference, 0.5 - this._intersectionThresholdDifference]
            });
          }
        }
      }

      /**
       * Stops the container from scrolling when focusing on a card outside the viewport.
       *
       * @param event The event.
       * @param event.target The event target.
       */
      // eslint-disable-next-line class-methods-use-this
    }, {
      kind: "method",
      key: "_handleScrollFocus",
      value: function _handleScrollFocus({
        target
      }) {
        target.scrollTo(0, 0);
      }

      /**
       * Handles card focus throughout pages.
       *
       * @param event The event.
       * @param event.target The event target.
       */
    }, {
      kind: "field",
      decorators: [HostListener('shadowRoot:focusin')],
      key: "_handleFocus",
      value() {
        return async ({
          target
        }) => {
          const containsCurrent = target !== this && this.contains(target);
          let currentItemIndex = 0;
          Array.from(this._childItems).forEach((carouselItem, index) => {
            if (carouselItem.contains(target)) {
              currentItemIndex = index;
            }
          });

          // Calculates proper page to display if focus is outside the current page
          if (containsCurrent && (currentItemIndex < this.start || currentItemIndex >= this.start + this.pageSize)) {
            // The `currentIndex` floored by `pageSize`
            const nextStart = Math.floor(currentItemIndex / this.pageSize) * this.pageSize;
            const pageOffset = this.start % this.pageSize;

            // Ensures the page moves by `this.pageSize` in either direction
            this.start = nextStart + pageOffset;
          }
        };
      }
    }, {
      kind: "field",
      decorators: [HostListener(`document:eventVideoTitleUpdated`)],
      key: "_handleVideoTitleUpdate",
      value() {
        return async event => {
          if (event) {
            this._setSameHeight();
          }
        };
      }
    }, {
      kind: "method",
      key: "_handleClickNextButton",
      value:
      /**
       * Handles card with video heading and applies the set same height function.
       *
       * @param event The event.
       */
      /**
       * Handles `click` event on the next button.
       */
      function _handleClickNextButton() {
        const {
          pageSize,
          start,
          _total: total
        } = this;
        this.start = Math.min(start + pageSize, total - 1);
        this._handleIsScrolling();
      }

      /**
       * Handles `click` event on the prev button.
       */
    }, {
      kind: "method",
      key: "_handleClickPrevButton",
      value: function _handleClickPrevButton() {
        const {
          pageSize,
          start
        } = this;
        this.start = Math.max(start - pageSize, 0);
        this._handleIsScrolling();
      }

      /**
       * Sets scrolling state of carousel
       */
    }, {
      kind: "method",
      key: "_handleIsScrolling",
      value: function _handleIsScrolling() {
        var _this$_contentsNode;
        this._isScrolling = true;
        (_this$_contentsNode = this._contentsNode) === null || _this$_contentsNode === void 0 || _this$_contentsNode.addEventListener('transitionend', () => {
          this._isScrolling = false;
        });
      }

      /**
       * Handles `touchstart` event.
       */
    }, {
      kind: "method",
      key: "_handleTouchStartEvent",
      value: function _handleTouchStartEvent(event) {
        this._startPos = event.touches[0].clientX;
        this._startTime = new Date().getTime();
      }

      /**
       * Handles `touchend` event.
       */
    }, {
      kind: "method",
      key: "_handleTouchEndEvent",
      value: function _handleTouchEndEvent(event) {
        const {
          _startPos,
          _startTime
        } = this;
        const {
          pageSize,
          start,
          _total: total
        } = this;
        const distTravelled = event.changedTouches[0].clientX - _startPos; // distance travelled
        const elapsedTime = new Date().getTime() - _startTime; // elapsed time

        if (elapsedTime <= MAX_GESTURE_DURATION && Math.abs(distTravelled) >= MIN_DISTANCE_TRAVELLED) {
          if (distTravelled < 0) {
            this.start = Math.min(start + pageSize, total - 1);
          } else {
            this.start = Math.max(start - pageSize, 0);
          }
          this._handleIsScrolling();
        }
      }

      /**
       * Handles `slotchange` event.
       */
    }, {
      kind: "method",
      key: "_handleSlotChange",
      value: function _handleSlotChange(event) {
        var _this$_intersectionOb;
        const slot = event.target;
        const {
          name
        } = slot;
        if (!name) {
          this._total = slot.assignedNodes().filter(node => node.nodeType === Node.ELEMENT_NODE).length;
        }
        this._updateGap();
        this._childItems = event.target.assignedElements();
        (_this$_intersectionOb = this._intersectionObserver) === null || _this$_intersectionOb === void 0 || _this$_intersectionOb.disconnect();
        this._childItems.forEach(item => {
          var _this$_intersectionOb2;
          (_this$_intersectionOb2 = this._intersectionObserver) === null || _this$_intersectionOb2 === void 0 || _this$_intersectionOb2.observe(item);
        });

        // retrieve item heading, eyebrows, and footers to set same height
        if (this._childItems) {
          this._childItems.filter(elem => elem.matches !== undefined ? elem.matches(this.constructor.selectorItem) || elem.matches(this.constructor.selectorItemVideoCTAContainer) : false).forEach(e => {
            var _querySelector;
            this._childItemEyebrows.push(e.querySelector(this.constructor.selectorItemEyebrow));
            this._childItemParagraphs.push(e.querySelector(this.constructor.selectorItemParagraph));
            this._childItemTagGroup.push(e.querySelector(this.constructor.selectorItemTagGroup));
            this._childItemHeadings.push(e.querySelector(this.constructor.selectorItemHeading));

            // gets card cta-type="video" headings
            this._childItemHeadings.push((_querySelector = e.querySelector(this.constructor.selectorItem)) === null || _querySelector === void 0 || (_querySelector = _querySelector.shadowRoot) === null || _querySelector === void 0 ? void 0 : _querySelector.querySelector(this.constructor.selectorItemHeading));
            this._childItemHeadings = this._childItemHeadings.filter(heading => heading);
            this._childItemFooters.push(e.querySelector(this.constructor.selectorItemFooter));
          });
          this._observeResizeRoot();
        }
      }

      /**
       * The observer for the resize of the scroll container.
       */
    }, {
      kind: "field",
      key: "_observeResizeContainer",
      value() {
        return records => {
          const {
            contentRect
          } = records[records.length - 1];
          const {
            width: contentsBaseWidth
          } = contentRect;
          this._contentsBaseWidth = contentsBaseWidth;
          this._updateGap();
        };
      }
    }, {
      kind: "field",
      key: "_observeResizeRoot",
      value() {
        return () => {
          const {
            customPropertyPageSize
          } = this.constructor;
          const {
            _contentsNode: contentsNode
          } = this;
          const {
            defaultView: w
          } = this.ownerDocument;
          this._pageSizeAuto = Number(w.getComputedStyle(contentsNode).getPropertyValue(customPropertyPageSize));
          this._setSameHeight();
        };
      }
    }, {
      kind: "get",
      key: "_getStatus",
      value:
      /**
       * The observer for the resize of the viewport.
       */
      function () {
        const {
          start,
          pageSize,
          _total: total
        } = this;
        // Copes with the condition where `start % pageSize` is non-zero
        const pagesBefore = Math.ceil(start / pageSize);
        const pagesSince = Math.ceil((total - start) / pageSize);
        return {
          currentPage: Math.ceil(start / pageSize) + 1,
          pages: pagesBefore + pagesSince
        };
      }
    }, {
      kind: "field",
      key: "_setSameHeight",
      value() {
        return () => {
          // check if items are not null before using sameHeight

          sameHeight(this._childItemEyebrows.filter(item => item !== null), 'sm');
          sameHeight(this._childItemHeadings.filter(item => item !== null), 'sm');
          sameHeight(this._childItemParagraphs.filter(item => item !== null), 'sm');
          sameHeight(this._childItemFooters.filter(item => item !== null), 'sm');
          let tagGroupHeight = 0;

          // Get the tallest height of tag groups.
          this._childItemTagGroup.forEach(item => {
            if (item) {
              const groupHeight = item.offsetHeight;
              if (groupHeight > tagGroupHeight) {
                tagGroupHeight = groupHeight;
              }
            }
          });
          this._childItemHeadings.forEach(e => {
            var _e$nextElementSibling;
            // add tag group height to heading to the cards lacking tag group
            if (e && !((_e$nextElementSibling = e.nextElementSibling) !== null && _e$nextElementSibling !== void 0 && _e$nextElementSibling.matches(this.constructor.selectorItemTagGroup))) {
              e.style.marginBottom = `${tagGroupHeight + headingBottomMargin}px`;
            }
          });
        };
      }
    }, {
      kind: "method",
      key: "_updateGap",
      value:
      /**
       * Calculates the width between cards.
       */
      function _updateGap() {
        const {
          _slotNode: slotNode
        } = this;
        const elems = slotNode.assignedElements();
        this._gap = elems.length <= 2 ? 0 : elems[1].getBoundingClientRect().left - elems[0].getBoundingClientRect().right;
      }
    }, {
      kind: "method",
      key: "_updateContentsPosition",
      value: function _updateContentsPosition(changedProperties) {
        // The calculation of the contents position is base on start,
        // _contentsBaseWidth, _gap and pageSize. If none of them changed, we've
        // got nothing to do.
        if (!changedProperties.has('start') && !changedProperties.has('_contentsBaseWidth') && !changedProperties.has('_gap') && !changedProperties.has('pageSize')) {
          return;
        }

        // Hard to update the contents node if it hasn't yet been populated. Return
        // early if it's falsy.
        if (!this._contentsNode) {
          return;
        }
        const contentsPosition = -this.start * (this._contentsBaseWidth + this._gap) / this.pageSize;
        this._contentsNode.style.insetInlineStart = `${contentsPosition}px`;
      }
    }, {
      kind: "get",
      key: "focusableElements",
      value: function () {
        var _this$shadowRoot;
        const {
          selectorTabbable: selectorTabbableForCarousel
        } = this.constructor;
        return [...Array.from(((_this$shadowRoot = this.shadowRoot) === null || _this$shadowRoot === void 0 ? void 0 : _this$shadowRoot.querySelectorAll(selectorTabbableForCarousel)) || []), ...Array.from(this.querySelectorAll(selectorTabbableForCarousel))];
      }

      /**
       * The formatters for the pagination status & aria-live announcement.
       * Should be changed with the locale in which the UI is rendered.
       */
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "formatStatus",
      value() {
        return ({
          currentPage,
          pages
        }) => `${currentPage} / ${pages}`;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "formatAnnouncement",
      value() {
        return ({
          currentPage,
          pages
        }) => {
          const visibleItemsCount = this._childItems.filter(item => !item.matches('[inert]')).length;
          return `Slide ${currentPage} of ${pages}. Showing ${visibleItemsCount} items.`;
        };
      }
    }, {
      kind: "get",
      decorators: [property({
        type: Number,
        attribute: 'page-size'
      })],
      key: "pageSize",
      value:
      /**
       * Number of items per page.
       * If `--c4d--carousel--page-size` CSS custom property is set to `<div class="cds--carousel__scroll-container">`
       * or its ancestor (e.g. the host `<c4d-carousel>`), this is set automatically from `--c4d--carousel--page-size`.
       */
      function () {
        const {
          _pageSize: pageSize,
          _pageSizeAuto: pageSizeAuto
        } = this;
        return pageSize !== null && pageSize !== void 0 ? pageSize : pageSizeAuto;
      }
    }, {
      kind: "set",
      key: "pageSize",
      value: function (value) {
        this._pageSize = value;
        // Don't call `.requestUpdate()` here given we track updates via `_pageSize` and `_pageSizeAuto`
      }

      /**
       * The assistive text for the button to go to next slide/group.
       */
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'next-button-text'
      })],
      key: "nextButtonText",
      value: void 0
    }, {
      kind: "field",
      key: "_defaultNextButtonText",
      value() {
        return 'next';
      }
    }, {
      kind: "field",
      key: "_defaultPrevButtonText",
      value() {
        return 'previous';
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'prev-button-text'
      })],
      key: "prevButtonText",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        type: Number
      })],
      key: "start",
      value() {
        return 0;
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value:
      /**
       * The assistive text for the button to go to previous slide/group.
       */
      /**
       * The current zero-based index of the left-most card.
       */
      function connectedCallback() {
        _superPropGet(C4DCarousel, "connectedCallback", this, 3)([]);
        this._cleanAndCreateObserverResize({
          create: true
        });
        this._cleanAndCreateObserverIntersection({
          create: true
        });
        const containingModal = this.closest(`${c4dPrefix}-expressive-modal`);
        if (containingModal) {
          containingModal.hasFocusableElements.push(this);
          this.setAttribute('in-modal', '');
          setTimeout(() => {
            containingModal.modalBody.style.overflow = 'hidden';
            containingModal.modalBody.style.width = 'var(--modal-vw)';
          }, 0);
        }
      }
    }, {
      kind: "method",
      key: "disconnectedCallback",
      value: function disconnectedCallback() {
        this._cleanAndCreateObserverResize();
        this._cleanAndCreateObserverIntersection();
        _superPropGet(C4DCarousel, "disconnectedCallback", this, 3)([]);
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        this._cleanAndCreateObserverResize({
          create: true
        });
        this._cleanAndCreateObserverIntersection({
          create: true
        });
        // Reflect the current writing mode in the dir attribute so that we can
        // make styling adjustments.
        this.setAttribute('dir', window.getComputedStyle(this).getPropertyValue('direction'));
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated(changedProperties) {
        this._updateContentsPosition(changedProperties);
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          customPropertyPageSize
        } = this.constructor;
        const {
          nextButtonText,
          _defaultNextButtonText: defaultNextButtonText,
          pageSize,
          prevButtonText,
          _defaultPrevButtonText: defaultPrevButtonText,
          start,
          _pageSize: pageSizeExplicit,
          _total: total,
          _getStatus: status,
          formatStatus,
          _handleClickNextButton: handleClickNextButton,
          _handleClickPrevButton: handleClickPrevButton,
          _handleScrollFocus: handleScrollFocus,
          _handleSlotChange: handleSlotChange,
          _handleTouchStartEvent: handleTouchStartEvent,
          _handleTouchEndEvent: handleTouchEndEvent,
          _isScrolling: isScrolling
        } = this;
        // Copes with the condition where `start % pageSize` is non-zero
        const pagesBefore = Math.ceil(start / pageSize);
        const pagesSince = Math.ceil((total - start) / pageSize);
        const scrollContentsClasses = classMap({
          [`${prefix}--carousel__scroll-contents`]: true,
          [`${prefix}--carousel__scroll-contents--scrolling`]: isScrolling
        });

        // Hide the navigation controls if there is only one page
        const numberOfPages = this.formatStatus(status);
        const hideControls = numberOfPages === '1 / 1';

        // Use another div from the host `<c4d-carousel>` to reflect private state
        return html(_t || (_t = _`
      <div part="region" role="region" aria-labelledby="carousel-title">
        <div part="title" id="carousel-title">
          <slot name="title">
            <span class="cds--visually-hidden" part="visually-hidden"
              >Carousel</span
            >
          </slot>
        </div>
        <div
          part="scroll-container"
          class="${0}--carousel__scroll-container"
          @scroll="${0}"
          @touchstart="${0}"
          @touchend="${0}"
          style="${0}">
          <div part="contents" class="${0}">
            <slot @slotchange="${0}"></slot>
          </div>
        </div>

        ${0}
      </div>
    `), prefix, handleScrollFocus, handleTouchStartEvent, handleTouchEndEvent, ifDefined(pageSizeExplicit == null ? null : `${customPropertyPageSize}: ${pageSizeExplicit}`), scrollContentsClasses, handleSlotChange, !hideControls ? html(_t2 || (_t2 = _`
              <nav
                part="navigation"
                aria-label="Carousel Navigation"
                class="${0}--carousel__navigation">
                <button
                  part="prev-button"
                  class="${0}--btn ${0}--btn--tertiary ${0}--btn--icon-only ${0}--carousel__navigation__btn"
                  ?disabled="${0}"
                  @click="${0}"
                  aria-label="${0}"
                  title="${0}">
                  ${0}
                </button>
                <span
                  part="status"
                  class="${0}--carousel__navigation__status"
                  aria-hidden="true"
                  >${0}</span
                >
                <span
                  class="${0}--visually-hidden"
                  aria-live="polite"
                  part="visually-hidden"></span>
                <button
                  part="next-button"
                  class="${0}--btn ${0}--btn--tertiary ${0}--btn--icon-only ${0}--carousel__navigation__btn"
                  ?disabled="${0}"
                  @click="${0}"
                  aria-label="${0}"
                  title="${0}">
                  ${0}
                </button>
              </nav>
            `), prefix, prefix, prefix, prefix, prefix, pagesBefore === 0, handleClickPrevButton, prevButtonText || defaultPrevButtonText, prevButtonText || defaultPrevButtonText, CaretLeft20(), prefix, formatStatus(status), prefix, prefix, prefix, prefix, prefix, pagesSince <= 1, handleClickNextButton, nextButtonText || defaultNextButtonText, nextButtonText || defaultNextButtonText, CaretRight20()) : '');
      }

      /**
       * The CSS custom property name for the live page size.
       * If the CSS custom property is set to `<div class="cds--carousel__scroll-container">`
       * or its ancestor (e.g. the host `<c4d-carousel>`), this is set automatically from the CSS custom property.
       */
    }, {
      kind: "get",
      static: true,
      key: "customPropertyPageSize",
      value: function () {
        return `--${c4dPrefix}--carousel--page-size`;
      }

      /**
       * The name of the custom event fired when the video title is updated
       */
    }, {
      kind: "get",
      static: true,
      key: "eventVideoTitleUpdated",
      value: function () {
        return `${c4dPrefix}-card-video-title-updated`;
      }

      /**
       * The selector for the card component
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItem",
      value: function () {
        return `${c4dPrefix}-card`;
      }

      // /**
      //  * The selector for the card cta
      //  */
      // static get selectorItemCardCTA() {
      //   return `${c4dPrefix}-card`;
      // }

      /**
       * The selector for the video cta container
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItemVideoCTAContainer",
      value: function () {
        return `${c4dPrefix}-video-cta-container`;
      }

      /**
       * A selector that will return the card item's eyebrow
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItemEyebrow",
      value: function () {
        return `${c4dPrefix}-card-eyebrow`;
      }

      /**
       * A selector that will return the card item's tag group
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItemTagGroup",
      value: function () {
        return `div`;
      }

      /**
       * A selector that will return the card item's tag group
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItemParagraph",
      value: function () {
        return `p`;
      }

      /**
       * A selector that will return the card item's heading
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItemHeading",
      value: function () {
        return `${c4dPrefix}-card-heading`;
      }

      /**
       * A selector that will return the card item's footer
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItemFooter",
      value: function () {
        return `${c4dPrefix}-card-footer`;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--carousel`;
      }

      /**
       * A selector selecting tabbable nodes.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorTabbable",
      value: function () {
        return `
      ${selectorTabbable}
    `;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, HostListenerMixin(StableSelectorMixin(LitElement)));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DCarousel;
//# sourceMappingURL=carousel.js.map
