import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2025
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././content-block.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * The paragraph content in content block.
 *
 * @element c4d-content-block-paragraph
 */
let C4DContentBlockParagraph = _decorate([customElement(`${c4dPrefix}-content-block-paragraph`)], function (_initialize, _StableSelectorMixin) {
  class C4DContentBlockParagraph extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DContentBlockParagraph,
    d: [{
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        if (!this.shadowRoot) {
          return;
        }
        const slot = this.shadowRoot.querySelector('slot');
        if (slot) {
          slot.addEventListener('slotchange', () => {
            this.toggleVisibility();
          });
        }
        this.toggleVisibility();
      }
    }, {
      kind: "method",
      key: "toggleVisibility",
      value: function toggleVisibility() {
        if (!this.shadowRoot) {
          return;
        }
        const slot = this.shadowRoot.querySelector('slot');
        if (!slot) {
          return;
        }
        const assignedNodes = slot.assignedNodes({
          flatten: true
        });
        const hasTextContent = node => {
          if (node.nodeType === Node.TEXT_NODE) {
            var _node$textContent;
            return !!((_node$textContent = node.textContent) !== null && _node$textContent !== void 0 && _node$textContent.trim());
          }
          if (node.nodeType === Node.ELEMENT_NODE) {
            return [...node.childNodes].some(hasTextContent);
          }
          return false;
        };
        const isEmpty = !assignedNodes.some(hasTextContent);
        this.style.display = isEmpty ? 'none' : 'block';
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t || (_t = _` <slot></slot> `));
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--content-block-paragraph`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
export default C4DContentBlockParagraph;
//# sourceMappingURL=content-block-paragraph.js.map
