import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4,
  _t5,
  _t6,
  _t7,
  _t8,
  _t9;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { classMap } from 'lit/directives/class-map.js';
import { html, LitElement } from 'lit';
import { property, state } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import { CONTENT_BLOCK_COMPLEMENTARY_STYLE_SCHEME } from "./defs.js";
import styles from "././content-block.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
export { CONTENT_BLOCK_COMPLEMENTARY_STYLE_SCHEME };
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * The table mapping slot name with the private property name that indicates the existence of the slot content.
 */
const slotExistencePropertyNames = {
  complementary: '_hasComplementary',
  copy: '_hasCopy',
  heading: '_hasHeading',
  footer: '_hasFooter',
  media: '_hasMedia'
};

// TODO: Figure out how to define a mixin type supporting abstract class
/**
 * Content block.
 *
 * @element c4d-content-block
 * @slot heading - The heading content.
 * @slot copy - The copy content.
 * @slot media - The media content.
 * @slot footer - The footer (CTA) content.
 * @slot complementary - The complementary (aside) content.
 * @csspart body - The body. Usage: `c4d-content-block::part(body)`
 * @csspart footer - The footer. Usage: `c4d-content-block::part(footer)`
 * @csspart content-layout - The content wrapper. Usage: `c4d-content-block::part(content-layout)`
 * @abstract
 */
let C4DContentBlock = _decorate([customElement(`${c4dPrefix}-content-block`)], function (_initialize, _StableSelectorMixin) {
  class C4DContentBlock extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DContentBlock,
    d: [{
      kind: "field",
      decorators: [state()],
      key: "_hasComplementary",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasContent",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasHeading",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasCopy",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasFooter",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasMedia",
      value() {
        return false;
      }
    }, {
      kind: "method",
      key: "_getContainerClasses",
      value:
      /**
       * `true` if there is complementary content.
       */

      /**
       * `true` if there is child content.
       */

      /**
       * `true` if there is heading content.
       */

      /**
       * `true` if there is copy content.
       */

      /**
       * `true` if there is footer content.
       */

      /**
       * `true` if there is media content.
       */

      /**
       * The CSS class list for the container (grid) node.
       */
      function _getContainerClasses() {
        const {
          complementaryStyleScheme,
          _hasContent: hasContent,
          _hasComplementary: hasComplementary,
          _hasFooter: hasFooter
        } = this;
        return classMap({
          [`${prefix}--content-layout`]: true,
          [`${prefix}--content-layout--with-children`]: hasContent,
          [`${prefix}--content-layout--with-complementary`]: hasComplementary,
          [`${prefix}--content-layout--with-footer`]: hasFooter,
          [`${prefix}--layout--border`]: complementaryStyleScheme === CONTENT_BLOCK_COMPLEMENTARY_STYLE_SCHEME.WITH_BORDER
        });
      }

      /**
       * Returns whether or not there is content to render in the body markup.
       */
    }, {
      kind: "method",
      key: "_hasBodyContent",
      value: function _hasBodyContent() {
        const {
          _hasContent: hasContent,
          _hasCopy: hasCopy,
          _hasMedia: hasMedia,
          _hasFooter: hasFooter
        } = this;
        return hasContent || hasCopy || hasMedia || hasFooter;
      }

      /**
       * Handles `slotchange` event.
       *
       * @param event The event.
       * @param event.target The event target.
       */
    }, {
      kind: "method",
      key: "_handleSlotChange",
      value: function _handleSlotChange({
        target
      }) {
        const {
          name
        } = target;
        const hasContent = target.assignedNodes().some(node => node.nodeType !== Node.TEXT_NODE || node.textContent.trim());
        this[slotExistencePropertyNames[name] || '_hasContent'] = hasContent;
      }

      /**
       * @returns The non-header, non-complementary contents.
       */
    }, {
      kind: "method",
      key: "_renderBody",
      value: function _renderBody() {
        return html(_t || (_t = _`
      <div
        part="body"
        ?hidden="${0}"
        class="${0}--content-layout__body">
        ${0}${0}${0}
      </div>
    `), !this._hasBodyContent(), prefix, this._renderCopy(), this._renderInnerBody(), this._renderFooter());
      }

      /**
       * @returns The main content.
       */
    }, {
      kind: "method",
      key: "_renderContent",
      value: function _renderContent() {
        const {
          _handleSlotChange: handleSlotChange
        } = this;
        return html(_t2 || (_t2 = _` <slot @slotchange="${0}"></slot> `), handleSlotChange);
      }

      /**
       * @returns The copy content.
       */
    }, {
      kind: "method",
      key: "_renderCopy",
      value: function _renderCopy() {
        const {
          _handleSlotChange: handleSlotChange
        } = this;
        return html(_t3 || (_t3 = _` <slot name="copy" @slotchange="${0}"></slot> `), handleSlotChange);
      }

      /**
       * @returns The footer content.
       */
    }, {
      kind: "method",
      key: "_renderFooter",
      value: function _renderFooter() {
        const {
          _hasFooter: hasFooter,
          _handleSlotChange: handleSlotChange
        } = this;

        // if card-group exists, ensure the card link footer item matches width of card-group-item
        const cardGroup = this.querySelector(this.constructor.selectorCardGroup);
        const cardGroupStyle = cardGroup === null || cardGroup === void 0 ? void 0 : cardGroup.getAttribute('style');
        return html(_t4 || (_t4 = _`
      <div
        part="footer"
        ?hidden="${0}"
        class="${0}"
        style="${0}"
        ?card-group="${0}"
        grid-mode="${0}">
        <slot name="footer" @slotchange="${0}"></slot>
      </div>
    `), !hasFooter, hasFooter && `${c4dPrefix}--content-block-footer`, cardGroupStyle, cardGroup, cardGroup === null || cardGroup === void 0 ? void 0 : cardGroup.getAttribute('grid-mode'), handleSlotChange);
      }

      /**
       * @returns The heading content.
       */
    }, {
      kind: "method",
      key: "_renderHeading",
      value: function _renderHeading() {
        const {
          _handleSlotChange: handleSlotChange
        } = this;
        return html(_t5 || (_t5 = _`
      <slot name="heading" @slotchange="${0}"></slot>
    `), handleSlotChange);
      }

      /**
       * @returns The main/media content.
       */
    }, {
      kind: "method",
      key: "_renderInnerBody",
      value: function _renderInnerBody() {
        return html(_t6 || (_t6 = _` ${0}${0} `), this._renderContent(), this._renderMedia());
      }

      /**
       * @returns The media content.
       */
    }, {
      kind: "method",
      key: "_renderMedia",
      value: function _renderMedia() {
        const {
          _handleSlotChange: handleSlotChange
        } = this;
        return html(_t7 || (_t7 = _` <slot name="media" @slotchange="${0}"></slot> `), handleSlotChange);
      }

      /**
       * @returns The complementary content.
       */
    }, {
      kind: "method",
      key: "_renderComplementary",
      value: function _renderComplementary() {
        const {
          _handleSlotChange: handleSlotChange
        } = this;
        return html(_t8 || (_t8 = _`
      <slot name="complementary" @slotchange="${0}"></slot>
    `), handleSlotChange);
      }

      /**
       * The style scheme for the complementary content.
       */
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'complementary-style-scheme'
      })],
      key: "complementaryStyleScheme",
      value() {
        return CONTENT_BLOCK_COMPLEMENTARY_STYLE_SCHEME.REGULAR;
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t9 || (_t9 = _`
      <div part="content-layout" class="${0}">
        ${0}${0}${0}
      </div>
    `), this._getContainerClasses(), this._renderHeading(), this._renderBody(), this._renderComplementary());
      }

      /**
       * A selector that will return the card-group element
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorCardGroup",
      value: function () {
        return `${c4dPrefix}-card-group`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DContentBlock;
//# sourceMappingURL=content-block.js.map
