import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html } from 'lit';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import C4DContentItem from "../content-item/content-item.js";
import styles from "././content-item-row-media.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * A component to present content in a row orientation with featured
 * media beneath.
 *
 * @element c4d-content-item-row-media-featured
 * @csspart row--eyebrow - The eyebrow. Usage: `c4d-contenr-item-row-media-featured::part(row--eyebrow)`
 * @csspart col--body - The body. Usage: `c4d-contenr-item-row-media-featured::part(col--body)`
 * @csspart row--media - The media. Usage: `c4d-contenr-item-row-media-featured::part(row--media)`
 */
let C4DContentItemRowMediaFeatured = _decorate([customElement(`${c4dPrefix}-content-item-row-media-featured`)], function (_initialize, _C4DContentItem) {
  class C4DContentItemRowMediaFeatured extends _C4DContentItem {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DContentItemRowMediaFeatured,
    d: [{
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t || (_t = _`
      <div class="${0}--content-item-row__row" part="row row--eyebrow">
        <div class="${0}--content-item-row__col" part="col col--eyebrow">
          <slot name="eyebrow" @slotchange="${0}"></slot>
          <slot name="heading"></slot>
        </div>
        <div class="${0}--content-item-row__col" part="col col--body">
          ${0} ${0}
        </div>
      </div>
      <div class="${0}--content-item-row__row" part="row row--media">
        <slot name="media" @slotchange="${0}"></slot>
      </div>
    `), prefix, prefix, this._handleSlotChange, prefix, this._renderBody(), this._renderFooter(), prefix, this._handleSlotChange);
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}-content-item-row-media-featured`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, C4DContentItem);
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DContentItemRowMediaFeatured;
//# sourceMappingURL=content-item-row-media-featured.js.map
