import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4,
  _t5,
  _t6;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2025
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html } from 'lit';
import { property, state } from 'lit/decorators.js';
import { baseFontSize, breakpoints } from '@carbon/layout';
import HostListener from '@carbon/web-components/es/globals/decorators/host-listener.js';
import HostListenerMixin from '@carbon/web-components/es/globals/mixins/host-listener.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import C4DContentItem from "../content-item/content-item.js";
import styles from "././content-item-row-media.css.js";
import { MEDIA_ALIGN } from "./defs.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;
const breakpoint = parseFloat(breakpoints.lg.width) * baseFontSize;

/**
 * A component to present content in a row orientation with media.
 *
 * @element c4d-content-item-row-media
 * @csspart col--eyebrow - the column eyebrow. Usage. `c4d-content-item-row-media::part(col--eyebrow)`
 * @csspart col--media - thecontent column media. Usage. `c4d-content-item-row-media::part(col--media)`
 * @csspart row--media - the content row media. Usage. `c4d-content-item-row-media::part(row--media)`
 * @csspart
 */
let C4DContentItemRowMedia = _decorate([customElement(`${c4dPrefix}-content-item-row-media`)], function (_initialize, _HostListenerMixin) {
  class C4DContentItemRowMedia extends _HostListenerMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DContentItemRowMedia,
    d: [{
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "align",
      value() {
        return MEDIA_ALIGN.RIGHT;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_isOneColumn",
      value() {
        return window.innerWidth < breakpoint;
      }
    }, {
      kind: "field",
      decorators: [HostListener('window:resize')],
      key: "_handleWindowResize",
      value() {
        return () => {
          this._isOneColumn = window.innerWidth < breakpoint;
        };
      }
    }, {
      kind: "method",
      key: "_renderTextCol",
      value:
      /**
       * Defines the alignment of the media: `left` or `right`
       */

      /**
       * Identifies whether the window width is below the breakpoint or not.
       */

      /**
       * @returns The text column content.
       */
      function _renderTextCol() {
        return html(_t || (_t = _`
      <div class="${0}--content-item-row__col" part="col col--eyebrow">
        <slot name="eyebrow" @slotchange="${0}"></slot>
        <slot name="heading"></slot>
        ${0} ${0}
      </div>
    `), prefix, this._handleSlotChange, this._renderBody(), this._renderFooter());
      }

      /**
       * @returns The media column content.
       */
    }, {
      kind: "method",
      key: "_renderMediaCol",
      value: function _renderMediaCol() {
        return html(_t2 || (_t2 = _`
      <div class="${0}--content-item-row__col" part="col col--media">
        <slot name="media" @slotchange="${0}"></slot>
      </div>
    `), prefix, this._handleSlotChange);
      }

      /**
       * @returns The component content in the appropriate tabbing order.
       */
    }, {
      kind: "method",
      key: "_renderContent",
      value: function _renderContent() {
        const alignedRight = this.align === MEDIA_ALIGN.RIGHT;

        // Always return image first when stacked on mobile
        if (this._isOneColumn) {
          return html(_t3 || (_t3 = _` ${0} ${0} `), this._renderMediaCol(), this._renderTextCol());
        }
        return alignedRight ? html(_t4 || (_t4 = _` ${0} ${0} `), this._renderTextCol(), this._renderMediaCol()) : html(_t5 || (_t5 = _` ${0} ${0} `), this._renderMediaCol(), this._renderTextCol());
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t6 || (_t6 = _`
      <div
        class="${0}--content-item-row__row ${0}--content-item-row-media__align-${0}"
        part="row row--media">
        ${0}
      </div>
    `), prefix, prefix, this.align, this._renderContent());
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--content-item-row-media`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, HostListenerMixin(C4DContentItem));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DContentItemRowMedia;
//# sourceMappingURL=content-item-row-media.js.map
