import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html } from 'lit';
import { property } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import C4DContentItem from "../content-item/content-item.js";
import styles from "././content-item-row.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * A component to present a content in a row orientation.
 *
 * @element c4d-content-item-row
 * @csspart heading-wrapper - The heading wrapper. Usage:  `c4d-content-item-row::part(eading-wrapper)`
 * @csspart content-wrapper - The content wrapper. Usage:  `c4d-content-item-row::part(content-wrapper)`
 * @csspart body-wrapper - The body wrapper. Usage:  `c4d-content-item-row::part(body-wrapper)`
 * @csspart col - Selector for all columns. Usage:  `c4d-content-item-row::part(col)`
 */
let C4DContentItemRow = _decorate([customElement(`${c4dPrefix}-content-item-row`)], function (_initialize, _C4DContentItem) {
  class C4DContentItemRow extends _C4DContentItem {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DContentItemRow,
    d: [{
      kind: "field",
      decorators: [property({
        type: Boolean
      })],
      key: "thumbnail",
      value() {
        return false;
      }
    }, {
      kind: "method",
      key: "_renderMedia",
      value:
      /**
       * Determines whether to render the thumbnail variant
       */

      /**
       * @returns The body content.
       */
      // eslint-disable-next-line class-methods-use-this
      function _renderMedia() {
        return html(_t || (_t = _` <slot name="media"></slot> `));
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t2 || (_t2 = _`
      ${0}
    `), !this.thumbnail ? html(_t3 || (_t3 = _`
            <div
              class="${0}--content-item-row__heading-wrapper"
              part="heading-wrapper">
              <slot
                name="eyebrow"
                @slotchange="${0}"></slot>
              <slot name="heading"></slot>
            </div>
            <div
              class="${0}--content-item-row__content-wrapper"
              part="content-wrapper">
              ${0}${0}${0}
            </div>
          `), prefix, this._handleSlotChange, prefix, this._renderBody(), this._renderFooter(), this._renderMedia()) : html(_t4 || (_t4 = _`
            <div
              class="${0}--content-item-row__body-wrapper"
              part="body-wrapper">
              <div
                class="${0}--content-item-row__heading-wrapper"
                part="heading-wrapper">
                <slot name="heading"></slot>
              </div>
              <div
                class="${0}--content-item-row__content-wrapper"
                part="content-wrapper">
                ${0}${0}
              </div>
            </div>
            <div class="${0}--content-item-row__col--2" part="col col--2">
              <slot name="thumbnail" @slotchange="${0}">
              </slot>
            </div>
          `), prefix, prefix, prefix, this._renderBody(), this._renderFooter(), prefix, this._handleSlotChange));
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--content-item-row`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, C4DContentItem);
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DContentItemRow;
//# sourceMappingURL=content-item-row.js.map
