import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4,
  _t5;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2025
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html, LitElement } from 'lit';
import { classMap } from 'lit/directives/class-map.js';
import { property, state } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././content-item.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * The table mapping slot name with the private property name that indicates the existence of the slot content.
 */
const slotExistencePropertyNames = {
  media: '_hasMedia',
  statistic: '_hasStatistic',
  footer: '_hasFooter'
};

/**
 * Content item.
 *
 * @element c4d-content-item
 * @slot media - The media content.
 * @slot heading - The heading content.
 * @slot footer - The footer (CTA) content.
 * @csspart statistics - The element. Usage: `c4d-content-item::part(statistics)`
 * @csspart media - The media content. Usage: `c4d-content-item::part(media)`
 * @csspart cta - The footer CTA. Usage: `c4d-content-item::part(cta)`
 * @csspart heading - The heading content. Usage: `c4d-content-item::part(heading)`
 * @csspart body - The body content. Usage: `c4d-content-item::part(body)`
 */
let C4DContentItem = _decorate([customElement(`${c4dPrefix}-content-item`)], function (_initialize, _StableSelectorMixin) {
  class C4DContentItem extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DContentItem,
    d: [{
      kind: "field",
      decorators: [state()],
      key: "_hasLogo",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasMedia",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasPictogram",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasStatistic",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasFooter",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean
      })],
      key: "horizontal",
      value() {
        return false;
      }
    }, {
      kind: "method",
      key: "_handleSlotChange",
      value:
      /**
       * `true` if there are CTA statistic in the content item area.
       */

      /**
       * `true` if there are CTA media in the content item area.
       */

      /**
       * `true` if there is a pictogram in the content
       */

      /**
       * `true` if there are CTA statistic in the content item area.
       */

      /**
       * `true` if there is a footer content.
       */

      /**
       * Handles `slotchange` event.
       *
       * @param event The event.
       * @param event.target The event target.
       */
      function _handleSlotChange({
        target
      }) {
        var _assignedNodes$, _assignedNodes$$match;
        const {
          name
        } = target;
        const hasContent = target.assignedNodes().some(node => node.nodeType !== Node.TEXT_NODE || node.textContent.trim());
        this[slotExistencePropertyNames[name] || '_hasStatistic'] = hasContent;
        if ((_assignedNodes$ = target.assignedNodes()[0]) !== null && _assignedNodes$ !== void 0 && (_assignedNodes$$match = _assignedNodes$.matches) !== null && _assignedNodes$$match !== void 0 && _assignedNodes$$match.call(_assignedNodes$, this.constructor.selectorImageLogo)) {
          this._hasLogo = true;
        } else {
          this._hasLogo = false;
        }
        if (target.getAttribute('name') == 'media') {
          const hasPictogram = target.assignedNodes().some(node => node.tagName.toLowerCase() == 'svg');
          this._hasPictogram = hasPictogram;
        }
      }

      /**
       * @returns The statistic content items
       */
    }, {
      kind: "method",
      key: "_renderStatistic",
      value: function _renderStatistic() {
        const {
          _hasStatistic: hasStatistic,
          _handleSlotChange: handleSlotChange
        } = this;
        return html(_t || (_t = _`
      <div
        ?hidden="${0}"
        class="${0}--content-item__statitics"
        part="statistics">
        <slot name="statistics" @slotchange="${0}"></slot>
      </div>
    `), !hasStatistic, c4dPrefix, handleSlotChange);
      }

      /**
       * @returns The media content items
       */
    }, {
      kind: "method",
      key: "_renderMedia",
      value: function _renderMedia() {
        const {
          _hasMedia: hasMedia,
          _handleSlotChange: handleSlotChange
        } = this;
        return html(_t2 || (_t2 = _`
      <div
        ?hidden="${0}"
        class="${0}--content-item__media"
        part="media">
        <slot name="media" @slotchange="${0}"></slot>
      </div>
    `), !hasMedia, c4dPrefix, handleSlotChange);
      }

      /**
       * @returns The body content.
       */
      // eslint-disable-next-line class-methods-use-this
    }, {
      kind: "method",
      key: "_renderBody",
      value: function _renderBody() {
        return html(_t3 || (_t3 = _` <slot></slot> `));
      }

      /**
       * @returns The footer content.
       */
    }, {
      kind: "method",
      key: "_renderFooter",
      value: function _renderFooter() {
        const {
          _hasFooter: hasFooter
        } = this;
        return html(_t4 || (_t4 = _`
      <div
        ?hidden="${0}"
        class="${0}--content-item__cta"
        part="cta">
        <slot name="footer" @slotchange="${0}"></slot>
      </div>
    `), !hasFooter, prefix, this._handleSlotChange);
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated() {
        if (this._hasFooter) {
          var _this$querySelector;
          (_this$querySelector = this.querySelector(`${c4dPrefix}-content-item-copy`)) === null || _this$querySelector === void 0 || _this$querySelector.setAttribute('has-cta', '');
        } else {
          var _this$querySelector2;
          (_this$querySelector2 = this.querySelector(`${c4dPrefix}-content-item-copy`)) === null || _this$querySelector2 === void 0 || _this$querySelector2.removeAttribute('has-cta');
        }
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          horizontal,
          _hasStatistic: hasStatistic,
          _hasLogo: hasLogo
        } = this;
        const horizontalClass = classMap({
          [`${c4dPrefix}--content-item__horizontal`]: horizontal && !hasStatistic && !hasLogo
        });
        return html(_t5 || (_t5 = _`
      <div class="${0}" part="heading">
        ${0} ${0}
        <div part="body">
          <slot name="heading"></slot>
          ${0}${0}
        </div>
      </div>
    `), horizontalClass, this._renderStatistic(), this._renderMedia(), this._renderBody(), this._renderFooter());
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--content-item`;
      }
    }, {
      kind: "get",
      static: true,
      key: "selectorImageLogo",
      value: function () {
        return `${c4dPrefix}-image-logo`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DContentItem;
//# sourceMappingURL=content-item.js.map
