import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html } from 'lit';
import { property } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././content-section.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import C4DMarkdown from "../markdown/markdown.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Copy content in content section.
 *
 * @element c4d-content-section-copy
 */
let C4DContentSectionCopy = _decorate([customElement(`${c4dPrefix}-content-section-copy`)], function (_initialize, _StableSelectorMixin) {
  class C4DContentSectionCopy extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DContentSectionCopy,
    d: [{
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "slot",
      value() {
        return 'copy';
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t || (_t = _` <slot></slot> `));
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        var _this$querySelector;
        (_this$querySelector = this.querySelector('p')) === null || _this$querySelector === void 0 || _this$querySelector.setAttribute('style', 'all:unset;');
        this.childNodes.forEach(node => {
          if (node.nodeType === Node.TEXT_NODE) {
            this.removeChild(node);
          }
        });
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--content-section-copy`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(C4DMarkdown));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DContentSectionCopy;
//# sourceMappingURL=content-section-copy.js.map
