import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././content-section.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * The Content Section component for use with cardSection
 *
 * @element c4d-content-section
 * @slot heading - Section heading
 * @csspart layout - The component wrapper. Usage: `c4d-content-section::part(layout)`
 * @csspart leading - The leading. Usage: `c4d-content-section::part(leading)`
 * @csspart body - The body. Usage: `c4d-content-section::part(body)`
 */
let C4DContentSection = _decorate([customElement(`${c4dPrefix}-content-section`)], function (_initialize, _StableSelectorMixin) {
  class C4DContentSection extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DContentSection,
    d: [{
      kind: "field",
      decorators: [property({
        attribute: 'children-custom-class',
        reflect: true
      })],
      key: "childrenCustomClass",
      value() {
        return '';
      }
    }, {
      kind: "method",
      key: "handleSlotChange",
      value:
      /**
       * An optional custom class for children.
       */

      /**
       * Handler for @slotchange, set the first button-group-item to kind tertiary and primary for the remaining ones
       *
       * @private
       */
      function handleSlotChange(event) {
        const childItems = event.target.assignedNodes().filter(node => node.nodeType !== Node.TEXT_NODE || node.textContent.trim());
        childItems.forEach(elem => {
          if (elem.matches(this.constructor.linkListSelector)) {
            elem.setAttribute('type', 'end');
            this.setAttribute('with-link-list', '');
          } else {
            this.removeAttribute('with-link-list');
          }
        });
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t || (_t = _`
      <div
        class="${0}--content-section ${0}--content-section-layout"
        part="layout">
        <div class="${0}--content-section__leading" part="leading">
          <slot name="heading"></slot>
          <slot name="copy"></slot>
          <slot name="footer"></slot>
        </div>
        <div
          class="${0}--content-section__body ${0}"
          part="body">
          <slot @slotchange="${0}"></slot>
        </div>
      </div>
    `), prefix, prefix, prefix, prefix, this.childrenCustomClass, this.handleSlotChange);
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--content-section`;
      }
    }, {
      kind: "get",
      static: true,
      key: "cardGroupSelector",
      value: function () {
        return `${c4dPrefix}-card-group`;
      }
    }, {
      kind: "get",
      static: true,
      key: "linkListSelector",
      value: function () {
        return `${c4dPrefix}-link-list`;
      }
    }, {
      kind: "get",
      static: true,
      key: "carouselSelector",
      value: function () {
        return `${c4dPrefix}-carousel`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DContentSection;
//# sourceMappingURL=content-section.js.map
