import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property, state } from 'lit/decorators.js';
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import LocaleAPI from '@carbon/ibmdotcom-services/es/services/Locale/Locale.js';
import MediaQueryMixin, { MQBreakpoints, MQDirs } from "../../component-mixins/media-query/media-query.js";
const {
  stablePrefix: c4dPrefix
} = settings;
const ms_per = {
  second: 1000,
  minute: 1000 * 60,
  hour: 1000 * 60 * 60,
  day: 1000 * 60 * 60 * 24
};
const units = Object.keys(ms_per);
const getFormatters = (locale, labelType) => {
  const lc_cc = `${locale.lc}-${locale.cc}`;

  // The Typescript compiler sees unitDisplay as type
  // "short" | "long" | "narrow" | undefined. Convert 'none' to undefined to
  // avoid passing an unknown value to the unitDisplay option.
  if (labelType === 'none') {
    labelType = undefined;
  }
  return Object.fromEntries(units.map(unit => [`to_${unit}s`, new Intl.NumberFormat(lc_cc, {
    style: 'unit',
    unit,
    unitDisplay: labelType,
    minimumIntegerDigits: unit === 'day' ? 1 : 2,
    // Force latin numerals. This fits for all current locales
    // supported on ibm.com with the added benefit of forcing preferred
    // latin numerals on sa-ar. In the future, if necessary, we could
    // expose this options object as a property which we would merge with
    // our defaults here, allowing clients to override our options.
    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-ignore
    numberingSystem: 'latn'
  })]));
};
/**
 * The Countdown component.
 * @element c4d-countdown
 */
let C4DCountdown = _decorate([customElement(`${c4dPrefix}-countdown`)], function (_initialize, _MediaQueryMixin) {
  class C4DCountdown extends _MediaQueryMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DCountdown,
    d: [{
      kind: "field",
      decorators: [state()],
      key: "isMdOrLarger",
      value() {
        return this.carbonBreakpoints.md.matches;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "timeDiff",
      value: void 0
    }, {
      kind: "field",
      decorators: [state()],
      key: "targetDateTime",
      value: void 0
    }, {
      kind: "field",
      decorators: [state()],
      key: "locale",
      value() {
        return {
          lc: 'en',
          cc: 'us'
        };
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'target'
      })],
      key: "targetInput",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'separator'
      })],
      key: "separator",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'label-type'
      })],
      key: "labelType",
      value() {
        return 'long';
      }
    }, {
      kind: "field",
      key: "_formatters",
      value() {
        return getFormatters(this.locale, this.labelType);
      }
    }, {
      kind: "method",
      key: "calculateDiff",
      value:
      /**
       * The target date, either in date time string format (ISO 8601), or UNIX timestamp.
       */

      /**
       * Optional date parts separator.
       */

      /**
       * Optional date parts label type. One of 'short', 'narrow', 'long', or 'none'.
       */

      function calculateDiff() {
        const {
          targetDateTime
        } = this;
        const now = Date.now();
        let diff = (targetDateTime !== null && targetDateTime !== void 0 ? targetDateTime : 0) - now;
        if (diff < 0) {
          clearInterval(this._clock);
          this.timeDiff = {
            days: 0,
            hours: 0,
            minutes: 0,
            seconds: 0
          };
          return;
        }
        const days = Math.floor(diff / ms_per.day);
        diff = diff - days * ms_per.day;
        const hours = Math.floor(diff / ms_per.hour);
        diff = diff - hours * ms_per.hour;
        const minutes = Math.floor(diff / ms_per.minute);
        diff = diff - minutes * ms_per.minute;
        const seconds = Math.floor(diff / ms_per.second);
        this.timeDiff = {
          days,
          hours,
          minutes,
          seconds
        };
      }
    }, {
      kind: "method",
      key: "_padInt",
      value: function _padInt(int, padLength) {
        return int.toString().padStart(padLength, '0');
      }
    }, {
      kind: "method",
      key: "formatOutput",
      value: function formatOutput() {
        const {
          _formatters: formatters,
          timeDiff,
          separator,
          labelType,
          isMdOrLarger,
          _padInt: padInt
        } = this;
        if (timeDiff === undefined) {
          return '';
        }
        const {
          days,
          hours,
          minutes,
          seconds
        } = timeDiff;
        let values;
        if (labelType === 'none') {
          values = [days, hours, minutes, seconds].join(separator !== null && separator !== void 0 ? separator : '');
        } else {
          const {
            to_days,
            to_hours,
            to_minutes,
            to_seconds
          } = formatters;
          values = isMdOrLarger ? [to_days.format(days), to_hours.format(hours), to_minutes.format(minutes), to_seconds.format(seconds)].join(separator !== null && separator !== void 0 ? separator : '') : `${to_days.format(days)} ${padInt(hours, 2)}:${padInt(minutes, 2)}:${padInt(seconds, 2)}`;
        }
        return values;
      }
    }, {
      kind: "method",
      key: "mediaQueryCallbackMD",
      value: function mediaQueryCallbackMD() {
        this.isMdOrLarger = this.carbonBreakpoints.md.matches;
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value: async function firstUpdated() {
        _superPropGet(C4DCountdown, "firstUpdated", this, 3)([]);
        this.style.display = 'contents';
        this.locale = await LocaleAPI.getLocale();
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated(changedProperties) {
        if (changedProperties.has('targetInput')) {
          let target = new Date(this.targetInput);
          const epochTime = parseInt(this.targetInput);

          // If date is invalid and epochTime is a valid number, assume a valid
          // epochTime and create a new Date from it.
          if (isNaN(target.valueOf()) && !isNaN(epochTime)) {
            target = new Date(epochTime);
          }
          if (!isNaN(target.valueOf())) {
            this.targetDateTime = target.getTime();
          }
        }
        if (changedProperties.has('targetDateTime')) {
          clearInterval(this._clock);
          this._clock = setInterval(this.calculateDiff.bind(this), 1000);
        }
        if (changedProperties.has('locale') || changedProperties.has('labelType')) {
          this._formatters = getFormatters(this.locale, this.labelType);
        }
      }
    }, {
      kind: "method",
      key: "createRenderRoot",
      value: function createRenderRoot() {
        return this;
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t || (_t = _` ${0} `), this.formatOutput());
      }
    }]
  };
}, MediaQueryMixin(LitElement, {
  [MQBreakpoints.MD]: MQDirs.MIN
}));
export default C4DCountdown;
//# sourceMappingURL=countdown.js.map
