import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t,
  _t2;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2025
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property, state } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././cta-block.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
import C4DContentItem from "../content-item/content-item.js";
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * The CTA BLOCK ITEM ROW component
 *
 * @element c4d-cta-block-item-row
 * @slot .
 */
let C4DCTABlockItemRow = _decorate([customElement(`${c4dPrefix}-cta-block-item-row`)], function (_initialize, _StableSelectorMixin) {
  class C4DCTABlockItemRow extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DCTABlockItemRow,
    d: [{
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true,
        attribute: 'no-border'
      })],
      key: "_noBorder",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasChildWithMedia",
      value() {
        return false;
      }
    }, {
      kind: "method",
      key: "checkForMedia",
      value: /** Defines if the bottom border is rendered */

      function checkForMedia() {
        const childrenWithMedia = Array.from(this.children).filter(elem => {
          if (elem instanceof C4DContentItem) {
            return (elem === null || elem === void 0 ? void 0 : elem._hasMedia) && !(elem !== null && elem !== void 0 && elem._hasPictogram);
          }
          return false;
        });
        this._hasChildWithMedia = childrenWithMedia.length > 0;
        this.render();
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          _hasChildWithMedia: hasChildWithMedia
        } = this;
        if (hasChildWithMedia) {
          return html(_t || (_t = _`<div class="scroll-container"><slot></slot></div>`));
        } else {
          return html(_t2 || (_t2 = _`<slot></slot>`));
        }
      }

      /**
       * Checks if the no-border attribute has changed and applies the border class accordingly
       */
    }, {
      kind: "method",
      key: "updated",
      value: function updated(changedProperties) {
        if (changedProperties.has('_noBorder')) {
          this.classList.toggle(`${prefix}--cta-block-item-row__border`, !this._noBorder);
        }
        this.updateComplete.then(() => {
          this.checkForMedia();
        });
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--cta-block-item-row`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
console.warn('The cta-block-item-row component has been deprecated in favor of the content-section/block and content-item components. ' + 'See content-section/block and content-items documentation for more information.');

/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DCTABlockItemRow;
//# sourceMappingURL=cta-block-item-row.js.map
