import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2025
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { css, html } from 'lit';
import { state } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import C4DContentItem from "../content-item/content-item.js";
import styles from "././cta-block.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * The table mapping slot name with the private property name that indicates the existence of the slot content.
 */
const slotExistencePropertyNames = {
  media: '_hasMedia',
  statistic: '_hasStatistic',
  footer: '_hasFooter'
};

/**
 * The CTA BLOCK ITEM component
 *
 * @element c4d-cta-block-item
 * @slot statistics
 * @slot media
 * @slot heading
 * @slot .
 * @slot footer
 * @csspart statistics -  The statistics. Usage: `c4d-cta-block-item::part(statistics)`
 * @csspart media -  The media. Usage: `c4d-cta-block-item::part(media)`
 */
let C4DCTABlockItem = _decorate([customElement(`${c4dPrefix}-cta-block-item`)], function (_initialize, _StableSelectorMixin) {
  class C4DCTABlockItem extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DCTABlockItem,
    d: [{
      kind: "field",
      decorators: [state()],
      key: "_hasMedia",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasStatistic",
      value() {
        return false;
      }
    }, {
      kind: "method",
      key: "_handleSlotChange",
      value:
      /**
       * `true` if there are CTA media in the content item area.
       */

      /**
       * `true` if there are CTA statistic in the content item area.
       */

      /**
       * Handles `slotchange` event.
       *
       * @param event The event.
       * @param event.target The event target.
       */
      function _handleSlotChange({
        target
      }) {
        const {
          name
        } = target;
        const hasContent = target.assignedNodes().some(node => node.nodeType !== Node.TEXT_NODE || node.textContent.trim());
        this[slotExistencePropertyNames[name] || '_hasStatistic'] = hasContent;
        if (target.getAttribute('name') == 'media') {
          const hasPictogram = target.assignedNodes().some(node => node.tagName.toLowerCase() == 'svg');
          this._hasPictogram = hasPictogram;
        }
      }

      /**
       * @returns The statistic content items
       */
    }, {
      kind: "method",
      key: "_renderStatistic",
      value: function _renderStatistic() {
        const {
          _hasStatistic: hasStatistic,
          _handleSlotChange: handleSlotChange
        } = this;
        return html(_t || (_t = _`
      <div
        ?hidden="${0}"
        class="${0}--cta-block-item__statitics"
        part="statistics">
        <slot name="statistics" @slotchange="${0}"></slot>
      </div>
    `), !hasStatistic, prefix, handleSlotChange);
      }

      /**
       * @returns The media content items
       */
    }, {
      kind: "method",
      key: "_renderMedia",
      value: function _renderMedia() {
        const {
          _hasMedia: hasMedia,
          _handleSlotChange: handleSlotChange
        } = this;
        return html(_t2 || (_t2 = _`
      <div
        ?hidden="${0}"
        class="${0}--cta-block-item__media"
        part="media">
        <slot name="media" @slotchange="${0}"></slot>
      </div>
    `), !hasMedia, prefix, handleSlotChange);
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t3 || (_t3 = _`
      ${0} ${0}
      <slot name="heading"></slot>
      ${0}${0}
    `), this._renderStatistic(), this._renderMedia(), _superPropGet(C4DCTABlockItem, "_renderBody", this, 3)([]), _superPropGet(C4DCTABlockItem, "_renderFooter", this, 3)([]));
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--cta-block-item`;
      }

      // `styles` here is a `CSSResult` generated by custom WebPack loader
    }, {
      kind: "get",
      static: true,
      key: "styles",
      value: function () {
        return css(_t4 || (_t4 = _`
      ${0}${0}
    `), _superPropGet(C4DCTABlockItem, "styles", this), styles);
      }
    }]
  };
}, StableSelectorMixin(C4DContentItem));
console.warn('The cta-block-item component has been deprecated in favor of the content-section/block and content-item components. ' + 'See content-section/block and content-items documentation for more information.');

/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DCTABlockItem;
//# sourceMappingURL=cta-block-item.js.map
