import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4,
  _t5,
  _t6;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html } from 'lit';
import { property, state } from 'lit/decorators.js';
import { classMap } from 'lit/directives/class-map.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././cta-block.css.js";
import C4DContentBlock from "../content-block/content-block.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * The table mapping slot name with the private property name that indicates the existence of the slot content.
 */
const slotExistencePropertyNames = {
  action: '_hasAction',
  'link-list': '_hasLinkList'
};

/**
 * The CTA BLOCK pattern
 *
 * @element c4d-cta-block
 * @slot heading - The text heading.
 * @slot action - The CTA Buttons.
 * @csspart cta - The CTA Usage: `c4d-cta-block::part(cta)`
 * @csspart helper-wrapper - The help text wrapper. Usage: `c4d-cta-block::part(helper-wrapper)`
 * @csspart content-item-wrapper - The Content item wrapper Usage: `c4d-cta-block::part(content-item-wrapper)`
 * @csspart body - The body Usage: `c4d-cta-block::part(body)`
 * @csspart copy - The copy. Usage: `c4d-cta-block::part(copy)`
 * @csspart link-list - The Link list. Usage: `c4d-cta-block::part(link-list)`
 */
let C4DCTABlock = _decorate([customElement(`${c4dPrefix}-cta-block`)], function (_initialize, _StableSelectorMixin) {
  class C4DCTABlock extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DCTABlock,
    d: [{
      kind: "field",
      decorators: [property({
        type: Boolean,
        attribute: 'no-border',
        reflect: true
      })],
      key: "_noBorder",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasAction",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasLinkList",
      value() {
        return false;
      }
    }, {
      kind: "method",
      key: "updated",
      value:
      /**
       * `true` if there are CTA action in the content item area.
       */

      /**
       * `true` if there is a link list.
       */

      /**
       * Checks if the no-border attribute has changed and applies the border class accordingly
       */
      function updated(changedProperties) {
        if (changedProperties.has('_noBorder')) {
          const layoutWrapper = this.shadowRoot.querySelector(`.${prefix}--content-layout`);
          layoutWrapper === null || layoutWrapper === void 0 || layoutWrapper.classList.toggle(`${prefix}--content-layout--border`, !this._noBorder);
        }
      }
    }, {
      kind: "method",
      key: "_hasBodyContent",
      value: function _hasBodyContent() {
        const {
          _hasLinkList,
          _hasAction
        } = this;
        return _hasLinkList || _hasAction || _superPropGet(C4DCTABlock, "_hasBodyContent", this, 3)([]);
      }

      /**
       * Handles `slotchange` event, also sets height to all headings to the tallest one.
       *
       * @param event The event.
       */
    }, {
      kind: "method",
      key: "_handleSlotChange",
      value: function _handleSlotChange(event) {
        const {
          target
        } = event;
        const {
          name
        } = target;
        if (!slotExistencePropertyNames[name]) {
          _superPropGet(C4DCTABlock, "_handleSlotChange", this, 3)([event]);
          return;
        }
        const hasContent = target.assignedNodes().some(node => node.nodeType !== Node.TEXT_NODE || node.textContent.trim());
        this[slotExistencePropertyNames[name]] = hasContent;
      }

      /**
       * @returns The actions (CTA) content.
       */
    }, {
      kind: "method",
      key: "_renderActions",
      value: function _renderActions() {
        const {
          _hasAction: hasAction,
          _handleSlotChange: handleSlotChange
        } = this;
        return html(_t || (_t = _`
      <div
        ?hidden="${0}"
        class="${0}--content-layout__cta"
        part="cta">
        <slot name="action" @slotchange="${0}"></slot>
      </div>
    `), !hasAction, prefix, handleSlotChange);
      }

      /**
       * @returns The main content.
       */
    }, {
      kind: "method",
      key: "_renderContent",
      value: function _renderContent() {
        const {
          _hasAction,
          _hasCopy,
          _hasLinkList,
          _hasContent,
          _handleSlotChange
        } = this;
        const classes = classMap({
          [`${prefix}--helper-wrapper`]: true,
          [`${prefix}--helper-wrapper--less-space`]: !_hasAction && !_hasCopy && !_hasLinkList
        });
        return html(_t2 || (_t2 = _`
      <div ?hidden="${0}" class="${0}" part="helper-wrapper">
        <div
          class="${0}--content-item-wrapper"
          part="content-item-wrapper">
          <slot @slotchange="${0}"></slot>
        </div>
      </div>
    `), !_hasContent, classes, prefix, _handleSlotChange);
      }

      /**
       * @returns The non-header, non-complementary contents.
       */
    }, {
      kind: "method",
      key: "_renderBody",
      value: function _renderBody() {
        const {
          _hasCopy,
          _hasAction,
          _hasLinkList,
          _hasContent
        } = this;
        const classes = classMap({
          [`${prefix}--content-layout__body`]: true,
          [`${prefix}--content-layout__body--tight`]: !_hasCopy && !_hasAction && (_hasLinkList || _hasContent)
        });
        return html(_t3 || (_t3 = _`
      <div ?hidden="${0}" class="${0}" part="body">
        ${0}${0}
      </div>
    `), !this._hasBodyContent(), classes, this._renderCopy(), this._renderInnerBody());
      }

      /**
       * @returns The copy content.
       */
    }, {
      kind: "method",
      key: "_renderCopy",
      value: function _renderCopy() {
        const {
          _hasCopy: hasCopy,
          _handleSlotChange: handleSlotChange
        } = this;
        return html(_t4 || (_t4 = _`
      <div
        ?hidden="${0}"
        class="${0}--content-layout__copy"
        part="copy">
        <slot name="copy" @slotchange="${0}"></slot>
      </div>
    `), !hasCopy, prefix, handleSlotChange);
      }

      /**
       * @returns The main content.
       */
    }, {
      kind: "method",
      key: "_renderInnerBody",
      value: function _renderInnerBody() {
        // Note: The media content in `<c4d-cta-section>` is not supported at the time of writing this code
        return html(_t5 || (_t5 = _`
      ${0}${0}${0}
    `), this._renderActions(), this._renderLinkList(), this._renderContent());
      }

      /**
       * @returns The link list content.
       */
    }, {
      kind: "method",
      key: "_renderLinkList",
      value: function _renderLinkList() {
        const {
          _hasLinkList: hasLinkList,
          _handleSlotChange: handleSlotChange
        } = this;
        return html(_t6 || (_t6 = _`
      <div
        ?hidden="${0}"
        class="${0}--content-layout__link-list"
        part="link-list">
        <slot name="link-list" @slotchange="${0}"></slot>
      </div>
    `), !hasLinkList, prefix, handleSlotChange);
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--cta-block`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(C4DContentBlock));
console.warn('The cta-block component has been deprecated in favor of the content-section/block and content-item components. ' + 'See content-section/block and content-items documentation for more information.');

/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DCTABlock;
//# sourceMappingURL=cta-block.js.map
