import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t,
  _t2,
  _t3;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
// @ts-nocheck

import { html } from 'lit';
import { property, query } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import { formatVideoCaption, formatVideoDuration } from '@carbon/ibmdotcom-utilities/es/utilities/formatVideoCaption/formatVideoCaption.js';
import C4DButtonGroupItem from "../button-group/button-group-item.js";
import CTAMixin from "../../component-mixins/cta/cta-v1.js";
import VideoCTAMixin from "../../component-mixins/cta/video.js";
import { CTA_TYPE } from "./defs.js";
import styles from "././cta.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
export { CTA_TYPE };
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Button CTA.
 *
 * @element c4d-button-cta
 */
let C4DButtonCTA = _decorate([customElement(`${c4dPrefix}-button-cta`)], function (_initialize, _VideoCTAMixin) {
  class C4DButtonCTA extends _VideoCTAMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DButtonCTA,
    d: [{
      kind: "field",
      decorators: [query('[part="button"]')],
      key: "_linkNode",
      value: void 0
    }, {
      kind: "method",
      key: "_renderContent",
      value:
      /**
       * The button that may work as a link.
       *
       * @private
       */

      /**
       * @returns The main content.
       */
      function _renderContent() {
        const {
          ctaType,
          _hasMainContent: hasMainContent
        } = this;
        if (ctaType !== CTA_TYPE.VIDEO) {
          return html(_t || (_t = _` <slot @slotchange="${0}"></slot> `), this._handleSlotChange);
        }
        const {
          videoDuration,
          videoName,
          formatVideoCaption: formatVideoCaptionInEffect,
          formatVideoDuration: formatVideoDurationInEffect
        } = this;
        const caption = hasMainContent ? undefined : formatVideoCaptionInEffect({
          duration: formatVideoDurationInEffect({
            duration: !videoDuration ? videoDuration : videoDuration * 1000
          }),
          name: videoName
        });
        return html(_t2 || (_t2 = _`
      <slot @slotchange="${0}"></slot>${0}
    `), this._handleSlotChange, caption);
      }
    }, {
      kind: "method",
      key: "_renderInner",
      value: function _renderInner() {
        return html(_t3 || (_t3 = _` ${0}${0} `), this._renderContent(), this._renderIcon());
      }

      /**
       * The CTA type.
       */
    }, {
      kind: "field",
      decorators: [property({
        reflect: true,
        attribute: 'cta-type'
      })],
      key: "ctaType",
      value() {
        return CTA_TYPE.REGULAR;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'href'
      })],
      key: "href",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "formatVideoCaption",
      value() {
        return formatVideoCaption;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "formatVideoDuration",
      value() {
        return formatVideoDuration;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Number,
        attribute: 'video-duration'
      })],
      key: "videoDuration",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'video-name'
      })],
      key: "videoName",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'video-description'
      })],
      key: "videoDescription",
      value: void 0
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value:
      /**
       * Link `href`.
       */
      /**
       * The formatter for the video caption, composed with the video name and the video duration.
       * Should be changed upon the locale the UI is rendered with.
       */
      /**
       * The formatter for the video duration.
       * Should be changed upon the locale the UI is rendered with.
       */
      /**
       * The video duration.
       */
      /**
       * The video name.
       */
      /**
       * The video description.
       */
      /**
       * The video thumbnail URL.
       * Button CTA does not support video thumbnail, and this property should never be set.
       */
      function () {
        return `${c4dPrefix}--button-cta`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, VideoCTAMixin(CTAMixin(C4DButtonGroupItem)));
console.warn(`The c4d-buton-cta component has been deprecated. All its features have been absorbed into
  the base c4d-button component. See migration guide for more information.`);

/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DButtonCTA;
//# sourceMappingURL=button-cta.js.map
