import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2,
  _t3;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
// @ts-nocheck

import { html } from 'lit';
import { property } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import { ifDefined } from 'lit/directives/if-defined.js';
import PlayVideo from "../../icons/play-video.js";
import { formatVideoCaption } from '@carbon/ibmdotcom-utilities/es/utilities/formatVideoCaption/formatVideoCaption.js';
import KalturaPlayerAPI from '@carbon/ibmdotcom-services/es/services/KalturaPlayer/KalturaPlayer';
import C4DCard from "../card/card.js";
import "../card/card-heading.js";
import "./card-cta-image.js";
import CTAMixin from "../../component-mixins/cta/cta-v1.js";
import VideoCTAMixin from "../../component-mixins/cta/video.js";
import "./card-cta-footer.js";
import { CTA_TYPE } from "./defs.js";
import styles from "././cta.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
export { CTA_TYPE };
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Card CTA.
 *
 * @element c4d-card-cta
 * @csspart heading - The heading content. Usage: `c4d-card-cta::part(heading)`
 */
let C4DCardCTA = _decorate([customElement(`${c4dPrefix}-card-cta`)], function (_initialize, _VideoCTAMixin) {
  class C4DCardCTA extends _VideoCTAMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DCardCTA,
    d: [{
      kind: "method",
      key: "_renderHeading",
      value: function _renderHeading() {
        const {
          ctaType,
          videoName,
          formatVideoCaption: formatVideoCaptionInEffect
        } = this;
        if (ctaType !== CTA_TYPE.VIDEO) {
          return _superPropGet(C4DCardCTA, "_renderHeading", this, 3)([]);
        }
        const caption = formatVideoCaptionInEffect({
          name: videoName
        });
        this.dispatchEvent(new CustomEvent(this.constructor.eventVideoTitleUpdated, {
          bubbles: true,
          composed: true
        }));
        return html(_t || (_t = _`
      <slot name="heading"></slot
      ><c4d-card-heading part="heading">${0}</c4d-card-heading>
    `), caption);
      }
    }, {
      kind: "method",
      key: "_renderImage",
      value: function _renderImage() {
        const {
          ctaType,
          videoName,
          videoThumbnailUrl,
          thumbnail,
          _hasImage: hasImage,
          noPoster
        } = this;
        const image = hasImage || ctaType !== CTA_TYPE.VIDEO || noPoster ? undefined : html(_t2 || (_t2 = _`
            <c4d-card-cta-image
              class="${0}--card__video-thumbnail"
              part="video-thumbnail"
              alt="${0}"
              default-src="${0}">
              ${0}
            </c4d-card-cta-image>
          `), prefix, ifDefined(videoName), ifDefined(thumbnail || videoThumbnailUrl), PlayVideo({
          slot: 'icon'
        }));
        return html(_t3 || (_t3 = _`
      <slot name="image" @slotchange="${0}"></slot>${0}
    `), this._handleSlotChange, image);
      }

      /**
       * The CTA type.
       */
    }, {
      kind: "field",
      decorators: [property({
        reflect: true,
        attribute: 'cta-type'
      })],
      key: "ctaType",
      value() {
        return CTA_TYPE.REGULAR;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "formatVideoCaption",
      value() {
        return formatVideoCaption;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "formatVideoDuration",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        type: Number,
        attribute: 'video-duration'
      })],
      key: "videoDuration",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'video-name'
      })],
      key: "videoName",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'video-description'
      })],
      key: "videoDescription",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'video-thumbnail-url'
      })],
      key: "videoThumbnailUrl",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        reflect: true,
        attribute: 'thumbnail'
      })],
      key: "thumbnail",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true,
        attribute: 'no-poster'
      })],
      key: "noPoster",
      value() {
        return false;
      }
    }, {
      kind: "method",
      key: "updated",
      value:
      /**
       * The formatter for the video caption, composed with the video name and the video duration.
       * Should be changed upon the locale the UI is rendered with.
       */
      /**
       * The formatter for the video duration.
       * Should be changed upon the locale the UI is rendered with.
       */
      /**
       * The video duration.
       */
      /**
       * The video name.
       */
      /**
       * The custom video description.
       */
      /**
       * The video thumbnail URL.
       */
      /**
       * Optional custom video thumbnail
       */
      /**
       * Set `true` if Poster Video Image should not be shown.
       */
      function updated(changedProperties) {
        _superPropGet(C4DCardCTA, "updated", this, 3)([changedProperties]);
        const footer = this.querySelector(this.constructor.selectorFooter);
        if (changedProperties.has('ctaType') || changedProperties.has('formatCaption') || changedProperties.has('formatDuration') || changedProperties.has('videoDuration') || changedProperties.has('videoName')) {
          var _this$querySelector;
          const {
            ctaType,
            videoDuration,
            videoName,
            videoDescription,
            formatVideoCaption: formatVideoCaptionInEffect,
            formatVideoDuration: formatVideoDurationInEffect
          } = this;
          const headingText = (_this$querySelector = this.querySelector(`${c4dPrefix}-card-heading`)) === null || _this$querySelector === void 0 ? void 0 : _this$querySelector.textContent;
          const copyText = this.textContent;
          if (footer) {
            const ariaTitle = videoName || headingText || copyText;
            let ariaDuration = '';
            if (videoDuration !== undefined) {
              ariaDuration = `, DURATION ${KalturaPlayerAPI.getMediaDurationFormatted(videoDuration, false)}`;
            }
            footer.altAriaLabel = `${ariaTitle}${ariaDuration}`;
            footer.ctaType = ctaType;
            footer.videoDuration = videoDuration;
            footer.videoName = videoName;
            footer.videoDescription = videoDescription;
            if (formatVideoCaptionInEffect) {
              footer.formatVideoCaption = formatVideoCaptionInEffect;
            }
            if (formatVideoDurationInEffect) {
              footer.formatVideoDuration = formatVideoDurationInEffect;
            }
          }
        }
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--card-cta`;
      }

      /**
       * The name of the custom event fired when the video title is updated
       */
    }, {
      kind: "get",
      static: true,
      key: "eventVideoTitleUpdated",
      value: function () {
        return `${c4dPrefix}-card-cta-video-title-updated`;
      }

      /**
       * A selector that will return the child footer.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorFooter",
      value: function () {
        return `${c4dPrefix}-card-cta-footer`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, VideoCTAMixin(CTAMixin(C4DCard)));
console.warn(`The c4d-card-cta component has been deprecated. All its features have been absorbed into
  the base c4d-card component. See migration guide for more information.`);

/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DCardCTA;
//# sourceMappingURL=card-cta.js.map
