import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4,
  _t5,
  _t6;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import HostListener from '@carbon/web-components/es/globals/decorators/host-listener.js';
import HostListenerMixin from '@carbon/web-components/es/globals/mixins/host-listener.js';
import styles from "././cta.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { formatVideoCaption, formatVideoDuration } from '@carbon/ibmdotcom-utilities/es/utilities/formatVideoCaption/formatVideoCaption.js';
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
import { CTA_TYPE } from "./defs.js";
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * CTA component
 *
 * @element c4d-cta
 * @csspart cta - Targets all styles. Usage: `c4d-cta::part(cta)`
 * @csspart cta--feature - Tagets the Feature style. Usage: `c4d-cta::part(cta--feature)`
 * @csspart cta--card - Tagets the Card style. Usage: `c4d-cta::part(cta--card)`
 * @csspart cta--card-link - Tagets the Card-link style. Usage: `c4d-cta::part(cta--card-link)`
 * @csspart cta--text - Tagets the Text style. Usage: `c4d-cta::part(cta--text)`
 * @csspart cta--button - Tagets the buttton style. Usage: `c4d-cta::part(cta--button)`
 */
let C4DCTAHead = _decorate([customElement(`${c4dPrefix}-cta`)], function (_initialize, _HostListenerMixin) {
  class C4DCTAHead extends _HostListenerMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DCTAHead,
    d: [{
      kind: "field",
      decorators: [property({
        attribute: 'cta-style'
      })],
      key: "ctaStyle",
      value() {
        return 'text';
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'cta-type'
      })],
      key: "ctaType",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'custom-video-title',
        reflect: true
      })],
      key: "customVideoTitle",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'footer-text'
      }), property({
        attribute: 'video-duration',
        reflect: true
      })],
      key: "videoDuration",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'video-thumbnail-url',
        reflect: true
      })],
      key: "videoThumbnailUrl",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "thumbnail",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'href'
      })],
      key: "href",
      value: void 0
    }, {
      kind: "method",
      key: "updated",
      value: function updated() {
        // transpose attributes from parent cta handler to desired cta style
        Array.from(this.attributes).forEach(e => {
          var _this$shadowRoot;
          (_this$shadowRoot = this.shadowRoot) === null || _this$shadowRoot === void 0 || _this$shadowRoot.children[0].setAttribute(e.name, e.value);
        });

        // ensure children components are used within the desired cta style
        Array.from(this.children).forEach(component => {
          var _this$shadowRoot2;
          (_this$shadowRoot2 = this.shadowRoot) === null || _this$shadowRoot2 === void 0 || _this$shadowRoot2.children[0].append(component);
        });
      }

      /**
       * Handles card with video heading and applies the set same height function.
       *
       * @param event The event.
       */
    }, {
      kind: "field",
      decorators: [HostListener(`document:eventRequestAdditionalVideoData`)],
      key: "_handleVideoTitleUpdate",
      value() {
        return async event => {
          if (event) {
            const {
              videoDuration,
              videoName,
              videoId
            } = event.detail;
            const formattedVideoDuration = formatVideoDuration({
              duration: !videoDuration ? videoDuration : videoDuration * 1000
            });
            this.videoDuration ? null : this.videoDuration = formattedVideoDuration;
            if (this.ctaStyle !== 'card' && this.ctaStyle !== 'feature' && this.ctaType === CTA_TYPE.VIDEO && this.href === videoId) {
              const heading = formatVideoCaption({
                duration: formattedVideoDuration,
                name: videoName
              });
              const ctaComponent = this.shadowRoot.querySelector(`c4d-${this.ctaStyle}-cta`);
              const spanElement = ctaComponent === null || ctaComponent === void 0 ? void 0 : ctaComponent.shadowRoot.querySelector('span');
              spanElement ? spanElement.textContent = heading : ctaComponent.textContent = heading;
            } else {
              var _this$shadowRoot3;
              const footer = (_this$shadowRoot3 = this.shadowRoot) === null || _this$shadowRoot3 === void 0 || (_this$shadowRoot3 = _this$shadowRoot3.querySelector(`${c4dPrefix}-${this.ctaStyle}-cta`)) === null || _this$shadowRoot3 === void 0 ? void 0 : _this$shadowRoot3.querySelector(`${c4dPrefix}-${this.ctaStyle}-cta-footer`);
              footer !== null && footer !== void 0 && footer.textContent ? null : footer.textContent = this.videoDuration;
            }
          }
        };
      }
    }, {
      kind: "field",
      decorators: [HostListener(`document:eventUpdateButtonGroup`)],
      key: "_handleButtonGroupupdate",
      value() {
        return async event => {
          if (event) {
            var _this$shadowRoot4;
            const button = (_this$shadowRoot4 = this.shadowRoot) === null || _this$shadowRoot4 === void 0 ? void 0 : _this$shadowRoot4.querySelector(`${c4dPrefix}-button-cta`);
            if (this.ctaStyle === 'button' && button && this.getAttribute('kind')) {
              button.setAttribute('kind', this.getAttribute('kind'));
            }
          }
        };
      }
    }, {
      kind: "method",
      key: "render",
      value:
      /**
       * Handles card with video heading and applies the set same height function.
       *
       * @param event The event.
       */
      function render() {
        return html(_t || (_t = _`
      ${0}
      ${0}
      ${0}
      ${0}
      ${0}
    `), this.ctaStyle === 'feature' ? html(_t2 || (_t2 = _` <c4d-feature-cta part="cta cta--feature"></c4d-feature-cta> `)) : ``, this.ctaStyle === 'card' ? html(_t3 || (_t3 = _`
            <c4d-card-cta part="cta cta--card"><slot></slot></c4d-card-cta>
          `)) : ``, this.ctaStyle === 'card-link' ? html(_t4 || (_t4 = _`
            <c4d-card-link-cta part="cta cta--card-link"
              ><slot></slot
            ></c4d-card-link-cta>
          `)) : ``, this.ctaStyle === 'text' ? html(_t5 || (_t5 = _`
            <c4d-text-cta part="cta cta--text"><slot></slot></c4d-text-cta>
          `)) : ``, this.ctaStyle === 'button' ? html(_t6 || (_t6 = _`
            <c4d-button-cta part="cta cta--button"
              ><slot></slot
            ></c4d-button-cta>
          `)) : ``);
      }

      /**
       * The name of the custom event fired when there is a user gesture to run the action.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventRequestAdditionalVideoData",
      value: function () {
        return `${c4dPrefix}-cta-request-additional-video-data`;
      }

      /**
       * The name of the custom event fired when there is a user gesture to run the action.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventUpdateButtonGroup",
      value: function () {
        return `${c4dPrefix}-button-group-update`;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}-cta`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, HostListenerMixin(StableSelectorMixin(LitElement)));
console.warn(`The c4d-cta component has been deprecated in favor of the c4d-card, c4d-feature-card, c4d-link-with-icon,
  and c4d-button-group. See migration guide for more information.`);

/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DCTAHead;
//# sourceMappingURL=cta.js.map
