import _decorate from "@babel/runtime/helpers/esm/decorate";
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
// @ts-nocheck

import { property } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import { formatVideoCaption, formatVideoDuration } from '@carbon/ibmdotcom-utilities/es/utilities/formatVideoCaption/formatVideoCaption.js';
import C4DFeatureCardFooter from "../feature-card/feature-card-footer.js";
import CTAMixin from "../../component-mixins/cta/cta-v1.js";
import VideoCTAMixin from "../../component-mixins/cta/video.js";
import { CTA_TYPE } from "./defs.js";
import styles from "././cta.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Feature CTA footer.
 *
 * @element c4d-feature-cta-footer
 */
let C4DFeatureCTAFooter = _decorate([customElement(`${c4dPrefix}-feature-cta-footer`)], function (_initialize, _VideoCTAMixin) {
  class C4DFeatureCTAFooter extends _VideoCTAMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DFeatureCTAFooter,
    d: [{
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "formatVideoCaption",
      value() {
        return formatVideoCaption;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "formatVideoDuration",
      value() {
        return formatVideoDuration;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Number,
        attribute: 'video-duration'
      })],
      key: "videoDuration",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'video-description'
      })],
      key: "videoDescription",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        reflect: true,
        attribute: 'cta-type'
      })],
      key: "ctaType",
      value() {
        return CTA_TYPE.REGULAR;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, VideoCTAMixin(CTAMixin(C4DFeatureCardFooter)));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DFeatureCTAFooter;
//# sourceMappingURL=feature-cta-footer.js.map
