import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2,
  _t3;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
// @ts-nocheck

import { html } from 'lit';
import { property } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import { ifDefined } from 'lit/directives/if-defined.js';
import PlayFilled from '@carbon/web-components/es/icons/play--filled/32.js';
import { formatVideoCaption, formatVideoDuration } from '@carbon/ibmdotcom-utilities/es/utilities/formatVideoCaption/formatVideoCaption.js';
import C4DFeatureCard from "../feature-card/feature-card.js";
import CTAMixin from "../../component-mixins/cta/cta-v1.js";
import VideoCTAMixin from "../../component-mixins/cta/video.js";
import "./feature-cta-footer.js";
import { CTA_TYPE } from "./defs.js";
import styles from "././cta.css.js";
import "../card/card-eyebrow.js";
import "../card/card-heading.js";
import "../image/image.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
export { CTA_TYPE };
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Feature CTA.
 *
 * @element c4d-feature-cta
 * @csspart copy - The copy content. Usage: `c4d-feature-cta::part(copy)`
 */
let C4DFeatureCTA = _decorate([customElement(`${c4dPrefix}-feature-cta`)], function (_initialize, _VideoCTAMixin) {
  class C4DFeatureCTA extends _VideoCTAMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DFeatureCTA,
    d: [{
      kind: "method",
      key: "_renderCopy",
      value: function _renderCopy() {
        const {
          ctaType,
          videoDuration,
          videoName,
          formatVideoCaption: formatCaptionInEffect,
          formatVideoDuration: formatDurationInEffect,
          _hasCopy: hasCopy
        } = this;
        if (ctaType !== CTA_TYPE.VIDEO) {
          return _superPropGet(C4DFeatureCTA, "_renderCopy", this, 3)([]);
        }
        const caption = formatCaptionInEffect({
          duration: formatDurationInEffect({
            duration: !videoDuration ? videoDuration : videoDuration * 1000
          }),
          name: videoName
        });
        this.captionHeading = caption;
        return html(_t || (_t = _`
      <div ?hidden="${0}" class="${0}--card__copy" part="copy">
        <slot @slotchange="${0}"></slot>
      </div>
    `), !hasCopy, prefix, this._handleCopySlotChange);
      }
    }, {
      kind: "method",
      key: "_renderImage",
      value: function _renderImage() {
        const {
          ctaType,
          noPoster,
          thumbnail,
          videoName,
          videoThumbnailUrl
        } = this;
        const image = ctaType !== CTA_TYPE.VIDEO || noPoster ? undefined : html(_t2 || (_t2 = _`
            <c4d-image
              alt="${0}"
              default-src="${0}"
              slot="image">
              ${0}
            </c4d-image>
          `), ifDefined(videoName), ifDefined(thumbnail || videoThumbnailUrl), PlayFilled({
          slot: 'icon'
        }));
        return noPoster ? undefined : html(_t3 || (_t3 = _`
          <div part="image-wrapper" class="${0}--card__image-wrapper">
            <slot name="image" @slotchange="${0}">
              ${0}
            </slot>
          </div>
        `), prefix, this._handleSlotChange, image);
      }

      /**
       * The video caption to replace the heading with.
       */
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "captionHeading",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        reflect: true,
        attribute: 'cta-type'
      })],
      key: "ctaType",
      value() {
        return CTA_TYPE.REGULAR;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "formatVideoCaption",
      value() {
        return formatVideoCaption;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "formatVideoDuration",
      value() {
        return formatVideoDuration;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true,
        attribute: 'no-poster'
      })],
      key: "noPoster",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true,
        attribute: 'thumbnail'
      })],
      key: "thumbnail",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        type: Number,
        attribute: 'video-duration'
      })],
      key: "videoDuration",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'video-name'
      })],
      key: "videoName",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'video-description'
      })],
      key: "videoDescription",
      value: void 0
    }, {
      kind: "method",
      key: "updated",
      value:
      /**
       * The CTA type.
       */
      /**
       * The formatter for the video caption, composed with the video name and the video duration.
       * Should be changed upon the locale the UI is rendered with.
       */
      /**
       * The formatter for the video duration.
       * Should be changed upon the locale the UI is rendered with.
       */
      /**
       * Set `true` if Poster Video Image should not be shown.
       */
      /**
       * Optional custom video thumbnail
       */
      /**
       * The video duration.
       */
      /**
       * The video name.
       */
      /**
       * The custom video description.
       */
      /**
       * The video thumbnail URL.
       */
      function updated(changedProperties) {
        _superPropGet(C4DFeatureCTA, "updated", this, 3)([changedProperties]);
        const {
          selectorFooter
        } = this.constructor;
        if (changedProperties.has('ctaType') || changedProperties.has('videoName') || changedProperties.has('captionHeading')) {
          const {
            ctaType,
            videoName,
            videoDescription
          } = this;
          const footer = this.querySelector(selectorFooter);
          if (footer) {
            footer.ctaType = ctaType;
            footer.altAriaLabel = this.videoName || this.captionHeading;
            footer.videoName = videoName;
            footer.videoDescription = videoDescription;
          }
        }
        if (changedProperties.has('captionHeading')) {
          const heading = this.querySelector(this.constructor.selectorHeading);
          if (heading) {
            heading.innerText = this.captionHeading;
          }
        }
      }

      /**
       * A selector that will return the child heading.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorHeading",
      value: function () {
        return `${c4dPrefix}-card-heading`;
      }

      /**
       * A selector that will return the child footer.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorFooter",
      value: function () {
        return `${c4dPrefix}-feature-cta-footer`;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--feature-cta`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, VideoCTAMixin(CTAMixin(C4DFeatureCard)));
console.warn(`The c4d-feature-cta component has been deprecated. All its features have been absorbed into
  the base c4d-feature-card component. See migration guide for more information.`);

/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DFeatureCTA;
//# sourceMappingURL=feature-cta.js.map
