import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html } from 'lit';
import { property, state } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import { formatVideoCaption, formatVideoDuration } from '@carbon/ibmdotcom-utilities/es/utilities/formatVideoCaption/formatVideoCaption.js';
import C4DLinkWithIcon from "../link-with-icon/link-with-icon.js";
import CTAMixin from "../../component-mixins/cta/cta-v1.js";
import VideoCTAMixin from "../../component-mixins/cta/video.js";
import { CTA_TYPE } from "./defs.js";
import styles from "././cta.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
export { CTA_TYPE };
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Text CTA.
 *
 * @element c4d-text-cta
 */
let C4DTextCTA = _decorate([customElement(`${c4dPrefix}-text-cta`)], function (_initialize, _VideoCTAMixin) {
  class C4DTextCTA extends _VideoCTAMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DTextCTA,
    d: [{
      kind: "field",
      decorators: [state()],
      key: "_hasContent",
      value() {
        return false;
      }
    }, {
      kind: "method",
      key: "_handleSlotChange",
      value:
      /**
       * `true` if there is a non-empty default slot content.
       */

      /**
       * Handles `slotchange` event on the default `<slot>`.
       */
      function _handleSlotChange({
        target
      }) {
        this._hasContent = target.assignedNodes().some(node => {
          var _node$nodeValue;
          return node.nodeType !== Node.COMMENT_NODE && (node.nodeType !== Node.TEXT_NODE || ((_node$nodeValue = node.nodeValue) === null || _node$nodeValue === void 0 ? void 0 : _node$nodeValue.trim()));
        });
      }
    }, {
      kind: "method",
      key: "_renderContent",
      value: function _renderContent() {
        const {
          ctaType,
          _hasContent: hasContent
        } = this;
        if (ctaType !== CTA_TYPE.VIDEO) {
          return _superPropGet(C4DTextCTA, "_renderContent", this, 3)([]);
        }
        const {
          videoDuration,
          videoName,
          formatVideoCaption: formatVideoCaptionInEffect,
          formatVideoDuration: formatVideoDurationInEffect
        } = this;
        const caption = hasContent ? undefined : formatVideoCaptionInEffect({
          duration: formatVideoDurationInEffect({
            duration: !videoDuration ? videoDuration : videoDuration * 1000
          }),
          name: videoName
        });
        return html(_t || (_t = _`
      <span
        ><slot @slotchange="${0}"></slot>${0}</span
      >
    `), this._handleSlotChange, caption);
      }

      /**
       * The CTA type.
       */
    }, {
      kind: "field",
      decorators: [property({
        reflect: true,
        attribute: 'cta-type'
      })],
      key: "ctaType",
      value() {
        return CTA_TYPE.REGULAR;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "formatVideoCaption",
      value() {
        return formatVideoCaption;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "formatVideoDuration",
      value() {
        return formatVideoDuration;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Number,
        attribute: 'video-duration'
      })],
      key: "videoDuration",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'video-name'
      })],
      key: "videoName",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'video-description'
      })],
      key: "videoDescription",
      value: void 0
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value:
      /**
       * The formatter for the video caption, composed with the video name and the video duration.
       * Should be changed upon the locale the UI is rendered with.
       */
      /**
       * The formatter for the video duration.
       * Should be changed upon the locale the UI is rendered with.
       */
      /**
       * The video duration.
       */
      /**
       * The video name.
       */
      /**
       * The video description.
       */
      /**
       * The video thumbnail URL.
       * Text CTA does not support video thumbnail, and this property should never be set.
       */
      function () {
        return `${c4dPrefix}--text-cta`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, VideoCTAMixin(CTAMixin(C4DLinkWithIcon)));
console.warn(`The c4d-feature-cta component has been deprecated. All its features have been absorbed into
  the base c4d-feature-card component. See migration guide for more information.`);

/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DTextCTA;
//# sourceMappingURL=text-cta.js.map
