import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property, state } from 'lit/decorators.js';
import on from '@carbon/web-components/es/globals/mixins/on.js';
import { ifDefined } from 'lit/directives/if-defined.js';
import HostListener from '@carbon/web-components/es/globals/decorators/host-listener.js';
import HostListenerMixin from '@carbon/web-components/es/globals/mixins/host-listener.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import ModalRenderMixin from "../../globals/mixins/modal-render.js";
// Above import is interface-only ref and thus code won't be brought into the build
// Above import is interface-only ref and thus code won't be brought into the build
import "../lightbox-media-viewer/lightbox-video-player-composite.js";
import { CTA_TYPE } from "./defs.js";
import styles from "././video-cta-composite.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Component that handles video CTAs in app.
 *
 * @element c4d-video-cta-composite
 */
let C4DVideoCTAComposite = _decorate([customElement(`${c4dPrefix}-video-cta-composite`)], function (_initialize, _ModalRenderMixin) {
  class C4DVideoCTAComposite extends _ModalRenderMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DVideoCTAComposite,
    d: [{
      kind: "field",
      decorators: [state()],
      key: "_activeVideoId",
      value: void 0
    }, {
      kind: "field",
      decorators: [state()],
      key: "_videoName",
      value: void 0
    }, {
      kind: "field",
      decorators: [state()],
      key: "_videoDescription",
      value: void 0
    }, {
      kind: "field",
      key: "_hCloseModal",
      value() {
        return null;
      }
    }, {
      kind: "field",
      key: "_handleCloseVideoPlayer",
      value() {
        return () => {
          this._activeVideoId = undefined;
        };
      }
    }, {
      kind: "method",
      decorators: [HostListener('eventRequestVideoData')],
      key: "_handleRequestVideoData",
      value:
      /**
       * The placeholder for `_embedMedia()` action that may be mixed in.
       *
       * @internal
       */

      /**
       * The placeholder for `_loadVideoData()` Redux action that may be mixed in.
       *
       * @internal
       */

      /**
       * `true` to show the video player.
       */

      /**
       * The video custom name.
       */

      /**
       * The video custom description.
       */

      /**
       * The handle for the listener of `${c4dPrefix}-expressive-modal-closed` event.
       */

      /**
       * Handles the user gesture of closing video player modal.
       */

      /**
       * Handles `${c4dPrefix}-cta-request-video-data` event.
       *
       * @param event The event.
       */
      async function _handleRequestVideoData(event) {
        var _this$_loadVideoData;
        const {
          href,
          videoName: customVideoName,
          videoDescription
        } = event.detail;
        const videoData = await ((_this$_loadVideoData = this._loadVideoData) === null || _this$_loadVideoData === void 0 ? void 0 : _this$_loadVideoData.call(this, href));
        if (videoData && videoData !== null && videoData !== void 0 && videoData.id) {
          const {
            duration,
            name
          } = videoData;
          const videoName = customVideoName || name;
          if (event.target) {
            event.target.videoName = videoName || customVideoName;
            event.target.videoDescription = videoDescription;
            event.target.videoDuration = duration;
          }
          const videoInfo = new CustomEvent(`${c4dPrefix}-cta-request-additional-video-data`, {
            bubbles: true,
            cancelable: true,
            composed: true,
            detail: {
              videoName,
              videoDuration: duration,
              videoId: href
            }
          });
          this.dispatchEvent(videoInfo);
        }
      }

      /**
       * Handles `${c4dPrefix}-cta-run-action` event.
       *
       * @param event The event.
       */
    }, {
      kind: "method",
      decorators: [HostListener('eventRunAction')],
      key: "_handleRunAction",
      value: function _handleRunAction(event) {
        const {
          ctaType,
          href,
          videoName,
          videoDescription
        } = event.detail;
        if (ctaType === CTA_TYPE.VIDEO) {
          this._activeVideoId = href;
          this._videoName = videoName;
          this._videoDescription = videoDescription;
        }
      }

      /**
       * The video player.
       */
    }, {
      kind: "get",
      key: "_videoPlayer",
      value: function () {
        var _this$modalRenderRoot, _modalRenderRoot;
        const {
          selectorVideoPlayer,
          selectorLightboxVideoPlayerComposite
        } = this.constructor;
        const lightbox = (_this$modalRenderRoot = this.modalRenderRoot) === null || _this$modalRenderRoot === void 0 ? void 0 : _this$modalRenderRoot.querySelector(selectorLightboxVideoPlayerComposite);
        return lightbox === null || lightbox === void 0 || (_modalRenderRoot = lightbox.modalRenderRoot) === null || _modalRenderRoot === void 0 ? void 0 : _modalRenderRoot.querySelector(selectorVideoPlayer);
      }

      /**
       * The embedded Kaltura player element (that has `.sendNotification()`, etc. APIs), keyed by the video ID.
       */
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "embeddedVideos",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "mediaData",
      value: void 0
    }, {
      kind: "method",
      key: "disconnectedCallback",
      value:
      /**
       * The video data, keyed by the video ID.
       */
      function disconnectedCallback() {
        if (this._hCloseModal) {
          this._hCloseModal = this._hCloseModal.release();
        }
        _superPropGet(C4DVideoCTAComposite, "disconnectedCallback", this, 3)([]);
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated(changedProperties) {
        _superPropGet(C4DVideoCTAComposite, "updated", this, 3)([changedProperties]);
        if (!this._hCloseModal) {
          const {
            selectorLightboxVideoPlayerComposite
          } = this.constructor;
          const videoPlayerComposite = this.modalRenderRoot.querySelector(selectorLightboxVideoPlayerComposite);
          // Manually hooks the event listeners on the modal render root to make the event names configurable
          this._hCloseModal = on(videoPlayerComposite.modalRenderRoot, this.constructor.eventCloseLightbox, this._handleCloseVideoPlayer);
        }
      }

      /**
       * @returns The media viewer lightbox for `type="video"`.
       */
    }, {
      kind: "method",
      key: "renderModal",
      value: function renderModal() {
        const {
          embeddedVideos,
          mediaData,
          _videoName: videoName,
          _activeVideoId: activeVideoId,
          _embedMedia: embedMedia,
          _videoDescription: videoDescription
        } = this;
        return html(_t || (_t = _`
      <c4d-lightbox-video-player-composite
        ?open="${0}"
        video-cta-lightbox="true"
        custom-video-name="${0}"
        custom-video-description="${0}"
        video-id="${0}"
        .embeddedVideos="${0}"
        .mediaData="${0}"
        ._embedMedia="${0}">
      </c4d-lightbox-video-player-composite>
    `), Boolean(activeVideoId), ifDefined(videoName), ifDefined(videoDescription), ifDefined(activeVideoId), ifDefined(embeddedVideos), ifDefined(mediaData), ifDefined(embedMedia));
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t2 || (_t2 = _` <slot></slot> `));
      }

      /**
       * A selector selecting the video player component.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorVideoPlayer",
      value: function () {
        return `${c4dPrefix}-lightbox-video-player`;
      }

      /**
       * A selector selecting the video player composite component.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorLightboxVideoPlayerComposite",
      value: function () {
        return `${c4dPrefix}-lightbox-video-player-composite`;
      }

      /**
       * The name of the custom event fired after the lightbox is closed upon a user gesture.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventCloseLightbox",
      value: function () {
        return `${c4dPrefix}-expressive-modal-closed`;
      }

      /**
       * The name of the custom event fired when there is a user gesture to run the action.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventRequestVideoData",
      value: function () {
        return `${c4dPrefix}-cta-request-video-data`;
      }

      /**
       * The name of the custom event fired when there is a user gesture to run the action.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventRunAction",
      value: function () {
        return `${c4dPrefix}-cta-run-action`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, ModalRenderMixin(HostListenerMixin(LitElement)));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DVideoCTAComposite;
//# sourceMappingURL=video-cta-composite.js.map
