import _decorate from "@babel/runtime/helpers/esm/decorate";
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { property } from 'lit/decorators.js';
import CDSModalCloseButton from '@carbon/web-components/es/components/modal/modal-close-button.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import { EXPRESSIVE_MODAL_SIZE } from "./defs.js";
import styles from "././expressive-modal.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Expressive modal close button.
 *
 * @element c4d-expressive-modal-close-button
 */
let C4DExpressiveModalCloseButton = _decorate([customElement(`${c4dPrefix}-expressive-modal-close-button`)], function (_initialize, _StableSelectorMixin) {
  class C4DExpressiveModalCloseButton extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DExpressiveModalCloseButton,
    d: [{
      kind: "field",
      decorators: [property({
        reflect: true,
        attribute: 'size'
      })],
      key: "size",
      value() {
        return EXPRESSIVE_MODAL_SIZE.REGULAR;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value:
      /**
       * The size variant.
       */

      function () {
        return `${c4dPrefix}--expressive-modal-close-button`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(CDSModalCloseButton));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DExpressiveModalCloseButton;
//# sourceMappingURL=expressive-modal-close-button.js.map
