import _decorate from "@babel/runtime/helpers/esm/decorate";
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { property } from 'lit/decorators.js';
import CDSModalFooter from '@carbon/web-components/es/components/modal/modal-footer.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././expressive-modal.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Expressive modal footer.
 *
 * @element c4d-expressive-modal-footer
 */
let C4DExpressiveModalFooter = _decorate([customElement(`${c4dPrefix}-expressive-modal-footer`)], function (_initialize, _StableSelectorMixin) {
  class C4DExpressiveModalFooter extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DExpressiveModalFooter,
    d: [{
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "slot",
      value() {
        return 'footer';
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value:
      /**
       * The slot in parent `<c4d-modal>`.
       */

      function () {
        return `${c4dPrefix}--expressive-modal-footer`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(CDSModalFooter));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DExpressiveModalFooter;
//# sourceMappingURL=expressive-modal-footer.js.map
