import _decorate from "@babel/runtime/helpers/esm/decorate";
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import CDSCheckbox from '@carbon/web-components/es/components/checkbox/checkbox.js';
import FocusMixin from '@carbon/web-components/es/globals/mixins/focus.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import '@carbon/web-components/es/components/modal/modal.js';
import styles from "././filter-panel.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Filter Panel Checkbox
 *
 * @element c4d-filter-panel-checkbox
 * @fires c4d-checkbox-select - The custom event fired after this changebox changes its checked state.
 */
let C4DFilterPanelCheckbox = _decorate([customElement(`${c4dPrefix}-filter-panel-checkbox`)], function (_initialize, _FocusMixin) {
  class C4DFilterPanelCheckbox extends _FocusMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DFilterPanelCheckbox,
    d: [{
      kind: "method",
      key: "_handleChange",
      value:
      /**
       * Handles `click` event on the `<input>` in the shadow DOM.
       */
      function _handleChange() {
        const {
          checked,
          indeterminate
        } = this._checkboxNode;
        this.checked = checked;
        this.indeterminate = indeterminate;
        const {
          eventChange
        } = this.constructor;
        this.dispatchEvent(new CustomEvent(eventChange, {
          bubbles: true,
          composed: true,
          detail: {
            value: this.value
          }
        }));
      }

      /**
       * The name of the event that fires upon checkbox is selected
       */
    }, {
      kind: "get",
      static: true,
      key: "eventChange",
      value: function () {
        return `${c4dPrefix}-checkbox-select`;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}-filter-panel-checkbox`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, FocusMixin(StableSelectorMixin(CDSCheckbox)));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DFilterPanelCheckbox;
//# sourceMappingURL=filter-panel-checkbox.js.map
