import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html, LitElement } from 'lit';
import { property, state, query } from 'lit/decorators.js';
import Filter from '@carbon/web-components/es/icons/filter/16.js';
import HostListenerMixin from '@carbon/web-components/es/globals/mixins/host-listener.js';
import "./filter-group.js";
import "./filter-panel.js";
import "./filter-panel-modal.js";
import HostListener from '@carbon/web-components/es/globals/decorators/host-listener.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././filter-panel.css.js";
import '@carbon/web-components/es/components/checkbox/checkbox.js';
import '@carbon/web-components/es/components/button/button.js';
import C4DFilterPanelCheckbox from "./filter-panel-checkbox.js";
import C4DFilterPanelInputSelect from "./filter-panel-input-select.js";
import C4DFilterPanelInputSelectItem from "./filter-panel-input-select-item.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
import MediaQueryMixin, { MQBreakpoints, MQDirs } from "../../component-mixins/media-query/media-query.js";
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Filter panel composite
 *
 * @element c4d-filter-panel-composite
 * @csspart panel-modal - The panel modal. Usage: `c4d-filter-panel::part(panel-modal)`
 * @csspart button - The button. Usage: `c4d-filter-panel::part(button)`
 * @csspart filter-panel - The filter panel. Usage: `c4d-filter-panel::part(filter-panel)`
 */
let C4DFilterPanelComposite = _decorate([customElement(`${c4dPrefix}-filter-panel-composite`)], function (_initialize, _MediaQueryMixin) {
  class C4DFilterPanelComposite extends _MediaQueryMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DFilterPanelComposite,
    d: [{
      kind: "field",
      decorators: [HostListener('document:eventInputSelectItem')],
      key: "_handleInputSelectItemStateChange",
      value() {
        return event => {
          const {
            value,
            lastValue,
            headerValue
          } = event.detail;
          const {
            stableSelector
          } = C4DFilterPanelInputSelectItem;
          this._focusElement = `${stableSelector}[value="${value}"]`;

          // remove the C4DInputSelect (header) value from list to add an inner child instead
          this._selectedValues = this._selectedValues.filter(e => e !== headerValue);
          if (!value) {
            this._selectedValues = this._selectedValues.filter(e => e !== value);
            return;
          }
          if (!this._selectedValues.includes(value)) {
            this._selectedValues = [...this._selectedValues, value];
          }
          if (lastValue && this._selectedValues.includes(lastValue)) {
            this._selectedValues = this._selectedValues.filter(e => e !== lastValue);
          }
        };
      }
    }, {
      kind: "field",
      decorators: [HostListener('document:eventCheckboxSelect')],
      key: "_handleCheckboxStateChange",
      value() {
        return event => {
          var _this$shadowRoot;
          const {
            value
          } = event.detail;

          // toggle checkbox in filter panel modal
          this.querySelectorAll(`${c4dPrefix}-filter-panel-checkbox`).forEach(e => {
            if (e.getAttribute('value') === value) {
              var _e$closest;
              e.toggleAttribute('checked');
              (_e$closest = e.closest(`${c4dPrefix}-filter-group-item`)) === null || _e$closest === void 0 || _e$closest.setAttribute('open', '');
              const {
                stableSelector
              } = C4DFilterPanelCheckbox;
              this._focusElement = `${stableSelector}[value="${value}"]`;
            }
          });
          const filterGroupItems = this.querySelectorAll(`${c4dPrefix}-filter-group-item`);
          (_this$shadowRoot = this.shadowRoot) === null || _this$shadowRoot === void 0 || _this$shadowRoot.querySelectorAll(`${c4dPrefix}-filter-group-item`).forEach((filterGroupItem, index) => {
            if (filterGroupItem.open) {
              filterGroupItems[index].open = true;
            }
          });

          // Toggle value in list.
          if (!this._selectedValues.includes(value)) {
            this._selectedValues = [...this._selectedValues, value];
          } else {
            this._selectedValues = this._selectedValues.filter(e => e !== value);
          }
        };
      }
    }, {
      kind: "field",
      decorators: [HostListener('document:eventFilterGroupViewAllToggle')],
      key: "_handleFilterGroupViewAllToggle",
      value() {
        return event => {
          const match = this._filterGroupsAllRevealed.findIndex(entry => {
            return entry.id === event.detail.id;
          });
          if (match !== -1) {
            this._filterGroupsAllRevealed[match].value = event.detail.value;
          } else {
            this._filterGroupsAllRevealed = [...this._filterGroupsAllRevealed, event.detail];
          }
        };
      }
    }, {
      kind: "field",
      decorators: [HostListener('document:eventModalClose')],
      key: "modalCloseEvent",
      value() {
        return () => {
          this.openFilterModal = false;
        };
      }
    }, {
      kind: "field",
      decorators: [HostListener('document:eventInputSelect')],
      key: "_handleInputSelectStateChange",
      value() {
        return event => {
          const {
            headerValue
          } = event.detail;
          const {
            stableSelector
          } = C4DFilterPanelInputSelect;
          this._focusElement = `${stableSelector}[header-value="${headerValue}"]`;

          // toggle checkbox in filter panel modal
          this.querySelectorAll(`${c4dPrefix}-filter-panel-input-select`).forEach(e => {
            // Capture the element counterpart in Filter Panel Modal.
            if (e.getAttribute('header-value') === headerValue) {
              const currentGroup = e.closest(`${c4dPrefix}-filter-group-item`);
              currentGroup === null || currentGroup === void 0 || currentGroup.setAttribute('open', '');

              // Clears all other sibling items in the Filter Group
              currentGroup === null || currentGroup === void 0 || currentGroup.querySelectorAll(`${c4dPrefix}-filter-panel-input-select`).forEach(inputSelect => {
                if (inputSelect === e) {
                  return;
                }
                this._selectedValues = this._selectedValues.filter(str => str !== inputSelect.getAttribute('header-value'));
                inputSelect.removeAttribute('selected');
                inputSelect.removeAttribute('is-open');
              });
              e.toggleAttribute('selected');
              e.toggleAttribute('is-open');
            }
          });

          // Toggle value in list.
          if (!this._selectedValues.includes(headerValue)) {
            this._selectedValues = [...this._selectedValues, headerValue];
          } else {
            this._selectedValues = this._selectedValues.filter(e => e !== headerValue);
          }
        };
      }
    }, {
      kind: "field",
      decorators: [HostListener('document:eventHeadingChange')],
      key: "_handleHeadingChange",
      value() {
        return () => {
          this._setHeadingFromSlot(this._headingSlot);
        };
      }
    }, {
      kind: "field",
      decorators: [property({
        type: String,
        reflect: true
      })],
      key: "selectValue",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [HostListener('document:eventSelectionClear')],
      key: "_handleClearSelection",
      value() {
        return () => {
          var _this$shadowRoot2, _this$shadowRoot3, _this$shadowRoot4;
          this._selectedValues = [];

          // Handles clear when clearing from the static filter panel modal.
          this._contents.forEach(group => {
            group.querySelectorAll(`${c4dPrefix}-filter-panel-checkbox`).forEach(e => {
              e.removeAttribute('checked');
            });
            group.querySelectorAll(`${c4dPrefix}-filter-panel-input-select-item`).forEach(e => {
              e.removeAttribute('selected');
              e.removeAttribute('is-open');
            });
            group.querySelectorAll(`${c4dPrefix}-filter-panel-input-select`).forEach(e => {
              e.removeAttribute('selected');
              e.removeAttribute('is-open');
            });
          });

          // handles clear when clearing from the filter panel static
          (_this$shadowRoot2 = this.shadowRoot) === null || _this$shadowRoot2 === void 0 || _this$shadowRoot2.querySelectorAll(`${c4dPrefix}-filter-panel-checkbox`).forEach(e => {
            e.removeAttribute('checked');
          });
          (_this$shadowRoot3 = this.shadowRoot) === null || _this$shadowRoot3 === void 0 || _this$shadowRoot3.querySelectorAll(`${c4dPrefix}-filter-panel-input-select-item`).forEach(e => {
            e.removeAttribute('selected');
            e.removeAttribute('is-open');
          });
          (_this$shadowRoot4 = this.shadowRoot) === null || _this$shadowRoot4 === void 0 || _this$shadowRoot4.querySelectorAll(`${c4dPrefix}-filter-panel-input-select`).forEach(e => {
            e.removeAttribute('selected');
            e.removeAttribute('is-open');
          });
        };
      }
    }, {
      kind: "field",
      decorators: [query('slot[name=heading]')],
      key: "_headingSlot",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean
      })],
      key: "openFilterModal",
      value() {
        return false;
      }
    }, {
      kind: "method",
      key: "_openModal",
      value:
      /**
       * Host listener for handling the state change when a input select item is selected.
       *
       * @param event content state change
       * @private
       */

      /**
       * Host listener for handling the state change when a checkbox is selected.
       *
       * @param event checkbox select event
       * @private
       */

      /**
       * Host listener for caching filter group items' view all states.
       *
       * @param event filter group item view all toggle event
       * @private
       */

      /**
       * handles modal close event
       */

      /**
       * Handles the state change when an input select is selected.
       *
       * @param event title state change
       * @private
       */

      /**
       * selected value property
       */

      /**
       * Event handler for the clearing functionality
       *
       * @private
       */

      /**
       * `true` to open the locale modal.
       */

      /**
       * Sets the open modal to true
       *
       * @private
       */
      function _openModal() {
        this.openFilterModal = true;
      }

      /**
       *
       */
    }, {
      kind: "field",
      decorators: [property()],
      key: "_contents",
      value() {
        return [];
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "_heading",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "_selectedValues",
      value() {
        return [];
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "_filterGroupsAllRevealed",
      value() {
        return [];
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_isMobile",
      value() {
        return this.carbonBreakpoints.lg.matches;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_focusElement",
      value() {
        return null;
      }
    }, {
      kind: "method",
      key: "mediaQueryCallbackMaxLG",
      value:
      /**
       * Sets the heading text, to be composed with the current count.
       */
      /**
       * sets the selected values into an array
       */
      /**
       * stores which filter groups have revealed filters
       */
      /**
       * An element to set focus to on render.
       */
      function mediaQueryCallbackMaxLG() {
        this._isMobile = this.carbonBreakpoints.lg.matches;
      }
    }, {
      kind: "method",
      key: "_querySelectorMobile",
      value: async function _querySelectorMobile(id) {
        return this.querySelector(id);
      }
    }, {
      kind: "method",
      key: "_querySelectorDesktop",
      value: async function _querySelectorDesktop(id) {
        let element;
        if (this.shadowRoot) {
          element = this.shadowRoot.querySelector(id);
        }
        return element;
      }
    }, {
      kind: "method",
      key: "_querySelector",
      value: async function _querySelector(id) {
        const {
          _isMobile
        } = this;
        let element;
        if (_isMobile) {
          element = await this._querySelectorMobile(id);
        } else {
          element = await this._querySelectorDesktop(id);
        }
        return element;
      }

      /**
       * Handles `slotchange` event.
       *
       * @param event The event.
       * @param event.target The event target.
       */
    }, {
      kind: "method",
      key: "_handleSlotChange",
      value: function _handleSlotChange({
        target
      }) {
        this._contents = target.assignedNodes().filter(node => node.nodeType !== Node.TEXT_NODE || node.textContent.trim());
        // Calculate initial this._selectedValues. Look at the first node, which is
        // expected to be <c4d-filter-group>.
        if (this._contents[0] instanceof Element) {
          const items = Array.from(this._contents[0].querySelectorAll(`${c4dPrefix}-filter-panel-checkbox[checked],
            ${c4dPrefix}-filter-panel-input-select[selected],
            ${c4dPrefix}-filter-panel-input-select-item[selected]`));
          this._selectedValues = items.map(item => {
            var _ref, _item$getAttribute;
            return (_ref = (_item$getAttribute = item.getAttribute('value')) !== null && _item$getAttribute !== void 0 ? _item$getAttribute : item.getAttribute('header-value')) !== null && _ref !== void 0 ? _ref : '';
          }).filter(item => !!item);
        }
      }
    }, {
      kind: "method",
      key: "_getComposedHeadingFilterCount",
      value: function _getComposedHeadingFilterCount() {
        const filterCount = this._selectedValues.length > 0 ? ` (${this._selectedValues.length})` : '';
        return `${this._heading}${filterCount}`;
      }

      /**
       * Handles `slotchange` event for the heading slot.
       *
       * @param event The event.
       * @param event.target The event target.
       */
    }, {
      kind: "method",
      key: "_handleHeadingSlotChange",
      value: function _handleHeadingSlotChange({
        target
      }) {
        this._setHeadingFromSlot(target);
      }
    }, {
      kind: "method",
      key: "_setHeadingFromSlot",
      value: function _setHeadingFromSlot(slot) {
        // Clean slate.
        this._heading = '';

        // Work through candidate headings, ultimately we're only interested in the
        // first non-empty node.
        const candidateHeadings = slot.assignedNodes().filter(node => node.nodeType !== Node.TEXT_NODE || node.textContent.trim());

        // If we found something, lets retain it's textContent as the heading.
        if (candidateHeadings.length > 0) {
          this._heading = candidateHeadings[0].textContent ? candidateHeadings[0].textContent.trim() : '';
        }
      }

      /**
       * Renders original content into the modal and listens for changes to this
       * content to then be stored in `this._heading` and `this._contents`.
       */
    }, {
      kind: "field",
      key: "_renderModal",
      value() {
        return () => html(_t || (_t = _`
    <c4d-filter-panel-modal
      part="panel-modal"
      ?open=${0}
      heading="${0}"
      ?has-selections="${0}">
      <slot @slotchange="${0}"></slot>
    </c4d-filter-panel-modal>
  `), this.openFilterModal, this._getComposedHeadingFilterCount(), this._selectedValues.length, this._handleSlotChange);
      }
    }, {
      kind: "field",
      key: "_renderMobile",
      value() {
        return () => html(_t2 || (_t2 = _`
    <cds-button part="button" kind="tertiary" @click=${0}>
      ${0} ${0}
    </cds-button>

    ${0}
  `), this._openModal, this._getComposedHeadingFilterCount(), Filter({
          slot: 'icon'
        }), this._renderModal());
      }
    }, {
      kind: "field",
      key: "_renderDesktop",
      value() {
        return () => html(_t3 || (_t3 = _`
    <c4d-filter-panel
      part="filter-panel"
      heading="${0}"
      ?has-selections="${0}">
      <slot @slotchange="${0}"></slot>
    </c4d-filter-panel>
  `), this._getComposedHeadingFilterCount(), this._selectedValues.length, this._handleSlotChange);
      }
    }, {
      kind: "method",
      key: "render",
      value:
      /**
       * Renders copies of slotted elements into the desktop presentation.
       */
      function render() {
        // Note that the <slot name="heading"> contents, intended to be
        // <c4d-filter-panel-heading> are never shown as is. The text contents
        // are composed, using this._getComposedHeadingFilterCount(), together with
        // the current filter count, and passed as an attribute to
        // <c4d-filter-panel-modal> and <c4d-filter-panel>.
        return html(_t4 || (_t4 = _`
      <slot
        name="heading"
        @slotchange="${0}"></slot>
      ${0}
    `), this._handleHeadingSlotChange, this._isMobile ? this._renderMobile() : this._renderDesktop());
      }
    }, {
      kind: "method",
      key: "updated",
      value: async function updated() {
        const {
          _focusElement
        } = this;
        if (_focusElement) {
          const targetElement = await this._querySelector(_focusElement);
          if (targetElement instanceof HTMLElement) {
            targetElement === null || targetElement === void 0 || targetElement.focus();
          }
          this._focusElement = null;
        }
      }

      /**
       * The name of the custom event captured upon selecting a checkbox
       */
    }, {
      kind: "get",
      static: true,
      key: "eventCheckboxSelect",
      value: function () {
        return `${c4dPrefix}-checkbox-select`;
      }

      /**
       * The name of the custom event captured upon selecting an input select item.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventInputSelectItem",
      value: function () {
        return `${c4dPrefix}-filter-panel-input-select`;
      }

      /**
       * The name of the custom event captured upon activating "view all" button in
       * a filter group item
       */
    }, {
      kind: "get",
      static: true,
      key: "eventFilterGroupViewAllToggle",
      value: function () {
        return `${c4dPrefix}-filter-group-view-all-toggle`;
      }

      /**
       * The name of the custom event captured upon closing the modal
       */
    }, {
      kind: "get",
      static: true,
      key: "eventModalClose",
      value: function () {
        return `${prefix}-modal-beingclosed`;
      }

      /**
       * The name of the custom event capture upon selecting an input select item
       */
    }, {
      kind: "get",
      static: true,
      key: "eventInputSelect",
      value: function () {
        return `${c4dPrefix}-filter-panel-input-select-title`;
      }

      /**
       * The name of the custom event fired to clear selections
       */
    }, {
      kind: "get",
      static: true,
      key: "eventSelectionClear",
      value: function () {
        return `${c4dPrefix}-selection-clear`;
      }

      /**
       * The name of the custom event capture when the heading changes
       */
    }, {
      kind: "get",
      static: true,
      key: "eventHeadingChange",
      value: function () {
        return `${c4dPrefix}-filter-panel-heading-change`;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}-filter-panel-composite`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, MediaQueryMixin(HostListenerMixin(StableSelectorMixin(LitElement)), {
  [MQBreakpoints.LG]: MQDirs.MAX
}));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DFilterPanelComposite;
//# sourceMappingURL=filter-panel-composite.js.map
