import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import Close from '@carbon/web-components/es/icons/close/16.js';
import FocusMixin from '@carbon/web-components/es/globals/mixins/focus.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././filter-panel.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * The container of the input select.
 *
 * @element c4d-filter-panel-input-select
 */
let C4DFilterPanelInputSelect = _decorate([customElement(`${c4dPrefix}-filter-panel-input-select`)], function (_initialize, _FocusMixin) {
  class C4DFilterPanelInputSelect extends _FocusMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DFilterPanelInputSelect,
    d: [{
      kind: "field",
      decorators: [property()],
      key: "ariaLabel",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'is-open',
        type: Boolean,
        reflect: true
      })],
      key: "isOpen",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "title",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'selected',
        type: Boolean,
        reflect: true
      })],
      key: "selected",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "value",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "lastValue",
      value: void 0
    }, {
      kind: "get",
      static: true,
      key: "selectorItem",
      value:
      /**
       * Sets the input selected dropdown to closed
       */

      /**
       * sets the title value to a string
       */

      /**
       * sets the selected value attribute to selected
       */

      /**
       * property for setting the value to a string
       */

      /**
       * targets the last selected item
       */

      function () {
        return `${c4dPrefix}-filter-panel-input-select-item`;
      }

      /**
       *
       * @param event sets the selected value attribute to selected and removes the attribute from the 'lastvalue'
       * @private
       */
    }, {
      kind: "method",
      key: "_handleClickInner",
      value: function _handleClickInner(event) {
        const {
          eventContentStateChange
        } = this.constructor;
        const selected = event.target.closest(this.constructor.selectorItem);
        if (selected.hasAttribute('selected')) {
          selected.removeAttribute('selected');
        } else {
          if (this.lastValue) {
            this.lastValue.removeAttribute('selected');
          }
          this.selected = false;
          this.removeAttribute('selected');
          selected.setAttribute('selected', '');
        }
        this.dispatchEvent(new CustomEvent(eventContentStateChange, {
          bubbles: true,
          composed: true,
          detail: {
            value: selected.getAttribute('value'),
            lastValue: this.lastValue ? this.lastValue.getAttribute('value') : '',
            headerValue: this.headerValue
          }
        }));
        this.lastValue = selected;
      }

      /**
       * Ensures the click header handler gets called upon clicking enter if focused.
       *
       * @param event captures the inputed key
       * @param event.key The event key.
       * @private
       */
    }, {
      kind: "field",
      key: "_handleKeydown",
      value() {
        return ({
          key
        }) => {
          if (key === 'Enter') {
            this._handleClickHeader();
          }
        };
      }
    }, {
      kind: "field",
      key: "_handleKeydownInner",
      value() {
        return event => {
          if (event.key === 'Enter') {
            this._handleClickInner(event);
          }
        };
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "_items",
      value() {
        return [];
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'header-value'
      })],
      key: "headerValue",
      value() {
        return '';
      }
    }, {
      kind: "method",
      key: "_handleClickHeader",
      value:
      /**
       * Ensures the click inner handler gets called upon clicking enter if focused.
       *
       * @param event captures the inputed key
       * @private
       */
      /**
       * sets the input select items to an array
       */
      /**
       * sets header-value attribute to the input selected header
       */
      /**
       * Toggles the input select dropdown and sets the header to selected and sets the value
       *
       * @private
       */
      function _handleClickHeader() {
        const {
          eventInputSelect
        } = this.constructor;
        this.isOpen = !this.isOpen;
        this.selected = !this.selected;
        this.dispatchEvent(new CustomEvent(eventInputSelect, {
          bubbles: true,
          composed: true,
          detail: {
            headerValue: this.headerValue
          }
        }));
      }

      /**
       * Handles `slotchange` event.
       *
       * @param event The event.
       * @param event.target The event target.
       */
    }, {
      kind: "method",
      key: "_handleSlotChange",
      value: function _handleSlotChange({
        target
      }) {
        this._items = target.assignedNodes().filter(node => node.nodeType !== Node.TEXT_NODE || node.textContent.trim());
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated(changedProperties) {
        if (changedProperties.has('selected')) {
          this.ariaLabel = `${this.title}, ${this.selected ? 'selected' : 'unselected'}`;
        }
        if (this._items.length) {
          var _this$shadowRoot;
          (_this$shadowRoot = this.shadowRoot) === null || _this$shadowRoot === void 0 || (_this$shadowRoot = _this$shadowRoot.querySelector(`.${prefix}--input-container__heading`)) === null || _this$shadowRoot === void 0 || _this$shadowRoot.setAttribute('aria-expanded', String(Boolean(this.isOpen)));
        }
        if (this._items.length) {
          var _this$shadowRoot2;
          (_this$shadowRoot2 = this.shadowRoot) === null || _this$shadowRoot2 === void 0 || (_this$shadowRoot2 = _this$shadowRoot2.querySelector(`.${prefix}--input-container__heading`)) === null || _this$shadowRoot2 === void 0 || _this$shadowRoot2.setAttribute('aria-expanded', String(Boolean(this.isOpen)));
        }
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          title
        } = this;
        return html(_t || (_t = _`
      <div class="${0}--input-container" part="container">
        <div
          class="${0}--input-container__heading"
          part="heading"
          tabindex="1"
          @click=${0}
          @keydown=${0}
          aria-controls="content"
          aria-label="${0}"
          role="button">
          ${0}
          <div class="${0}--close__icon" part="icon">
            ${0}
          </div>
        </div>
        <ul
          id="content"
          @click=${0}
          @keydown=${0}
          class="${0} ${0}--selected-option-dropdown"
          part="dropdown">
          <slot @slotchange="${0}"></slot>
        </ul>
      </div>
    `), prefix, prefix, this._handleClickHeader, this._handleKeydown, this.ariaLabel, title, prefix, this.selected && this.isOpen ? Close() : null, this._handleClickInner, this._handleKeydownInner, this.isOpen ? '' : `${prefix}--selected-option-dropdown__hidden`, prefix, this._handleSlotChange);
      }

      /**
       * The name of the custom event fired upon selecting the title
       */
    }, {
      kind: "get",
      static: true,
      key: "eventInputSelect",
      value: function () {
        return `${c4dPrefix}-filter-panel-input-select-title`;
      }

      /**
       * The name of the custom event fired after the search content is changed upon a user gesture.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventContentStateChange",
      value: function () {
        return `${c4dPrefix}-filter-panel-input-select`;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}-filter-panel-input-select`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, FocusMixin(StableSelectorMixin(LitElement)));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DFilterPanelInputSelect;
//# sourceMappingURL=filter-panel-input-select.js.map
