import _decorate from "@babel/runtime/helpers/esm/decorate";
let _2 = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html } from 'lit';
import { property } from 'lit/decorators.js';
import HostListenerMixin from '@carbon/web-components/es/globals/mixins/host-listener.js';
import "./filter-group.js";
import "./filter-modal-button.js";
import "./filter-modal-heading.js";
import C4DExpressiveModal from "../expressive-modal/expressive-modal.js";
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import "./filter-modal-footer.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././filter-panel.css.js";
import '@carbon/web-components/es/components/checkbox/checkbox.js';
import '@carbon/web-components/es/components/modal/modal-close-button.js';
import '@carbon/web-components/es/components/modal/modal-header.js';
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Renders the filter panel modal
 *
 * @element c4d-filter-panel-modal
 * @csspart sentinel-button - Targets all sentinel buttons. Usage: `c4d-filter-panel-modal::part(sentinel-button)`
 * @csspart sentinel-button--start - The Start sentinel button. Usage: `c4d-filter-panel-modal::part(sentinel-button--start)`
 * @csspart sentinel-button--end - The End sentinel button. Usage: `c4d-filter-panel-modal::part(sentinel-button--end)`
 * @csspart section - The filter pannel section. Usage: `c4d-filter-panel-modal::part(section)`
 * @csspart modal-header - The modal header. Usage: `c4d-filter-panel-modal::part(modal-header)`
 * @csspart modal-close-button - The modal clode button. Usage: `c4d-filter-panel-modal::part(modal-close-button)`
 * @csspart modal-heading - The modal heading. Usage: `c4d-filter-panel-modal::part(modal-heading)`
 * @csspart modal-body - The modal body. Usage: `c4d-filter-panel-modal::part(modal-body)`
 * @csspart modal-footer - The modal footer button. Usage: `c4d-filter-panel-modal::part(modal-footer)`
 * @csspart modal-footer-button - Targets all modal footer buttons. Usage: `c4d-filter-panel-modal::part(modal-footer-button)`
 * @csspart modal-footer-button--clear - The clear modal footer button. Usage: `c4d-filter-panel-modal::part(modal-footer-button--clear)`
 * @csspart modal-footer-button--close - The close modal footer button. Usage: `c4d-filter-panel-modal::part(modal-footer-button--close)`
 */
let C4DFilterPanelModal = _decorate([customElement(`${c4dPrefix}-filter-panel-modal`)], function (_initialize, _HostListenerMixin) {
  class C4DFilterPanelModal extends _HostListenerMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DFilterPanelModal,
    d: [{
      kind: "field",
      decorators: [property()],
      key: "selectedValues",
      value() {
        return [];
      }
    }, {
      kind: "method",
      key: "_handleContentStateChange",
      value:
      /**
       * Renders the selected values.
       */

      // eslint-disable-next-line class-methods-use-this, @typescript-eslint/no-unused-vars
      function _handleContentStateChange(_) {}

      /**
       * Handles `click` event on the `<input>` in the shadow DOM.
       */
    }, {
      kind: "method",
      key: "_handleClear",
      value: function _handleClear() {
        const {
          eventSelectionClear
        } = this.constructor;
        this.dispatchEvent(new CustomEvent(eventSelectionClear, {
          bubbles: true,
          composed: true,
          detail: {
            clear: true
          }
        }));
      }

      /**
       * Handles items in the selected array
       */
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'has-selections',
        type: Boolean
      })],
      key: "hasSelections",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "heading",
      value: void 0
    }, {
      kind: "method",
      key: "_handleUserClose",
      value:
      /**
       * Renders the filter heading
       */
      /**
       * Handles user-initiated close request of this modal.
       *
       * @param triggeredBy The element that triggered this close request.
       */
      function _handleUserClose(triggeredBy) {
        if (this.open) {
          const init = {
            bubbles: true,
            cancelable: true,
            composed: true,
            detail: {
              triggeredBy
            }
          };
          if (this.dispatchEvent(new CustomEvent(this.constructor.eventBeforeClose, init))) {
            this.open = false;
            this.dispatchEvent(new CustomEvent(this.constructor.eventClose, init));
          }
        }
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          _handleFocusIn: handleFocusIn
        } = this;
        return html(_t || (_t = _2`
      <button
        id="start-sentinel"
        class="${0}--visually-hidden"
        part="sentinel-button sentinel-button--start"
        @focusin="${0}">
        START
      </button>
      <section
        class="${0}--filter-panel__section ${0}--modal-container"
        part="section">
        <cds-modal-header part="modal-header">
          <cds-modal-close-button
            part="modal-close-button"
            @click=${0}></cds-modal-close-button>
          <c4d-filter-modal-heading part="modal-heading"
            >${0}</c4d-filter-modal-heading
          >
        </cds-modal-header>
        <div class="${0}--modal-body" part="modal-body"><slot></slot></div>
        <c4d-filter-modal-footer part="modal-footer">
          <c4d-filter-modal-footer-button
            part="modal-footer-button modal-footer-button--clear"
            ?disabled="${0}"
            @click=${0}
            kind="secondary"
            >Clear</c4d-filter-modal-footer-button
          >
          <c4d-filter-modal-footer-button
            part="modal-footer-button modal-footer-button--close"
            @click=${0}
            kind="primary"
            >See Results</c4d-filter-modal-footer-button
          >
        </c4d-filter-modal-footer>
      </section>
      <button
        id="end-sentinel"
        class="${0}--visually-hidden"
        part="sentinel-button sentinel-button--end"
        @focusin="${0}">
        END
      </button>
    `), prefix, handleFocusIn, prefix, prefix, this._handleUserClose, this.heading, prefix, !this.hasSelections, this._handleClear, this._handleUserClose, prefix, handleFocusIn);
      }

      /**
       * The name of the custom event fired upon the modal being closed
       */
    }, {
      kind: "get",
      static: true,
      key: "eventBeforeClose",
      value: function () {
        return `${prefix}-modal-beingclosed`;
      }

      /**
       * The name of the custom event captured upon cleared selections
       */
    }, {
      kind: "get",
      static: true,
      key: "eventSelectionClear",
      value: function () {
        return `${c4dPrefix}-selection-clear`;
      }

      /**
       * The name of the heading selector
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorHeading",
      value: function () {
        return `${c4dPrefix}-filter-panel-heading`;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}-filter-panel-modal`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, HostListenerMixin(StableSelectorMixin(C4DExpressiveModal)));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DFilterPanelModal;
//# sourceMappingURL=filter-panel-modal.js.map
