import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import Reset from '@carbon/web-components/es/icons/reset/16.js';
import HostListenerMixin from '@carbon/web-components/es/globals/mixins/host-listener.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././filter-panel.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * The filter panel.
 *
 * @element c4d-filter-panel
 * @csspart section - The filter panel section. Usage: `c4d-filter-panel::part(section)`
 * @csspart heading-clear - Contains the filter heading an the button. Usage: `c4d-filter-panel::part(heading-clear)`
 * @csspart filter-heading - The heading. Usage: `c4d-filter-panel::part(filter-heading)`
 * @csspart button-clear - The button. Usage: `c4d-filter-panel::part(button-clear)`
 * @csspart container - The button inner container. Usage: `c4d-filter-panel::part(container)`
 * @csspart icon - The button icon. Usage: `c4d-filter-panel::part(icon)`
 */
let C4DFilterPanel = _decorate([customElement(`${c4dPrefix}-filter-panel`)], function (_initialize, _HostListenerMixin) {
  class C4DFilterPanel extends _HostListenerMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DFilterPanel,
    d: [{
      kind: "field",
      decorators: [property()],
      key: "heading",
      value: void 0
    }, {
      kind: "method",
      key: "_handleClear",
      value:
      /**
       * Renders the filter heading
       */

      /**
       * Handles `click` event on the `<input>` in the shadow DOM.
       */
      function _handleClear() {
        const {
          eventSelectionClear
        } = this.constructor;
        this.dispatchEvent(new CustomEvent(eventSelectionClear, {
          bubbles: true,
          composed: true,
          detail: {
            clear: true
          }
        }));
      }

      /**
       * the filter title
       */
    }, {
      kind: "field",
      decorators: [property()],
      key: "title",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "selectedValues",
      value() {
        return [];
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'has-selections',
        type: Boolean
      })],
      key: "hasSelections",
      value() {
        return false;
      }
    }, {
      kind: "method",
      key: "render",
      value:
      /**
       * renders the selected values
       */
      /**
       * Handles items in the selected array
       */
      function render() {
        return html(_t || (_t = _`
      <section class="${0}--filter-panel__section" part="section">
        <div class="${0}--heading-clear" part="heading-clear">
          <div class="${0}--filter__heading" part="filter-heading">
            ${0}
          </div>
          <button
            class="${0}--clear"
            part="button-clear"
            @click=${0}
            ?disabled="${0}">
            <div class="${0}--clear__container" part="container">
              Clear
              <div class="${0}--reset__icon" part="icon">${0}</div>
            </div>
          </button>
        </div>
        <slot></slot>
      </section>
    `), prefix, prefix, prefix, this.heading, prefix, this._handleClear, !this.hasSelections, prefix, prefix, Reset());
      }

      /**
       * The name of the custom event fired to clear selections
       */
    }, {
      kind: "get",
      static: true,
      key: "eventSelectionClear",
      value: function () {
        return `${c4dPrefix}-selection-clear`;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}-filter-panel`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, HostListenerMixin(StableSelectorMixin(LitElement)));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DFilterPanel;
//# sourceMappingURL=filter-panel.js.map
