import _decorate from "@babel/runtime/helpers/esm/decorate";
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import pickBy from 'lodash-es/pickBy.js';
import { bindActionCreators } from 'redux';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import ConnectMixin from "../../globals/mixins/connect.js";
import store from '../../internal/vendor/@carbon/ibmdotcom-services-store/store.js';
import { loadLanguage, setLanguage, loadLocaleList, setLocaleList } from '../../internal/vendor/@carbon/ibmdotcom-services-store/actions/localeAPI.js';
import { loadTranslation, setTranslation } from '../../internal/vendor/@carbon/ibmdotcom-services-store/actions/translateAPI.js';
import C4DFooterComposite from "./footer-composite.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * The Redux actions used for `<c4d-footer-container>`.
 */

/**
 * The Redux state used for `<c4d-footer-container>`.
 */

/**
 * The properties for `<c4d-footer-container>` from Redux state.
 */

/**
 * @param state The Redux state for masthead.
 * @returns The converted version of the given state, tailored for `<c4d-footer-container>`.
 */
export function mapStateToProps(state) {
  var _translations$languag, _translations$languag2;
  const {
    localeAPI,
    translateAPI
  } = state;
  const {
    language,
    localeLists
  } = localeAPI !== null && localeAPI !== void 0 ? localeAPI : {};
  const {
    translations
  } = translateAPI !== null && translateAPI !== void 0 ? translateAPI : {};
  return pickBy({
    localeList: !language ? undefined : localeLists === null || localeLists === void 0 ? void 0 : localeLists[language],
    links: !language ? undefined : translations === null || translations === void 0 || (_translations$languag = translations[language]) === null || _translations$languag === void 0 ? void 0 : _translations$languag.footerMenu,
    legalLinks: !language ? undefined : translations === null || translations === void 0 || (_translations$languag2 = translations[language]) === null || _translations$languag2 === void 0 ? void 0 : _translations$languag2.footerThin
  }, value => value !== undefined);
}

/**
 * @param dispatch The Redux `dispatch()` API.
 * @returns The methods in `<c4d-footer-container>` to dispatch Redux actions.
 */
export function mapDispatchToProps(dispatch) {
  return bindActionCreators({
    _loadLanguage: loadLanguage,
    _setLanguage: setLanguage,
    _loadLocaleList: loadLocaleList,
    _setLocaleList: setLocaleList,
    _loadTranslation: loadTranslation,
    _setTranslation: setTranslation
  }, dispatch // TS definition of `bindActionCreators()` seems to have no templated `Dispatch`
  );
}

/**
 * Container component for masthead.
 *
 * @element c4d-footer-container
 */
let C4DFooterContainer = _decorate([customElement(`${c4dPrefix}-footer-container`)], function (_initialize, _ConnectMixin) {
  class C4DFooterContainer extends _ConnectMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DFooterContainer,
    d: []
  };
}, ConnectMixin(store, mapStateToProps, mapDispatchToProps)(C4DFooterComposite));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DFooterContainer;
//# sourceMappingURL=footer-container.js.map
