import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2,
  _t3;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property, state } from 'lit/decorators.js';
import ChevronRight16 from '@carbon/web-components/es/icons/chevron--right/16.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import MediaQueryMixin, { MQBreakpoints, MQDirs } from "../../component-mixins/media-query/media-query.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././footer.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Footer nav group.
 *
 * @element c4d-footer-nav-group
 * @csspart nav-group-title - The nav group title. Usage: `c4d-footer-nav::part(nav-group-title)`
 * @csspart accordion-heading - The accordion nav heading. Usage: `c4d-footer-nav::part(accordion-heading)`
 * @csspart accordion-title - The accordion title. Usage: `c4d-footer-nav::part(accordion-title)`
 * @csspart accordion-content - The accordion content. Usage: `c4d-footer-nav::part(accordion-content)`
 * @csspart link-list - The list of links. Usage: `c4d-footer-nav-group::part(link-list)`
 * @slot title - The title content.
 */
let C4DFooterNavGroup = _decorate([customElement(`${c4dPrefix}-footer-nav-group`)], function (_initialize, _MediaQueryMixin) {
  class C4DFooterNavGroup extends _MediaQueryMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DFooterNavGroup,
    d: [{
      kind: "field",
      decorators: [state()],
      key: "_isMediumOrGreater",
      value() {
        return this.carbonBreakpoints.md.matches;
      }
    }, {
      kind: "method",
      key: "mediaQueryCallbackMD",
      value: function mediaQueryCallbackMD() {
        this._isMediumOrGreater = this.carbonBreakpoints.md.matches;
      }

      /**
       * Handles user-initiated toggle request of this accordion item.
       *
       * @param open The new open state.
       */
    }, {
      kind: "method",
      key: "_handleUserInitiatedToggle",
      value: function _handleUserInitiatedToggle(open = !this.open) {
        const {
          eventBeforeToggle,
          eventToggle
        } = this.constructor;
        const init = {
          bubbles: true,
          cancelable: true,
          composed: true,
          detail: {
            open
          }
        };
        if (this.dispatchEvent(new CustomEvent(eventBeforeToggle, init))) {
          this.open = open;
          this.dispatchEvent(new CustomEvent(eventToggle, init));
        }
      }

      /**
       * Handles the `click` event on the expando button.
       */
    }, {
      kind: "method",
      key: "_handleClickExpando",
      value: function _handleClickExpando() {
        this._handleUserInitiatedToggle();
      }

      /**
       * Handles the `keydown` event on the expando button.
       *
       * @param event The event.
       * @param event.key The event key.
       */
    }, {
      kind: "field",
      key: "_handleKeydownExpando",
      value() {
        return ({
          key
        }) => {
          if (this.open && (key === 'Esc' || key === 'Escape')) {
            this._handleUserInitiatedToggle(false);
          }
        };
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true
      })],
      key: "open",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'title-text'
      })],
      key: "titleText",
      value() {
        return '';
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value:
      /**
       * `true` if the check box should be open.
       */
      /**
       * The title text.
       */
      function connectedCallback() {
        if (!this.hasAttribute('role')) {
          this.setAttribute('role', 'listitem');
        }
        _superPropGet(C4DFooterNavGroup, "connectedCallback", this, 3)([]);
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          titleText,
          open,
          _isMediumOrGreater: isMediumOrGreater,
          _handleClickExpando: handleClickExpando,
          _handleKeydownExpando: handleKeydownExpando
        } = this;
        const heading = isMediumOrGreater ? html(_t || (_t = _`
          <h2 part="nav-group-title" class="${0}--footer-nav-group__title">
            <slot name="title">${0}</slot>
          </h2>
        `), prefix, titleText) : html(_t2 || (_t2 = _`
          <button
            part="accordion-heading"
            type="button"
            class="${0}--accordion__heading"
            aria-controls="content"
            aria-expanded="${0}"
            @click="${0}"
            @keydown="${0}">
            ${0}
            <div part="accordion-title" class="${0}--accordion__title">
              <slot name="title">${0}</slot>
            </div>
          </button>
        `), prefix, String(Boolean(open)), handleClickExpando, handleKeydownExpando, ChevronRight16({
          class: `${prefix}--accordion__arrow`
        }), prefix, titleText);
        return html(_t3 || (_t3 = _`
      ${0}
      <div
        part="accordion-content"
        id="content"
        class="${0}--accordion__content">
        <ul part="link-list">
          <slot></slot>
        </ul>
      </div>
    `), heading, prefix);
      }

      /**
       * The name of the custom event fired before this accordion item is being toggled upon a user gesture.
       * Cancellation of this event stops the user-initiated action of toggling this accordion item.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventBeforeToggle",
      value: function () {
        return `${c4dPrefix}-footer-nav-group-beingtoggled`;
      }

      /**
       * The name of the custom event fired after this accordion item is toggled upon a user gesture.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventToggle",
      value: function () {
        return `${c4dPrefix}-footer-nav-group-toggled`;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--footer-nav-group`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, MediaQueryMixin(StableSelectorMixin(LitElement), {
  [MQBreakpoints.MD]: MQDirs.MIN
}));
export default C4DFooterNavGroup;
//# sourceMappingURL=footer-nav-group.js.map
