import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import { classMap } from 'lit/directives/class-map.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { FOOTER_SIZE } from "./defs.js";
import styles from "././footer.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
export { FOOTER_SIZE };
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * The top-level element in footer.
 *
 * @element c4d-footer
 * @csspart main-section - The <section> container. Usage: `c4d-footer::part(main-section)`
 * @csspart main-container - The main container. Usage: `c4d-footer::part(main-container)`
 * @csspart logo-container - The logo container. Usage: `c4d-footer::part(logo-container)`
 * @csspart logo-row - The logo row. Usage: `c4d-footer::part(logo-row)`
 * @slot brand - The brand content.
 * @slot legal-nav - The legal nav content.
 * @slot locale-button - The locale button content.
 */
let C4DFooter = _decorate([customElement(`${c4dPrefix}-footer`)], function (_initialize, _StableSelectorMixin) {
  class C4DFooter extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DFooter,
    d: [{
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "size",
      value() {
        return FOOTER_SIZE.REGULAR;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        attribute: 'disable-locale-button'
      })],
      key: "disableLocaleButton",
      value() {
        return false;
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value:
      /**
       * Footer size.
       */

      /**
       * Update the CSS selectors depending on the locale button being rendered or not.
       */

      function connectedCallback() {
        this.setAttribute('role', 'contentinfo');
        if (!this.hasAttribute('aria-label')) {
          this.setAttribute('aria-label', 'footer');
        }
        _superPropGet(C4DFooter, "connectedCallback", this, 3)([]);
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          disableLocaleButton
        } = this;
        const classes = {
          [`${prefix}--footer__logo-container`]: true,
          [`${prefix}--footer__locale-button--disabled`]: disableLocaleButton
        };
        return html(_t || (_t = _`
      <section part="main-section" class="${0}--footer__main">
        <div part="main-container" class="${0}--footer__main-container">
          <div part="logo-container" class=${0}>
            <div part="logo-row" class="${0}--footer__logo-row">
              <slot name="brand"></slot>
              <slot name="locale-button"></slot>
              <slot name="language-selector"></slot>
              <slot></slot>
            </div>
          </div>
        </div>
      </section>
      <slot name="legal-nav"></slot>
    `), prefix, prefix, classMap(classes), prefix);
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--footer`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
export default C4DFooter;
//# sourceMappingURL=footer.js.map
