import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { property, query, state } from 'lit/decorators.js';
import HostListener from '@carbon/web-components/es/globals/decorators/host-listener.js';
import HostListenerMixin from '@carbon/web-components/es/globals/mixins/host-listener.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import { LANGUAGE_SELECTOR_STYLE_SCHEME } from "./defs.js";
import C4DComboBox from "./combo-box.js";
import styles from "././footer.css.js";
import { findIndex, forEach } from "../../globals/internal/collection-helpers.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Language selector component - desktop.
 * The API for language selection is still subject to change.
 *
 * @element c4d-language-selector-desktop
 */
let C4DLanguageSelectorDesktop = _decorate([customElement(`${c4dPrefix}-language-selector-desktop`)], function (_initialize, _HostListenerMixin) {
  class C4DLanguageSelectorDesktop extends _HostListenerMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLanguageSelectorDesktop,
    d: [{
      kind: "field",
      decorators: [state()],
      key: "_lastValidLang",
      value: void 0
    }, {
      kind: "field",
      decorators: [query('input')],
      key: "_filterInputNode",
      value: void 0
    }, {
      kind: "field",
      decorators: [HostListener('document:click')],
      key: "_handleClickOutside",
      value() {
        return event => {
          if (!this.contains(event.target)) {
            this._filterInputValue = this._lastValidLang;
            this._filterInputNode.value = this._lastValidLang;
            this.open = false;
            this.requestUpdate(); // If the only change is to `_filterInputValue`, auto-update doesn't happen
          }
        };
      }
    }, {
      kind: "method",
      key: "_handleInput",
      value:
      /**
       * Property that saves the last valid language to use on reset cases.
       */

      /**
       * The `<input>` for filtering.
       */

      /**
       * Reverts input value to last chosen valid language.
       *
       * @param event the event
       */

      /**
       * Handles `input` event on the `<input>` for filtering.
       * Highlights and scrolls into the view the matched item.
       */
      function _handleInput() {
        const items = this.querySelectorAll(this.constructor.selectorItem);
        const index = !this._filterInputNode.value ? -1 : findIndex(items, this._testItemWithQueryText, this);
        forEach(items, (item, i) => {
          if (i === index) {
            item.scrollIntoView();
          }
          item.highlighted = i === index;
        });
        const {
          _filterInputNode: filterInput
        } = this;
        this._filterInputValue = !filterInput ? '' : filterInput.value;
        this.open = true;
        this.requestUpdate(); // If the only change is to `_filterInputValue`, auto-update doesn't happen
      }

      /**
       * Handles user-initiated clearing the `<input>` for filtering.
       * Also saves the current valid language.
       */
    }, {
      kind: "method",
      key: "_handleUserInitiatedClearInput",
      value: function _handleUserInitiatedClearInput() {
        forEach(this.querySelectorAll(this.constructor.selectorItem), item => {
          item.highlighted = false;
          item.selected = false;
        });
        this._lastValidLang = this._filterInputValue;
        this._filterInputValue = '';
        this._filterInputNode.focus();
        this.open = false;
        this.requestUpdate();
      }

      /**
       * Updates the input and last valid language to the selected item text.
       *
       * @param item that was selected
       */
    }, {
      kind: "method",
      key: "_handleUserInitiatedSelectItem",
      value: function _handleUserInitiatedSelectItem(item) {
        if (item && !this._selectionShouldChange(item)) {
          // Escape hatch for `shouldUpdate()` logic that updates `._filterInputValue()` when selection changes,
          // given we want to update the `<input>` and close the dropdown even if selection doesn't update.
          // Use case:
          // 1. Select the 2nd item in combo box drop down
          // 2. Type some text in the `<input>`
          // 3. Re-select the 2nd item in combo box drop down,
          //    the `<input>` has to updated with the 2nd item and the dropdown should be closed,
          //    even if there is no change in the selected value
          this._filterInputValue = item.textContent || '';
          this.open = false;
          this.requestUpdate();
        }
        this._lastValidLang = item === null || item === void 0 ? void 0 : item.textContent;
        item.selected = true;
        _superPropGet(C4DLanguageSelectorDesktop, "_handleUserInitiatedSelectItem", this, 3)([item]);
      }

      /**
       * Size property to apply different styles.
       */
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'style-scheme'
      })],
      key: "styleScheme",
      value() {
        return LANGUAGE_SELECTOR_STYLE_SCHEME.REGULAR;
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "slot",
      value() {
        return 'language-selector';
      }
    }, {
      kind: "method",
      key: "updated",
      value:
      /**
       * The shadow slot this language-selector should be in.
       */
      function updated(changedProperties) {
        _superPropGet(C4DLanguageSelectorDesktop, "updated", this, 3)([changedProperties]);
        if (changedProperties.has('value')) {
          this._lastValidLang = this.value;
        }
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, HostListenerMixin(C4DComboBox));
export default C4DLanguageSelectorDesktop;
//# sourceMappingURL=language-selector-desktop.js.map
