import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { state } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././footer.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Legal nav item, working as a placeholder for cookie perference link.
 *
 * @element c4d-legal-nav-cookie-preferences-placeholder
 * @csspart legal-nav-cookie-preferences - The legal nav cookie preferences container. Usage: `c4d-legal-nav-cookie-preferences-placeholder::part(legal-nav-cookie-preferences)`
 */
let C4DLegalNavCookiePreferencesPlaceholder = _decorate([customElement(`${c4dPrefix}-legal-nav-cookie-preferences-placeholder`)], function (_initialize, _StableSelectorMixin) {
  class C4DLegalNavCookiePreferencesPlaceholder extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLegalNavCookiePreferencesPlaceholder,
    d: [{
      kind: "field",
      decorators: [state()],
      key: "_hasCookies",
      value() {
        return false;
      }
    }, {
      kind: "method",
      key: "_handleSlotChange",
      value:
      /**
       * `true` if there is cookie content.
       */

      /**
       * Handles `slotchange` event.
       */
      function _handleSlotChange(event) {
        // Finds new injected links
        const linkNodes = event.target.assignedNodes().filter(node => node.tagName === 'A');
        linkNodes.forEach(node => {
          // Adds Carbon CSS classes
          node.classList.add(`${prefix}--link`);
          node.classList.add(`${prefix}--footer__link`);
          // Moves new injected links to shadow DOM
          this.shadowRoot.appendChild(node);
        });
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          _handleSlotChange: handleSlotchange,
          _hasCookies: hasCookies
        } = this;
        return html(_t || (_t = _`
      <div part="legal-nav-cookie-preferences" ?hidden="${0}">
        <slot @slotchange="${0}"></slot>
      </div>
    `), !hasCookies, handleSlotchange);
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--privacy-cp`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
export default C4DLegalNavCookiePreferencesPlaceholder;
//# sourceMappingURL=legal-nav-cookie-preferences-placeholder.js.map
