import _decorate from "@babel/runtime/helpers/esm/decorate";
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { property } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import C4DFooterNavItem from "./footer-nav-item.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Legal nav item.
 *
 * @element c4d-legal-nav-item
 */
let C4DLegalNavItem = _decorate([customElement(`${c4dPrefix}-legal-nav-item`)], function (_initialize, _C4DFooterNavItem) {
  class C4DLegalNavItem extends _C4DFooterNavItem {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLegalNavItem,
    d: [{
      kind: "field",
      decorators: [property()],
      key: "autoid",
      value() {
        return '';
      }
    }, {
      kind: "method",
      key: "updated",
      value:
      /**
       * autoid text.
       */

      function updated() {
        const {
          _linkNode: linkNode
        } = this;
        if (linkNode) {
          var _this$autoid;
          const dataTitle = (_this$autoid = this.autoid) === null || _this$autoid === void 0 ? void 0 : _this$autoid.replace(/[^-a-zA-Z0-9_ ]/g, '').replace(/ +/g, '-').toLowerCase();
          linkNode.classList.add(`${prefix}--footer__link`);
          linkNode.setAttribute('data-autoid', `${c4dPrefix}--footer-legal-nav__link-${dataTitle}`);
        }
      }
    }]
  };
}, C4DFooterNavItem);
export default C4DLegalNavItem;
//# sourceMappingURL=legal-nav-item.js.map
