import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property, query, state } from 'lit/decorators.js';
import { classMap } from 'lit/directives/class-map.js';
import { ifDefined } from 'lit/directives/if-defined.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import { FOOTER_SIZE } from "./footer.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././footer.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Legal nav.
 *
 * @element c4d-legal-nav
 * @csspart legal-nav - The <nav> container. Usage: `c4d-legal-nav::part(legal-nav)`
 * @csspart legal-nav-list-container - The legal nav list container. Usage: `c4d-legal-nav::part(legal-nav-list-container)`
 * @csspart legal-nav-list - The list of links. Usage: `c4d-legal-nav::part(legal-nav-list)`
 * @csspart adjunct-links-list - The list of adjunct links. Usage: `c4d-legal-nav::part(adjunct-links-list)`
 * @csspart adjunct-links-container - The adjunct links container. Usage: `c4d-legal-nav::part(adjunct-links-container)`
 * @csspart legal-nav-items-container - The legal nav items container. Usage: `c4d-legal-nav::part(legal-nav-items-container)`
 */
let C4DLegalNav = _decorate([customElement(`${c4dPrefix}-legal-nav`)], function (_initialize, _StableSelectorMixin) {
  class C4DLegalNav extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLegalNav,
    d: [{
      kind: "field",
      decorators: [property()],
      key: "size",
      value() {
        return FOOTER_SIZE.REGULAR;
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "navLabel",
      value() {
        return 'Legal Navigation';
      }
    }, {
      kind: "field",
      decorators: [query('[name="adjunct-links"]')],
      key: "_adjunctLinksSlot",
      value: void 0
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasAdjunctLinks",
      value() {
        return false;
      }
    }, {
      kind: "method",
      key: "_getTypeClass",
      value:
      /**
       * Size property used for applying classes
       */

      /**
       * Navigation label for accessibility.
       */

      /**
       * The adjunct links slot
       */

      /**
       * Returns a class-name based on the type parameter type
       */
      function _getTypeClass() {
        return classMap({
          [`${c4dPrefix}--legal-nav__list`]: true,
          [`${c4dPrefix}--legal-nav__micro`]: this.size === FOOTER_SIZE.MICRO
        });
      }

      /**
       * Handles slot change event of adjunct-links slot to track if there are any.
       */
    }, {
      kind: "field",
      key: "_handleAdjunctLinksVisibility",
      value() {
        return () => {
          const {
            _adjunctLinksSlot: adjunctLinksSlot
          } = this;
          this._hasAdjunctLinks = ((adjunctLinksSlot === null || adjunctLinksSlot === void 0 ? void 0 : adjunctLinksSlot.assignedNodes().length) || 0) !== 0;
        };
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "slot",
      value() {
        return 'legal-nav';
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value:
      /**
       * The shadow slot this legal nav should be in.
       */
      function connectedCallback() {
        if (this.hasAttribute('role')) {
          this.removeAttribute('role');
        }
        _superPropGet(C4DLegalNav, "connectedCallback", this, 3)([]);
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        const {
          _adjunctLinksSlot: adjunctLinksSlot
        } = this;
        this._hasAdjunctLinks = ((adjunctLinksSlot === null || adjunctLinksSlot === void 0 ? void 0 : adjunctLinksSlot.assignedNodes().length) || 0) !== 0;
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          navLabel,
          _hasAdjunctLinks: hasAdjunctLinks
        } = this;
        return this.size !== FOOTER_SIZE.MICRO ? html(_t || (_t = _`
          <nav
            part="legal-nav"
            class="${0}--legal-nav"
            aria-label="${0}">
            <div
              part="legal-nav-list-container"
              class="${0}">
              <ul part="legal-nav-list">
                <slot></slot>
              </ul>
              <slot name="locale"></slot>
            </div>
            <div
              part="adjunct-links-container"
              class="${0}--adjunct-links__container${0}">
              <ul part="adjunct-links-list adjunct-links-list">
                <slot
                  name="adjunct-links"
                  @slotchange="${0}"></slot>
              </ul>
            </div>
          </nav>
        `), c4dPrefix, ifDefined(navLabel), this._getTypeClass(), c4dPrefix, hasAdjunctLinks ? '' : ` ${c4dPrefix}--adjunct-links__container--hidden`, this._handleAdjunctLinksVisibility) : html(_t2 || (_t2 = _`
          <nav part="legal-nav" class="${0}--legal-nav">
            <div
              part="legal-nav-list-container"
              class="${0}">
              <div part="legal-nav-items-container">
                <slot name="brand"></slot>
                <ul part="legal-nav-list">
                  <slot></slot>
                </ul>
              </div>
              <slot name="locale"></slot>
            </div>
          </nav>
        `), c4dPrefix, this._getTypeClass());
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--footer-legal-nav`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
export default C4DLegalNav;
//# sourceMappingURL=legal-nav.js.map
