import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4,
  _t5;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2019, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property, query } from 'lit/decorators.js';
import { baseFontSize, breakpoints } from '@carbon/layout';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././global-banner.css.js";
import StickyHeader from '@carbon/ibmdotcom-utilities/es/utilities/StickyHeader/StickyHeader.js';
import { icons as ctaIcons } from "../../component-mixins/cta/cta.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const gridLgBreakpoint = parseFloat(breakpoints.lg.width) * baseFontSize;
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Global banner
 *
 * @element c4d-global-banner
 * @csspart container - Targets all container elements. Usage: `c4d-global-banner::part(container)`
 * @csspart container--static - Container for Static type. Usage: `c4d-global-banner::part(container--static)`
 * @csspart container--link - Container for Link type. Usage: `c4d-global-banner::part(container--link)`
 * @csspart content - The content. Usage: `c4d-global-banner::part(content)`
 * @csspart image-container -  The image container. Usage: `c4d-global-banner::part(image-container)`
 * @csspart text-container - The text container. Usage: `c4d-global-banner::part(text-container)`
 * @csspart cta-container - The CTA container. Usage: `c4d-global-banner::part(cta-container)`
 * @csspart icon - The icon. Usage: `c4d-global-banner::part(icon)`
 */
let C4DGlobalBanner = _decorate([customElement(`${c4dPrefix}-global-banner`)], function (_initialize, _StableSelectorMixin) {
  class C4DGlobalBanner extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DGlobalBanner,
    d: [{
      kind: "field",
      decorators: [property()],
      key: "buttonHref",
      value: void 0
    }, {
      kind: "field",
      decorators: [property()],
      key: "ctaType",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'has-image',
        reflect: true,
        type: Boolean
      })],
      key: "hasImage",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'image-width',
        reflect: true,
        type: String
      })],
      key: "imageWidth",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean
      })],
      key: "_shouldRenderAsLink",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [query(`.${prefix}--global-banner-layout-container`)],
      key: "_linkWrapper",
      value: void 0
    }, {
      kind: "method",
      key: "_handleImageSlotChange",
      value:
      /**
       * Saves the button CTA's href to use in link-with-icon for the small breakpoint
       */

      /**
       * Saves the button CTA's type to properly set the icon at `sm` and `md` breakpoints.
       */

      /**
       * `true` if there is an image.
       */

      /**
       * Grid media options to display image.
       * Available options are either '4-col' or '8-col'.
       */

      /**
       * Handles `slotchange` event on the cta `<slot>`.
       */
      function _handleImageSlotChange({
        target
      }) {
        this.hasImage = target.assignedNodes().some(node => node.nodeType !== Node.TEXT_NODE || node.textContent.trim());
        if (this.hasImage && !this.imageWidth) {
          this.imageWidth = '4-col';
        }
      }

      /**
       * Handles `slotchange` event on the cta `<slot>`.
       */
    }, {
      kind: "method",
      key: "_handleButtonSlotChange",
      value: function _handleButtonSlotChange({
        target
      }) {
        var _hasContent$, _hasContent$2;
        const hasContent = target.assignedNodes().filter(elem => {
          var _matches, _ref;
          return (_matches = (_ref = elem).matches) === null || _matches === void 0 ? void 0 : _matches.call(_ref, this.constructor.ctaButton);
        });
        this.buttonHref = (_hasContent$ = hasContent[0]) === null || _hasContent$ === void 0 ? void 0 : _hasContent$.getAttribute('href');
        this.ctaType = (_hasContent$2 = hasContent[0]) === null || _hasContent$2 === void 0 ? void 0 : _hasContent$2.ctaType;
      }
    }, {
      kind: "method",
      key: "_handleResize",
      value: function _handleResize() {
        const {
          _breakpoint: breakpoint
        } = this;
        this._shouldRenderAsLink = !breakpoint.matches;
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        StickyHeader.global.banner = this;
        this._breakpoint = window.matchMedia(`(min-width: ${gridLgBreakpoint}px)`);
        this._breakpoint.addEventListener('change', this._handleResize.bind(this));
        this._handleResize();
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value: function connectedCallback() {
        if (!this.hasAttribute('role')) {
          this.setAttribute('role', 'banner');
        }
        _superPropGet(C4DGlobalBanner, "connectedCallback", this, 3)([]);
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated(changedProperties) {
        if (changedProperties.has('_shouldRenderAsLink')) {
          const {
            _shouldRenderAsLink: shouldRenderAsLink,
            ctaType
          } = this;
          if (shouldRenderAsLink && ctaType === 'external') {
            setTimeout(() => {
              this._linkWrapper.setAttribute('target', '_blank');
            }, 0);
          }
        }
      }

      /**
       * Renders shadow dom within a static div
       */
    }, {
      kind: "method",
      key: "_renderAsStatic",
      value: function _renderAsStatic() {
        return html(_t || (_t = _`
      <div
        class="${0}--global-banner-layout-container"
        part="container container--static">
        ${0}
      </div>
    `), prefix, this._renderInnerContents());
      }
    }, {
      kind: "method",
      key: "_renderAsLink",
      value: function _renderAsLink() {
        return html(_t2 || (_t2 = _`
      <a
        href="${0}"
        class="${0}--global-banner-layout-container"
        part="container container--link">
        ${0}
      </a>
    `), this.buttonHref, prefix, this._renderInnerContents());
      }
    }, {
      kind: "method",
      key: "_renderIcon",
      value: function _renderIcon() {
        return html(_t3 || (_t3 = _` ${0} `), ctaIcons[this.ctaType]());
      }
    }, {
      kind: "method",
      key: "_renderInnerContents",
      value: function _renderInnerContents() {
        return html(_t4 || (_t4 = _`
      <div class="${0}--global-banner-content-wrapper" part="content">
        <div
          ?hidden="${0}"
          class="${0}--global-banner-image-container"
          part="image-container">
          <slot
            name="image"
            @slotchange="${0}"></slot>
        </div>

        <div
          class="${0}--global-banner-text-container"
          part="text-container">
          <slot name="heading"></slot>
          <slot name="copy"></slot>
        </div>

        <div
          class="${0}--global-banner-cta-container"
          part="cta-container">
          <slot name="cta" @slotchange="${0}"></slot>
        </div>

        <div class="${0}--global-banner-icon" part="icon">
          ${0}
        </div>
      </div>
    `), prefix, !this.hasImage, prefix, this._handleImageSlotChange, prefix, prefix, this._handleButtonSlotChange, prefix, this.ctaType ? this._renderIcon() : '');
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t5 || (_t5 = _`
      ${0}
    `), this._shouldRenderAsLink ? this._renderAsLink() : this._renderAsStatic());
      }

      /**
       * A selector that will return the CTA button
       */
    }, {
      kind: "get",
      static: true,
      key: "ctaButton",
      value: function () {
        return `${c4dPrefix}-button`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DGlobalBanner;
//# sourceMappingURL=global-banner.js.map
