import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement } from 'lit';
import { property } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { HR_TYPE, HR_SIZE, HR_CONTRAST, HR_WEIGHT } from "./defs.js";
import styles from "././horizontal-rule.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
export { HR_TYPE, HR_SIZE, HR_CONTRAST, HR_WEIGHT };
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Horizontal Rule
 *
 * @element c4d-hr
 */
let C4DHorizontalRule = _decorate([customElement(`${c4dPrefix}-hr`)], function (_initialize, _StableSelectorMixin) {
  class C4DHorizontalRule extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DHorizontalRule,
    d: [{
      kind: "field",
      decorators: [property({
        attribute: 'type',
        reflect: true
      })],
      key: "type",
      value() {
        return HR_TYPE.SOLID;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'size',
        reflect: true
      })],
      key: "size",
      value() {
        return HR_SIZE.FLUID;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'contrast',
        reflect: true
      })],
      key: "contrast",
      value() {
        return HR_CONTRAST.STRONG;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'weight',
        reflect: true
      })],
      key: "weight",
      value() {
        return HR_WEIGHT.THIN;
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value:
      /**
       * Style of the HR (solid (default) | dashed)
       */

      /**
       * Length of the HR
       * (fluid (default) | small | medium | large)
       */

      /**
       * Contrast of the HR
       * 'strong' (default) | subtle)
       */

      /**
       * Weight of the HR
       * (thin (default) | thick)
       */

      function connectedCallback() {
        if (!this.hasAttribute('role')) {
          this.setAttribute('role', 'separator');
        }
        _superPropGet(C4DHorizontalRule, "connectedCallback", this, 3)([]);
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--hr`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DHorizontalRule;
//# sourceMappingURL=horizontal-rule.js.map
