import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t,
  _t2,
  _t3;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { state, property } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import "../horizontal-rule/horizontal-rule.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././leadspace-block.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * The table mapping slot name with the private property name that indicates the existence of the slot content.
 */
const slotExistencePropertyNames = {
  title: '_hasTitle'
};

/**
 * LeadSpace Block Component.
 *
 * @element c4d-leadspace-block
 * @csspart content-layout - The outer wrapper. Usage: c4d-leadpsace-block::part(content-layout)
 * @csspart content-body - The inner wrapper. Usage: c4d-leadpsace-block::part(content-body)
 * @csspart hr - The horizontal rule. Usage: c4d-leadpsace-block::part(hr)
 */
let C4DLeadSpaceBlock = _decorate([customElement(`${c4dPrefix}-leadspace-block`)], function (_initialize, _StableSelectorMixin) {
  class C4DLeadSpaceBlock extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLeadSpaceBlock,
    d: [{
      kind: "field",
      decorators: [state()],
      key: "_hasTitle",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean
      })],
      key: "border",
      value() {
        return false;
      }
    }, {
      kind: "method",
      key: "_handleSlotChange",
      value:
      /**
       * `true` if there is a title.
       */

      /**
       * `true` if there is a border.
       */

      /**
       * Handles `slotchange` event.
       *
       * @param event The event.
       * @param event.target The event target.
       */
      function _handleSlotChange({
        target
      }) {
        const {
          name
        } = target;
        const hasTitle = target.assignedNodes().some(node => node.nodeType !== Node.TEXT_NODE || node.textContent.trim());
        this[slotExistencePropertyNames[name] || '_hasTitle'] = hasTitle;
      }

      /**
       * Render the Leadspace Block title
       */
    }, {
      kind: "method",
      key: "_renderHeading",
      value: function _renderHeading() {
        const {
          _hasTitle: hasTitle
        } = this;
        return html(_t || (_t = _`
      <slot
        ?hidden="${0}"
        name="heading"
        @slotchange="${0}"></slot>
    `), !hasTitle, this._handleSlotChange);
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t2 || (_t2 = _`
      <div class="${0}--content-layout" part="content-layout">
        ${0}
        <div class="${0}--content-layout__body" part="content-body">
          <slot></slot>
          ${0}
        </div>
      </div>
    `), prefix, this._renderHeading(), prefix, this.border ? html(_t3 || (_t3 = _`<c4d-hr part="hr"></c4d-hr>`)) : ``);
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--leadspace-block`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DLeadSpaceBlock;
//# sourceMappingURL=leadspace-block.js.map
