import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import { classMap } from 'lit/directives/class-map.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import "../horizontal-rule/horizontal-rule.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././leadspace-with-search.css.js";
import { ADJACENT_THEMES, DUAL_THEMES } from "./defs.js";
import StickyHeader from '@carbon/ibmdotcom-utilities/es/utilities/StickyHeader/StickyHeader.js';
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
import { themes } from '@carbon/themes';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Leadspace with Search
 *
 * @element c4d-leadspace-with-search
 * @csspart content-layout - The content container. Usage: `c4d-leadspace-with-search::part(content-layout)`
 * @csspart content-layout-body - The content container body. Usage: `c4d-leadspace-with-search::part(content-layout-body)`
 * @csspart search-container - The search container. Usage: `c4d-leadspace-with-search::part(search-container)`
 * @csspart search-container-inner - The search container inner content. Usage: `c4d-leadspace-with-search::part(search-container-inner)`
 * @csspart sticky-header - The sticky header container. Usage: `c4d-leadspace-with-search::part(sticky-header)`
 */
let C4DLeadspaceWithSearch = _decorate([customElement(`${c4dPrefix}-leadspace-with-search`)], function (_initialize, _StableSelectorMixin) {
  class C4DLeadspaceWithSearch extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLeadspaceWithSearch,
    d: [{
      kind: "field",
      decorators: [property()],
      key: "_heading",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'scroll-behavior',
        reflect: true,
        type: Boolean
      })],
      key: "_scrollBehavior",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'adjacent-theme',
        reflect: true
      })],
      key: "adjacentTheme",
      value() {
        return ADJACENT_THEMES.MONOTHEME;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'dual-theme',
        reflect: true
      })],
      key: "dualTheme",
      value() {
        return DUAL_THEMES.MONOTHEME;
      }
    }, {
      kind: "method",
      key: "_handleHeadingSlotChange",
      value:
      /**
       * sets the heading for sticky search
       */

      /**
       * `true` if there is an image.
       */

      /**
       * The adjacent theme.
       *
       * Options are:
       * "monotheme",
       * "dual-theme"
       *
       */

      /**
       * The adjacent theme.
       *
       * Color scheme options are:
       * "white-and-g10",
       * "g10-and-white",
       * "g90-and-g100",
       * "g100-and-g90"
       */

      /**
       * Handles `slotchange` event.
       *
       * @param event The event.
       * @param event.target The event target.
       */
      function _handleHeadingSlotChange({
        target
      }) {
        var _querySelector;
        // @ts-ignore
        this._heading = (_querySelector = target.assignedNodes()[0].querySelector('h1')) === null || _querySelector === void 0 ? void 0 : _querySelector.innerText;
      }

      /**
       * Returns a class-name based on the Adjacent theme type
       */
    }, {
      kind: "method",
      key: "_getSearchClass",
      value: function _getSearchClass() {
        return classMap({
          [`${prefix}--search-container`]: true,
          [`${prefix}--search-container-dual-theme`]: this.adjacentTheme === ADJACENT_THEMES.DUAL_THEME
        });
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        var _this$querySelector;
        StickyHeader.global.leadspaceSearch = this;
        (_this$querySelector = this.querySelector(`${c4dPrefix}-leadspace-heading`)) === null || _this$querySelector === void 0 || _this$querySelector.setAttribute('type-style', 'fluid-heading-05');
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated() {
        const currentBackground = window.getComputedStyle(this).getPropertyValue('--cds-background');
        const currentTheme = Object.keys(themes).find(colorName => themes[colorName].background === currentBackground);
        if (this.adjacentTheme === ADJACENT_THEMES.DUAL_THEME) {
          for (const key in DUAL_THEMES) {
            if (DUAL_THEMES[key].startsWith(currentTheme)) {
              this.dualTheme = DUAL_THEMES[key];
              break;
            }
          }
        } else {
          this.dualTheme = '';
        }
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t || (_t = _`
      <div part="content-layout" class="${0}--content-layout">
        <slot
          name="heading"
          @slotchange=${0}></slot>
        <div part="content-layout-body" class="${0}--content-layout__body">
          <slot name="copy"></slot>
        </div>
      </div>
      <div part="search-container" class="${0}">
        <div
          part="search-container-inner"
          class="${0}--search-container-inner">
          <div part="sticky-header" class="${0}--sticky-header">
            ${0}
          </div>
          <slot name="search"></slot>
        </div>
      </div>
      <slot name="hr"></slot>
    `), prefix, this._handleHeadingSlotChange, prefix, this._getSearchClass(), prefix, prefix, this._heading);
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--leadspace-with-search`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DLeadspaceWithSearch;
//# sourceMappingURL=leadspace-with-search.js.map
