import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4,
  _t5,
  _t6,
  _t7;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html, LitElement, svg } from 'lit';
import { property } from 'lit/decorators.js';
import { classMap } from 'lit/directives/class-map.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import { LEADSPACE_TYPE, LEADSPACE_GRADIENT_STYLE_SCHEME, LEADSPACE_SIZE } from "./defs.js";
import styles from "././leadspace.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
export { LEADSPACE_TYPE, LEADSPACE_GRADIENT_STYLE_SCHEME, LEADSPACE_SIZE };
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * The LeadSpace component.
 *
 * @element c4d-leadspace
 * @slot action The action (CTA) content.
 * @slot image The image content.
 * @csspart content - The content. Usage: `c4d-leadspace::part(content)`
 * @csspart content-item - The subheading paragraph. Usage: `c4d-leadspace::part(content-item)`
 * @csspart row - Row wrappers. Usage: `c4d-leadspace::part(row)`
 * @csspart row--description - Row wrapper for the description. Usage: `c4d-leadspace::part(row--description)`
 * @csspart row--content - Row wrapper for the navigation and heading. Usage: `c4d-leadspace::part(row--content)`
 * @csspart description - The description. Usage`c4d-leadspace::part(description)`
 * @csspart section - The first DOM node inside the shadow-root. Usage: `c4d-leadspace::part(section)`
 * @csspart container - The container around the whole leadspace. Usage: `c4d-leadspace::part(container)`
 * @csspart content-container - The container around just the content of the leadspace. Usage: `c4d-leadspace::part(content-container)`
 * @csspart overlay - The leadspace overlay wrapping all contents and optional gradient. Usage: `c4d-leadspace::part(overlay)`
 * @csspart gradient - The SVG gradient. Usage: `c4d-leadspace::part(gradient)`
 * @csspart action - The action. Usage: `c4d-leadspace::part(action)`
 */
let C4DLeadSpace = _decorate([customElement(`${c4dPrefix}-leadspace`)], function (_initialize, _StableSelectorMixin) {
  class C4DLeadSpace extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLeadSpace,
    d: [{
      kind: "method",
      key: "_handleSlotChange",
      value:
      /**
       * Handler for @slotchange, ensure that the only element being rendered is C4DTagGroup
       *
       * @private
       */
      function _handleSlotChange(event) {
        const childItems = event.target.assignedNodes();
        childItems.filter(elem => {
          var _matches, _ref;
          return ((_matches = (_ref = elem).matches) === null || _matches === void 0 ? void 0 : _matches.call(_ref, this.constructor.tagGroupSelector)) || this.constructor.breadcrumbSelector;
        });
      }

      /**
       * Returns a class-name based on the gradient parameter type
       */
    }, {
      kind: "method",
      key: "_getGradientClass",
      value: function _getGradientClass() {
        return classMap({
          [`${c4dPrefix}--leadspace--gradient`]: this.defaultSrc,
          [`${c4dPrefix}--leadspace__overlay`]: true
        });
      }

      /**
       * Returns a class-name based on the type parameter type
       */
    }, {
      kind: "method",
      key: "_getTypeClass",
      value: function _getTypeClass() {
        return classMap({
          [`${c4dPrefix}--leadspace--centered`]: this.type === LEADSPACE_TYPE.CENTERED,
          [`${c4dPrefix}--leadspace--centered__image`]: this.type === LEADSPACE_TYPE.CENTERED && this.defaultSrc,
          [`${c4dPrefix}--leadspace--productive`]: this.type === LEADSPACE_TYPE.SMALL,
          [`${c4dPrefix}--leadspace__section`]: true
        });
      }

      /**
       * Renders Leadspace copy/description
       */
    }, {
      kind: "method",
      key: "_renderCopy",
      value: function _renderCopy() {
        const {
          copy
        } = this;
        return html(_t || (_t = _`
      <div class="${0}--leadspace__row" part="row row--description">
        <p
          data-autoid="${0}--leadspace__desc"
          class="${0}--leadspace__desc"
          part="description">
          <slot>${0}</slot>
        </p>
      </div>
    `), c4dPrefix, c4dPrefix, c4dPrefix, copy);
      }

      /**
       * Renders Leadspace title slot
       */
    }, {
      kind: "method",
      key: "_renderHeading",
      value: function _renderHeading() {
        const {
          title
        } = this;
        return html(_t2 || (_t2 = _` <slot name="heading">${0}</slot> `), title);
      }

      /**
       * The alternate text.
       */
    }, {
      kind: "field",
      decorators: [property()],
      key: "alt",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'default-src'
      })],
      key: "defaultSrc",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "copy",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true,
        attribute: 'gradient-style-scheme'
      })],
      key: "gradientStyleScheme",
      value() {
        return LEADSPACE_GRADIENT_STYLE_SCHEME.WITH_GRADIENT;
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "title",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "type",
      value() {
        return LEADSPACE_TYPE.LEFT;
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "size",
      value() {
        return 'tall';
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean
      })],
      key: "isRTL",
      value() {
        return false;
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value:
      /**
       * The image source.
       */
      /**
       * The leadspace copy.
       */
      /**
       * The gradient style scheme.
       */
      /**
       * The leadspace title.
       */
      /**
       *  Leadspace type (small, left, or centered)
       */
      /**
       *  Leadspace size (super, tall, medium, or short)
       */
      /**
       *  Determines if the direction is right-to-left
       */
      function connectedCallback() {
        _superPropGet(C4DLeadSpace, "connectedCallback", this, 3)([]);

        // initializing the MutationObserver
        this.observer = new MutationObserver(() => {
          this.isRTL = this.dir === 'rtl' || getComputedStyle(this).direction === 'rtl';
        });

        // observing the 'dir' attr in the root element
        this.observer.observe(document.documentElement, {
          attributes: true,
          attributeFilter: ['dir']
        });

        // Initial check for the direction
        this.isRTL = this.dir === 'rtl' || getComputedStyle(this).direction === 'rtl';
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        Array.from(this.children).forEach(child => {
          if ((child.tagName === 'C4D-BACKGROUND-MEDIA' || child.tagName === 'C4D-LEADSPACE-IMAGE') && child.slot === '') {
            child.slot = 'image';
          }
        });
        if (this.size === 'short') {
          var _this$querySelector;
          (_this$querySelector = this.querySelector('c4d-leadspace-heading')) === null || _this$querySelector === void 0 || _this$querySelector.setAttribute('type-style', 'fluid-heading-05');
        }
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          gradientStyleScheme,
          type,
          size
        } = this;
        return html(_t3 || (_t3 = _`
      <section class="${0}" part="section">
        <div class="${0}--leadspace__container" part="container">
          <div class="${0}" part="overlay">
            ${0}
            <div
              class="${0}--leadspace--content__container"
              part="content-container">
              <div class="${0}--leadspace__row" part="row row--content">
                <slot
                  name="navigation"
                  @slotchange="${0}"></slot>
                ${0}
              </div>
              ${0}
            </div>
          </div>
          <slot name="image"></slot>
        </div>
      </section>
    `), this._getTypeClass(), c4dPrefix, this._getGradientClass(), gradientStyleScheme === LEADSPACE_GRADIENT_STYLE_SCHEME.NONE ? undefined : svg(_t4 || (_t4 = _`
                <svg
                  class="${0}--leadspace__gradient" part="gradient"
                  viewBox="0 0 100 100"
                  preserveAspectRatio="none"
                  xmlns="http://www.w3.org/2000/svg"
                  xmlns:xlink="http://www.w3.org/1999/xlink"
                >
                  <defs>
                    <linearGradient id="stops" class="${0}--leadspace__gradient__stops"     gradientTransform="${0}">
                      ${0}
                    </linearGradient>
                  </defs>
                  <rect class="${0}--leadspace__gradient__rect" width="100" height="100" />
                </svg>
              `), c4dPrefix, c4dPrefix, type === LEADSPACE_TYPE.CENTERED ? 'rotate(90)' : this.isRTL ? 'scale(-1, 1) translate(-1, 0)' : '', type === LEADSPACE_TYPE.CENTERED ? svg(_t5 || (_t5 = _`
                          <stop offset="0%" />
                          <stop offset="54%" />
                          <stop offset="77%" />
                          <stop offset="100%" />
                        `)) : svg(_t6 || (_t6 = _`
                          <stop offset="0%" />
                          <stop offset="25%" />
                          <stop offset="50%" />
                          <stop offset="75%" />
                        `)), c4dPrefix), c4dPrefix, c4dPrefix, this._handleSlotChange, this._renderHeading(), size !== LEADSPACE_SIZE.SHORT ? html(_t7 || (_t7 = _`
                    <div
                      class="${0}--leadspace__content"
                      part="content">
                      ${0}
                      <div
                        class="${0}--leadspace__action"
                        part="action">
                        <slot name="action"></slot>
                      </div>
                    </div>
                  `), c4dPrefix, this._renderCopy(), c4dPrefix) : ``);
      }
    }, {
      kind: "get",
      static: true,
      key: "breadcrumbSelector",
      value: function () {
        return `${prefix}-breadcrumb`;
      }
    }, {
      kind: "get",
      static: true,
      key: "headingSelector",
      value: function () {
        return `${c4dPrefix}-leadspace-heading`;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--leadspace`;
      }
    }, {
      kind: "get",
      static: true,
      key: "tagGroupSelector",
      value: function () {
        return `div`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DLeadSpace;
//# sourceMappingURL=leadspace.js.map
