import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import CDSModal from '@carbon/web-components/es/components/modal/modal.js';
import HostListenerMixin from '@carbon/web-components/es/globals/mixins/host-listener.js';
import HostListener from '@carbon/web-components/es/globals/decorators/host-listener.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import "./leaving-ibm-modal.js";
import "./leaving-ibm-modal-body.js";
import "./leaving-ibm-modal-heading.js";
import "./leaving-ibm-modal-supplemental.js";
import ModalRenderMixin from "../../globals/mixins/modal-render.js";
import '@carbon/web-components/es/components/modal/modal-header.js';
import '@carbon/web-components/es/components/modal/modal-close-button.js';
import '@carbon/web-components/es/components/modal/modal-footer.js';
import '@carbon/web-components/es/components/button/button.js';
import styles from "././leaving-ibm.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Component that renders leaving IBM modal component.
 *
 * @element c4d-leaving-ibm-composite
 * @csspart modal - The modal container. Usage `c4d-leaving-ibm-composite::part(modal)`
 * @csspart header - The header. Usage `c4d-leaving-ibm-composite::part(header)`
 * @csspart button - The close button.  Usage `c4d-leaving-ibm-composite::part(close-button)`
 * @csspart heading - The modal title. Usage `c4d-leaving-ibm-composite::part(heading)`
 * @csspart body - The modal body. Usage `c4d-leaving-ibm-composite::part(body)`
 * @csspart supplemental - The modal supplemental. Usage `c4d-leaving-ibm-composite::part(supplemental)`
 * @csspart footer - The modal footer. Usage `c4d-leaving-ibm-composite::part(footer)`
 */
let C4DLeavingIbmComposite = _decorate([customElement(`${c4dPrefix}-leaving-ibm-composite`)], function (_initialize, _HostListenerMixin) {
  class C4DLeavingIbmComposite extends _HostListenerMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLeavingIbmComposite,
    d: [{
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "leavingIbmCopy",
      value() {
        return {
          LEAVING001: '',
          LEAVING002: '',
          LEAVING003: ''
        };
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "leavingIbmButtonLabel",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "language",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true
      })],
      key: "open",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "href",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [HostListener('document:click')],
      key: "_handleDocumentClick",
      value() {
        return event => {
          const {
            attributeLeaving
          } = this.constructor;
          if (!this.open) {
            const {
              target
            } = event;
            const linkTarget = target instanceof HTMLAnchorElement ? target : event.composedPath().find(pathTarget => {
              return pathTarget instanceof HTMLAnchorElement;
            });
            if (linkTarget) {
              const linkIsExternal = linkTarget.hasAttribute(attributeLeaving);
              const targetIsExternal = target instanceof Element && target.hasAttribute(attributeLeaving);
              if (linkIsExternal || targetIsExternal) {
                event.preventDefault();
                this.href = linkTarget.href;
                this.open = true;
              }
            }
          }
        };
      }
    }, {
      kind: "field",
      decorators: [HostListener(`document:${CDSModal.eventClose}`)],
      key: "handleEventClose",
      value() {
        return () => {
          this.open = false;
          this.href = '';
        };
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value:
      /**
       * The placeholder for `setLanguage()` Redux action that will be mixed in.
       *
       * @internal
       */

      /**
       * The placeholder for `loadTranslation()` Redux action that will be mixed in.
       *
       * @internal
       */

      /**
       * Leaving IBM modal copy
       */

      /**
       * Leaving IBM modal button label
       */

      /**
       * The language used for query.
       */

      /**
       * `true` to open the modal.
       */

      /**
       * external url triggering the leaving ibm modal.
       */

      function firstUpdated() {
        var _this$_loadTranslatio;
        const {
          language
        } = this;
        if (language) {
          var _this$_setLanguage;
          (_this$_setLanguage = this._setLanguage) === null || _this$_setLanguage === void 0 || _this$_setLanguage.call(this, language);
        }
        (_this$_loadTranslatio = this._loadTranslation) === null || _this$_loadTranslatio === void 0 || _this$_loadTranslatio.call(this, language).catch(() => {}); // The error is logged in the Redux store
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated(changedProperties) {
        if (changedProperties.has('language')) {
          const {
            language
          } = this;
          if (language) {
            var _this$_setLanguage2;
            (_this$_setLanguage2 = this._setLanguage) === null || _this$_setLanguage2 === void 0 || _this$_setLanguage2.call(this, language);
          }
        }
      }
    }, {
      kind: "method",
      key: "renderModal",
      value: function renderModal() {
        const {
          open,
          leavingIbmCopy,
          leavingIbmButtonLabel,
          href
        } = this;
        return html(_t || (_t = _`
      <c4d-leaving-ibm-modal ?open="${0}" part="modal">
        <cds-modal-header part="header">
          <cds-modal-close-button part="close-button"></cds-modal-close-button>
          <c4d-leaving-ibm-modal-heading part="heading"
            >${0}</c4d-leaving-ibm-modal-heading
          >
        </cds-modal-header>
        <c4d-leaving-ibm-modal-body part="body" href="${0}">
          <p>${0}</p>
          <c4d-leaving-ibm-modal-supplemental part="supplemental"
            >${0}</c4d-leaving-ibm-modal-supplemental
          >
        </c4d-leaving-ibm-modal-body>
        <cds-modal-footer part="footer">
          <cds-button
            part="footer-button"
            data-autoid="${0}--leaving-ibm-cta"
            href="${0}"
            kind="primary"
            >${0}</cds-button
          >
        </cds-modal-footer>
      </c4d-leaving-ibm-modal>
    `), open, leavingIbmCopy === null || leavingIbmCopy === void 0 ? void 0 : leavingIbmCopy.LEAVING001, href, leavingIbmCopy === null || leavingIbmCopy === void 0 ? void 0 : leavingIbmCopy.LEAVING002, leavingIbmCopy === null || leavingIbmCopy === void 0 ? void 0 : leavingIbmCopy.LEAVING003, c4dPrefix, href, leavingIbmButtonLabel);
      }

      /**
       * Attribute that triggers Leaving IBM modal on click.
       */
    }, {
      kind: "get",
      static: true,
      key: "attributeLeaving",
      value: function () {
        return 'data-leaving-ibm';
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, HostListenerMixin(ModalRenderMixin(LitElement)));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DLeavingIbmComposite;
//# sourceMappingURL=leaving-ibm-composite.js.map
