import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html } from 'lit';
import { property } from 'lit/decorators.js';
import CDSModalBody from '@carbon/web-components/es/components/modal/modal-body.js';
import { ifDefined } from 'lit/directives/if-defined.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import '@carbon/web-components/es/components/link/link.js';
import styles from "././leaving-ibm.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Leaving IBM Modal body.
 *
 * @element c4d-leaving-ibm-modal-body
 * @csspart content - The content. Usage `c4d-leaving-ibm-modal-body::part(content)`
 * @csspart supplemental-link - The supplemental link. Usage `c4d-leaving-ibm-modal-body::part(supplemental-link)`
 */
let C4DLeavingIbmModalBody = _decorate([customElement(`${c4dPrefix}-leaving-ibm-modal-body`)], function (_initialize, _StableSelectorMixin) {
  class C4DLeavingIbmModalBody extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLeavingIbmModalBody,
    d: [{
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "href",
      value() {
        return '';
      }
    }, {
      kind: "method",
      key: "render",
      value:
      /**
       * external url triggering the leaving ibm modal.
       */

      function render() {
        const {
          href
        } = this;
        return html(_t || (_t = _`
      <p part="content"><slot></slot></p>
      <slot name="supplemental"></slot>
      <cds-link size="lg" href="${0}" part="supplemental-link"
        >${0}</cds-link
      >
    `), ifDefined(href), !href ? href : new URL(href).hostname);
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--leaving-ibm-modal-body`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(CDSModalBody));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DLeavingIbmModalBody;
//# sourceMappingURL=leaving-ibm-modal-body.js.map
