/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import C4DLightboxMediaViewerBody from './lightbox-media-viewer-body';
import '../expressive-modal/expressive-modal';
import '../expressive-modal/expressive-modal-close-button';
/**
 * The image content of lightbox media viewer.
 *
 * @element c4d-lightbox-image-viewer
 * @slot title - The title content.
 * @slot description - The description content.
 * @csspart container - The wrapper around the lightbox media. Usage: `c4d-lightbox-video-player::part(container)`
 * @csspart row - The wrapper around the row. Usage: `c4d-lightbox-video-player::part(row)`
 * @csspart media - The wrapper around media. Usage: `c4d-lightbox-video-player::part(media)`
 * @csspart content-wrapper - The wrapper around content. Usage: `c4d-lightbox-video-player::part(content-wrapper)`
 * @csspart content - The inner wrapper around content. Usage: `c4d-lightbox-video-player::part(content)`
 * @csspart title - The title of the media. Usage: `c4d-lightbox-video-player::part(title)`
 * @csspart description - The description of the media. Usage: `c4d-lightbox-video-player::part(description)`
 * @csspart image - The image displayed in the lightbox image viewer. Usage: `c4d-lightbox-video-player::part(image)`
 */
declare class C4DLightboxImageViewer extends C4DLightboxMediaViewerBody {
    _renderDescription(): import("lit-html").TemplateResult<1>;
    _renderMedia(): import("lit-html").TemplateResult<1>;
    _renderTitle(): import("lit-html").TemplateResult<1>;
    /**
     * The alternate text.
     */
    alt: string;
    /**
     * The image source.
     */
    defaultSrc: string;
    /**
     * The media description.
     */
    description: string;
    /**
     * The media title.
     */
    title: string;
}
export default C4DLightboxImageViewer;

//# sourceMappingURL=lightbox-image-viewer.d.ts.map
