/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import C4DLightboxMediaViewerBody from './lightbox-media-viewer-body';
/**
 * The image content of lightbox media viewer.
 *
 * @element c4d-lightbox-media-viewer
 * @slot title - The title content.
 * @slot description - The description content.
 * @csspart container - The wrapper around the lightbox media. Usage: `c4d-lightbox-video-player::part(container)`
 * @csspart row - The wrapper around the row. Usage: `c4d-lightbox-video-player::part(row)`
 * @csspart media - The wrapper around media. Usage: `c4d-lightbox-video-player::part(media)`
 * @csspart content-wrapper - The wrapper around content. Usage: `c4d-lightbox-video-player::part(content-wrapper)`
 * @csspart content - The inner wrapper around content. Usage: `c4d-lightbox-video-player::part(content)`
 * @csspart title - The title of the media. Usage: `c4d-lightbox-video-player::part(title)`
 * @csspart description - The description of the media. Usage: `c4d-lightbox-video-player::part(description)`
 * @csspart h2 - The h2 element that holds the title. Usage: `c4d-lightbox-video-player::part(h2)`
 */
declare class C4DLightboxMediaViewer extends C4DLightboxMediaViewerBody {
    _renderDescription(): import("lit-html").TemplateResult<1>;
    _renderMedia(): import("lit-html").TemplateResult<1>;
    _renderTitle(): import("lit-html").TemplateResult<1>;
    private _mediaItem?;
    private _mediaWindow;
    private _containingCarousel?;
    private _containingModal?;
    private _handleSlotChange;
    private _intersectionObserver?;
    private _handleOutOfCarouselView;
    private _handleModalClosed;
    private _pauseVideo;
    _boundModalClosedHandler?: EventListenerOrEventListenerObject;
    connectedCallback(): void;
    update(changedProperties: any): void;
    /**
     * The alternate text.
     */
    alt: string;
    /**
     * The image source.
     */
    defaultSrc: string;
    /**
     * The media description.
     */
    description: string;
    /**
     * The media title.
     */
    title: string;
    videoId: string;
    caption: string;
    hideCaption: boolean;
    thumbnail: string;
    /**
     * The name of the custom event fired before this modal is being closed upon a user gesture.
     * Cancellation of this event stops the user-initiated action of closing this modal.
     */
    static get eventBeforeModalClose(): string;
}
export default C4DLightboxMediaViewer;

//# sourceMappingURL=lightbox-media-viewer.d.ts.map
