import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2,
  _t3;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html } from 'lit';
import { property, query } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import C4DLightboxMediaViewerBody from "./lightbox-media-viewer-body.js";
import C4DVideoPlayerContainer from "../video-player/video-player-container.js";
import C4DExpressiveModal from "../expressive-modal/expressive-modal.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * The image content of lightbox media viewer.
 *
 * @element c4d-lightbox-media-viewer
 * @slot title - The title content.
 * @slot description - The description content.
 * @csspart container - The wrapper around the lightbox media. Usage: `c4d-lightbox-video-player::part(container)`
 * @csspart row - The wrapper around the row. Usage: `c4d-lightbox-video-player::part(row)`
 * @csspart media - The wrapper around media. Usage: `c4d-lightbox-video-player::part(media)`
 * @csspart content-wrapper - The wrapper around content. Usage: `c4d-lightbox-video-player::part(content-wrapper)`
 * @csspart content - The inner wrapper around content. Usage: `c4d-lightbox-video-player::part(content)`
 * @csspart title - The title of the media. Usage: `c4d-lightbox-video-player::part(title)`
 * @csspart description - The description of the media. Usage: `c4d-lightbox-video-player::part(description)`
 * @csspart h2 - The h2 element that holds the title. Usage: `c4d-lightbox-video-player::part(h2)`
 */
let C4DLightboxMediaViewer = _decorate([customElement(`${c4dPrefix}-lightbox-media-viewer`)], function (_initialize, _C4DLightboxMediaView) {
  class C4DLightboxMediaViewer extends _C4DLightboxMediaView {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLightboxMediaViewer,
    d: [{
      kind: "method",
      key: "_renderDescription",
      value: function _renderDescription() {
        const {
          description
        } = this;
        return html(_t || (_t = _` <slot name="description">${0}</slot> `), description);
      }
    }, {
      kind: "method",
      key: "_renderMedia",
      value: function _renderMedia() {
        return html(_t2 || (_t2 = _`
      <slot name="media" @slotchange="${0}"></slot>
    `), this._handleSlotChange);
      }
    }, {
      kind: "method",
      key: "_renderTitle",
      value: function _renderTitle() {
        const {
          title
        } = this;
        return html(_t3 || (_t3 = _`
      <slot name="title"
        ><h2 part="h2" style="all: inherit;">${0}</h2></slot
      >
    `), title);
      }
    }, {
      kind: "field",
      decorators: [query(`.${c4dPrefix}--lightbox-media-viewer__media`)],
      key: "_mediaWindow",
      value: void 0
    }, {
      kind: "method",
      key: "_handleSlotChange",
      value: function _handleSlotChange(event) {
        const {
          _containingModal: containingModal
        } = this;
        const [media] = event.target.assignedNodes();
        this._mediaItem = media;

        // Disconnect & delete intersection observer
        if (this._intersectionObserver instanceof IntersectionObserver) {
          this._intersectionObserver.disconnect();
          this._intersectionObserver = undefined;
        }

        // Remove modal closed listeners from the containing modal
        if (containingModal && this._boundModalClosedHandler) {
          containingModal.removeEventListener(C4DExpressiveModal.eventBeforeClose, this._boundModalClosedHandler);
          this._boundModalClosedHandler = undefined;
        }
        if (media instanceof C4DVideoPlayerContainer) {
          const {
            _mediaWindow: mediaWindow,
            _containingCarousel: containingCarousel
          } = this;

          // Watch for out-of-view if we're in a carousel
          if (mediaWindow && containingCarousel) {
            const callback = this._handleOutOfCarouselView.bind(this);
            this._intersectionObserver = new IntersectionObserver(callback, {
              root: containingCarousel,
              rootMargin: '999px 0px 999px 0px',
              threshold: 1
            });
            this._intersectionObserver.observe(mediaWindow);
          }

          // Watch for modal close
          if (containingModal) {
            this._boundModalClosedHandler = this._handleModalClosed.bind(this);
            containingModal.addEventListener(C4DExpressiveModal.eventBeforeClose, this._boundModalClosedHandler);
          }
        }
      }
    }, {
      kind: "method",
      key: "_handleOutOfCarouselView",
      value: function _handleOutOfCarouselView(entries) {
        entries.forEach(entry => {
          if (entry.intersectionRatio < 1) {
            this._pauseVideo();
          }
        });
      }
    }, {
      kind: "method",
      key: "_handleModalClosed",
      value: function _handleModalClosed() {
        this._pauseVideo();
      }
    }, {
      kind: "method",
      key: "_pauseVideo",
      value: function _pauseVideo() {
        const {
          _mediaItem: mediaItem
        } = this;
        if (mediaItem instanceof C4DVideoPlayerContainer) {
          mediaItem.pauseAllVideos();
        }
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value: function connectedCallback() {
        _superPropGet(C4DLightboxMediaViewer, "connectedCallback", this, 3)([]);
        this._containingCarousel = this.closest(`${c4dPrefix}-carousel`) || undefined;
        this._containingModal = this.closest(`${c4dPrefix}-expressive-modal`) || undefined;
      }
    }, {
      kind: "method",
      key: "update",
      value: function update(changedProperties) {
        if (this.videoId) {
          const {
            videoId,
            caption,
            hideCaption,
            thumbnail
          } = this;
          this.innerHTML = `
        <c4d-video-player-container
          playing-mode="inline"
          video-id="${videoId}"
          caption="${caption}"
          ?hide-caption="${hideCaption}"
          thumbnail="${thumbnail}"
          slot="media"
        ></c4d-video-player-container>
      `;
        } else {
          const {
            alt,
            defaultSrc
          } = this;
          this.innerHTML = `
        <img
          class="${c4dPrefix}--image__img"
          alt="${alt}"
          src="${defaultSrc}"
          loading="lazy"
          slot="media"
          style="max-width:100%;max-height:100%"
        />
      `;
        }
        _superPropGet(C4DLightboxMediaViewer, "update", this, 3)([changedProperties]);
      }

      /**
       * The alternate text.
       */
    }, {
      kind: "field",
      decorators: [property()],
      key: "alt",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'default-src'
      })],
      key: "defaultSrc",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "description",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "title",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'video-id'
      })],
      key: "videoId",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "caption",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "hideCaption",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "thumbnail",
      value() {
        return '';
      }
    }, {
      kind: "get",
      static: true,
      key: "eventBeforeModalClose",
      value:
      /**
       * The image source.
       */
      /**
       * The media description.
       */
      /**
       * The media title.
       */
      /**
       * The name of the custom event fired before this modal is being closed upon a user gesture.
       * Cancellation of this event stops the user-initiated action of closing this modal.
       */
      function () {
        return `${c4dPrefix}-expressive-modal-beingclosed`;
      }
    }]
  };
}, C4DLightboxMediaViewerBody);
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DLightboxMediaViewer;
//# sourceMappingURL=lightbox-media-viewer.js.map
