/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import C4DLightboxMediaViewerBody from './lightbox-media-viewer-body';
/**
 * The video content of lightbox media viewer.
 *
 * @element c4d-lightbox-video-player
 * @slot title - The title content.
 * @slot description - The description content.
 * @csspart container - The wrapper around the lightbox media. Usage: `c4d-lightbox-video-player::part(container)`
 * @csspart row - The wrapper around the row. Usage: `c4d-lightbox-video-player::part(row)`
 * @csspart media - The wrapper around media. Usage: `c4d-lightbox-video-player::part(media)`
 * @csspart content-wrapper - The wrapper around content. Usage: `c4d-lightbox-video-player::part(content-wrapper)`
 * @csspart content - The inner wrapper around content. Usage: `c4d-lightbox-video-player::part(content)`
 * @csspart title - The title of the media. Usage: `c4d-lightbox-video-player::part(title)`
 * @csspart description - The description of the media. Usage: `c4d-lightbox-video-player::part(description)`
 * @csspart video-player - The wrapper around the video player. Usage: `c4d-lightbox-video-player::part(video-player)`
 * @csspart video-container - The inner wrapper around the slotted video player. Usage: `c4d-lightbox-video-player::part(video-container)`
 * @csspart h2 - The h2 element that holds the title. Usage: `c4d-lightbox-video-player::part(h2)`
 */
declare class C4DLightboxVideoPlayer extends C4DLightboxMediaViewerBody {
    _renderDescription(): import("lit-html").TemplateResult<1>;
    _renderMedia(): import("lit-html").TemplateResult<1>;
    _renderTitle(): import("lit-html").TemplateResult<1>;
    updated(changedProperties: any): void;
    connectedCallback(): void;
    /**
     * The media description.
     */
    description: string;
    /**
     * The video duration.
     */
    duration?: number;
    /**
     * The formatter for the video caption, composed with the video name and the video duration.
     * Should be changed upon the locale the UI is rendered with.
     */
    formatCaption: any;
    /**
     * The formatter for the video duration.
     * Should be changed upon the locale the UI is rendered with.
     */
    formatDuration: any;
    /**
     * The video name.
     */
    name: string;
}
export default C4DLightboxVideoPlayer;

//# sourceMappingURL=lightbox-video-player.d.ts.map
