import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2,
  _t3;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html } from 'lit';
import { property } from 'lit/decorators.js';
import removeHtmlTagEntities from '@carbon/ibmdotcom-utilities/es/utilities/removeHtmlTagEntities/removeHtmlTagEntities.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import { formatVideoCaption, formatVideoDuration } from '@carbon/ibmdotcom-utilities/es/utilities/formatVideoCaption/formatVideoCaption.js';
import C4DLightboxMediaViewerBody from "./lightbox-media-viewer-body.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * The video content of lightbox media viewer.
 *
 * @element c4d-lightbox-video-player
 * @slot title - The title content.
 * @slot description - The description content.
 * @csspart container - The wrapper around the lightbox media. Usage: `c4d-lightbox-video-player::part(container)`
 * @csspart row - The wrapper around the row. Usage: `c4d-lightbox-video-player::part(row)`
 * @csspart media - The wrapper around media. Usage: `c4d-lightbox-video-player::part(media)`
 * @csspart content-wrapper - The wrapper around content. Usage: `c4d-lightbox-video-player::part(content-wrapper)`
 * @csspart content - The inner wrapper around content. Usage: `c4d-lightbox-video-player::part(content)`
 * @csspart title - The title of the media. Usage: `c4d-lightbox-video-player::part(title)`
 * @csspart description - The description of the media. Usage: `c4d-lightbox-video-player::part(description)`
 * @csspart video-player - The wrapper around the video player. Usage: `c4d-lightbox-video-player::part(video-player)`
 * @csspart video-container - The inner wrapper around the slotted video player. Usage: `c4d-lightbox-video-player::part(video-container)`
 * @csspart h2 - The h2 element that holds the title. Usage: `c4d-lightbox-video-player::part(h2)`
 */
let C4DLightboxVideoPlayer = _decorate([customElement(`${c4dPrefix}-lightbox-video-player`)], function (_initialize, _C4DLightboxMediaView) {
  class C4DLightboxVideoPlayer extends _C4DLightboxMediaView {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLightboxVideoPlayer,
    d: [{
      kind: "method",
      key: "_renderDescription",
      value: function _renderDescription() {
        const {
          description
        } = this;
        return html(_t || (_t = _`
      <slot name="description">${0}</slot>
    `), removeHtmlTagEntities(description));
      }

      // eslint-disable-next-line class-methods-use-this
    }, {
      kind: "method",
      key: "_renderMedia",
      value: function _renderMedia() {
        return html(_t2 || (_t2 = _`
      <div class="${0}--video-player" part="video-player">
        <div
          class="${0}--video-player__video-container"
          part="video-container">
          <slot></slot>
        </div>
      </div>
    `), c4dPrefix, c4dPrefix);
      }
    }, {
      kind: "method",
      key: "_renderTitle",
      value: function _renderTitle() {
        const {
          duration,
          formatCaption,
          formatDuration,
          name
        } = this;
        return html(_t3 || (_t3 = _`
      <slot name="title">
        <h2 style="all: inherit;" part="h2">
          ${0}
        </h2>
      </slot>
    `), formatCaption({
          duration: formatDuration({
            duration: !duration ? duration : duration * 1000
          }),
          name
        }));
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated(changedProperties) {
        if (changedProperties.has('name')) {
          this.setAttribute('aria-label', this.name);
        }
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value: function connectedCallback() {
        this.setAttribute('role', 'dialog');
        _superPropGet(C4DLightboxVideoPlayer, "connectedCallback", this, 3)([]);
      }

      /**
       * The media description.
       */
    }, {
      kind: "field",
      decorators: [property()],
      key: "description",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Number
      })],
      key: "duration",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "formatCaption",
      value() {
        return formatVideoCaption;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "formatDuration",
      value() {
        return formatVideoDuration;
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "name",
      value() {
        return '';
      }
    }]
  };
}, C4DLightboxMediaViewerBody);
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DLightboxVideoPlayer;
//# sourceMappingURL=lightbox-video-player.js.map
