import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { html } from 'lit';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././link-list-section.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import C4DContentSection from "../content-section/content-section.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Link list.
 *
 * @element c4d-link-list
 * @slot heading - The heading content.
 * @csspart grid - The outer wrapper. Usage `c4d-link-list-section::part(grid)`
 * @csspart row - The inner wrapper. Usage `c4d-link-list-section::part(row)`
 * @csspart heading - The heading's column container. Usage `c4d-link-list-section::part(heading)`
 * @csspart children - The link-list's column container. Usage `c4d-link-list-section::part(children)`
 */
let C4DLinkListSection = _decorate([customElement(`${c4dPrefix}-link-list-section`)], function (_initialize, _StableSelectorMixin) {
  class C4DLinkListSection extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLinkListSection,
    d: [{
      kind: "field",
      key: "_handleSlotChange",
      value() {
        return event => {
          const slot = event.target.assignedElements().filter(elem => elem.localName === this.constructor.linkListSelector)[0];
          if (slot && (!slot.hasAttribute('type') || slot.getAttribute('type') !== 'end')) {
            slot.setAttribute('type', 'end');
          }
        };
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          _handleSlotChange: handleSlotChange
        } = this;
        return html(_t || (_t = _`
      <div class="${0}--content-section__grid" part="grid">
        <div class="${0}--content-section__row" part="row">
          <div class="${0}--content-section__left" part="heading">
            <slot name="heading"></slot>
          </div>
          <div class="${0}--content-section__children" part="children">
            <slot @slotchange="${0}"></slot>
          </div>
        </div>
      </div>
    `), prefix, prefix, prefix, prefix, handleSlotChange);
      }
    }, {
      kind: "get",
      static: true,
      key: "linkListSelector",
      value: function () {
        return `${c4dPrefix}-link-list`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value:
      // `styles` here is a `CSSResult` generated by custom WebPack loader

      function () {
        return `${c4dPrefix}--link-list-section`;
      }
    }]
  };
}, StableSelectorMixin(C4DContentSection));
console.warn('The link-list-section component has been deprecated in favor of the content-section/block and link-list end of section variant components. ' + 'See content-section/block and link-list documentation for more information.');

/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DLinkListSection;
//# sourceMappingURL=link-list-section.js.map
