import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { classMap } from 'lit/directives/class-map.js';
import { LitElement, html } from 'lit';
import { property, state } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { LINK_LIST_TYPE, LINK_LIST_ITEM_TYPE } from "./defs.js";
import styles from "././link-list.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;
export let END_TYPE_LAYOUT;

/**
 * Link list.
 *
 * @element c4d-link-list
 * @slot heading - The heading content.
 * @csspart heading - The heading wrapper. Usage `c4d-link-list::part(heading)`
 * @csspart list - The list wrapper. Usage `c4d-link-list::part(list)`
 */
(function (END_TYPE_LAYOUT) {
  END_TYPE_LAYOUT["DEFAULT"] = "default";
  END_TYPE_LAYOUT["TWO_COLUMNS"] = "two-columns";
  END_TYPE_LAYOUT["THREE_COLUMNS"] = "three-columns";
})(END_TYPE_LAYOUT || (END_TYPE_LAYOUT = {}));
let C4DLinkList = _decorate([customElement(`${c4dPrefix}-link-list`)], function (_initialize, _StableSelectorMixin) {
  class C4DLinkList extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLinkList,
    d: [{
      kind: "field",
      decorators: [state()],
      key: "_endTypeLayout",
      value() {
        return END_TYPE_LAYOUT.DEFAULT;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_childItems",
      value() {
        return [];
      }
    }, {
      kind: "method",
      key: "_handleSlotChange",
      value:
      /**
       * Defines the layout for the end layout - based on END_TYPE_LAYOUT
       */

      /**
       * Child items
       */

      /**
       * Handler for @slotChange, toggles the split layout class and set the children link-list-item to the same height
       *
       * @private
       */
      function _handleSlotChange(event) {
        const {
          selectorItem
        } = this.constructor;
        this._childItems = event.target.assignedNodes({
          flatten: true
        }).filter(node => node.nodeType === Node.ELEMENT_NODE && (node === null || node === void 0 ? void 0 : node.matches(selectorItem)));
        if (this._childItems.length > 3) {
          if (this._childItems.length < 7) {
            this._endTypeLayout = END_TYPE_LAYOUT.TWO_COLUMNS;
          } else {
            this._endTypeLayout = END_TYPE_LAYOUT.THREE_COLUMNS;
          }
        } else {
          this._endTypeLayout = END_TYPE_LAYOUT.DEFAULT;
        }
        if (this.type === LINK_LIST_TYPE.END) {
          this._childItems.forEach(elem => {
            elem.type = LINK_LIST_ITEM_TYPE.END;
          });
        }
      }

      /**
       * The link list type.
       * possible values are:
       * default - Vertically stacked card-like links;
       * vertical - Vertically stacked inline links;
       * horizontal - Horizontaly stacked inline links;
       * end - End of section variant - Inline links stacked up to three columns based on the quantity of links;
       */
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "type",
      value() {
        return LINK_LIST_TYPE.DEFAULT;
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value: function connectedCallback() {
        _superPropGet(C4DLinkList, "connectedCallback", this, 3)([]);
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          type,
          _endTypeLayout: endTypeLayout
        } = this;
        const headingClasses = classMap({
          [`${c4dPrefix}-ce--link-list__heading__wrapper`]: true,
          [`${c4dPrefix}-ce--link-list__heading--split`]: type === LINK_LIST_TYPE.END && endTypeLayout === END_TYPE_LAYOUT.TWO_COLUMNS
        });
        const listTypeClasses = {
          [LINK_LIST_TYPE.HORIZONTAL]: `${c4dPrefix}--link-list__list--horizontal`,
          [LINK_LIST_TYPE.VERTICAL]: `${c4dPrefix}--link-list__list--vertical`,
          [LINK_LIST_TYPE.END]: `${c4dPrefix}-ce--link-list__list--end`,
          [LINK_LIST_TYPE.DEFAULT]: `${c4dPrefix}--link-list__list`
        }[type];
        const listClasses = classMap({
          // [`${c4dPrefix}--link-list__list`]: LINK_LIST_TYPE.DEFAULT,
          [listTypeClasses]: true,
          [`${c4dPrefix}-ce--link-list__list--split`]: type === LINK_LIST_TYPE.END && endTypeLayout === END_TYPE_LAYOUT.TWO_COLUMNS,
          [`${c4dPrefix}-ce--link-list__list--three-columns`]: type === LINK_LIST_TYPE.END && endTypeLayout === END_TYPE_LAYOUT.THREE_COLUMNS
        });
        return html(_t || (_t = _`
      <div class="${0}" part="heading">
        <slot name="heading"></slot>
      </div>
      <ul part="list" name="list" class="${0}">
        <slot @slotchange="${0}"></slot>
      </ul>
    `), headingClasses, listClasses, this._handleSlotChange);
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated() {
        if (this.type === LINK_LIST_TYPE.HORIZONTAL || this.type === LINK_LIST_TYPE.VERTICAL) {
          this._childItems.forEach(elem => {
            elem.iconInline = true;
          });
        }
      }

      /**
       * A selector selecting the child items.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItem",
      value: function () {
        return `${c4dPrefix}-link-list-item, ${c4dPrefix}-link-list-item-cta`;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--link-list`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DLinkList;
//# sourceMappingURL=link-list.js.map
