import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html } from 'lit';
import { property } from 'lit/decorators.js';
import CDSLink from '@carbon/web-components/es/components/link/link.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import ipcinfoCookie from '@carbon/ibmdotcom-utilities/es/utilities/ipcinfoCookie/ipcinfoCookie.js';
import styles from "././locale-modal.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Locale item.
 *
 * @element c4d-locale-item
 * @csspart country - the country text container. Usage: `c4d-locale-item::part(country)`
 * @csspart language - the language text container. Usage: `c4d-locale-item::part(language)`
 */
let C4DLocaleItem = _decorate([customElement(`${c4dPrefix}-locale-item`)], function (_initialize, _CDSLink) {
  class C4DLocaleItem extends _CDSLink {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLocaleItem,
    d: [{
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "country",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "language",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "locale",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "region",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "role",
      value() {
        return 'listitem';
      }
    }, {
      kind: "method",
      key: "_handleClick",
      value:
      /**
       * The country.
       */

      /**
       * The language.
       */

      /**
       * The locale ID.
       */

      /**
       * The region the country is in.
       */

      /**
       * Element's role for assistive technologies
       */

      /**
       * method to handle when country/region has been selected
       * sets the ipcInfo cookie with selected locale
       */
      function _handleClick() {
        const {
          locale
        } = this;
        const localeSplit = locale.split('-');
        const localeObj = {
          cc: localeSplit[1],
          lc: localeSplit[0]
        };
        ipcinfoCookie.set(localeObj);
      }

      /**
       * @returns The inner content.
       */
    }, {
      kind: "method",
      key: "_renderInner",
      value: function _renderInner() {
        const {
          country,
          language
        } = this;
        return html(_t || (_t = _`
      <div class="${0}--locale-modal__locales__name" part="country">
        ${0}
      </div>
      <div class="${0}--locale-modal__locales__name" part="language">
        ${0}
      </div>
    `), c4dPrefix, country, c4dPrefix, language);
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, CDSLink);
export default C4DLocaleItem;
//# sourceMappingURL=locale-item.js.map
