import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4,
  _t5;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import { ifDefined } from 'lit/directives/if-defined.js';
import LocaleAPI from '@carbon/ibmdotcom-services/es/services/Locale/Locale.js';
import ArrowRight20 from '@carbon/web-components/es/icons/arrow--right/20.js';
import Error20 from '@carbon/web-components/es/icons/error/20.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import altlangs from '@carbon/ibmdotcom-utilities/es/utilities/altlangs/altlangs.js';
import HostListener from '@carbon/web-components/es/globals/decorators/host-listener.js';
import HostListenerMixin from '@carbon/web-components/es/globals/mixins/host-listener.js';
import HybridRenderMixin from "../../globals/mixins/hybrid-render.js";
import "./locale-modal.js";
import C4DLocaleModal from "./locale-modal.js";
import "./regions.js";
import "./region-item.js";
import "./locale-search.js";
import "./locale-item.js";
import "../card/card-heading.js";
import "../card/card-footer.js";
import styles from "././locale-modal-composite.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Container component for locale modal.
 *
 * @element c4d-locale-modal-composite
 */
let C4DLocaleModalComposite = _decorate([customElement(`${c4dPrefix}-locale-modal-composite`)], function (_initialize, _HostListenerMixin) {
  class C4DLocaleModalComposite extends _HostListenerMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLocaleModalComposite,
    d: [{
      kind: "method",
      key: "_sortCountries",
      value:
      /**
       * @param countries A country list.
       * @returns Sorted version of the given country list.
       */
      function _sortCountries(countries) {
        return countries.sort((lhs, rhs) => this.collatorCountryName.compare(lhs.name, rhs.name));
      }

      /**
       * The placeholder for `loadLocaleList()` Redux action that may be mixed in.
       *
       * @internal
       */

      /**
       * The placeholder for `setLanguage()` Redux action that may be mixed in.
       *
       * @internal
       */
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "collatorCountryName",
      value() {
        return new Intl.Collator();
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'lang-display'
      })],
      key: "langDisplay",
      value: void 0
    }, {
      kind: "field",
      decorators: [property()],
      key: "language",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "localeList",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean
      })],
      key: "open",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "chosenRegion",
      value: void 0
    }, {
      kind: "method",
      decorators: [HostListener(C4DLocaleModal.eventRegionUpdated)],
      key: "_handleRegionUpdatedEvent",
      value:
      /**
       * The g11n collator to use for sorting contry names.
       */
      /**
       * The language to show in the UI.
       */
      /**
       * The language used for query.
       */
      /**
       * The locale list.
       */
      /**
       * `true` to open the modal.
       */
      /**
       * The region chosen by user.
       */
      function _handleRegionUpdatedEvent(event) {
        this.chosenRegion = event.detail.region || undefined;
      }

      // eslint-disable-next-line class-methods-use-this
    }, {
      kind: "method",
      key: "getLangDisplay",
      value: async function getLangDisplay() {
        const response = await LocaleAPI.getLangDisplay();
        return response;
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        var _this$_loadLocaleList;
        const {
          language
        } = this;
        if (language) {
          var _this$_setLanguage;
          (_this$_setLanguage = this._setLanguage) === null || _this$_setLanguage === void 0 || _this$_setLanguage.call(this, language);
        }
        (_this$_loadLocaleList = this._loadLocaleList) === null || _this$_loadLocaleList === void 0 || _this$_loadLocaleList.call(this, language);
        this.getLangDisplay().then(res => {
          this.langDisplay = res;
        });
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated(changedProperties) {
        const {
          language
        } = this;
        if (changedProperties.has('language')) {
          if (language) {
            var _this$_setLanguage2, _this$_loadLocaleList2;
            (_this$_setLanguage2 = this._setLanguage) === null || _this$_setLanguage2 === void 0 || _this$_setLanguage2.call(this, language);
            (_this$_loadLocaleList2 = this._loadLocaleList) === null || _this$_loadLocaleList2 === void 0 || _this$_loadLocaleList2.call(this, language).catch(() => {}); // The error is logged in the Redux store
          }
        }
      }
    }, {
      kind: "method",
      key: "renderLightDOM",
      value: function renderLightDOM() {
        const {
          chosenRegion,
          langDisplay,
          localeList,
          open
        } = this;
        const {
          localeModal,
          regionList
        } = localeList !== null && localeList !== void 0 ? localeList : {};
        const {
          availabilityText,
          headerTitle,
          modalClose,
          searchClearText,
          searchLabel,
          searchPlaceholder,
          unavailabilityText
        } = localeModal !== null && localeModal !== void 0 ? localeModal : {};
        const pageLangs = altlangs();
        if (Object.keys(pageLangs).length === 0 && (regionList === null || regionList === void 0 ? void 0 : regionList.length) > 0) {
          const messages = ['Detected that `<link rel="alternate">` is likely missing.', 'The locale search UI will yield to an empty result.'];
          console.warn(messages.join(' ')); // eslint-disable-line no-console
        }
        const massagedCountryList = regionList === null || regionList === void 0 ? void 0 : regionList.reduce((acc, {
          countryList,
          name: region
        }) => {
          this._sortCountries(countryList).forEach(({
            name: country,
            locale: localeItems
          }) => {
            localeItems.forEach(([locale, language]) => {
              const href = pageLangs[locale];
              if (href) {
                acc.push({
                  locale,
                  region,
                  country,
                  href,
                  language
                });
              }
            });
          });
          return acc;
        }, []);
        return html(_t || (_t = _`
      <c4d-locale-modal
        close-button-assistive-text="${0}"
        header-title="${0}"
        lang-display="${0}"
        ?open="${0}">
        <c4d-regions title="${0}">
          ${0}
        </c4d-regions>

        <c4d-locale-search
          close-button-assistive-text="${0}"
          label-text="${0}"
          placeholder="${0}"
          availability-label-text="${0}"
          unavailability-label-text="${0}">
          ${0}
        </c4d-locale-search>
      </c4d-locale-modal>
    `), ifDefined(modalClose), ifDefined(headerTitle), ifDefined(langDisplay), open, ifDefined(headerTitle), regionList === null || regionList === void 0 ? void 0 : regionList.map(({
          countryList,
          name
        }) => {
          const isInvalid = countryList.length === 0 || (massagedCountryList === null || massagedCountryList === void 0 ? void 0 : massagedCountryList.find(({
            region
          }) => region === name)) === undefined;
          return html(_t2 || (_t2 = _`
              <c4d-region-item link ?disabled="${0}" name="${0}">
                <c4d-card-heading>${0}</c4d-card-heading>
                <div
                  slot="footer"
                  class="${0}--region-item-footer"
                  ?disabled="${0}">
                  ${0}
                </div>
              </c4d-region-item>
            `), isInvalid, name, name, c4dPrefix, isInvalid, isInvalid ? Error20({
            slot: 'icon',
            class: `${c4dPrefix}--card__cta`
          }) : ArrowRight20({
            slot: 'icon',
            class: `${c4dPrefix}--card__cta`
          }));
        }), ifDefined(searchClearText), ifDefined(searchLabel), ifDefined(searchPlaceholder), ifDefined(availabilityText), ifDefined(unavailabilityText), chosenRegion ? html(_t3 || (_t3 = _`
                ${0}
              `), massagedCountryList === null || massagedCountryList === void 0 ? void 0 : massagedCountryList.filter(({
          region
        }) => {
          return region === chosenRegion;
        }).map(({
          country,
          href,
          language,
          locale,
          region
        }) => html(_t4 || (_t4 = _`
                      <c4d-locale-item
                        country="${0}"
                        href="${0}"
                        language="${0}"
                        locale="${0}"
                        region="${0}">
                      </c4d-locale-item>
                    `), country, href, language, locale, region))) : ``);
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t5 || (_t5 = _` <slot></slot> `));
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, HostListenerMixin(HybridRenderMixin(LitElement)));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DLocaleModalComposite;
//# sourceMappingURL=locale-modal-composite.js.map
