import _decorate from "@babel/runtime/helpers/esm/decorate";
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import pickBy from 'lodash-es/pickBy.js';
import { bindActionCreators } from 'redux';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import ConnectMixin from "../../globals/mixins/connect.js";
import store from '../../internal/vendor/@carbon/ibmdotcom-services-store/store.js';
import { loadLanguage, setLanguage, loadLocaleList } from '../../internal/vendor/@carbon/ibmdotcom-services-store/actions/localeAPI.js';
import C4DLocaleModalComposite from "./locale-modal-composite.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * The Redux actions used for `<c4d-locale-modal-container>`.
 */

/**
 * The Redux state used for `<c4d-locale-modal-container>`.
 */

/**
 * The properties for `<c4d-locale-modal-container>` from Redux state.
 */

/**
 * @param state The Redux state for masthead.
 * @returns The converted version of the given state, tailored for `<c4d-locale-modal-container>`.
 */
export function mapStateToProps(state) {
  const {
    localeAPI
  } = state;
  const {
    language,
    localeLists
  } = localeAPI !== null && localeAPI !== void 0 ? localeAPI : {};
  return pickBy({
    localeList: !language ? undefined : localeLists === null || localeLists === void 0 ? void 0 : localeLists[language]
  }, value => value !== undefined);
}

/**
 * @param dispatch The Redux `dispatch()` API.
 * @returns The methods in `<c4d-locale-modal-container>` to dispatch Redux actions.
 */
export function mapDispatchToProps(dispatch) {
  return bindActionCreators({
    _loadLanguage: loadLanguage,
    _setLanguage: setLanguage,
    _loadLocaleList: loadLocaleList
  }, dispatch // TS definition of `bindActionCreators()` seems to have no templated `Dispatch`
  );
}

/**
 * Container component for masthead.
 *
 * @element c4d-locale-modal-container
 */
let C4DLocaleModalContainer = _decorate([customElement(`${c4dPrefix}-locale-modal-container`)], function (_initialize, _ConnectMixin) {
  class C4DLocaleModalContainer extends _ConnectMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLocaleModalContainer,
    d: []
  };
}, ConnectMixin(store, mapStateToProps, mapDispatchToProps)(C4DLocaleModalComposite));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DLocaleModalContainer;
//# sourceMappingURL=locale-modal-container.js.map
