/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import C4DExpressiveModal from '../expressive-modal/expressive-modal';
import '../expressive-modal/expressive-modal-header';
import '../expressive-modal/expressive-modal-heading';
import '../expressive-modal/expressive-modal-close-button';
/**
 * Locale modal.
 *
 * @element c4d-locale-modal
 * @slot regions-selector - The area for the regions selector.
 * @slot locales-selector - The area for the locales selector.
 * @csspart header-label - The header label. Usage: `c4d-locale-modal::part(header-label)`
 * @csspart link-with-icon - The link with icon. Usage: `c4d-locale-modal::part(link-with-icon)`
 * @csspart link-heading - The link heading. Usage: `c4d-locale-modal::part(link-heading)`
 * @csspart modal-content - The modal-content. Usage: `c4d-locale-modal::part(modal-content)`
 * @csspart header-container - The header container. Usage: `c4d-locale-modal::part(header-container)`
 * @csspart header - The header. Usage: `c4d-locale-modal::part(header)`
 * @csspart close-button - The close button. Usage: `c4d-locale-modal::part(close-button)`
 * @csspart heading - The heading. Usage: `c4d-locale-modal::part(heading)`
 * @csspart title - The title. Usage: `c4d-locale-modal::part(title)`
 */
declare class C4DLocaleModal extends C4DExpressiveModal {
    /**
     * The current region.
     */
    private _currentRegion?;
    /**
     * Handles `click` event on the back button.
     */
    private _handleClickBackButton;
    /**
     * Handles `click` event on a region card.
     *
     * @param event The event.
     */
    private _handleClickRegionSelector;
    private _handleAfterClose;
    /**
     * Sets focus on primary selectable element.
     */
    private _setPrimaryFocus;
    /**
     * Sets focus on locale selector search.
     */
    private _setSearchFocus;
    /**
     * @returns The heading content for the region selector page.
     */
    private _renderRegionSelectorHeading;
    /**
     * @returns The heading content for the locale selector page.
     */
    private _renderLocaleSelectorHeading;
    /**
     * @returns The heading content.
     */
    private _renderHeading;
    /**
     * @returns The body content for the region selector page.
     */
    private _renderRegionSelectorBody;
    /**
     * @returns The body content for the locale selector page.
     */
    private _renderLocaleSelectorBody;
    protected _renderHeader(): import("lit-html").TemplateResult<1>;
    protected _renderBody(): import("lit-html").TemplateResult<1>;
    /**
     * The assistive text for the close button.
     */
    closeButtonAssistiveText?: string;
    /**
     * The header title.
     */
    headerTitle: string;
    /**
     * The language to show in the UI.
     */
    langDisplay?: string;
    firstUpdated(): void;
    updated(changedProperties: any): Promise<void>;
    static get stableSelector(): string;
    /**
     * A selector selecting the locale search UI.
     */
    static get selectorLocaleSearch(): string;
    /**
     * A selector selecting the nodes that should be focused when modal gets open.
     */
    static get selectorPrimaryFocus(): string;
    /**
     * A selector selecting tabbable nodes.
     */
    static get selectorTabbable(): string;
    /**
     * Name for event fired when a region is selected.
     */
    static get eventRegionUpdated(): string;
    static styles: any;
}
export default C4DLocaleModal;

//# sourceMappingURL=locale-modal.d.ts.map
