import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4,
  _t5,
  _t6,
  _t7;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html } from 'lit';
import { property, state } from 'lit/decorators.js';
import ArrowLeft20 from '@carbon/web-components/es/icons/arrow--left/20.js';
import EarthFilled16 from '@carbon/web-components/es/icons/earth--filled/16.js';
import HostListener from '@carbon/web-components/es/globals/decorators/host-listener.js';
import { ifDefined } from 'lit/directives/if-defined.js';
import { selectorTabbable } from '@carbon/web-components/es/globals/settings.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import C4DExpressiveModal from "../expressive-modal/expressive-modal.js";
import "../expressive-modal/expressive-modal-header.js";
import "../expressive-modal/expressive-modal-heading.js";
import "../expressive-modal/expressive-modal-close-button.js";
import styles from "././locale-modal.css.js";
import { ICON_PLACEMENT } from "../link-with-icon/link-with-icon.js";
import StickyHeader from '@carbon/ibmdotcom-utilities/es/utilities/StickyHeader/StickyHeader.js';
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Locale modal.
 *
 * @element c4d-locale-modal
 * @slot regions-selector - The area for the regions selector.
 * @slot locales-selector - The area for the locales selector.
 * @csspart header-label - The header label. Usage: `c4d-locale-modal::part(header-label)`
 * @csspart link-with-icon - The link with icon. Usage: `c4d-locale-modal::part(link-with-icon)`
 * @csspart link-heading - The link heading. Usage: `c4d-locale-modal::part(link-heading)`
 * @csspart modal-content - The modal-content. Usage: `c4d-locale-modal::part(modal-content)`
 * @csspart header-container - The header container. Usage: `c4d-locale-modal::part(header-container)`
 * @csspart header - The header. Usage: `c4d-locale-modal::part(header)`
 * @csspart close-button - The close button. Usage: `c4d-locale-modal::part(close-button)`
 * @csspart heading - The heading. Usage: `c4d-locale-modal::part(heading)`
 * @csspart title - The title. Usage: `c4d-locale-modal::part(title)`
 */
let C4DLocaleModal = _decorate([customElement(`${c4dPrefix}-locale-modal`)], function (_initialize, _C4DExpressiveModal) {
  class C4DLocaleModal extends _C4DExpressiveModal {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLocaleModal,
    d: [{
      kind: "field",
      decorators: [state()],
      key: "_currentRegion",
      value: void 0
    }, {
      kind: "method",
      key: "_handleClickBackButton",
      value:
      /**
       * The current region.
       */

      /**
       * Handles `click` event on the back button.
       */
      function _handleClickBackButton(e) {
        e.preventDefault();
        this._currentRegion = undefined;
      }

      /**
       * Handles `click` event on a region card.
       *
       * @param event The event.
       */
    }, {
      kind: "method",
      key: "_handleClickRegionSelector",
      value: function _handleClickRegionSelector(event) {
        const {
          disabled,
          name
        } = event.target;
        if (!disabled) {
          this._currentRegion = name;
        }
      }
    }, {
      kind: "method",
      decorators: [HostListener('eventClose')],
      key: "_handleAfterClose",
      value: function _handleAfterClose() {
        this._currentRegion = undefined;
      }

      /**
       * Sets focus on primary selectable element.
       */
    }, {
      kind: "method",
      key: "_setPrimaryFocus",
      value: async function _setPrimaryFocus() {
        const {
          selectorPrimaryFocus
        } = C4DLocaleModal;
        const focusTarget = this.querySelector(selectorPrimaryFocus);
        if (focusTarget) {
          focusTarget.tabIndex = 0;
          focusTarget.focus();
        }
      }

      /**
       * Sets focus on locale selector search.
       */
    }, {
      kind: "method",
      key: "_setSearchFocus",
      value: async function _setSearchFocus() {
        const {
          selectorLocaleSearch
        } = C4DLocaleModal;
        await this.updateComplete;
        const localeSearch = this.querySelector(selectorLocaleSearch);
        if (localeSearch) {
          localeSearch.reset();
          localeSearch.focus();
        }
      }

      /**
       * @returns The heading content for the region selector page.
       */
    }, {
      kind: "method",
      key: "_renderRegionSelectorHeading",
      value: function _renderRegionSelectorHeading() {
        const {
          headerTitle,
          langDisplay
        } = this;
        return html(_t || (_t = _`
      ${0}
      ${0}
    `), langDisplay && html(_t2 || (_t2 = _`
        <p
          class="${0}--modal-header__label ${0}--type-delta"
          part="header-label">
          ${0}${0}
        </p>
      `), prefix, prefix, langDisplay, EarthFilled16({
          class: `${c4dPrefix}--locale-modal__label-globe`
        })), langDisplay && headerTitle && html(_t3 || (_t3 = _`
        <p class="cds--modal-header__heading cds--type-beta" part="title">
          ${0}
        </p>
      `), headerTitle));
      }

      /**
       * @returns The heading content for the locale selector page.
       */
    }, {
      kind: "method",
      key: "_renderLocaleSelectorHeading",
      value: function _renderLocaleSelectorHeading() {
        const {
          headerTitle,
          _currentRegion: currentRegion,
          _handleClickBackButton: handleClickBackButton
        } = this;
        return html(_t4 || (_t4 = _`
      <c4d-link-with-icon
        icon-placement="${0}"
        href="#"
        part="link-with-icon"
        @click="${0}">
        ${0}${0}
      </c4d-link-with-icon>
      <p
        class="cds--modal-header__heading cds--type-beta"
        tabindex="0"
        part="link-heading">
        ${0}
      </p>
    `), ICON_PLACEMENT.LEFT, handleClickBackButton, headerTitle, ArrowLeft20({
          slot: 'icon',
          class: `${c4dPrefix}--locale-modal__label-arrow`
        }), currentRegion);
      }

      /**
       * @returns The heading content.
       */
    }, {
      kind: "method",
      key: "_renderHeading",
      value: function _renderHeading() {
        const {
          _currentRegion: currentRegion
        } = this;
        return !currentRegion ? this._renderRegionSelectorHeading() : this._renderLocaleSelectorHeading();
      }

      /**
       * @returns The body content for the region selector page.
       */
    }, {
      kind: "method",
      key: "_renderRegionSelectorBody",
      value: function _renderRegionSelectorBody() {
        const {
          _handleClickRegionSelector: handleClickRegionSelector
        } = this;
        return html(_t5 || (_t5 = _`
      <div
        class="${0}--modal-content ${0}--locale-modal"
        @click="${0}"
        part="modal-content">
        <slot name="regions-selector"></slot>
      </div>
    `), prefix, c4dPrefix, handleClickRegionSelector);
      }

      /**
       * @returns The body content for the locale selector page.
       */
      // eslint-disable-next-line class-methods-use-this
    }, {
      kind: "method",
      key: "_renderLocaleSelectorBody",
      value: function _renderLocaleSelectorBody() {
        return html(_t6 || (_t6 = _` <slot name="locales-selector"></slot> `));
      }
    }, {
      kind: "method",
      key: "_renderHeader",
      value: function _renderHeader() {
        const {
          closeButtonAssistiveText
        } = this;
        return html(_t7 || (_t7 = _`
      <div id="${0}--modal-header" part="header-container">
        <c4d-expressive-modal-header part="header">
          <c4d-expressive-modal-close-button
            assistive-text="${0}"
            part="close-button">
          </c4d-expressive-modal-close-button>
          <c4d-expressive-modal-heading part="heading"
            >${0}</c4d-expressive-modal-heading
          >
        </c4d-expressive-modal-header>
      </div>
    `), prefix, ifDefined(closeButtonAssistiveText), this._renderHeading());
      }
    }, {
      kind: "method",
      key: "_renderBody",
      value: function _renderBody() {
        const {
          _currentRegion: currentRegion
        } = this;
        return !currentRegion ? this._renderRegionSelectorBody() : this._renderLocaleSelectorBody();
      }

      /**
       * The assistive text for the close button.
       */
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'close-button-assistive-text'
      })],
      key: "closeButtonAssistiveText",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'header-title'
      })],
      key: "headerTitle",
      value() {
        return 'Select geographic area';
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'lang-display'
      })],
      key: "langDisplay",
      value: void 0
    }, {
      kind: "method",
      key: "firstUpdated",
      value:
      /**
       * The header title.
       */
      /**
       * The language to show in the UI.
       */
      function firstUpdated() {
        StickyHeader.global.localeModal = this;
      }
    }, {
      kind: "method",
      key: "updated",
      value: async function updated(changedProperties) {
        _superPropGet(C4DLocaleModal, "updated", this, 3)([changedProperties]);
        if (changedProperties.has('_currentRegion')) {
          // Allow listening components to update their state.
          this.dispatchEvent(new CustomEvent(this.constructor.eventRegionUpdated, {
            bubbles: true,
            composed: true,
            cancelable: true,
            detail: {
              region: this._currentRegion
            }
          }));

          // Pass state to search element.
          const {
            selectorLocaleSearch
          } = this.constructor;
          const localeSearch = this.querySelector(selectorLocaleSearch);
          if (localeSearch) {
            var _this$_currentRegion;
            localeSearch.region = (_this$_currentRegion = this._currentRegion) !== null && _this$_currentRegion !== void 0 ? _this$_currentRegion : '';
          }

          // Set element focus.
          this._currentRegion ? this._setSearchFocus() : this._setPrimaryFocus();
        }
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--locale-modal`;
      }

      /**
       * A selector selecting the locale search UI.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorLocaleSearch",
      value: function () {
        return `${c4dPrefix}-locale-search`;
      }

      /**
       * A selector selecting the nodes that should be focused when modal gets open.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorPrimaryFocus",
      value: function () {
        return `
      [data-modal-primary-focus],
      ${c4dPrefix}-region-item
    `;
      }

      /**
       * A selector selecting tabbable nodes.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorTabbable",
      value: function () {
        return `
      ${selectorTabbable},
      ${c4dPrefix}-expressive-modal,
      ${c4dPrefix}-expressive-modal-close-button,
      ${c4dPrefix}-region-item,
      ${prefix}-search,
      ${c4dPrefix}-locale-item
    `;
      }

      /**
       * Name for event fired when a region is selected.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventRegionUpdated",
      value: function () {
        return `${c4dPrefix}-locale-modal-region-updated`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, C4DExpressiveModal);
export default C4DLocaleModal;
//# sourceMappingURL=locale-modal.js.map
