import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property, query, state } from 'lit/decorators.js';
import { INPUT_SIZE } from '@carbon/web-components/es/components/text-input/text-input.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import ThrottedInputMixin from "../../globals/mixins/throttled-input.js";
import { forEach } from "../../globals/internal/collection-helpers.js";
import '@carbon/web-components/es/components/search/search.js';
import styles from "././locale-modal.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * @param target The strings to find the given `searchText` within.
 * @param searchText The search string.
 * @returns `true` if there is a match.
 */
function search(target, searchText) {
  const isEmpty = !target || !target.some(Boolean);
  if (isEmpty || !searchText) {
    return true;
  }
  return target.some(item => item && item.toLowerCase().indexOf(searchText.toLowerCase()) >= 0);
}

/**
 * Locale search box.
 *
 * @element c4d-locale-search
 * @csspart filter - The filter. Usage: `c4d-locale-search::part(filter)`
 * @csspart search - The search. Usage: `c4d-locale-search::part(search)`
 * @csspart aria-updates - The hidden div between searchbox and search-text. Usage: `c4d-locale-search::part(aria-updates)`
 * @csspart search-text - The search text. Usage: `c4d-locale-search::part(search-text)`
 * @csspart list - The list. Usage: `c4d-locale-search::part(ist)`
 * @csspart searchbox - The searchbox. Usage: `c4d-locale-search::part(searchbox)`
 */
let C4DLocaleSearch = _decorate([customElement(`${c4dPrefix}-locale-search`)], function (_initialize, _ThrottedInputMixin) {
  class C4DLocaleSearch extends _ThrottedInputMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLocaleSearch,
    d: [{
      kind: "field",
      decorators: [query(`.${c4dPrefix}--locale-modal__list`)],
      key: "_listNode",
      value: void 0
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasAvailableItem",
      value() {
        return true;
      }
    }, {
      kind: "field",
      decorators: [query(`${prefix}-search`)],
      key: "_searchNode",
      value: void 0
    }, {
      kind: "field",
      decorators: [query('[aria-live]')],
      key: "_liveRegion",
      value: void 0
    }, {
      kind: "method",
      key: "_updateSearchResults",
      value:
      /**
       * The container for the locale list.
       */

      /**
       * `true` if there is one or more search result.
       */

      /**
       * The search box.
       */

      /**
       * Updates the search results.
       *
       * @param searchText The search text.
       */
      function _updateSearchResults(searchText) {
        const {
          selectorItem
        } = this.constructor;
        const {
          region: currentRegion,
          _liveRegion: liveRegion
        } = this;
        let count = 0;
        forEach(this.querySelectorAll(selectorItem), item => {
          const {
            country,
            language,
            region
          } = item;
          const matches = region === currentRegion && search([country, language], searchText);
          if (matches) {
            count++;
          }
          item.hidden = !matches;
        });
        this._hasAvailableItem = count > 0;
        if (liveRegion) {
          const announcement = count === 1 ? `${count} result` : `${count} results`;
          liveRegion.innerText = announcement;
        }
      }
    }, {
      kind: "method",
      key: "_handleThrottledInput",
      value: function _handleThrottledInput(event) {
        this._updateSearchResults(event.detail.value);
      }

      /**
       * The text for the label for the UI showing the available locales.
       */
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'availability-label-text'
      })],
      key: "availabilityLabelText",
      value() {
        return 'This page is available in the following locations and languages';
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'close-button-assistive-text'
      })],
      key: "closeButtonAssistiveText",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Number,
        attribute: 'input-timeout'
      })],
      key: "inputTimeout",
      value() {
        return 200;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'label-text'
      })],
      key: "labelText",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "placeholder",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "region",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "slot",
      value() {
        return 'locales-selector';
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'unavailability-label-text'
      })],
      key: "unavailabilityLabelText",
      value() {
        return 'This page is unavailable in your preferred location or language';
      }
    }, {
      kind: "method",
      key: "focus",
      value:
      /**
       * The assistive text for the close button in the search box.
       */
      /**
       * The throttle timeout to run query upon user input.
       */
      /**
       * The label text for the search box.
       */
      /**
       * The placeholder text for the search box.
       */
      /**
       * The current region.
       */
      /**
       * The shadow slot this locale search box should be in.
       */
      /**
       * The text for the label for the UI showing no available locale.
       */
      /**
       * Focus on first focusable element in shadow DOM
       */
      function focus() {
        // @ts-ignore: Ultil `delegatesFocus` is added to `ShadowRoot` definition
        if (this.shadowRoot.delegatesFocus) {
          _superPropGet(C4DLocaleSearch, "focus", this, 3)([]);
        } else {
          const {
            selectorTabable
          } = this.constructor;
          const delegateTarget = this.shadowRoot.querySelector(selectorTabable);
          if (delegateTarget) {
            delegateTarget.focus();
          } else {
            _superPropGet(C4DLocaleSearch, "focus", this, 3)([]);
          }
        }
      }

      /**
       * Resets the search box and the scroll position.
       */
    }, {
      kind: "method",
      key: "reset",
      value: function reset() {
        const {
          _listNode: listNode,
          _searchNode: searchNode
        } = this;
        if (listNode) {
          listNode.scrollTop = 0;
        }
        if (searchNode) {
          searchNode.value = '';
          this._updateSearchResults('');
        }
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        const {
          _searchNode: searchNode
        } = this;
        if (searchNode) {
          this._updateSearchResults(searchNode.value);
        }
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated(changedProperties) {
        if (changedProperties.has('region')) {
          const {
            selectorItem
          } = this.constructor;
          const {
            region
          } = this;
          forEach(this.querySelectorAll(selectorItem), item => {
            item.hidden = item.region !== region;
          });
        }
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          availabilityLabelText,
          closeButtonAssistiveText,
          labelText,
          placeholder,
          unavailabilityLabelText,
          _hasAvailableItem: hasAvailableItem
        } = this;
        return html(_t || (_t = _`
      <div class="${0}--locale-modal__filter" part="filter">
        <div class="${0}--locale-modal__search" part="search">
          <cds-search
            part="searchbox"
            close-button-assistive-text="${0}"
            label-text="${0}"
            placeholder="${0}"
            size="${0}"
            data-autoid="${0}--locale-modal__filter">
          </cds-search>
          <div
            class="${0}--visually-hidden"
            aria-live="polite"
            part="aria-updates"></div>
          <p class="${0}--locale-modal__search-text" part="search-text">
            ${0}
          </p>
        </div>
        <div class="${0}--locale-modal__list" part="list" role="list">
          <slot></slot>
        </div>
      </div>
    `), c4dPrefix, c4dPrefix, closeButtonAssistiveText, labelText, placeholder, INPUT_SIZE.LARGE, c4dPrefix, prefix, c4dPrefix, hasAvailableItem ? availabilityLabelText : unavailabilityLabelText, c4dPrefix);
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--locale-search`;
      }

      /**
       * A selector selecting the locale item,
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorTabable",
      value: function () {
        return `${prefix}-search`;
      }

      /**
       * A selector selecting the locale items.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItem",
      value: function () {
        return `${c4dPrefix}-locale-item`;
      }

      /**
       * The event that represents the user input gesture.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventInput",
      value: function () {
        return `${prefix}-search-input`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, ThrottedInputMixin(StableSelectorMixin(LitElement)));
export default C4DLocaleSearch;
//# sourceMappingURL=locale-search.js.map
