import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4,
  _t5;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { css, html } from 'lit';
import { property } from 'lit/decorators.js';
import { classMap } from 'lit/directives/class-map.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import parseAspectRatio from '@carbon/ibmdotcom-utilities/es/utilities/parseAspectRatio/parseAspectRatio.js';
import C4DContentBlock from "../content-block/content-block.js";
import "../horizontal-rule/horizontal-rule.js";
import "../content-block/content-block-heading.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././logo-grid.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Logo grid.
 *
 * @element c4d-logo-grid
 * @csspart content-wrapper - The wrapper. Usage: 'c4d-logo-grid::part(content-wrapper)'
 * @csspart content-body - The content body. Usage: 'c4d-logo-grid::part(content-body)'
 * @csspart content - The content. Usage 'c4d-logo-grid::part(content)'
 * @csspart footer-container - The footer container. Usage: 'c4d-logo-grid::part(footer-containe)'
 * @csspart footer - The footer. Usage: 'c4d-logo-grid::part(footer)'
 * @csspart hr - The horizontal rule. Usage: 'c4d-logo-grid::part(hr)'
 */
let C4DLogoGrid = _decorate([customElement(`${c4dPrefix}-logo-grid`)], function (_initialize, _StableSelectorMixin) {
  class C4DLogoGrid extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLogoGrid,
    d: [{
      kind: "method",
      key: "_renderInnerBody",
      value: function _renderInnerBody() {
        const {
          _hasContent: hasContent,
          _hasMedia: hasMedia,
          logoCount
        } = this;
        const rowClasses = {
          [`${prefix}--logo-grid__row`]: true,
          [`${prefix}--logo-grid__${logoCount}-columns`]: logoCount
        };
        return html(_t || (_t = _`
      <div
        ?hidden="${0}"
        class="${0}--content-block__children ${0}--content-layout__body"
        part="content-body">
        <div class="${0}" part="content">
          ${0}${0}
        </div>
      </div>
    `), !hasContent && !hasMedia, prefix, prefix, classMap(rowClasses), this._renderContent(), this._renderMedia());
      }

      /**
       * @returns The footer content.
       */
    }, {
      kind: "method",
      key: "_renderFooter",
      value: function _renderFooter() {
        const {
          _hasFooter: hasFooter,
          _handleSlotChange: handleSlotChange
        } = this;
        return html(_t2 || (_t2 = _`
      <div
        ?hidden="${0}"
        class="${0}--content-block__cta-row"
        part="footer-container">
        <div
          class="${0}--content-block__cta ${0}-content-block__cta-col"
          part="footer">
          <slot name="footer" @slotchange="${0}"></slot>
        </div>
      </div>
    `), !hasFooter, prefix, prefix, prefix, handleSlotChange);
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'hide-border',
        reflect: true,
        type: Boolean
      })],
      key: "hideBorder",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'logo-count',
        reflect: true
      })],
      key: "logoCount",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'logo-ratio',
        reflect: true
      })],
      key: "logoRatio",
      value: void 0
    }, {
      kind: "method",
      key: "updated",
      value:
      /**
       * Integer value that determines the number of columns in the grid.
       *
       * While any non-zero integer will work, styles will constrain values to between
       * two and four.
       */
      /**
       * Aspect ratio of grid cells.
       *
       * Values should match the format `<integer><divider-character><integer>`.
       * Any non-digit character can work as a divider.
       */
      function updated(changedProperties) {
        const {
          logoRatio
        } = this;
        if (changedProperties.has('logoRatio')) {
          if (logoRatio) {
            const ratioSplit = parseAspectRatio(logoRatio);
            if (ratioSplit.length === 2) {
              const [w, h] = ratioSplit;
              this.style.setProperty('--logo-ratio', `${w}/${h}`);
            }
          } else {
            this.style.removeProperty('--logo-ratio');
          }
        }
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t3 || (_t3 = _`
      <div class="${0}--content-layout--logo-grid" part="content-wrapper">
        <slot name="heading"></slot>
        ${0}
      </div>
      ${0}
    `), prefix, this._renderBody(), !this.hideBorder ? html(_t4 || (_t4 = _` <c4d-hr part="hr"></c4d-hr> `)) : ``);
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--logo-grid`;
      }

      // `styles` here is a `CSSResult` generated by custom WebPack loader
    }, {
      kind: "get",
      static: true,
      key: "styles",
      value: function () {
        return css(_t5 || (_t5 = _`
      ${0}${0}
    `), _superPropGet(C4DLogoGrid, "styles", this), styles);
      }
    }]
  };
}, StableSelectorMixin(C4DContentBlock));
console.warn('The logo-grid component has been deprecated in favor of the content-section/block and image-group component. ' +
//TODO confirm new image-group or images in grid
'See content-section/block and image-group documentation for more information.');

/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DLogoGrid;
//# sourceMappingURL=logo-grid.js.map
