/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { LitElement } from 'lit';
import '@carbon/web-components/es/components/link/link.js';
import '@carbon/web-components/es/components/list/ordered-list.js';
import '@carbon/web-components/es/components/list/unordered-list.js';
import '@carbon/web-components/es/components/list/list-item.js';
/**
 * Markdown content.
 *
 * @element c4d-markdown
 * @csspart link - The custom link element. Usage: `c4d-markdown::part(link)`
 * @csspart ordered-list - The ordered list element. Usage: `c4d-markdown::part(ordered-list)`
 * @csspart unordered-list - The unordered list element. Usage: `c4d-markdown::part(unordered-list)`
 * @csspart list - The list element. Usage: `c4d-markdown::part(list)`
 * @csspart list-item - The list item element. Usage: `c4d-markdown::part(list-item)`
 */
declare class C4DMarkdown extends LitElement {
    /**
     * `true` if the first rendering has happened.
     */
    private _hasRendered;
    /**
     * The list of custom element tags that is rendered by our custom renderer.
     */
    protected get _customTags(): Set<string>;
    /**
     * The custom renderer for the markup parser.
     */
    protected get _renderer(): {
        link(href: any, title: any, text: any): string;
        list(body: any, ordered: any): string;
        listitem(text: any): string;
    };
    /**
     * The markdown content.
     */
    content?: string;
    update(changedProperties: any): void;
    render(): import("lit-html").TemplateResult<1>;
    static styles: any;
}
export default C4DMarkdown;

//# sourceMappingURL=markdown.d.ts.map
