import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t,
  _t2,
  _t3;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { state, property } from 'lit/decorators.js';
import { classMap } from 'lit/directives/class-map.js';
import ArrowRight20 from '@carbon/web-components/es/icons/arrow--right/20.js';
import ArrowLeft20 from '@carbon/web-components/es/icons/arrow--left/20.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
import styles from "././masthead.css.js";
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * MegaMenu Category Group Description.
 *
 * @element c4d-megamenu-category-group-desc
 * @csspart heading - The h2 element of the left navigation menu category heading. Usage: `c4d-left-nav-menu-category-heading::part(heading)`
 * @csspart heading-link - The link element of the left navigation menu category heading. Usage: `c4d-left-nav-menu-category-heading::part(heading-link)`
 * @csspart container - The side navigation heading container. Usage: `c4d-left-nav-menu-category-heading::part(container)`
 * @csspart description - The description container within the side navigation heading. Usage: `c4d-left-nav-menu-category-heading::part(description)`
 */
let C4DLeftNavMenuCategoryHeading = _decorate([customElement(`${c4dPrefix}-left-nav-menu-category-heading`)], function (_initialize, _LitElement) {
  class C4DLeftNavMenuCategoryHeading extends _LitElement {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLeftNavMenuCategoryHeading,
    d: [{
      kind: "field",
      decorators: [property({
        attribute: 'title'
      })],
      key: "headingText",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'url'
      })],
      key: "url",
      value: void 0
    }, {
      kind: "field",
      decorators: [state()],
      key: "boostSize",
      value: void 0
    }, {
      kind: "method",
      key: "updated",
      value: function updated(changedProperties) {
        if (changedProperties.has('boostSize')) {
          this.classList.toggle(`${prefix}--left-nav-menu-category__heading-large`, this.boostSize);
        }
      }
    }, {
      kind: "method",
      key: "_renderHeading",
      value: function _renderHeading() {
        const {
          headingText,
          url
        } = this;
        const isRTL = document.dir.toLowerCase() === 'rtl';
        const headingClasses = {
          [`${prefix}--side-nav__menu-section-title`]: this.boostSize || false,
          [`${prefix}--side-nav__heading-title`]: !url
        };
        return url ? html(_t || (_t = _`
          <h2 part="heading" class="${0}">
            <a
              part="heading-link"
              href="${0}"
              class="${0}--side-nav__heading-title"
              data-attribute1="headerNav"
              data-attribute2="FlatHdline"
              data-attribute3="${0}">
              ${0}${0}
            </a>
          </h2>
        `), classMap(headingClasses), url, prefix, headingText, headingText, isRTL ? ArrowLeft20() : ArrowRight20()) : html(_t2 || (_t2 = _`
          <h2 part="heading" class="${0}">
            ${0}
          </h2>
        `), classMap(headingClasses), headingText);
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t3 || (_t3 = _`
      <div part="container" class="${0}--side-nav__heading">
        ${0}
        <div
          part="description"
          class="${0}--side-nav__heading-description">
          <slot></slot>
        </div>
      </div>
    `), prefix, this._renderHeading(), prefix);
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, LitElement);
export default C4DLeftNavMenuCategoryHeading;
//# sourceMappingURL=left-nav-menu-category-heading.js.map
