import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import HostListener from '@carbon/web-components/es/globals/decorators/host-listener.js';
import HostListenerMixin from '@carbon/web-components/es/globals/mixins/host-listener.js';
import ChevronLeft16 from '@carbon/web-components/es/icons/chevron--left/16.js';
import FocusMixin from '@carbon/web-components/es/globals/mixins/focus.js';
import { selectorTabbable } from '@carbon/web-components/es/globals/settings.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././masthead.css.js";
import C4DLeftNav from "./left-nav.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Masthead left nav menu section.
 *
 * @element c4d-left-nav-menu-section
 * @csspart side-nav-submenu-container - The container for the submenu. Usage: `c4d-left-nav-menu-section::part(side-nav-submenu-container)`
 * @csspart menu-item - The submenu item. Usage: `c4d-left-nav-menu-section::part(menu-item)`
 * @csspart menu-link - The side navigation link. Usage: `c4d-left-nav-menu-section::part(menu-link)`
 * @csspart menu-link-text - The text within the side navigation link. Usage: `c4d-left-nav-menu-section::part(menu-link-text back-button-text)`
 * @csspart back-button - The back button. Usage: `c4d-left-nav-menu-section::part(back-button)`
 * @fires c4d-left-nav-menu-beingtoggled
 *   The custom event fired before this side nav menu is being toggled upon a user gesture.
 *   Cancellation of this event stops the user-initiated action of toggling this side nav menu.
 * @fires c4d-left-nav-menu-toggled The custom event fired after this side nav menu is toggled upon a user gesture.
 */
let C4DLeftNavMenuSection = _decorate([customElement(`${c4dPrefix}-left-nav-menu-section`)], function (_initialize, _HostListenerMixin) {
  class C4DLeftNavMenuSection extends _HostListenerMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLeftNavMenuSection,
    d: [{
      kind: "field",
      decorators: [property({
        type: String,
        attribute: 'aria-hidden',
        reflect: true
      })],
      key: "ariaHidden",
      value() {
        return 'true';
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'back-button-text'
      })],
      key: "backButtonText",
      value() {
        return 'Back';
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true
      })],
      key: "expanded",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: String,
        attribute: 'section-id'
      })],
      key: "sectionId",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true
      })],
      key: "transition",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        attribute: 'is-submenu'
      })],
      key: "isSubmenu",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true,
        attribute: 'show-back-button'
      })],
      key: "showBackBtn",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "title",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "titleUrl",
      value() {
        return '';
      }
    }, {
      kind: "method",
      key: "_requestLeftNavMenuSectionUpdate",
      value:
      /**
       * Set aria-hidden property.
       */

      /**
       * The back button's text.
       */

      /**
       * `true` if the menu should be visible.
       */

      /**
       * id of the menu section.
       */

      /**
       * in transition mode.
       */

      /**
       * is a submenu menu section.
       */

      /**
       * Render back button.
       */

      /**
       * The title text.
       */

      /**
       * The title url.
       */

      async function _requestLeftNavMenuSectionUpdate() {
        const {
          eventToggle
        } = this.constructor;
        return new Promise(resolve => {
          this.dispatchEvent(new CustomEvent(eventToggle, {
            bubbles: true,
            cancelable: true,
            composed: true,
            detail: {
              active: this.expanded,
              resolveFn: resolve
            }
          }));
          setTimeout(() => {
            resolve();
          }, 0);
        });
      }

      /**
       * Handler for the `click` event on the back button.
       */
    }, {
      kind: "method",
      key: "_handleClickBack",
      value: function _handleClickBack() {
        const {
          eventToggle
        } = this.constructor;
        const id = this.sectionId.split(', ');
        let panelId = '';
        /**
         * if second part of id string is '-1' that means user is on level 1 menu panel,
         * set first part of string to -1 to bring back to level 0 menu panel.
         */
        if (id[1] === '-1') {
          panelId = '-1, -1';
        } else {
          panelId = `${id[0]}, -1`;
        }
        const init = {
          bubbles: true,
          cancelable: true,
          composed: true,
          detail: {
            panelId
          }
        };
        this.dispatchEvent(new CustomEvent(eventToggle, init));
      }
    }, {
      kind: "method",
      decorators: [HostListener('transitionend')],
      key: "_handleTransitionEnd",
      value: function _handleTransitionEnd() {
        setTimeout(() => {
          if (this.expanded) {
            // Allow active section to scroll
            this.style.overflow = '';
          } else {
            // Hide previous section & restrict size
            this.style.visibility = 'hidden';
            this.style.height = '0';
            this.style.overflow = 'hidden';
          }
        }, 0);
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        if (this.sectionId === '-1, -1') {
          this.expanded = true;
          this.ariaHidden = 'false';
        } else {
          this.expanded = false;
          this.ariaHidden = 'true';
          // Hide all submenus, and restrict their height/overflow.
          this.style.visibility = 'hidden';
          this.style.height = '0';
          this.style.overflow = 'hidden';
        }
      }
    }, {
      kind: "method",
      key: "shouldUpdate",
      value: function shouldUpdate(changedProperties) {
        if (changedProperties.has('expanded')) {
          // Allow incoming menu section to show before transition.
          if (this.expanded) {
            this.style.visibility = '';
            this.style.height = '';
          }
        }
        return true;
      }
    }, {
      kind: "method",
      key: "updated",
      value: async function updated(changedProperties) {
        await this._requestLeftNavMenuSectionUpdate();
        if (changedProperties.has('expanded')) {
          const {
            expanded,
            isSubmenu
          } = this;
          if (expanded) {
            // set focus to first element of menu panel to allow for tabbing through the menu
            let tabbable;
            if (isSubmenu) {
              var _this$shadowRoot;
              // set focus to back button
              tabbable = (_this$shadowRoot = this.shadowRoot) === null || _this$shadowRoot === void 0 ? void 0 : _this$shadowRoot.querySelector('button');
            } else {
              // set focus to first menu item of section
              tabbable = this.getRootNode().querySelector(C4DLeftNav.selectorNavItems);
            }
            if (tabbable) {
              this.addEventListener('transitionend', () => {
                tabbable.focus();
              }, {
                once: true
              });
            }
          }
        }
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value: function connectedCallback() {
        _superPropGet(C4DLeftNavMenuSection, "connectedCallback", this, 3)([]);
        if (document.dir) {
          this.dir = document.dir;
        }
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          backButtonText,
          _handleClickBack: handleClickBack,
          showBackBtn
        } = this;
        return html(_t || (_t = _`
      <ul part="side-nav-submenu-container">
        ${0}
        <slot></slot>
      </ul>
    `), showBackBtn ? html(_t2 || (_t2 = _`
              <li
                part="menu-item back-button-wrapper"
                class="${0}--side-nav__menu-item ${0}--masthead__side-nav--submemu-back"
                role="none">
                <button
                  part="menu-link back-button"
                  class="${0}--side-nav__link"
                  @click="${0}">
                  <span
                    part="menu-link-text back-button-text"
                    class="${0}--side-nav__link-text"
                    >${0}${0}</span
                  >
                </button>
              </li>
            `), prefix, prefix, prefix, handleClickBack, prefix, ChevronLeft16(), backButtonText) : undefined);
      }

      /**
       * The name of the custom event fired after this side nav menu is toggled upon a user gesture.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventToggle",
      value: function () {
        return `${c4dPrefix}-left-nav-menu-toggled`;
      }

      /**
       * A selector that will return the nav menus.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorNavMenu",
      value: function () {
        return `${c4dPrefix}-left-nav-menu`;
      }

      /**
       * A selector that will return the menu items.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorNavItem",
      value: function () {
        return `${c4dPrefix}-left-nav-menu-item`;
      }

      /**
       * A selector selecting tabbable nodes.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorTabbable",
      value: function () {
        return [selectorTabbable, `${c4dPrefix}-left-nav-menu`, `${c4dPrefix}-left-nav-menu-item`].join(',');
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, HostListenerMixin(FocusMixin(LitElement)));
export default C4DLeftNavMenuSection;
//# sourceMappingURL=left-nav-menu-section.js.map
