import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import { classMap } from 'lit/directives/class-map.js';
import ChevronDown16 from '@carbon/web-components/es/icons/chevron--down/16.js';
import FocusMixin from '@carbon/web-components/es/globals/mixins/focus.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././masthead.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Masthead left nav submenu.
 *
 * @element c4d-left-nav-menu
 * @fires c4d-left-nav-menu-beingtoggled
 *   The custom event fired before this side nav menu is being toggled upon a user gesture.
 *   Cancellation of this event stops the user-initiated action of toggling this side nav menu.
 * @fires c4d-left-nav-menu-toggled The custom event fired after this side nav menu is toggled upon a user gesture.
 * @csspart side-nav-item-button - The button for the side navigation item. Usage: `c4d-left-nav-menu::part(side-nav-item-button)`
 * @csspart side-nav-submenu-content - The content of the side navigation submenu. Usage: `c4d-left-nav-menu::part(side-nav-submenu-content)`
 * @csspart side-nav-submenu-title - The title of the side navigation submenu. Usage: `c4d-left-nav-menu::part(side-nav-submenu-title)`
 * @csspart side-nav-icon - The icon of the side navigation submenu. Usage: `c4d-left-nav-menu::part(side-nav-icon)`
 *  @csspart side-nav-item-container - The container for the side navigation item. Usage: `c4d-left-nav-menu::part(side-nav-item-container)`
 */
let C4DLeftNavMenu = _decorate([customElement(`${c4dPrefix}-left-nav-menu`)], function (_initialize, _FocusMixin) {
  class C4DLeftNavMenu extends _FocusMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLeftNavMenu,
    d: [{
      kind: "method",
      key: "_handleUserInitiatedToggle",
      value:
      /**
       * Handles user-initiated toggle request of this side nav menu.
       *
       * @param expanded The new expanded state.
       */
      function _handleUserInitiatedToggle(expanded = !this.expanded, panelId = this.panelId) {
        const {
          eventBeforeToggle,
          eventToggle
        } = this.constructor;
        const init = {
          bubbles: true,
          cancelable: true,
          composed: true,
          detail: {
            expanded,
            panelId
          }
        };
        if (this.dispatchEvent(new CustomEvent(eventBeforeToggle, init))) {
          this.expanded = expanded;
          this.dispatchEvent(new CustomEvent(eventToggle, init));
        }
      }

      /**
       * Handler for the `click` event on the expando button.
       */
    }, {
      kind: "method",
      key: "_handleClickExpando",
      value: function _handleClickExpando() {
        this._handleUserInitiatedToggle();
      }

      /**
       * `true` if the menu should be in its active state.
       */
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true
      })],
      key: "active",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true
      })],
      key: "expanded",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: String,
        attribute: 'panel-id'
      })],
      key: "panelId",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "title",
      value() {
        return '';
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value:
      /**
       * `true` if the menu should be open.
       */
      /**
       * `true` if the menu should be open.
       */
      /**
       * The title text.
       */
      function connectedCallback() {
        _superPropGet(C4DLeftNavMenu, "connectedCallback", this, 3)([]);
        if (document.dir) {
          this.dir = document.dir;
        }
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        var _this$parentElement;
        const {
          active,
          expanded,
          title,
          _handleClickExpando: handleClickExpando
        } = this;
        const buttonClasses = classMap({
          [`${prefix}--side-nav__submenu`]: true,
          [`${prefix}--masthead__side-nav--submemu--selected`]: active
        });
        const isSubitem = ((_this$parentElement = this.parentElement) === null || _this$parentElement === void 0 ? void 0 : _this$parentElement.hasAttribute('is-submenu')) || false;
        return html(_t || (_t = _`
      <div class="${0}--side-nav__item" part="side-nav-item-container">
        <button
          part="side-nav-item-button"
          type="button"
          aria-haspopup="true"
          aria-expanded="${0}"
          class="${0}"
          @click=${0}
          data-attribute1="headerNav"
          data-attribute2="${0}"
          data-attribute3="${0}">
          <div
            part="side-nav-submenu-content"
            class="${0}--side-nav__submenu-content">
            <span
              part="side-nav-submenu-title"
              class="${0}--side-nav__submenu-title"
              >${0}</span
            >
            <div
              part="side-nav-icon"
              class="${0}--side-nav__icon ${0}--side-nav__icon--small ${0}--side-nav__submenu-chevron">
              ${0}
            </div>
          </div>
        </button>
      </div>
    `), prefix, expanded, buttonClasses, handleClickExpando, isSubitem ? 'TabHdline' : 'L0', title, prefix, prefix, title, prefix, prefix, prefix, ChevronDown16());
      }

      /**
       * The name of the custom event fired before this side nav menu is being toggled upon a user gesture.
       * Cancellation of this event stops the user-initiated action of toggling this side nav menu.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventBeforeToggle",
      value: function () {
        return `${c4dPrefix}-left-nav-menu-beingtoggled`;
      }

      /**
       * The name of the custom event fired after this side nav menu is toggled upon a user gesture.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventToggle",
      value: function () {
        return `${c4dPrefix}-left-nav-menu-toggled`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, FocusMixin(LitElement));
export default C4DLeftNavMenu;
//# sourceMappingURL=left-nav-menu.js.map
