import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2025
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import findLast from 'lodash-es/findLast.js';
import { html } from 'lit';
import { property, query } from 'lit/decorators.js';
import { selectorTabbable } from '@carbon/web-components/es/globals/settings.js';
import HostListener from '@carbon/web-components/es/globals/decorators/host-listener.js';
import CDSSideNav, { SIDE_NAV_USAGE_MODE } from '@carbon/web-components/es/components/ui-shell/side-nav.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import focuswrap from '@carbon/ibmdotcom-utilities/es/utilities/focuswrap/focuswrap.js';
import { find, forEach } from "../../globals/internal/collection-helpers.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././masthead.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

// eslint-disable-next-line no-bitwise
const PRECEDING = Node.DOCUMENT_POSITION_PRECEDING | Node.DOCUMENT_POSITION_CONTAINS;
// eslint-disable-next-line no-bitwise
const FOLLOWING = Node.DOCUMENT_POSITION_FOLLOWING | Node.DOCUMENT_POSITION_CONTAINED_BY;

/**
 * Masthead left nav.
 *
 * @element c4d-left-nav
 * @csspart side-nav-wrapper - The wrapper element for the side nav. Usage: `c4d-left-nav::part(side-nav-wrapper)`
 * @csspart platform-name - The element containing the platform name slot. Usage: `c4d-left-nav::part(platform-name)`
 * @csspart menu-sections - The element containing the menu sections slot. Usage: `c4d-left-nav::part(menu-sections)`
 */
let C4DLeftNav = _decorate([customElement(`${c4dPrefix}-left-nav`)], function (_initialize, _StableSelectorMixin) {
  class C4DLeftNav extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DLeftNav,
    d: [{
      kind: "field",
      key: "_hFocusWrap",
      value() {
        return null;
      }
    }, {
      kind: "field",
      decorators: [query('#start-sentinel')],
      key: "_startSentinelNode",
      value: void 0
    }, {
      kind: "field",
      decorators: [query('#end-sentinel')],
      key: "_endSentinelNode",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean
      })],
      key: "_importedSideNav",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [HostListener('parentRoot:eventButtonToggle')],
      key: "_handleButtonToggle",
      value() {
        return async event => {
          if (!this._importedSideNav) {
            await Promise.all([import('./left-nav-name'), import('./left-nav-menu'), import('./left-nav-menu-section'), import('./left-nav-menu-item'), import('./left-nav-menu-category-heading'), import('./left-nav-overlay')]);
            this._importedSideNav = true;
          }
          this.expanded = event.detail.active;
        };
      }
    }, {
      kind: "field",
      decorators: [HostListener('document:cds-request-focus-wrap')],
      key: "_handleRequestMenuButtonFocusWrap",
      value() {
        return event => {
          const {
            selectorButtonToggle
          } = this.constructor;
          /**
           * If focus leaves this element, send focus to the menu toggle.
           * Else if focus leaves the menu toggle, bring it back to this element.
           */
          if (event.target === this) {
            const toggle = this.getRootNode().querySelector(selectorButtonToggle);
            if (toggle) {
              toggle.focus();
            }
          } else if (event.composedPath()[1].tagName === selectorButtonToggle.toUpperCase()) {
            const {
              comparisonResult
            } = event.detail;
            const {
              selectorExpandedMenuSection,
              selectorTabbable: selectorTabbableForLeftnav
            } = this.constructor;
            const expandedMenuSection = this.querySelector(selectorExpandedMenuSection);

            // focus on first tabbable element when expanding left-nav
            if (comparisonResult === -1) {
              const tabbable = find(this.querySelectorAll(selectorTabbableForLeftnav), elem => Boolean(elem.offsetParent));
              if (tabbable) {
                tabbable.focus();
              }
            }
            // wrap focus to last tabbable element focusing out of first tabbable element
            // eslint-disable-next-line no-bitwise
            else if (comparisonResult & PRECEDING) {
              const tabbable = findLast(expandedMenuSection === null || expandedMenuSection === void 0 ? void 0 : expandedMenuSection.querySelectorAll(selectorTabbableForLeftnav), elem => Boolean(elem.offsetParent));
              if (tabbable) {
                tabbable.focus();
              }
            }
            // wrap focus to first tabbable element focusing out of last tabbable element
            // eslint-disable-next-line no-bitwise
            else if (comparisonResult & FOLLOWING) {
              var _expandedMenuSection$;
              const allTabbable = [...Array.from((expandedMenuSection === null || expandedMenuSection === void 0 || (_expandedMenuSection$ = expandedMenuSection.shadowRoot) === null || _expandedMenuSection$ === void 0 ? void 0 : _expandedMenuSection$.querySelectorAll(selectorTabbableForLeftnav)) || []), ...Array.from((expandedMenuSection === null || expandedMenuSection === void 0 ? void 0 : expandedMenuSection.querySelectorAll(selectorTabbableForLeftnav)) || [])];
              if (allTabbable.length) {
                allTabbable[0].focus();
              }
            }
          }
        };
      }
    }, {
      kind: "method",
      key: "_handleClickOut",
      value:
      /**
       * The handle for focus wrapping.
       */

      /**
       * Node to track focus going outside of modal content.
       */

      /**
       * Node to track focus going outside of modal content.
       */

      /**
       * Handles `${prefix}-header-menu-button-toggle` event on the document.
       */

      /**
       * Handles `cds-request-focus-wrap` event on the document dispatched from focuswrap.
       *
       * @param event The event.
       */

      function _handleClickOut(event) {
        const {
          selectorButtonToggle
        } = this.constructor;
        const toggleButton = this.getRootNode().querySelector(selectorButtonToggle);

        // TODO: check why `target` returns `c4d-masthead-container` (parent) in Lit v2
        if (this.expanded && event.composedPath()[0].tagName === 'C4D-LEFT-NAV-OVERLAY') {
          this.expanded = false;
          toggleButton === null || toggleButton === void 0 || toggleButton.focus();
        }
      }
    }, {
      kind: "method",
      decorators: [HostListener('keydown')],
      key: "_handleKeydown",
      value: function _handleKeydown(event) {
        const {
          selectorButtonToggle
        } = this.constructor;
        const toggleButton = this.getRootNode().querySelector(selectorButtonToggle);
        if (event.key === 'Escape') {
          this.expanded = false;
          toggleButton === null || toggleButton === void 0 || toggleButton.focus();
        }
      }
    }, {
      kind: "field",
      decorators: [HostListener('parentRoot:eventToggle')],
      key: "_handleContentStateChangeDocument",
      value() {
        return event => {
          const {
            selectorMenuSections
          } = this.constructor;
          const {
            panelId
          } = event.detail;
          const menuSections = Array.from(this.querySelectorAll(selectorMenuSections));
          const expandedSection = menuSections.filter(section => section.matches('[expanded]')).shift();
          const requestedSection = menuSections.filter(section => section.matches(`[section-id="${panelId}"]`)).shift();
          if (expandedSection !== undefined && requestedSection !== undefined && expandedSection !== requestedSection) {
            const id = panelId.split(', ');
            requestedSection.expanded = true;
            requestedSection.ariaHidden = 'false';
            requestedSection.transition = false;
            expandedSection.expanded = false;
            expandedSection.ariaHidden = 'true';

            /**
             * if next menu section expanded is a level 2 menu section and current expanded
             * menu section is a level 1 menu section, add transition attribute for proper animation
             */
            if (id[0] !== '-1' && id[1] !== '-1' && !requestedSection.matches('[section-id*=" -1"]')) {
              expandedSection.transition = true;
            }
          }
        };
      }
    }, {
      kind: "method",
      key: "_handleFocusOut",
      value: //TODO: Remove this override when upstream bug is fixed.
      //@ts-ignore: Overriding the Focus Out Function
      function _handleFocusOut({
        relatedTarget
      }) {
        const {
          collapseMode
        } = this;
        if (collapseMode !== this.collapseMode) {
          if (!this.contains(relatedTarget)) {
            this.expanded = false;
          }
        }
      }

      /**
       * Usage mode of the side nav.
       */
    }, {
      kind: "field",
      decorators: [property({
        reflect: true,
        attribute: 'usage-mode'
      })],
      key: "usageMode",
      value() {
        return SIDE_NAV_USAGE_MODE.HEADER_NAV;
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value: function connectedCallback() {
        _superPropGet(C4DLeftNav, "connectedCallback", this, 3)([]);
        document.addEventListener('click', this._handleClickOut.bind(this));
      }
    }, {
      kind: "method",
      key: "updated",
      value: async function updated(changedProperties) {
        _superPropGet(C4DLeftNav, "updated", this, 3)([changedProperties]);
        const {
          usageMode
        } = this;
        if (changedProperties.has('usageMode') && usageMode !== SIDE_NAV_USAGE_MODE.HEADER_NAV) {
          // eslint-disable-next-line no-console
          console.warn('c4d-left-nav supports only `header-nav` for its `usage-mode` attribute or `usageMode` property. The value is ignored:', usageMode);
        }
        if (changedProperties.has('expanded')) {
          var _doc$querySelector;
          const doc = this.getRootNode();
          forEach(doc.querySelectorAll(this.constructor.selectorOverlay), item => {
            item.active = this.expanded;
          });
          const {
            expanded,
            _startSentinelNode: startSentinelNode,
            _endSentinelNode: endSentinelNode
          } = this;
          const masthead = doc === null || doc === void 0 || (_doc$querySelector = doc.querySelector(`${c4dPrefix}-masthead-container,
          ${c4dPrefix}-masthead-composite`)) === null || _doc$querySelector === void 0 ? void 0 : _doc$querySelector.querySelector(`${c4dPrefix}-masthead`);
          if (expanded && masthead) {
            var _doc$body;
            this._hFocusWrap = focuswrap(this.shadowRoot, [startSentinelNode, endSentinelNode]);
            if ((_doc$body = doc.body) !== null && _doc$body !== void 0 && _doc$body.style) {
              doc.body.style.overflow = `hidden`;
            }

            // TODO: remove this logic once masthead can account for banners.
            // set masthead position to `fixed` when left-nav is open for cloud-mastead
            if (masthead) {
              masthead.style.position = 'fixed';
            }
          } else {
            const {
              selectorMenuSections,
              selectorFirstMenuSection
            } = this.constructor;

            // TODO: remove this logic once masthead can account for banners.
            // remove set position from mastead when left-nav is closed for cloud-mastead
            if (masthead) {
              document.body.style.overflow = 'auto';
              masthead.style.position = '';
            }
            this.querySelectorAll(selectorMenuSections).forEach(c4dLeftNavMenuSection => {
              c4dLeftNavMenuSection.expanded = false;
              c4dLeftNavMenuSection.transition = false;
            });

            // reset to first menu section
            this.querySelectorAll(selectorFirstMenuSection).forEach(c4dLeftNavMenuSection => {
              c4dLeftNavMenuSection.expanded = true;
            });
            if (this._hFocusWrap) {
              this._hFocusWrap = this._hFocusWrap.release();
            }
          }
        }
      }
    }, {
      kind: "field",
      key: "_renderSentinel",
      value() {
        return side => {
          return html(_t || (_t = _`
      <button
        id="${0}-sentinel"
        type="button"
        class="${0}--visually-hidden"></button>
    `), side, prefix);
        };
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          _renderSentinel: renderSentinel
        } = this;
        return html(_t2 || (_t2 = _`
      <div class="${0}--side-nav__wrapper" part="side-nav-wrapper">
        ${0}
        <div class="${0}--side-nav__platform-name" part="platform-name">
          <slot name="platform-id"></slot>
        </div>
        <div class="${0}--side-nav__menu-sections" part="menu-sections">
          <slot></slot>
        </div>
        ${0}
      </div>
    `), prefix, renderSentinel('start'), prefix, prefix, renderSentinel('end'));
      }

      /**
       * A selector that will return the toggle buttons.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorButtonToggle",
      value: function () {
        return `${c4dPrefix}-masthead-menu-button`;
      }

      /**
       * A selector that will return side nav focusable items.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorNavItems",
      value: function () {
        return [`${c4dPrefix}-left-nav-menu`, `${c4dPrefix}-left-nav-menu-item`, `${c4dPrefix}-left-nav-name`].join(', ');
      }

      /**
       * A selector that will return menu sections.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorMenuSections",
      value: function () {
        return `${c4dPrefix}-left-nav-menu-section`;
      }

      /**
       * A selector that will return expanded menu section.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorExpandedMenuSection",
      value: function () {
        return `${c4dPrefix}-left-nav-menu-section[expanded]`;
      }

      /**
       * A selector that will return first main visible menu section.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorFirstMenuSection",
      value: function () {
        return `${c4dPrefix}-left-nav-menu-section[section-id='-1, -1']`;
      }

      /**
       * A selector selecting tabbable nodes.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorTabbable",
      value: function () {
        return [selectorTabbable, `${c4dPrefix}-left-nav-menu`, `${c4dPrefix}-left-nav-menu-item`, `${c4dPrefix}-left-nav-name`].join(', ');
      }

      /**
       * A selector that will return the overlays.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorOverlay",
      value: function () {
        return `${c4dPrefix}-left-nav-overlay`;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--masthead__l0-sidenav`;
      }

      /**
       * The name of the custom event fired after this side nav menu is toggled upon a user gesture.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventToggle",
      value: function () {
        return `${c4dPrefix}-left-nav-menu-toggled`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(CDSSideNav));
export default C4DLeftNav;
//# sourceMappingURL=left-nav.js.map
