import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2022, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html } from 'lit';
import { property } from 'lit/decorators.js';
import { ifDefined } from 'lit/directives/if-defined.js';
import Chat20 from '@carbon/web-components/es/icons/chat/20.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import HostListener from '@carbon/web-components/es/globals/decorators/host-listener.js';
import styles from "././masthead.css.js";
import C4DMastheadProfile from "./masthead-profile.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * The contact button UI in the masthead.
 *
 * @element c4d-masthead-contact
 * @csspart contact-link -The masthead contact link. Usage `c4d-masthead-contact::part(contact-link)`
 */
let C4DMastheadContact = _decorate([customElement(`${c4dPrefix}-masthead-contact`)], function (_initialize, _C4DMastheadProfile) {
  class C4DMastheadContact extends _C4DMastheadProfile {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DMastheadContact,
    d: [{
      kind: "field",
      decorators: [property({
        attribute: 'trigger-label'
      })],
      key: "triggerLabel",
      value() {
        return 'Contact';
      }
    }, {
      kind: "field",
      decorators: [HostListener('document:cm-app-pane-displayed')],
      key: "_handleCMAppDisplayed",
      value() {
        return _event => {
          this.triggerLabel = 'Close contact window';
        };
      }
    }, {
      kind: "field",
      decorators: [HostListener('document:cm-app-pane-hidden')],
      key: "_handleCMAppHidden",
      value() {
        return _event => {
          this.triggerLabel = 'Show contact window';
        };
      }
    }, {
      kind: "method",
      key: "render",
      value:
      /**
       * The `aria-label` attribute for the trigger button.
       */

      /**
       * Handles cm-app-pane-displayed event fired by CM_APP.
       *
       * @see DOCUMENT_EVENTS live-advisor/cm-app/js/helpers/otherConstants.js
       *   - https://github.ibm.com/live-advisor/cm-app/blob/master/js/helpers/otherConstants.js
       */

      /**
       * Handles cm-app-pane-hidden event fired by CM_APP.
       *
       * @see DOCUMENT_EVENTS live-advisor/cm-app/js/helpers/otherConstants.js
       *   - https://github.ibm.com/live-advisor/cm-app/blob/master/js/helpers/otherConstants.js
       */

      function render() {
        const {
          triggerLabel,
          _handleClick: handleClick
        } = this;
        return html(_t || (_t = _`
      <a
        part="contact-link"
        href="javascript:void 0"
        class="${0}--header__menu-item ${0}--header__menu-title"
        aria-label="${0}"
        @click=${0}>
        ${0}
      </a>
    `), prefix, prefix, ifDefined(triggerLabel), handleClick, Chat20());
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, C4DMastheadProfile);
export default C4DMastheadContact;
//# sourceMappingURL=masthead-contact.js.map
