import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { classMap } from 'lit/directives/class-map.js';
import { LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import HostListener from '@carbon/web-components/es/globals/decorators/host-listener.js';
import HostListenerMixin from '@carbon/web-components/es/globals/mixins/host-listener.js';
import FocusMixin from '@carbon/web-components/es/globals/mixins/focus.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././masthead.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * The action bar in masthead.
 *
 * @element c4d-masthead-global-bar
 * @csspart container -The ce header global container. Usage `c4d-masthead-global-bar::part(container)`
 */
let C4DMastheadGlobalBar = _decorate([customElement(`${c4dPrefix}-masthead-global-bar`)], function (_initialize, _FocusMixin) {
  class C4DMastheadGlobalBar extends _FocusMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DMastheadGlobalBar,
    d: [{
      kind: "field",
      decorators: [property({
        attribute: 'has-search-active',
        type: Boolean,
        reflect: true
      })],
      key: "_hasSearchActive",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [HostListener('parentRoot:eventToggleSearch')],
      key: "_handleSearchToggle",
      value() {
        return event => {
          if (event.detail.active !== undefined) {
            this._hasSearchActive = event.detail.active;
          }
        };
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "slot",
      value() {
        return 'profile';
      }
    }, {
      kind: "method",
      key: "render",
      value:
      /**
       * Search bar opened flag.
       */

      /**
       * Handles toggle event from the search component.
       *
       * @param event The event.
       */

      /**
       * The shadow slot this action bar should be in.
       */

      function render() {
        const {
          _hasSearchActive: hasSearchActive
        } = this;
        const classes = classMap({
          [`${c4dPrefix}-ce--header__global__container`]: true,
          [`${c4dPrefix}-ce--header__global__container--has-search-active`]: hasSearchActive
        });
        return html(_t || (_t = _`
      <div part="container" class="${0}">
        <slot></slot>
      </div>
    `), classes);
      }

      /**
       * The name of the custom event fired after the seach is toggled.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventToggleSearch",
      value: function () {
        return `${c4dPrefix}-search-with-typeahead-toggled`;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--masthead-global-bar`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, FocusMixin(HostListenerMixin(StableSelectorMixin(LitElement))));
export default C4DMastheadGlobalBar;
//# sourceMappingURL=masthead-global-bar.js.map
