import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4,
  _t5;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html, LitElement } from 'lit';
import { property, state } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
import ArrowRight16 from '@carbon/web-components/es/icons/arrow--right/16.js';
import ArrowLeft16 from '@carbon/web-components/es/icons/arrow--left/16.js';
import Calendar16 from '@carbon/web-components/es/icons/calendar/16.js';
import Chat16 from '@carbon/web-components/es/icons/chat/16.js';
import Demo16 from '@carbon/web-components/es/icons/demo/16.js';
import Email16 from '@carbon/web-components/es/icons/email/16.js';
import Phone16 from '@carbon/web-components/es/icons/phone/16.js';
import Quote16 from '@carbon/web-components/es/icons/request-quote/16.js';
import styles from "././masthead-l1.css.js";
import { L1_CTA_TYPES } from "./defs.js";
import layoutBreakpoint from "./masthead-breakpoint.js";
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Masthead L1 CTA.
 *
 * @element c4d-masthead-l1-cta
 * @slot cta-text - The CTA text
 * @csspart inner-wrapper-desktop - The inner wrapper for the desktop view. Usage: `c4d-masthead-l1-cta::part(inner-wrapper-desktop)`
 * @csspart l1-button - The button element for CTA. Usage: `c4d-masthead-l1-cta::part(l1-button)`
 * @csspart l1-link - The link element for CTA. Usage: `c4d-masthead-l1-cta::part(l1-link)`
 */
let C4DMastheadL1Cta = _decorate([customElement(`${c4dPrefix}-masthead-l1-cta`)], function (_initialize, _StableSelectorMixin) {
  class C4DMastheadL1Cta extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DMastheadL1Cta,
    d: [{
      kind: "field",
      decorators: [state()],
      key: "isMobileVersion",
      value() {
        return layoutBreakpoint.matches;
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "href",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "type",
      value() {
        return L1_CTA_TYPES.NONE;
      }
    }, {
      kind: "method",
      key: "setCMAppAttributes",
      value:
      /**
       * Whether the current viewport is below 800px or not
       */

      /**
       * Sets attributes that enable integration with the global Contact Module app.
       *
       * @returns void
       */
      function setCMAppAttributes() {
        const {
          type
        } = this;
        if (type) {
          var _this$shadowRoot;
          this.setAttribute('data-ibm-contact', `${type}-link`);
          const textSlot = this === null || this === void 0 || (_this$shadowRoot = this.shadowRoot) === null || _this$shadowRoot === void 0 ? void 0 : _this$shadowRoot.querySelector('slot[name="cta-text"]');
          if (textSlot) {
            var _assignedElements;
            (_assignedElements = textSlot.assignedElements()) === null || _assignedElements === void 0 || _assignedElements.forEach(element => {
              element.setAttribute('data-ibm-contact', `${type}-text`);
            });
          }
        }
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        // Allows component conditions on breakpoint change
        layoutBreakpoint.addEventListener('change', () => {
          this.isMobileVersion = layoutBreakpoint.matches;
        });
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value: function connectedCallback() {
        _superPropGet(C4DMastheadL1Cta, "connectedCallback", this, 3)([]);
        this.setCMAppAttributes();
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated(changedProperties) {
        _superPropGet(C4DMastheadL1Cta, "updated", this, 3)([changedProperties]);
        if (changedProperties.has('type')) {
          this.setCMAppAttributes();
        }
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          isMobileVersion,
          href,
          type
        } = this;
        const classname = isMobileVersion ? `${prefix}--masthead__l1-dropdown-cta` : `${prefix}--masthead__l1-cta`;

        // Adds inner wrapper markup in desktop displays.
        const desktopWrapper = markup => {
          if (!isMobileVersion) {
            return html(_t || (_t = _`
          <div part="inner-wrapper-desktop" class="${0}-inner">
            ${0}
          </div>
        `), classname, markup);
          }
          return markup;
        };

        /**
         * Maps L1_CTA_TYPES values to CMApp CTA options.
         *
         * @see https://github.ibm.com/live-advisor/cm-app/blob/master/docs/cm-doc.md#calls-to-action
         */
        const iconMap = new Map([[L1_CTA_TYPES.CONTACT_US, Chat16()], [L1_CTA_TYPES.CHAT_NOW, Chat16()], [L1_CTA_TYPES.EMAIL_US, Email16()], [L1_CTA_TYPES.CALL_US, Phone16()], [L1_CTA_TYPES.BOOK_A_CONSULTATION, Calendar16()], [L1_CTA_TYPES.REQUEST_A_DEMO, Demo16()], [L1_CTA_TYPES.REQUEST_A_QUOTE, Quote16()]]);
        if (type && iconMap.has(type)) {
          const icon = iconMap.get(type);
          return html(_t2 || (_t2 = _`
        <button
          part="l1-button"
          class="${0}"
          data-ibm-contact="${0}-link">
          ${0}
        </button>
      `), classname, type, desktopWrapper(html(_t3 || (_t3 = _`
            <slot name="cta-text"></slot>
            ${0}
          `), icon)));
        }
        if (href) {
          const isRTL = document.dir.toLowerCase() === 'rtl';
          const ArrowIcon = isRTL ? ArrowLeft16 : ArrowRight16;
          const icon = isMobileVersion ? ArrowIcon() : '';
          return html(_t4 || (_t4 = _`
        <a part="l1-link" class="${0}" href="${0}">
          ${0}
        </a>
      `), classname, href, desktopWrapper(html(_t5 || (_t5 = _`<slot name="cta-text"></slot>${0}`), icon)));
        }
        return '';
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
export default C4DMastheadL1Cta;
//# sourceMappingURL=masthead-l1-cta.js.map
