import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././masthead.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Masthead.
 *
 * @element c4d-masthead-l1-name
 * @csspart l1-name-title - The title element. Usage: `c4d-masthead-l1-name::part(l1-name-title)`
 * @csspart l1-name-link - The link element. Usage: `c4d-masthead-l1-name::part(l1-name-link)`
 */
let C4DMastheadL1Name = _decorate([customElement(`${c4dPrefix}-masthead-l1-name`)], function (_initialize, _StableSelectorMixin) {
  class C4DMastheadL1Name extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DMastheadL1Name,
    d: [{
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "slot",
      value() {
        return 'name';
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "url",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "title",
      value() {
        return '';
      }
    }, {
      kind: "method",
      key: "render",
      value:
      /**
       * slot name for this component in the masthead l1
       */

      function render() {
        return html(_t || (_t = _`
      <span part="l1-name-title" class="${0}--masthead__l1-name-title">
        <a part="l1-name-link" href="${0}">${0}</a>
      </span>
    `), prefix, this.url, this.title);
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--masthead__l1-name`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
export default C4DMastheadL1Name;
//# sourceMappingURL=masthead-l1-name.js.map
