import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html } from 'lit';
import { property, state } from 'lit/decorators.js';
import CDSLink from '@carbon/web-components/es/components/link/link.js';
import HostListener from '@carbon/web-components/es/globals/decorators/host-listener.js';
import HostListenerMixin from '@carbon/web-components/es/globals/mixins/host-listener.js';
import FocusMixin from '@carbon/web-components/es/globals/mixins/focus.js';
import IBM8BarLogoH23 from '../../../es/icons/IBM-8bar-logo--h23.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././masthead.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * The IBM logo UI in masthead.
 *
 * @element c4d-masthead-logo
 */
let C4DMastheadLogo = _decorate([customElement(`${c4dPrefix}-masthead-logo`)], function (_initialize, _FocusMixin) {
  class C4DMastheadLogo extends _FocusMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DMastheadLogo,
    d: [{
      kind: "field",
      decorators: [state()],
      key: "_hasSearchActive",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [HostListener('parentRoot:eventToggleSearch')],
      key: "_handleSearchToggle",
      value() {
        return event => {
          if (event.detail.active !== undefined) {
            this._hasSearchActive = event.detail.active;
          }
        };
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true,
        attribute: 'hide-logo'
      })],
      key: "hideLogo",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "href",
      value() {
        return this.constructor.hrefDefault;
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "slot",
      value() {
        return 'brand';
      }
    }, {
      kind: "method",
      key: "_renderInner",
      value:
      /**
       * Search bar opened flag.
       */

      /**
       * Handles toggle event from the search component.
       *
       * @param event The event.
       */

      /**
       * `true` to hide the logo at render
       */

      /**
       * Link `href`.
       */

      /**
       * The shadow slot this logo UI should be in.
       */

      // eslint-disable-next-line class-methods-use-this
      function _renderInner() {
        return html(_t || (_t = _` <slot>${0}</slot> `), IBM8BarLogoH23());
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated(changedProperties) {
        const {
          _linkNode: linkNode
        } = this;
        if (changedProperties.has('hideLogo')) {
          this._hasSearchActive = this.hideLogo;
        }
        if (linkNode) {
          linkNode.setAttribute('aria-label', 'IBM logo');
          linkNode.classList.remove(`${prefix}--link`);
          linkNode.classList.toggle(`${c4dPrefix}-ce--header__logo--has-search-active`, this._hasSearchActive);
        }
      }

      /**
       * The default value to use for hrefs.
       */
    }, {
      kind: "get",
      static: true,
      key: "hrefDefault",
      value: function () {
        return 'https://www.ibm.com/';
      }

      /**
       * The name of the custom event fired after the seach is toggled.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventToggleSearch",
      value: function () {
        return `${c4dPrefix}-search-with-typeahead-toggled`;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--masthead-logo`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, FocusMixin(HostListenerMixin(StableSelectorMixin(CDSLink))));
export default C4DMastheadLogo;
//# sourceMappingURL=masthead-logo.js.map
