import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2025
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { classMap } from 'lit/directives/class-map.js';
import { html } from 'lit';
import { property, query, state } from 'lit/decorators.js';
import HostListener from '@carbon/web-components/es/globals/decorators/host-listener.js';
import HostListenerMixin from '@carbon/web-components/es/globals/mixins/host-listener.js';
import CDSHeaderMenuButton from '@carbon/web-components/es/components/ui-shell/header-menu-button.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import focuswrap from '@carbon/ibmdotcom-utilities/es/utilities/focuswrap/focuswrap.js';
import styles from "././masthead.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Toggle button for masthead left nav.
 *
 * @element c4d-masthead-menu-button
 * @csspart sentinel-button - The sentinel button for managing focus.
 * @csspart ce-header-menu-trigger-container - Container for the menu trigger button.
 * @csspart sentinel-button--start - The start sentinel button for managing focus. Usage: `c4d-masthead-menu-button::part(sentinel-button--start)`
 * @csspart sentinel-button--end - The end sentinel button for managing focus. Usage: `c4d-masthead-menu-button::part(sentinel-button--end)`
 */
let C4DMastheadMenuButton = _decorate([customElement(`${c4dPrefix}-masthead-menu-button`)], function (_initialize, _HostListenerMixin) {
  class C4DMastheadMenuButton extends _HostListenerMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DMastheadMenuButton,
    d: [{
      kind: "field",
      key: "_hFocusWrap",
      value() {
        return null;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_hasSearchActive",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [HostListener('parentRoot:eventToggleSearch')],
      key: "_handleSearchToggle",
      value() {
        return event => {
          if (event.detail.active !== undefined) {
            this._hasSearchActive = event.detail.active;
            this.hideMenuButton = event.detail.active;
          }
        };
      }
    }, {
      kind: "field",
      decorators: [query('#start-sentinel')],
      key: "_startSentinelNode",
      value: void 0
    }, {
      kind: "field",
      decorators: [query('#end-sentinel')],
      key: "_endSentinelNode",
      value: void 0
    }, {
      kind: "field",
      decorators: [query(`.${prefix}--header__menu-trigger`)],
      key: "_buttonNode",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "slot",
      value() {
        return 'brand';
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true,
        attribute: 'hide-menu-button'
      })],
      key: "hideMenuButton",
      value() {
        return false;
      }
    }, {
      kind: "method",
      key: "focus",
      value:
      /**
       * The handle for focus wrapping.
       */

      /**
       * Search bar opened flag.
       */

      /**
       * Handles toggle event from the search component.
       *
       * @param event The event.
       */

      /**
       * Node to track focus going outside of modal content.
       */

      /**
       * Node to track focus going outside of modal content.
       */

      /**
       * The `<button>`.
       */

      /**
       * The shadow slot this toggle button should be in.
       */

      /**
       * `true` to hide the logo at render
       */

      function focus() {
        const {
          _buttonNode: buttonNode
        } = this;
        if (buttonNode) {
          buttonNode.focus();
        }
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        const boundHideButton = this.hideButtonIfNoNavItemsFound.bind(this);
        window.addEventListener(`load`, () => {
          boundHideButton();
        });
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated(changedProperties) {
        if (changedProperties.has('active')) {
          const {
            active,
            _startSentinelNode: startSentinelNode,
            _endSentinelNode: endSentinelNode
          } = this;
          if (active) {
            this._hFocusWrap = focuswrap(this.shadowRoot, [startSentinelNode, endSentinelNode]);
          } else if (this._hFocusWrap) {
            this._hFocusWrap = this._hFocusWrap.release();
          }
        }
        if (changedProperties.has('hideMenuButton')) {
          this._hasSearchActive = this.hideMenuButton;
        }
        this.hideButtonIfNoNavItemsFound();
      }
    }, {
      kind: "method",
      key: "hideButtonIfNoNavItemsFound",
      value: function hideButtonIfNoNavItemsFound() {
        var _this$closest;
        const NavMenuItems = (_this$closest = this.closest(`${c4dPrefix}-masthead-container`)) === null || _this$closest === void 0 ? void 0 : _this$closest.querySelectorAll(`${c4dPrefix}-left-nav-menu`);
        if (!(NavMenuItems !== null && NavMenuItems !== void 0 && NavMenuItems.length)) {
          this.hideMenuButton = true;
          this.style.display = 'none';
        } else if (this.style.display == 'none') {
          this.hideMenuButton = false;
          this.style.display = '';
        }
      }
    }, {
      kind: "field",
      key: "_renderSentinel",
      value() {
        return side => {
          return html(_t || (_t = _`
      <button
        part="sentinel-button sentinel-button--${0}"
        id="${0}-sentinel"
        type="button"
        class="${0}--visually-hidden"></button>
    `), side, side, prefix);
        };
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          active,
          _hasSearchActive: hasSearchActive,
          _renderSentinel: renderSentinel
        } = this;
        const classes = classMap({
          [`${c4dPrefix}-ce--header__menu-trigger__container`]: true,
          [`${c4dPrefix}-ce--header__menu-trigger__container--has-search-active`]: hasSearchActive
        });
        const startSentinel = active ? renderSentinel('start') : '';
        const endSentinel = active ? renderSentinel('end') : '';
        return html(_t2 || (_t2 = _`
      <div part="ce-header-menu-trigger-container" class="${0}">
        ${0}${0}${0}
      </div>
    `), classes, startSentinel, _superPropGet(C4DMastheadMenuButton, "render", this, 3)([]), endSentinel);
      }

      /**
       * The name of the custom event fired after the seach is toggled.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventToggleSearch",
      value: function () {
        return `${c4dPrefix}-search-with-typeahead-toggled`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, HostListenerMixin(CDSHeaderMenuButton));
export default C4DMastheadMenuButton;
//# sourceMappingURL=masthead-menu-button.js.map
