import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t;
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { ifDefined } from 'lit/directives/if-defined.js';
import { LitElement, html } from 'lit';
import { property, query } from 'lit/decorators.js';
import User20 from '@carbon/web-components/es/icons/user/20.js';
import UserOnline20 from '@carbon/web-components/es/icons/user--online/20.js';
import FocusMixin from '@carbon/web-components/es/globals/mixins/focus.js';
import HostListenerMixin from '@carbon/web-components/es/globals/mixins/host-listener.js';
import HostListener from '@carbon/web-components/es/globals/decorators/host-listener.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././masthead.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * The profile menu UI in the masthead.
 *
 * @element c4d-masthead-profile
 * @csspart profile-link - The masthead contact link. Usage: `c4d-masthead-contact::part(profile-link)`
 * @csspart header-menu - The header menu element. Usage: `c4d-masthead-contact::part(header-menu)`
 */
let C4DMastheadProfile = _decorate([customElement(`${c4dPrefix}-masthead-profile`)], function (_initialize, _HostListenerMixin) {
  class C4DMastheadProfile extends _HostListenerMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DMastheadProfile,
    d: [{
      kind: "field",
      decorators: [query('a')],
      key: "_trigger",
      value: void 0
    }, {
      kind: "method",
      key: "_handleClick",
      value:
      /**
       * The trigger button.
       */

      /**
       * Handles `click` event handler on this element.
       */
      function _handleClick() {
        this._handleUserInitiatedToggle();
      }

      /**
       * Handles user-initiated toggling the open state.
       *
       * @param [force] If specified, forces the open state to the given one.
       */
    }, {
      kind: "method",
      key: "_handleUserInitiatedToggle",
      value: function _handleUserInitiatedToggle(force = !this.expanded) {
        this.expanded = force;
        if (!force) {
          this._trigger.focus();
        }
      }

      /**
       * Handles `blur` event handler on this element.
       */
    }, {
      kind: "method",
      decorators: [HostListener('focusout')],
      key: "_handleBlur",
      value: function _handleBlur({
        relatedTarget
      }) {
        if (!this.contains(relatedTarget)) {
          this.expanded = false;
        }
      }

      /**
       * Handler for the `keydown` event.
       */
    }, {
      kind: "method",
      decorators: [HostListener('keydown')],
      key: "_handleKeydown",
      value: function _handleKeydown({
        key
      }) {
        if (key === 'Esc' || key === 'Escape') {
          this._handleUserInitiatedToggle(false);
        }
      }

      /**
       * `true` if the trigger button should show the UI of the authenticated state.
       */
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true
      })],
      key: "authenticated",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true
      })],
      key: "expanded",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'menu-label'
      })],
      key: "menuLabel",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'trigger-label'
      })],
      key: "triggerLabel",
      value() {
        return 'User profile';
      }
    }, {
      kind: "method",
      key: "render",
      value:
      /**
       * `true` if the menu should be expanded.
       */
      /**
       * The `aria-label` attribute for the menu UI.
       */
      /**
       * The `aria-label` attribute for the trigger button.
       */
      function render() {
        const {
          authenticated,
          expanded,
          menuLabel,
          triggerLabel,
          _handleClick: handleClick
        } = this;
        return html(_t || (_t = _`
      <a
        part="profile-link"
        role="button"
        tabindex="0"
        class="${0}--header__menu-item ${0}--header__menu-title"
        href="javascript:void 0"
        aria-expanded="${0}"
        aria-label="${0}"
        @click=${0}>
        ${0}
      </a>
      <ul
        class="${0}--header__menu"
        aria-label="${0}"
        part="header-menu">
        <slot></slot>
      </ul>
    `), prefix, prefix, String(Boolean(expanded)), ifDefined(triggerLabel), handleClick, authenticated ? UserOnline20() : User20(), prefix, ifDefined(menuLabel));
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--masthead-profile`;
      }
    }, {
      kind: "field",
      static: true,
      key: "shadowRootOptions",
      value() {
        return _objectSpread(_objectSpread({}, LitElement.shadowRootOptions), {}, {
          delegatesFocus: true
        });
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, HostListenerMixin(FocusMixin(StableSelectorMixin(LitElement))));
export default C4DMastheadProfile;
//# sourceMappingURL=masthead-profile.js.map
