import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././masthead.css.js";
import StickyHeader from '@carbon/ibmdotcom-utilities/es/utilities/StickyHeader/StickyHeader.js';
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Masthead.
 *
 * @element c4d-masthead
 * @csspart l0 - The Masthead L0. Usage: `c4d-masthead::part(l0)`
 * @csspart header - The header. Usage: `c4d-masthead::part(header)`
 * @csspart header-search - The header search. Usage: `c4d-masthead::part(header-search)`
 * @csspart header-nav-container - The header nav container. Usage: `c4d-masthead::part(header-nav-container)`
 * @slot brand - The left hand area.
 * @slot nav - The nav content.
 * @slot profile - The right hand area.
 */
let C4DMasthead = _decorate([customElement(`${c4dPrefix}-masthead`)], function (_initialize, _StableSelectorMixin) {
  class C4DMasthead extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DMasthead,
    d: [{
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        StickyHeader.global.masthead = this;
      }

      /**
       * Re-initializes masthead component with StickyHeader class in case of L1 addition/removal.
       */
    }, {
      kind: "method",
      key: "handleL1Change",
      value: function handleL1Change({
        target
      }) {
        const L1Navs = target.assignedElements().filter(element => element.tagName.toLowerCase() === `${c4dPrefix}-masthead-l1`);
        if (L1Navs.length) {
          StickyHeader.global.masthead = this;
        }
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t || (_t = _`
      <div part="l0" class="${0}--masthead__l0">
        <div part="header" class="${0}--header">
          <slot name="brand"></slot>
          <div part="header-search" class="${0}--header__search">
            <div
              part="header-nav-container"
              class="${0}--header__nav-container">
              <slot></slot>
            </div>
            <slot name="search"></slot>
          </div>
          <slot name="profile"></slot>
        </div>
      </div>
      <slot name="masthead-l1" @slotchange=${0}></slot>
    `), prefix, prefix, prefix, prefix, this.handleL1Change);
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--masthead`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DMasthead;
//# sourceMappingURL=masthead.js.map
