import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html, LitElement } from 'lit';
import { property } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././masthead.css.js";
import "./megamenu-link-with-icon.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * MegaMenu category group
 *
 * @element c4d-megamenu-category-group
 * @csspart shield - The shield element of the megamenu category group. Usage: `c4d-megamenu-category-group::part(shield)`
 * @csspart content-wrapper - The content wrapper of the megamenu category group. Usage: `c4d-megamenu-category-group::part(content-wrapper)`
 * @csspart heading - The heading of the megamenu category group. Usage: `c4d-megamenu-category-group::part(heading)`
 * @csspart content - The content of the megamenu category group. Usage: `c4d-megamenu-category-group::part(content)`
 */
let C4DMegaMenuCategoryGroup = _decorate([customElement(`${c4dPrefix}-megamenu-category-group`)], function (_initialize, _LitElement) {
  class C4DMegaMenuCategoryGroup extends _LitElement {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DMegaMenuCategoryGroup,
    d: [{
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "href",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "title",
      value() {
        return '';
      }
    }, {
      kind: "method",
      key: "render",
      value:
      /**
       * href for the category group title
       */

      /**
       * category group title/heading
       */

      function render() {
        return html(_t || (_t = _`
      <div
        part="shield"
        class="${0}--masthead__megamenu__category-group-shield">
        <div
          part="content-wrapper"
          class="${0}--masthead__megamenu__category-group-content-wrapper">
          <div
            part="heading"
            class="${0}--masthead__megamenu__category-group-heading">
            <slot name="heading"></slot>
          </div>
          <div
            part="content"
            class="${0}--masthead__megamenu__category-group-content">
            <slot></slot>
          </div>
        </div>
      </div>
    `), prefix, prefix, prefix, prefix);
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, LitElement);
export default C4DMegaMenuCategoryGroup;
//# sourceMappingURL=megamenu-category-group.js.map
