import _decorate from "@babel/runtime/helpers/esm/decorate";
/**
 * @license
 *
 * Copyright IBM Corp. 2022, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { property } from 'lit/decorators.js';
import ArrowRight20 from '@carbon/web-components/es/icons/arrow--right/20.js';
import ArrowLeft20 from '@carbon/web-components/es/icons/arrow--left/20.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import C4DMegaMenuHeading from "./megamenu-heading.js";
import styles from "././masthead.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * MegaMenu Category Heading.
 *
 * @element c4d-megamenu-category-heading
 * @csspart l0-arrow-cat-heading -  Targets the heading category arrow icon. Usage: `c4d-megamenu-category-heading::part(l0-arrow-cat-heading)`
 */
let C4DMegaMenuCategoryHeading = _decorate([customElement(`${c4dPrefix}-megamenu-category-heading`)], function (_initialize, _C4DMegaMenuHeading) {
  class C4DMegaMenuCategoryHeading extends _C4DMegaMenuHeading {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DMegaMenuCategoryHeading,
    d: [{
      kind: "get",
      key: "_arrowIcon",
      value: function () {
        const isRTL = document.dir.toLowerCase() === 'rtl';
        return isRTL ? ArrowLeft20({
          part: 'l0-arrow-cat-heading'
        }) : ArrowRight20({
          part: 'l0-arrow-cat-heading'
        });
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true,
        type: Number,
        attribute: 'heading-level'
      })],
      key: "headingLevel",
      value() {
        return 3;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, C4DMegaMenuHeading);
export default C4DMegaMenuCategoryHeading;
//# sourceMappingURL=megamenu-category-heading.js.map
