import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4,
  _t5,
  _t6,
  _t7,
  _t8;
/**
 * @license
 *
 * Copyright IBM Corp. 2022, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import ArrowRight24 from '@carbon/web-components/es/icons/arrow--right/24.js';
import ArrowLeft24 from '@carbon/web-components/es/icons/arrow--left/24.js';
import HostListenerMixin from '@carbon/web-components/es/globals/mixins/host-listener.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././masthead.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * MegaMenu Heading.
 *
 * @element c4d-megamenu-heading
 * @csspart heading-link - The link element of the megamenu heading. Usage: `c4d-megamenu-heading::part(heading-link)`
 * @csspart heading-h2 - The h2 element of the megamenu heading. Usage: `c4d-megamenu-heading::part(heading-h2)`
 * @csspart heading-h3 - The h3 element of the megamenu heading. Usage: `c4d-megamenu-heading::part(heading-h3)`
 * @csspart heading-h4 - The h4 element of the megamenu heading. Usage: `c4d-megamenu-heading::part(heading-h4)`
 * @csspart heading-h5 - The h5 element of the megamenu heading. Usage: `c4d-megamenu-heading::part(heading-h5)`
 * @csspart heading-h6 - The h6 element of the megamenu heading. Usage: `c4d-megamenu-heading::part(heading-h6)`
 * @csspart heading-span - The span element containing slotted content. Usage: `c4d-megamenu-heading::part(heading-span)`
 * @csspart l0-heading-arrow -  Targets the heading arrow icon. Usage: `c4d-megamenu-heading::part(l0-heading-arrow)`
 */
let C4DMegaMenuHeading = _decorate([customElement(`${c4dPrefix}-megamenu-heading`)], function (_initialize, _HostListenerMixin) {
  class C4DMegaMenuHeading extends _HostListenerMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DMegaMenuHeading,
    d: [{
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "href",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "title",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true,
        type: Number,
        attribute: 'heading-level'
      })],
      key: "headingLevel",
      value() {
        return 2;
      }
    }, {
      kind: "get",
      key: "_arrowIcon",
      value:
      /**
       * Megamenu heading href.
       */

      /**
       * Megamenu heading text.
       */

      /**
       * Arrow icon to use when presented as link.
       */
      function () {
        const isRTL = document.dir.toLowerCase() === 'rtl';
        return isRTL ? ArrowLeft24({
          part: 'l0-heading-arrow'
        }) : ArrowRight24({
          part: 'l0-heading-arrow'
        });
      }

      /**
       * Render heading as link.
       */
    }, {
      kind: "method",
      key: "renderLink",
      value: function renderLink() {
        const {
          _arrowIcon
        } = this;
        return html(_t || (_t = _`
      <a
        part="heading-link"
        href="${0}"
        data-attribute1="headerNav"
        data-attribute2="FlatHdline"
        data-attribute3="${0}">
        ${0} ${0}
      </a>
    `), this.href, this.title, this.title, _arrowIcon);
      }

      /**
       * Render heading as plain text.
       */
    }, {
      kind: "method",
      key: "renderPlain",
      value: function renderPlain() {
        return html(_t2 || (_t2 = _` ${0} `), this.title);
      }

      /**
       * Render heading markup.
       */
    }, {
      kind: "method",
      key: "renderHeading",
      value: function renderHeading() {
        const {
          headingLevel
        } = this;
        const hasHref = Boolean(this.href);
        switch (headingLevel) {
          case 3:
            return html(_t3 || (_t3 = _`
          <h3 part="heading-h3" ?data-has-href="${0}">
            ${0}
          </h3>
        `), hasHref, this.renderHeadingInner());
          case 4:
            return html(_t4 || (_t4 = _`
          <h4 part="heading-h4" ?data-has-href="${0}">
            ${0}
          </h4>
        `), hasHref, this.renderHeadingInner());
          case 5:
            return html(_t5 || (_t5 = _`
          <h5 part="heading-h5" ?data-has-href="${0}">
            ${0}
          </h5>
        `), hasHref, this.renderHeadingInner());
          case 6:
            return html(_t6 || (_t6 = _`
          <h6 part="heading-h6" ?data-has-href="${0}">
            ${0}
          </h6>
        `), hasHref, this.renderHeadingInner());
          default:
            return html(_t7 || (_t7 = _`
          <h2 part="heading-h2" ?data-has-href="${0}">
            ${0}
          </h2>
        `), hasHref, this.renderHeadingInner());
        }
      }

      /**
       * Render inner heading contents as link or plain text.
       */
    }, {
      kind: "method",
      key: "renderHeadingInner",
      value: function renderHeadingInner() {
        return this.href ? this.renderLink() : this.renderPlain();
      }
    }, {
      kind: "method",
      key: "_handleSlotChange",
      value: function _handleSlotChange(event) {
        const hasContent = event.target.assignedNodes().filter(child => {
          var _child$textContent;
          return child === null || child === void 0 || (_child$textContent = child.textContent) === null || _child$textContent === void 0 ? void 0 : _child$textContent.trim();
        }).length > 0;
        this.classList.toggle('has-content', hasContent);
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t8 || (_t8 = _`
      ${0}
      <span part="heading-span">
        <slot @slotchange=${0}></slot>
      </span>
    `), this.renderHeading(), this._handleSlotChange);
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, HostListenerMixin(LitElement));
export default C4DMegaMenuHeading;
//# sourceMappingURL=megamenu-heading.js.map
