import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import { classMap } from 'lit/directives/class-map.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { MEGAMENU_RIGHT_NAVIGATION_STYLE_SCHEME } from "./defs.js";
import styles from "././masthead.css.js";
import "./megamenu-link-with-icon.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
export { MEGAMENU_RIGHT_NAVIGATION_STYLE_SCHEME };
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * MegaMenu right navigation section
 *
 * @element c4d-megamenu-right-navigation
 * @csspart container - The container for the megamenu. Usage: `c4d-megamenu-right-navigation::part(container)`
 * @csspart container-inner - The inner container of the megamenu. Usage: `c4d-megamenu-right-navigation::part(container-inner)`
 * @csspart heading - The heading of the megamenu. Usage: `c4d-megamenu-right-navigation::part(heading)`
 * @csspart categories - The categories section of the megamenu. Usage: `c4d-megamenu-right-navigation::part(categories)`
 * @csspart view-all - The view all section of the megamenu. Usage: `c4d-megamenu-right-navigation::part(view-all)`
 * @csspart view-all-border - The border for the view all section. Usage: `c4d-megamenu-right-navigation::part(view-all-border)`
 */
let C4DMegaMenuRightNavigation = _decorate([customElement(`${c4dPrefix}-megamenu-right-navigation`)], function (_initialize, _StableSelectorMixin) {
  class C4DMegaMenuRightNavigation extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DMegaMenuRightNavigation,
    d: [{
      kind: "field",
      decorators: [property({
        reflect: true,
        attribute: 'style-scheme'
      })],
      key: "styleScheme",
      value() {
        return MEGAMENU_RIGHT_NAVIGATION_STYLE_SCHEME.FULL;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'data-child-count',
        reflect: true
      })],
      key: "childCount",
      value: void 0
    }, {
      kind: "method",
      key: "_getClassNames",
      value:
      /**
       * `true` to render left (highlighted) section layout.
       */

      /**
       * Returns a class-name(s) for megamenu container
       */
      function _getClassNames() {
        return classMap({
          [`${prefix}--masthead__megamenu-container`]: true,
          [`${prefix}--masthead__megamenu-container--has-sidebar`]: this.styleScheme === MEGAMENU_RIGHT_NAVIGATION_STYLE_SCHEME.HAS_SIDEBAR
        });
      }

      /**
       * Handles default slot content changes.
       *
       * @param event Event
       */
    }, {
      kind: "method",
      key: "_handleSlotChange",
      value: function _handleSlotChange(event) {
        const {
          onlyChildClassName
        } = this.constructor;
        const children = event.target.assignedElements();
        this.childCount = children.length;

        // Supports alternative layout for single items.
        if (children.length === 1 && onlyChildClassName) {
          children[0].classList.add(onlyChildClassName);
        } else if (children[0].classList.contains(onlyChildClassName)) {
          children[0].classList.remove(onlyChildClassName);
        }
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated() {
        var _this$shadowRoot, _this$shadowRoot2;
        const hasViewAll = ((_this$shadowRoot = this.shadowRoot) === null || _this$shadowRoot === void 0 ? void 0 : _this$shadowRoot.querySelector('slot[name="view-all"]')).assignedElements().length > 0;
        (_this$shadowRoot2 = this.shadowRoot) === null || _this$shadowRoot2 === void 0 || (_this$shadowRoot2 = _this$shadowRoot2.querySelector(`.${prefix}--masthead__megamenu-container`)) === null || _this$shadowRoot2 === void 0 || _this$shadowRoot2.classList.toggle(`${prefix}--masthead__megamenu-container--has-view-all-link`, hasViewAll);
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t || (_t = _`
      <div part="container" class="${0}">
        <div
          part="container-inner"
          class="${0}--masthead__megamenu-container-inner">
          <div part="heading" class="${0}--masthead__megamenu__heading">
            <slot name="heading"></slot>
          </div>
          <div
            part="categories"
            class="${0}--masthead__megamenu__categories">
            <slot @slotchange="${0}"></slot>
          </div>
        </div>
        <div part="view-all" class="${0}--masthead__megamenu__view-all">
          <span
            part="view-all-border"
            class="${0}--masthead__megamenu__view-all__border"></span>
          <slot name="view-all"></slot>
        </div>
      </div>
    `), this._getClassNames(), prefix, prefix, prefix, this._handleSlotChange, prefix, prefix);
      }
    }, {
      kind: "get",
      static: true,
      key: "onlyChildClassName",
      value: function () {
        return 'only-child';
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--masthead__megamenu-right-navigation`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
export default C4DMegaMenuRightNavigation;
//# sourceMappingURL=megamenu-right-navigation.js.map
