import _decorate from "@babel/runtime/helpers/esm/decorate";
/**
 * @license
 *
 * Copyright IBM Corp. 2021, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import CDSTabs from '@carbon/web-components/es/components/tabs/tabs.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././masthead.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Megamenu Tabs.
 *
 * @element c4d-megamenu-tabs
 */
let C4DMegaMenuTabs = _decorate([customElement(`${c4dPrefix}-megamenu-tabs`)], function (_initialize, _CDSTabs) {
  class C4DMegaMenuTabs extends _CDSTabs {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DMegaMenuTabs,
    d: [{
      kind: "field",
      key: "_disableIntersectionObservers",
      value() {
        return true;
      }
    }, {
      kind: "method",
      key: "renderPreviousButton",
      value:
      /**
       * @inheritdoc
       */
      // eslint-disable-next-line class-methods-use-this
      function renderPreviousButton() {
        // Button is not desirable for our vertical tabs display.
        return null;
      }

      /**
       * @inheritdoc
       */
      // eslint-disable-next-line class-methods-use-this
    }, {
      kind: "method",
      key: "renderNextButton",
      value: function renderNextButton() {
        // Button is not desirable for our vertical tabs display.
        return null;
      }

      /**
       * A selector that will return megamenu tabs.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItem",
      value: function () {
        return `${c4dPrefix}-megamenu-tab`;
      }

      /**
       * A selector that will return enabled tab items.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItemEnabled",
      value: function () {
        return `${c4dPrefix}-megamenu-tab:not([disabled])`;
      }

      /**
       * A selector that will return selected items.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItemSelected",
      value: function () {
        return `${c4dPrefix}-megamenu-tab[selected]`;
      }

      /**
       * The name of the custom event fired before a tab is selected upon a user gesture.
       * Cancellation of this event stops changing the user-initiated selection.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventBeforeSelect",
      value: function () {
        return `${c4dPrefix}-megamenu-tabs-beingselected`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, CDSTabs);
export default C4DMegaMenuTabs;
//# sourceMappingURL=megamenu-tabs.js.map
