/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import C4DMegaMenu from './megamenu';
import C4DTopNavMenu from './top-nav-menu';
/**
 * Megamenu top nav menu.
 *
 * @element c4d-megamenu-top-nav-menu
 */
declare class C4DMegaMenuTopNavMenu extends C4DTopNavMenu {
    /**
     * The megamenu component
     */
    megaMenu: C4DMegaMenu;
    /**
     * The menu ul node.
     */
    private _menuNode;
    /**
     * scrollbar width.
     */
    private _scrollBarWidth;
    /**
     * Identifier for this menu's position in a series.
     */
    menuIndex: number | undefined;
    /**
     * The observer for the resize of the viewport.
     */
    private _observerResizeRoot;
    /**
     * Cleans-up and creats the resize observer for the scrolling container.
     *
     * @param [options] The options.
     * @param [options.create] `true` to create the new resize observer.
     */
    private _cleanAndCreateObserverResize;
    /**
     * The observer for the resize of the viewport.
     */
    private _observeResizeRoot;
    private _requestMegaMenuRenderUpdate;
    private _setAnalyticsAttributes;
    /**
     * Sets inline styles on an element to accommodate any scrollbars that push it
     * out of Carbon grid alignment.
     *
     * @private
     */
    private _handleScrollbarOffset;
    connectedCallback(): void;
    disconnectedCallback(): void;
    firstUpdated(): void;
    updated(changedProperties: any): Promise<void>;
    /**
     * The CSS custom property name for the live viewport width.
     */
    static get customPropertyViewportWidth(): string;
    /**
     * A selector that will return the overlays.
     */
    static get selectorOverlay(): string;
    /**
     * The custom event name for when a megamenu is toggled.
     */
    static get eventMegaMenuToggled(): string;
    static styles: any;
}
export default C4DMegaMenuTopNavMenu;

//# sourceMappingURL=megamenu-top-nav-menu.d.ts.map
