import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { query, state, property } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import C4DTopNavMenu from "./top-nav-menu.js";
import styles from "././masthead.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Megamenu top nav menu.
 *
 * @element c4d-megamenu-top-nav-menu
 */
let C4DMegaMenuTopNavMenu = _decorate([customElement(`${c4dPrefix}-megamenu-top-nav-menu`)], function (_initialize, _C4DTopNavMenu) {
  class C4DMegaMenuTopNavMenu extends _C4DTopNavMenu {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DMegaMenuTopNavMenu,
    d: [{
      kind: "field",
      decorators: [property()],
      key: "megaMenu",
      value: void 0
    }, {
      kind: "field",
      decorators: [query(`.${prefix}--header__menu`)],
      key: "_menuNode",
      value: void 0
    }, {
      kind: "field",
      decorators: [state()],
      key: "_scrollBarWidth",
      value() {
        return this.ownerDocument.defaultView.innerWidth - this.ownerDocument.body.offsetWidth;
      }
    }, {
      kind: "field",
      key: "_observerResizeRoot",
      value() {
        return null;
      }
    }, {
      kind: "method",
      key: "_cleanAndCreateObserverResize",
      value:
      /**
       * The megamenu component
       */

      /**
       * The menu ul node.
       */

      /**
       * scrollbar width.
       */

      /**
       * Identifier for this menu's position in a series.
       */

      /**
       * The observer for the resize of the viewport.
       */
      // TODO: Wait for `.d.ts` update to support `ResizeObserver`

      /**
       * Cleans-up and creats the resize observer for the scrolling container.
       *
       * @param [options] The options.
       * @param [options.create] `true` to create the new resize observer.
       */
      function _cleanAndCreateObserverResize({
        create
      } = {}) {
        if (this._observerResizeRoot) {
          this._observerResizeRoot.disconnect();
          this._observerResizeRoot = null;
        }
        if (create) {
          // TODO: Wait for `.d.ts` update to support `ResizeObserver`
          // @ts-ignore
          this._observerResizeRoot = new ResizeObserver(this._observeResizeRoot);
          this._observerResizeRoot.observe(this.ownerDocument.documentElement);
        }
      }

      /**
       * The observer for the resize of the viewport.
       */
    }, {
      kind: "field",
      key: "_observeResizeRoot",
      value() {
        return records => {
          const {
            contentRect
          } = records[records.length - 1];
          // A workaround for Safari bug where `100vw` in Shadow DOM causes delayed rendering
          // https://github.com/carbon-design-system/carbon-for-ibm-dotcom/issues/4493
          const {
            customPropertyViewportWidth
          } = this.constructor;
          this.style.setProperty(customPropertyViewportWidth, `${contentRect.width}px`);
        };
      }
    }, {
      kind: "method",
      key: "_requestMegaMenuRenderUpdate",
      value: async function _requestMegaMenuRenderUpdate() {
        return new Promise(resolve => {
          const {
            eventMegaMenuToggled
          } = this.constructor;
          this.dispatchEvent(new CustomEvent(eventMegaMenuToggled, {
            bubbles: true,
            cancelable: true,
            composed: true,
            detail: {
              active: this.expanded,
              index: this.menuIndex,
              resolveFn: resolve
            }
          }));
          setTimeout(() => {
            resolve();
          }, 5000);
        });
      }
    }, {
      kind: "method",
      key: "_setAnalyticsAttributes",
      value: function _setAnalyticsAttributes() {
        const {
          _topMenuItem: trigger
        } = this;
        trigger.setAttribute('data-attribute1', 'headerNav');
        trigger.setAttribute('data-attribute2', 'L0');
        trigger.setAttribute('data-attribute3', this.menuLabel);
      }

      /**
       * Sets inline styles on an element to accommodate any scrollbars that push it
       * out of Carbon grid alignment.
       *
       * @private
       */
    }, {
      kind: "method",
      key: "_handleScrollbarOffset",
      value: function _handleScrollbarOffset(element) {
        element.style.marginInlineEnd = this.expanded ? `${this._scrollBarWidth}px` : `0px`;
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value: function connectedCallback() {
        _superPropGet(C4DMegaMenuTopNavMenu, "connectedCallback", this, 3)([]);
        this._cleanAndCreateObserverResize({
          create: true
        });
      }
    }, {
      kind: "method",
      key: "disconnectedCallback",
      value: function disconnectedCallback() {
        this._cleanAndCreateObserverResize();
        _superPropGet(C4DMegaMenuTopNavMenu, "disconnectedCallback", this, 3)([]);
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        this._menuNode.removeAttribute('role');
        this._cleanAndCreateObserverResize({
          create: true
        });
        this._setAnalyticsAttributes();
        if (this.hasAttribute('role') && this.getAttribute('role') === 'listitem') {
          this.removeAttribute('role');
        }
      }
    }, {
      kind: "method",
      key: "updated",
      value: async function updated(changedProperties) {
        _superPropGet(C4DMegaMenuTopNavMenu, "updated", this, 3)([changedProperties]);
        if (changedProperties.has('expanded')) {
          var _masthead$shadowRoot;
          const doc = this.ownerDocument;
          const rootNode = this.getRootNode();
          const masthead = rootNode.querySelector('c4d-masthead');

          // Find overlay and update its state.
          const overlays = rootNode.querySelectorAll(this.constructor.selectorOverlay);
          overlays.forEach(item => {
            item.active = this.expanded;
          });

          // Collect elements that should have offsets applied to accommodate any
          // scrollbars when they appear in the layout.
          const elementsToAdjust = [doc.body, masthead === null || masthead === void 0 || (_masthead$shadowRoot = masthead.shadowRoot) === null || _masthead$shadowRoot === void 0 ? void 0 : _masthead$shadowRoot.querySelector(`.${prefix}--masthead__l0`), masthead === null || masthead === void 0 ? void 0 : masthead.querySelector(`${c4dPrefix}-masthead-l1`)].filter(element => element instanceof HTMLElement);
          if (this.expanded) {
            var _this$parentElement;
            // Import needed subcomponents on first expansion
            if (!((_this$parentElement = this.parentElement) !== null && _this$parentElement !== void 0 && _this$parentElement.importedMegamenu)) {
              await Promise.all([import('./megamenu-left-navigation'), import('./megamenu-category-link'), import('./megamenu-category-link-group'), import('./megamenu-category-group'), import('./megamenu-category-group-copy'), import('./megamenu-category-heading'), import('./megamenu-link-with-icon'), import('./megamenu-overlay'), import('./megamenu-tab'), import('./megamenu-tabs')]);
              this.parentElement.importedMegamenu = true;
            }

            // Ask masthead-composite to render megamenu.
            // Pause further execution until the render is complete.
            await this._requestMegaMenuRenderUpdate();

            // Lock document to prevent scrolling while menu is open.
            doc.body.style.overflow = `hidden`;

            // Set scrollbar adjustments.
            elementsToAdjust.forEach(element => this._handleScrollbarOffset(element));
          } else {
            /**
             * Return focus to topMenuItem only when expanded explicitly equals false.
             * On load, when expanded is undefined, avoid taking control of focus.
             * This is deliberately in a 0ms timeout to put the check at the end of
             * the event loop to avoid interrupting the browser's focus handoff.
             */
            if (changedProperties.get('expanded') === false) {
              setTimeout(() => {
                const {
                  activeElement
                } = document;
                if (activeElement === null || activeElement.tagName.toLowerCase() === 'body') {
                  this._topMenuItem.focus();
                }
              }, 0);
            }

            // Ask masthead-composite to un-render megamenu.
            // Wait long enough for the transition to end.
            setTimeout(() => {
              this._requestMegaMenuRenderUpdate();
            }, 500);

            // Unlock document to enable scrolling once menu is closed.
            doc.body.style.overflow = '';

            // Unset scrollbar adjustments.
            elementsToAdjust.forEach(element => this._handleScrollbarOffset(element));
          }
        }
        if (changedProperties.has('menuLabel')) {
          this._setAnalyticsAttributes();
        }
      }

      /**
       * The CSS custom property name for the live viewport width.
       */
    }, {
      kind: "get",
      static: true,
      key: "customPropertyViewportWidth",
      value: function () {
        return `--${c4dPrefix}-ce--viewport-width`;
      }

      /**
       * A selector that will return the overlays.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorOverlay",
      value: function () {
        return `${c4dPrefix}-megamenu-overlay`;
      }

      /**
       * The custom event name for when a megamenu is toggled.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventMegaMenuToggled",
      value: function () {
        return `${c4dPrefix}-megamenu-top-nav-menu-toggle`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, C4DTopNavMenu);
export default C4DMegaMenuTopNavMenu;
//# sourceMappingURL=megamenu-top-nav-menu.js.map
