import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t;
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html, LitElement } from 'lit';
import { property } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././masthead.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
import { MEGAMENU_LAYOUT_SCHEME } from "./defs.js";
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * MegaMenu
 *
 * @element c4d-megamenu
 * @csspart container - The masthead megamenu container. Usage: c4d-megamenu::part(container)
 * @csspart container-row - The masthead megamenu container row. Usage: c4d-megamenu::part(container-row)
 */
let C4DMegaMenu = _decorate([customElement(`${c4dPrefix}-megamenu`)], function (_initialize, _StableSelectorMixin) {
  class C4DMegaMenu extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DMegaMenu,
    d: [{
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "layout",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        reflect: true,
        type: Boolean
      })],
      key: "overflowing",
      value() {
        return false;
      }
    }, {
      kind: "field",
      key: "mutationObserver",
      value() {
        return new MutationObserver(this._setOverflowing.bind(this));
      }
    }, {
      kind: "field",
      key: "resizeObserver",
      value() {
        return new ResizeObserver(this._setOverflowing.bind(this));
      }
    }, {
      kind: "method",
      key: "_setOverflowing",
      value:
      /**
       * Determine if any navigation columns are taller than megamenu.
       */
      function _setOverflowing() {
        const {
          navLeftSelector,
          navRightSelector,
          navColumnInnerSelector
        } = this.constructor;
        const navColumns = this.querySelectorAll(`
      ${navLeftSelector},
      ${this.layout === MEGAMENU_LAYOUT_SCHEME.TAB ? `[role="tabpanel"] > ${navRightSelector}` : navRightSelector}
    `);
        const columnHeights = [];
        navColumns.forEach(column => {
          var _column$shadowRoot;
          const height = navColumnInnerSelector ? (_column$shadowRoot = column.shadowRoot) === null || _column$shadowRoot === void 0 || (_column$shadowRoot = _column$shadowRoot.querySelector(navColumnInnerSelector)) === null || _column$shadowRoot === void 0 ? void 0 : _column$shadowRoot.scrollHeight : column.scrollHeight;
          columnHeights.push(height);
        });
        this.overflowing = columnHeights.some(height => height ? height > this.scrollHeight : false);
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value: function connectedCallback() {
        const sharedOptions = {
          childList: true,
          subtree: true,
          attributes: true
        };
        const options = this.layout === MEGAMENU_LAYOUT_SCHEME.TAB ? _objectSpread(_objectSpread({}, sharedOptions), {}, {
          attributeFilter: ['selected']
        }) : sharedOptions;
        this.mutationObserver.observe(this, options);
        this.resizeObserver.observe(this);
        _superPropGet(C4DMegaMenu, "connectedCallback", this, 3)([]);
      }
    }, {
      kind: "method",
      key: "disconnectedCallback",
      value: function disconnectedCallback() {
        this.mutationObserver.disconnect();
        this.resizeObserver.disconnect();
        _superPropGet(C4DMegaMenu, "disconnectedCallback", this, 3)([]);
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t || (_t = _`
      <div part="container" class="${0}--masthead__megamenu__container">
        <div
          part="container-row"
          class="${0}--masthead__megamenu__container--row ${0}--masthead__megamenu__container--row--${0}">
          <slot></slot>
        </div>
      </div>
    `), prefix, prefix, prefix, this.layout);
      }
    }, {
      kind: "get",
      static: true,
      key: "navLeftSelector",
      value: function () {
        return `${c4dPrefix}-megamenu-left-navigation`;
      }
    }, {
      kind: "get",
      static: true,
      key: "navRightSelector",
      value: function () {
        return `${c4dPrefix}-megamenu-right-navigation`;
      }
    }, {
      kind: "get",
      static: true,
      key: "navColumnInnerSelector",
      value: function () {
        return `.${prefix}--masthead__megamenu-container-inner`;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--masthead__megamenu`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
export default C4DMegaMenu;
//# sourceMappingURL=megamenu.js.map
