import _decorate from "@babel/runtime/helpers/esm/decorate";
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { property } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
import C4DTopNav from "./top-nav.js";
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Masthead top nav for L1.
 *
 * @element c4d-top-nav-l1
 */
let C4DTopNavL1 = _decorate([customElement(`${c4dPrefix}-top-nav-l1`)], function (_initialize, _C4DTopNav) {
  class C4DTopNavL1 extends _C4DTopNav {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DTopNavL1,
    d: [{
      kind: "field",
      key: "_handleSearchToggle",
      value() {
        return () => {
          // Do nothing
        };
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true,
        attribute: 'hide-divider'
      })],
      key: "hideDivider",
      value() {
        return true;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value:
      // eslint-disable-next-line class-methods-use-this

      /**
       * `true` to hide the divider.
       */

      function () {
        return `${c4dPrefix}--masthead__l1-nav`;
      }
    }]
  };
}, C4DTopNav);
export default C4DTopNavL1;
//# sourceMappingURL=top-nav-l1.js.map
