import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2022, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html } from 'lit';
import { property } from 'lit/decorators.js';
import HostListenerMixin from '@carbon/web-components/es/globals/mixins/host-listener.js';
import HostListener from '@carbon/web-components/es/globals/decorators/host-listener.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import C4DStructuredList from "../structured-list/structured-list.js";
import styles from "././pricing-table.css.js";
import C4DPricingTableHeaderCell from "./pricing-table-header-cell.js";
import C4DPricingTableHead from "./pricing-table-head.js";
import C4DPricingTableHeaderRow from "./pricing-table-header-row.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * @element c4d-pricing-table
 * @csspart container - The table container. Usage `c4d-pricing-table::part(container)`
 * @csspart sentinel - A sentinel node. Usage `c4d-pricing-table::part(sentinel)`
 * @csspart start-sentinel - The start sentinel. Usage `c4d-pricing-table::part(start-sentinel)`
 * @csspart end-sentinel - The end sentinel. Usage `c4d-pricing-table::part(end-sentinel)`
 */
let C4DPricingTable = _decorate([customElement(`${c4dPrefix}-pricing-table`)], function (_initialize, _HostListenerMixin) {
  class C4DPricingTable extends _HostListenerMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DPricingTable,
    d: [{
      kind: "field",
      decorators: [property({
        reflect: true,
        attribute: 'highlight-column'
      })],
      key: "highlightColumn",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        reflect: true,
        attribute: 'highlight-label'
      })],
      key: "highlightLabel",
      value: void 0
    }, {
      kind: "field",
      decorators: [property()],
      key: "highlightClass",
      value() {
        return 'highlighted';
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "highlightGap",
      value() {
        return 0;
      }
    }, {
      kind: "method",
      key: "_getHeaderElements",
      value:
      /**
       * This table's C4DPricingTableHead node.
       */

      /**
       * This table's C4DPricingTableHeaderRow node.
       */

      /**
       * This table's C4DPricingTableHeaderCell nodes.
       */

      /**
       * Collect and store references to current header elements.
       */
      function _getHeaderElements() {
        this.head = undefined;
        this.headerRow = undefined;
        this.headerCells = undefined;
        const head = this.querySelector(`${c4dPrefix}-pricing-table-head`);
        if (head instanceof C4DPricingTableHead) {
          this.head = head;
        }
        const headerRow = head === null || head === void 0 ? void 0 : head.querySelector(`${c4dPrefix}-pricing-table-header-row`);
        if (headerRow instanceof C4DPricingTableHeaderRow) {
          this.headerRow = headerRow;
          this.headerCells = Array.from(headerRow.children);
        }
      }
    }, {
      kind: "method",
      key: "_renderHighlightLabel",
      value: function _renderHighlightLabel() {
        const {
          highlightLabel
        } = this;
        const element = this.ownerDocument.createElement(`${c4dPrefix}-pricing-table-highlight-label`);
        element.innerText = highlightLabel || '';
        return element;
      }
    }, {
      kind: "method",
      key: "_unhighlightCells",
      value: function _unhighlightCells(cells) {
        const {
          highlightClass
        } = this;
        cells.forEach(cell => {
          var _cell$querySelector;
          cell.classList.remove(highlightClass);
          (_cell$querySelector = cell.querySelector(`${c4dPrefix}-pricing-table-highlight-label`)) === null || _cell$querySelector === void 0 || _cell$querySelector.remove();
          this.style.marginTop = '';
        });
      }
    }, {
      kind: "method",
      key: "_highlightCells",
      value: function _highlightCells(cells) {
        const {
          highlightLabel,
          highlightClass
        } = this;
        cells.forEach(cell => cell.classList.add(highlightClass));
        if (highlightLabel) {
          const firstCell = cells[0];
          if (firstCell instanceof C4DPricingTableHeaderCell) {
            firstCell.prepend(this._renderHighlightLabel());
          }
          this._setHighlightGap();
        }
      }
    }, {
      kind: "method",
      key: "_setHighlightGap",
      value: function _setHighlightGap() {
        var _this$shadowRoot;
        const wrapper = ((_this$shadowRoot = this.shadowRoot) === null || _this$shadowRoot === void 0 ? void 0 : _this$shadowRoot.getElementById(C4DStructuredList.wrapperId)) || this;
        (async () => {
          return this.querySelector(`${c4dPrefix}-pricing-table-highlight-label`);
        })().then(value => {
          this.highlightGap = (value === null || value === void 0 ? void 0 : value.getBoundingClientRect().height) || 0;
          wrapper.style.marginTop = `${this.highlightGap}px`;
        }).catch(() => {
          wrapper.style.marginTop = '';
        });
      }

      /**
       * Host listener for updating header element references when cells are
       * updated.
       *
       * @protected
       */
    }, {
      kind: "field",
      decorators: [HostListener('document:eventHeaderRowSlotchange')],
      key: "_handleHeaderRowSlotChange",
      value() {
        return () => {
          this._getHeaderElements();
        };
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated() {
        const {
          highlightColumn
        } = this;
        this._getHeaderElements();
        if (highlightColumn) {
          this._unhighlightCells(this.querySelectorAll(`
        ${c4dPrefix}-pricing-table-cell,
        ${c4dPrefix}-pricing-table-header-cell`));
          this._highlightCells(this.querySelectorAll(`
        ${c4dPrefix}-pricing-table-cell:nth-child(${highlightColumn}),
        ${c4dPrefix}-pricing-table-header-cell:nth-child(${highlightColumn})
      `));
        }
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value: function connectedCallback() {
        this._newChildObserver.observe(this, {
          childList: true,
          subtree: true,
          attributes: false
        });
        this._resetIntersectionObserver();
        _superPropGet(C4DPricingTable, "connectedCallback", this, 3)([]);
      }
    }, {
      kind: "method",
      key: "disconnectedCallback",
      value: function disconnectedCallback() {
        _superPropGet(C4DPricingTable, "disconnectedCallback", this, 3)([]);
      }
    }, {
      kind: "method",
      key: "renderInner",
      value: function renderInner() {
        const {
          sentinelClass
        } = this.constructor;
        return html(_t || (_t = _`
      <section
        id="section"
        class="${0}"
        part="container">
        <span
          class="${0}"
          id="start-sentinel"
          part="sentinel start-sentinel"></span>
        <slot></slot>
        <span
          class="${0}"
          id="end-sentinel"
          part="sentinel end-sentinel"></span>
      </section>
    `), `${prefix}--structured-list`, sentinelClass, sentinelClass);
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--pricing-table`;
      }

      /**
       * The name of the custom event captured when the header row's slot changes.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventHeaderRowSlotchange",
      value: function () {
        return C4DPricingTableHeaderRow.eventSlotChange;
      }
    }, {
      kind: "get",
      static: true,
      key: "sentinelClass",
      value: function () {
        return `${c4dPrefix}-pricing-table-sentinel`;
      }
    }, {
      kind: "get",
      static: true,
      key: "cellSelector",
      value: function () {
        return `${c4dPrefix}-pricing-table-cell, ${c4dPrefix}-pricing-table-header-cell`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, HostListenerMixin(StableSelectorMixin(C4DStructuredList)));
export default C4DPricingTable;
//# sourceMappingURL=pricing-table.js.map
