import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4;
/**
 * @license
 *
 * Copyright IBM Corp. 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { state, queryAssignedNodes } from 'lit/decorators.js';
import { classMap } from 'lit/directives/class-map.js';
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
import { baseFontSize, breakpoints } from '@carbon/layout';
import styles from "././promo-banner.css.js";
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import CTAMixin, { icons as ctaIcons } from "../../component-mixins/cta/cta.js";
import ifNonEmpty from '@carbon/web-components/es/globals/directives/if-non-empty';
const {
  stablePrefix: c4dPrefix,
  prefix
} = settings;
const breakpoint = parseFloat(breakpoints.lg.width) * baseFontSize;
const layoutBreakpoint = window.matchMedia(`(min-width: ${breakpoint}px)`);

/**
 * The Promo Banner component.
 * @element c4d-promo-banner
 */
let C4DPromoBanner = _decorate([customElement(`${c4dPrefix}-promo-banner`)], function (_initialize, _CTAMixin) {
  class C4DPromoBanner extends _CTAMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DPromoBanner,
    d: [{
      kind: "field",
      decorators: [state()],
      key: "isDesktopVersion",
      value() {
        return layoutBreakpoint.matches;
      }
    }, {
      kind: "field",
      decorators: [queryAssignedNodes('image', false)],
      key: "slottedImage",
      value: void 0
    }, {
      kind: "field",
      decorators: [queryAssignedNodes('cta', false)],
      key: "slottedCta",
      value: void 0
    }, {
      kind: "method",
      key: "handleSlotChange",
      value: function handleSlotChange(e) {
        var _e$target$name, _e$target;
        this.requestUpdate();
        const slotname = (_e$target$name = e === null || e === void 0 || (_e$target = e.target) === null || _e$target === void 0 ? void 0 : _e$target.name) !== null && _e$target$name !== void 0 ? _e$target$name : '';
        if (slotname === 'cta') {
          this.harvestCtaProps();
        }
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        layoutBreakpoint.addEventListener('change', e => {
          this.isDesktopVersion = e.matches;
        });
        this.harvestCtaProps();
      }
    }, {
      kind: "method",
      key: "harvestCtaProps",
      value: function harvestCtaProps() {
        const slotted_cta = this.querySelector('[slot="cta"]');
        if (slotted_cta) {
          const {
            _linkNode,
            ctaType,
            disabled,
            download,
            href,
            target
          } = slotted_cta;
          this._linkNode = _linkNode;
          this.ctaType = ctaType;
          this.disabled = disabled;
          this.download = download;
          this.href = href;
          this.target = target;
          this.requestUpdate();
          return;
        }
        this._linkNode = undefined;
        this.ctaType = '';
        this.disabled = false;
        this.download = '';
        this.href = '';
        this.target = '';
        this.requestUpdate();
      }

      /**
       * @inheritdoc
       */
    }, {
      kind: "method",
      key: "_renderIcon",
      value: function _renderIcon() {
        var _ctaIcons$ctaType;
        const {
          ctaType
        } = this;
        return html(_t || (_t = _`
      <slot name="icon">
        ${0}
      </slot>
    `), (_ctaIcons$ctaType = ctaIcons[ctaType]) === null || _ctaIcons$ctaType === void 0 ? void 0 : _ctaIcons$ctaType.call(ctaIcons, {
          class: `${prefix}--card__cta ${c4dPrefix}-ce--cta__icon`
        }));
      }
    }, {
      kind: "method",
      key: "_renderMobileLayout",
      value: function _renderMobileLayout() {
        const {
          href,
          disabled,
          target,
          download,
          innerText
        } = this;
        const classes = {
          'banner-wrapper': true,
          'no-cta': !href
        };
        return html(_t2 || (_t2 = _`
      <div class="${0}" part="wrapper">
        <div class="banner-content" aria-hidden=${0} part="content">
          <slot></slot>
        </div>
        ${0}
      </div>
    `), classMap(classes), true, href ? html(_t3 || (_t3 = _`
              <a
                class="banner-cta"
                href=${0}
                ?disabled=${0}
                target=${0}
                download=${0}
                aria-label=${0}
                part="cta">
                <span class="banner-cta-icon" part="icon">
                  ${0}
                </span>
              </a>
            `), href, ifNonEmpty(disabled), ifNonEmpty(target), ifNonEmpty(download), innerText, this._renderIcon()) : '');
      }
    }, {
      kind: "method",
      key: "_renderDesktopLayout",
      value: function _renderDesktopLayout() {
        const {
          slottedImage,
          slottedCta,
          handleSlotChange
        } = this;
        return html(_t4 || (_t4 = _`
      <div
        class="banner-wrapper"
        @slotchange=${0}
        part="wrapper">
        <div class="banner-image" ?hidden=${0} part="image">
          <slot name="image"></slot>
        </div>
        <div class="banner-content" part="content">
          <slot></slot>
        </div>
        <div class="banner-cta" ?hidden=${0} part="cta">
          <slot name="cta"></slot>
        </div>
      </div>
    `), handleSlotChange, !(slottedImage !== null && slottedImage !== void 0 && slottedImage.length), !(slottedCta !== null && slottedCta !== void 0 && slottedCta.length));
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          isDesktopVersion
        } = this;
        return isDesktopVersion ? this._renderDesktopLayout() : this._renderMobileLayout();
      }
    }, {
      kind: "get",
      static: true,
      key: "styles",
      value: function () {
        return styles;
      }
    }]
  };
}, CTAMixin(LitElement));
export default C4DPromoBanner;
//# sourceMappingURL=promo-banner.js.map
