import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4,
  _t5,
  _t6,
  _t7,
  _t8,
  _t9,
  _t10;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2025
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././quote.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { QUOTE_TYPES } from "./defs.js";
import "../horizontal-rule/horizontal-rule.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
import LocaleAPI from '@carbon/ibmdotcom-services/es/services/Locale/Locale.js';
export { QUOTE_TYPES };
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;
const slotExistencePropertyNames = {
  'source-heading': '_hasSourceHeading',
  'source-copy': '_hasSourceCopy',
  'source-bottom-copy': '_hasSourceBottomCopy',
  footer: '_hasFooter'
};

/**
 * Quote.
 *
 * @element c4d-quote
 * @slot copy - The copy content.
 * @slot footer - The footer (CTA) content.
 * @slot source-heading - The heading content of the quote source.
 * @slot source-copy - The copy content of the quote source.
 * @slot source-bottom-copy - The copy content of the quote source placed at the bottom.
 * @csspart mark - Quote mark. Usage `c4d-quote::part(mark)`
 * @csspart mark--opening - Opening quote mark. Usage `c4d-quote::part(mark--opening)`
 * @csspart mark--closing - Closing quote mark. Usage `c4d-quote::part(mark--closing)`
 * @csspart copy - Quote body copy. Usage `c4d-quote::part(copy)`
 * @csspart source - Quote source slot. Usage `c4d-quote::part(source)`
 * @csspart footer - Quote footer. Usage `c4d-quote::part(footer)`
 * @csspart container - Quote container. Usage `c4d-quote::part(container)`
 * @csspart wrapper - Quote wrapper. Usage `c4d-quote::part(wrapper)`
 * @csspart hr - Horizontal rule. Usage `c4d-quote::part(wrapper)`
 * @csspart bubble-pointer-svg - The bubble quote variation pointer. Usage `c4d-quote::part(bubble-pointer-svg)`
 * @csspart bubble-pointer-fill-svg - The fill color of the pointer. Usage `c4d-quote::part(bubble-pointer-fill-svg)`
 * @csspart bubble-pointer-stroke-svg - The stroke color of the pointer. Usage `c4d-quote::part(bubble-pointer-stroke-svg)`
 */
let C4DQuote = _decorate([customElement(`${c4dPrefix}-quote`)], function (_initialize, _StableSelectorMixin) {
  class C4DQuote extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DQuote,
    d: [{
      kind: "field",
      decorators: [property({
        reflect: true,
        attribute: 'mark-type'
      })],
      key: "markType",
      value() {
        return QUOTE_TYPES.DEFAULT;
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true,
        attribute: 'lang'
      })],
      key: "lc",
      value: void 0
    }, {
      kind: "field",
      key: "_hasSourceHeading",
      value() {
        return false;
      }
    }, {
      kind: "field",
      key: "_hasSourceCopy",
      value() {
        return false;
      }
    }, {
      kind: "field",
      key: "_hasSourceBottomCopy",
      value() {
        return false;
      }
    }, {
      kind: "field",
      key: "_hasFooter",
      value() {
        return false;
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value:
      /**
       * Defines rendered quote mark style
       * styles:
       * `double-curved`: `“ ”`;
       * `single-curved`: `‘ ’`;
       * `single-angle`: `‹ ›`;
       * `double-angle`: `« »`;
       * `low-high-reversed-double-curved`: `„ “`;
       * `corner-bracket`: `「 」`;
       */

      /**
       * `true` if there is source heading.
       */

      /**
       * `true` if there is source copy.
       */

      /**
       * `true` if there is source bottom copy.
       */

      /**
       * `true` if there is cta.
       */

      /**
       * Handles `slotchange` event.
       */

      function connectedCallback() {
        _superPropGet(C4DQuote, "connectedCallback", this, 3)([]);
        LocaleAPI.getLang().then(({
          lc
        }) => {
          this.lc = lc;
        });
      }
    }, {
      kind: "method",
      key: "_handleSlotChange",
      value: function _handleSlotChange({
        target
      }) {
        const {
          name
        } = target;
        const hasContent = target.assignedNodes().some(node => node.nodeType !== Node.TEXT_NODE || node.textContent.trim());
        this[slotExistencePropertyNames[name]] = hasContent;
        this.requestUpdate();
      }
    }, {
      kind: "method",
      key: "_renderQuote",
      value: function _renderQuote() {
        switch (this.markType) {
          case QUOTE_TYPES.SINGLE_CURVED:
            return html(_t || (_t = _`
          <span class="${0}--quote__mark" part="mark mark--opening"
            >‘</span
          >
          <blockquote class="${0}--quote__copy" part="copy">
            <slot></slot
            ><span
              class="${0}--quote__mark-closing"
              part="mark mark--closing"
              >’</span
            >
          </blockquote>
        `), prefix, prefix, prefix);
          case QUOTE_TYPES.DOUBLE_ANGLE:
            return html(_t2 || (_t2 = _`
          <span class="${0}--quote__mark" part="mark mark--opening"
            >«</span
          >
          <blockquote class="${0}--quote__copy" part="copy">
            <slot></slot
            ><span
              class="${0}--quote__mark-closing"
              part="mark mark--closing"
              >»</span
            >
          </blockquote>
        `), prefix, prefix, prefix);
          case QUOTE_TYPES.SINGLE_ANGLE:
            return html(_t3 || (_t3 = _`
          <span class="${0}--quote__mark" part="mark mark--opening"
            >‹</span
          >
          <blockquote class="${0}--quote__copy" part="copy">
            <slot></slot
            ><span
              class="${0}--quote__mark-closing"
              part="mark mark--closing"
              >›</span
            >
          </blockquote>
        `), prefix, prefix, prefix);
          case QUOTE_TYPES.LOW_HIGH_REVERSED_DOUBLE_CURVED:
            return html(_t4 || (_t4 = _`
          <span class="${0}--quote__mark" part="mark mark--opening"
            >„</span
          >
          <blockquote class="${0}--quote__copy" part="copy">
            <slot></slot
            ><span
              class="${0}--quote__mark-closing"
              part="mark mark--closing"
              >“</span
            >
          </blockquote>
        `), prefix, prefix, prefix);
          case QUOTE_TYPES.CORNER_BRACKET:
            return html(_t5 || (_t5 = _`
          <span
            class="${0}--quote__mark ${0}--quote__mark-corner-bracket"
            part="mark mark--opening"
            >「</span
          >
          <blockquote class="${0}--quote__copy" part="copy">
            <slot></slot
            ><span
              class="${0}--quote__mark-closing"
              part="mark mark--closing"
              >」</span
            >
          </blockquote>
        `), prefix, prefix, prefix, prefix);
          case QUOTE_TYPES.BUBBLE_QUOTE:
            return html(_t6 || (_t6 = _`
          <span class="${0}--quote__mark" part="mark mark--opening">
            ${0}
          </span>
          <blockquote
            class="${0}--quote__copy ${0}-bubble-quote"
            part="copy">
            <slot></slot>
            <svg
              width="47"
              height="37"
              viewBox="0 0 47 37"
              fill="none"
              xmlns="http://www.w3.org/2000/svg"
              class="bubble-pointer"
              part="bubble-pointer-svg">
              <path
                d="M4 31.84V4.5C4 2.29086 2.20914 0.5 0 0.5V0H46.6569V0.5C45.596 0.5 44.5786 0.919855 43.8284 1.67L10.8284 34.67C8.30857 37.1899 4 35.4036 4 31.84Z"
                fill="#F4F4F4"
                class="bubble-pointer-fill"
                part="bubble-pointer-fill-svg" />
              <path
                d="M0 0.5C2.20914 0.5 4 2.29086 4 4.5V31.84C4 35.4036 8.30857 37.1899 10.8284 34.67L43.8284 1.67C44.5786 0.919855 45.596 0.5 46.6569 0.5"
                stroke="#8D8D8D"
                class="bubble-pointer-stroke"
                part="bubble-pointer-stroke-svg" />
            </svg>
            <span
              class="${0}--quote__mark-closing"
              part="mark mark--closing"
              >${0}</span
            >
          </blockquote>
        `), prefix, this.lc !== 'ar' ? '“' : '”', prefix, prefix, prefix, this.lc !== 'ar' ? '”' : '“');
          default:
            return html(_t7 || (_t7 = _`
          <span class="${0}--quote__mark" part="mark mark--opening"
            >${0}</span
          >
          <blockquote class="${0}--quote__copy" part="copy">
            <slot></slot
            ><span
              class="${0}--quote__mark-closing"
              part="mark mark--closing"
              >${0}</span
            >
          </blockquote>
        `), prefix, this.lc !== 'ar' ? '“' : '”', prefix, prefix, this.lc !== 'ar' ? '”' : '“');
        }
      }
    }, {
      kind: "method",
      key: "_renderSource",
      value: function _renderSource() {
        const {
          _hasSourceHeading: hasSourceHeading,
          _hasSourceCopy: hasSourceCopy,
          _handleSlotChange: handleSlotChange
        } = this;
        return html(_t8 || (_t8 = _`
      <div
        ?hidden="${0}"
        class="${0}--quote__source"
        part="source">
        <slot @slotchange="${0}" name="source-heading"></slot>
        <slot @slotchange="${0}" name="source-copy"></slot>
        <slot
          @slotchange="${0}"
          name="source-bottom-copy"></slot>
      </div>
    `), !hasSourceHeading || !hasSourceCopy, prefix, handleSlotChange, handleSlotChange, handleSlotChange);
      }
    }, {
      kind: "method",
      key: "_renderFooter",
      value: function _renderFooter() {
        const {
          _hasFooter: hasFooter,
          _handleSlotChange: handleSlotChange
        } = this;
        return html(_t9 || (_t9 = _`
      <div
        ?hidden="${0}"
        class="${0}--quote__footer"
        part="footer">
        <c4d-hr part="hr"></c4d-hr>
        <slot name="footer" @slotchange="${0}"></slot>
      </div>
    `), !hasFooter, prefix, handleSlotChange);
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t10 || (_t10 = _`
      <div class="${0}--quote__container" part="container">
        <div class="${0}--quote__wrapper" part="wrapper">
          ${0}${0}${0}
        </div>
      </div>
    `), prefix, prefix, this._renderQuote(), this._renderSource(), this._renderFooter());
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--quote`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DQuote;
//# sourceMappingURL=quote.js.map
