import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4,
  _t5,
  _t6,
  _t7;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import Filter20 from '@carbon/web-components/es/icons/filter/20.js';
import { html } from 'lit';
import { property } from 'lit/decorators.js';
import CDSSelect from '@carbon/web-components/es/components/select/select.js';
import { INPUT_SIZE } from '@carbon/web-components/es/components/text-input/text-input.js';
import { classMap } from 'lit/directives/class-map.js';
import { ifDefined } from 'lit/directives/if-defined.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import { filter } from "../../globals/internal/collection-helpers.js";
import styles from "././search-with-typeahead.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Scoped search dropdown - mobile version.
 * The dropdown to scope the search suggestions in mobile
 *
 * @element c4d-scoped-search-dropdown-mobile
 * @internal
 * @csspart select-option - An option in the select list. Usage `c4d-scoped-search-dropdown-mobile::part(select-option)`
 * @csspart select-optgroup - An optgroup in the select list. Usage `c4d-scoped-search-dropdown-mobile::part(select-optgroup)`
 * @csspart helper-text - The helper text. Usage `c4d-scoped-search-dropdown-mobile::part(helper-text)`
 * @csspart form-requirement - The message that appears on invalid input. Usage `c4d-scoped-search-dropdown-mobile::part(form-requirement)`
 * @csspart label-text - The label text. Usage `c4d-scoped-search-dropdown-mobile::part(label-text)`
 * @csspart select-input-wrapper - The select input wrapper. Usage `c4d-scoped-search-dropdown-mobile::part(select-input-wrapper)`
 * @csspart select-input - The input selector. Usage `c4d-scoped-search-dropdown-mobile::part(select-input)`
 */
let C4DScopedSearchDropdownMobile = _decorate([customElement(`${c4dPrefix}-scoped-search-dropdown-mobile`)], function (_initialize, _CDSSelect) {
  class C4DScopedSearchDropdownMobile extends _CDSSelect {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DScopedSearchDropdownMobile,
    d: [{
      kind: "field",
      key: "_placeholderItemValueMobile",
      value() {
        return `__${prefix}-select-placeholder_${Math.random().toString(36).slice(2)}`;
      }
    }, {
      kind: "method",
      key: "_handleInputMobile",
      value:
      /**
       * The `value` for placeholder `<option>`.
       */

      /**
       * Handles `oninput` event on the `<input>`
       *
       * @param event The event.
       * @param event.target The event target.
       */
      function _handleInputMobile({
        target
      }) {
        const {
          value
        } = target;
        this.value = value;
        const {
          eventSelect
        } = this.constructor;
        this.dispatchEvent(new CustomEvent(eventSelect, {
          bubbles: true,
          composed: true,
          detail: {
            appId: value
          }
        }));
      }

      /**
       * @param element The parent element containing pseudo `<optgroup>`/`<option>`.
       * @returns The template containing child `<optgroup>`/`<option>` that will be rendered to shadow DOM.
       */
    }, {
      kind: "method",
      key: "_renderItemsMobile",
      value: function _renderItemsMobile(element) {
        const {
          selectorItem,
          selectorLeafItem
        } = this.constructor;
        // Harvests attributes from `<cds-select-item>` and `<cds-select-item-group>`.
        // Does not use properties to avoid delay in attribute to property mapping, which runs in custom element reaction cycle:
        // https://html.spec.whatwg.org/multipage/custom-elements.html#custom-element-reactions
        return html(_t || (_t = _`
      ${0}
    `), filter(element.childNodes, item => item.nodeType === Node.ELEMENT_NODE && item.matches(selectorItem)).map(item => {
          const disabled = item.hasAttribute('disabled');
          const label = item.getAttribute('label');
          const selected = item.hasAttribute('selected');
          const value = item.getAttribute('value');
          const {
            textContent
          } = item;
          return item.matches(selectorLeafItem) ? html(_t2 || (_t2 = _`
              <option
                class="${0}--select-option"
                part="select-option"
                ?disabled="${0}"
                label="${0}"
                ?selected="${0}"
                value="${0}">
                ${0}
              </option>
            `), prefix, disabled, ifDefined(label !== null && label !== void 0 ? label : textContent), selected, ifDefined(value), textContent) : html(_t3 || (_t3 = _`
              <optgroup
                class="${0}--select-optgroup"
                part="select-optgroup"
                ?disabled="${0}"
                label="${0}">
                ${0}
              </optgroup>
            `), prefix, disabled, ifDefined(label), this._renderItemsMobile(item));
        }));
      }

      /**
       * Property that specifies the Select to have size xl
       *
       * @internal
       */
    }, {
      kind: "field",
      decorators: [property()],
      key: "size",
      value() {
        return INPUT_SIZE.EXTRA_LARGE;
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          disabled,
          helperText,
          invalid,
          labelText,
          placeholder,
          size,
          invalidText,
          value,
          _placeholderItemValueMobile: placeholderItemValue,
          _handleInputMobile: handleInput
        } = this;
        const inputClasses = classMap({
          [`${prefix}--select-input`]: true,
          [`${prefix}--select-input--${size}`]: size
        });
        const labelClasses = classMap({
          [`${prefix}--label`]: true,
          [`${prefix}--label--disabled`]: disabled
        });
        const helperTextClasses = classMap({
          [`${prefix}--form__helper-text`]: true,
          [`${prefix}--form__helper-text--disabled`]: disabled
        });
        const supplementalText = !invalid ? html(_t4 || (_t4 = _`
          <div class="${0}" part="helper-text">
            <slot name="helper-text"> ${0} </slot>
          </div>
        `), helperTextClasses, helperText) : html(_t5 || (_t5 = _`
          <div
            class="${0}--form-requirement"
            part="form-requirement"
            id="validity-message">
            <slot name="validity-message"> ${0} </slot>
          </div>
        `), prefix, invalidText);
        return html(_t6 || (_t6 = _`
      <label class="${0}" part="label-text" for="input">
        <slot name="label-text"> ${0} </slot>
      </label>
      <div
        class="${0}--select-input__wrapper"
        part="select-input-wrapper"
        ?data-invalid="${0}">
        <select
          id="input"
          class="${0}"
          part="select-input"
          ?disabled="${0}"
          aria-invalid="${0}"
          aria-describedby="${0}"
          @input="${0}">
          ${0}
          ${0}
        </select>
        ${0}
      </div>
      ${0}
    `), labelClasses, labelText, prefix, invalid, inputClasses, disabled, String(Boolean(invalid)), ifDefined(!invalid ? undefined : 'validity-message'), handleInput, !placeholder || value ? undefined : html(_t7 || (_t7 = _`
                <option
                  disabled
                  hidden
                  class="${0}--select-option"
                  value="${0}"
                  selected>
                  ${0}
                </option>
              `), prefix, placeholderItemValue, placeholder), this._renderItemsMobile(this), Filter20({
          class: `${prefix}--select__arrow`
        }), supplementalText);
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, CDSSelect);
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DScopedSearchDropdownMobile;
//# sourceMappingURL=scoped-search-dropdown-mobile.js.map
