/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { LitElement, TemplateResult } from 'lit';
/**
 * Search result item in masthead.
 *
 * @element c4d-search-with-typeahead-item
 * @csspart item item-highlighted - The highlighted item. Usage `c4d-search-with-typeahead-item::part(item item-highlighted)`
 * @csspart item-container - The item container. Usage `c4d-search-with-typeahead-item::part(item-container)`
 */
declare class C4DSearchWithTypeaheadItem extends LitElement {
    /**
     * The the search result to be shown.
     */
    private _content?;
    /**
     * Boolean checking if page is RTL
     */
    private _pageIsRTL;
    /**
     * The optional href to redirect the user to.
     */
    href: string;
    /**
     * `true` if this dropdown item should be highlighted.
     * If `true`, parent `<c4d-search-with-typeahead>` selects/deselects this dropdown item upon keyboard interaction.
     *
     * @private
     */
    highlighted: boolean;
    /**
     * The search result text.
     */
    text: string;
    /**
     * Retrieves the current search query string from the parent element.
     */
    protected _getCurrentQuery(): any;
    /**
     * Returns this element's text content with the portion that matches the current
     * search query highlighted.
     */
    protected _getHighlightedText(): (string | TemplateResult)[];
    connectedCallback(): void;
    shouldUpdate(changedProperties: any): boolean;
    updated(changedProperties: any): void;
    render(): TemplateResult<1>;
    static styles: any;
}
export default C4DSearchWithTypeaheadItem;

//# sourceMappingURL=search-with-typeahead-item.d.ts.map
