import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { classMap } from 'lit/directives/class-map.js';
import { html, LitElement } from 'lit';
import { property, state } from 'lit/decorators.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././search-with-typeahead.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Search result item in masthead.
 *
 * @element c4d-search-with-typeahead-item
 * @csspart item item-highlighted - The highlighted item. Usage `c4d-search-with-typeahead-item::part(item item-highlighted)`
 * @csspart item-container - The item container. Usage `c4d-search-with-typeahead-item::part(item-container)`
 */
let C4DSearchWithTypeaheadItem = _decorate([customElement(`${c4dPrefix}-search-with-typeahead-item`)], function (_initialize, _LitElement) {
  class C4DSearchWithTypeaheadItem extends _LitElement {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DSearchWithTypeaheadItem,
    d: [{
      kind: "field",
      decorators: [state()],
      key: "_pageIsRTL",
      value() {
        return this.ownerDocument.documentElement.dir === 'rtl';
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "href",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true
      })],
      key: "highlighted",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "text",
      value() {
        return '';
      }
    }, {
      kind: "method",
      key: "_getCurrentQuery",
      value:
      /**
       * The the search result to be shown.
       */

      /**
       * Boolean checking if page is RTL
       */

      /**
       * The optional href to redirect the user to.
       */

      /**
       * `true` if this dropdown item should be highlighted.
       * If `true`, parent `<c4d-search-with-typeahead>` selects/deselects this dropdown item upon keyboard interaction.
       *
       * @private
       */

      /**
       * The search result text.
       */

      /**
       * Retrieves the current search query string from the parent element.
       */
      function _getCurrentQuery() {
        const parent = this.getRootNode().host;
        const {
          searchQueryString
        } = parent !== null && parent !== void 0 ? parent : {};
        return searchQueryString === null || searchQueryString === void 0 ? void 0 : searchQueryString.toLowerCase();
      }

      /**
       * Returns this element's text content with the portion that matches the current
       * search query highlighted.
       */
    }, {
      kind: "method",
      key: "_getHighlightedText",
      value: function _getHighlightedText() {
        const {
          text
        } = this;
        let searchQueryString = this._getCurrentQuery();
        const lowerCaseText = text.toLowerCase();
        if (lowerCaseText.includes(searchQueryString)) {
          const startingIndex = lowerCaseText.indexOf(searchQueryString);
          searchQueryString = text.substring(startingIndex, startingIndex + searchQueryString.length);
        }
        const highlightedResult = html(_t || (_t = _`<span
      class="${0}-ce--search-with-typeahead-item__highlighted"
      part="item item-highlighted"
      >${0}</span
    >`), c4dPrefix, searchQueryString);
        const content = text.split(new RegExp(searchQueryString, 'i')).reduce((acc, item) => {
          acc.push(item.replace(/^\s/, '\xa0').replace(/\s$/, '\xa0'));
          acc.push(highlightedResult);
          return acc;
        }, []);
        content.pop();
        if (this._pageIsRTL) {
          content.reverse();
        }
        return content;
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value: function connectedCallback() {
        if (!this.hasAttribute('role')) {
          this.setAttribute('role', 'option');
        }
        _superPropGet(C4DSearchWithTypeaheadItem, "connectedCallback", this, 3)([]);
      }
    }, {
      kind: "method",
      key: "shouldUpdate",
      value: function shouldUpdate(changedProperties) {
        const result = _superPropGet(C4DSearchWithTypeaheadItem, "shouldUpdate", this, 3)([changedProperties]);
        if (changedProperties.has('text')) {
          const {
            text
          } = this;
          const searchQueryString = this._getCurrentQuery();
          this._content = !searchQueryString || this.hasAttribute('groupTitle') ? text : this._getHighlightedText();
        }
        return result;
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated(changedProperties) {
        _superPropGet(C4DSearchWithTypeaheadItem, "updated", this, 3)([changedProperties]);
        if (changedProperties.has('highlighted')) {
          this.setAttribute('aria-selected', String(Boolean(this.highlighted)));
        }
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          highlighted,
          _content: content
        } = this;
        const containerClasses = classMap({
          [`${prefix}--container-class`]: true,
          [`${prefix}--container-highlight-class`]: highlighted
        });
        return html(_t2 || (_t2 = _`
      <div class="${0}" part="item-container" tabindex="-1">
        ${0}
      </div>
    `), containerClasses, content);
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, LitElement);
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DSearchWithTypeaheadItem;
//# sourceMappingURL=search-with-typeahead-item.js.map
