import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4,
  _t5,
  _t6,
  _t7,
  _t8,
  _t9,
  _t10,
  _t11,
  _t12,
  _t13,
  _t14;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2019, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { ifDefined } from 'lit/directives/if-defined.js';
import { classMap } from 'lit/directives/class-map.js';
import { html } from 'lit';
import { property, query, state } from 'lit/decorators.js';
import Close20 from '@carbon/web-components/es/icons/close/20.js';
import Search20 from '@carbon/web-components/es/icons/search/20.js';
import CDSDropdown, { DROPDOWN_KEYBOARD_ACTION } from '@carbon/web-components/es/components/dropdown/dropdown.js';
import HostListener from '@carbon/web-components/es/globals/decorators/host-listener.js';
import HostListenerMixin from '@carbon/web-components/es/globals/mixins/host-listener.js';
import { baseFontSize, breakpoints } from '@carbon/layout';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import SearchTypeaheadAPI from '@carbon/ibmdotcom-services/es/services/SearchTypeahead/SearchTypeahead.js';
import { forEach, indexOf } from "../../globals/internal/collection-helpers.js";
import styles from "././search-with-typeahead.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import "./search-with-typeahead-item.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
import C4DSearchWithTypeaheadItem from "./search-with-typeahead-item.js";
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;
const gridBreakpoint = parseFloat(breakpoints.lg.width) * baseFontSize;

/**
 * Search with Typeahead
 *
 * @element c4d-search-with-typeahead
 * @csspart search-input - The input box for search. Usage `c4d-search-with-typeahead::part(search-input)`
 * @csspart search-form - The search form. Usage `c4d-search-with-typeahead::part(search-form)`
 * @csspart container - The search form container. Usage `c4d-search-with-typeahead::part(container)`
 * @csspart dropdown - The search dropdown. Usage `c4d-search-with-typeahead::part(dropdown)`
 * @csspart dropdown-item - The dropdown item. Usage `c4d-search-with-typeahead::part(dropdown-item)`
 * @csspart dropdown-mobile - The search dropdown for mobile. Usage `c4d-search-with-typeahead::part(dropdown-mobile)`
 * @csspart select-item - The item selector. Usage `c4d-search-with-typeahead::part(select-item)`
 * @csspart suggestions-container - The suggestions container. Usage `c4d-search-with-typeahead::part(suggestions-container)`
 * @csspart suggestions-list - The suggestions list. Usage `c4d-search-with-typeahead::part(suggestions-list)`
 * @csspart search-with-typeahead-item - The search item. Usage `c4d-search-with-typeahead::part(search-with-typeahead-item)`
 * @csspart open-button - The button to show the search box. Usage `c4d-search-with-typeahead::part(open-button)`
 * @csspart close-button - The button to hide the search box. Usage `c4d-search-with-typeahead::part(close-button)`
 * @csspart header-search-actions - The container for the search bar. Usage `c4d-search-with-typeahead::part(header-search-actions)`
 * @csspart suggestion-item - The search item. Usage `c4d-search-with-typeahead::part(suggestion-item)`
 * @fires c4d-search-with-typeahead-beingredirected
 *   The custom event fired before the page is being redirected to the search result page.
 *   Cancellation of this event stops the user-initiated action of redirection.
 * @fires c4d-search-with-typeahead-input
 *   The name of the custom event fired after the search content is changed upon a user gesture.
 * @fires c4d-search-with-typeahead-toggled
 *   The name of the custom event fired after this search box is toggled upon a user gesture.
 */
let C4DSearchWithTypeahead = _decorate([customElement(`${c4dPrefix}-search-with-typeahead`)], function (_initialize, _HostListenerMixin) {
  class C4DSearchWithTypeahead extends _HostListenerMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DSearchWithTypeahead,
    d: [{
      kind: "method",
      key: "getResults",
      value:
      // eslint-disable-next-line class-methods-use-this
      async function getResults(searchQuery) {
        const response = await SearchTypeaheadAPI.getResults(searchQuery, this.appId);
        return response.map(res => res[0]);
      }

      /**
       * The formatter for the placeholder text on the search box.
       * Should be changed upon the locale the UI is rendered with.
       */
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "placeholderFormatter",
      value() {
        return ({
          appId
        }) => `Search in ${appId}`;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'leadspace-search',
        type: Boolean
      })],
      key: "leadspaceSearch",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'custom-typeahead-api',
        type: Boolean
      })],
      key: "customTypeaheadAPI",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "currentSearchResults",
      value: void 0
    }, {
      kind: "field",
      decorators: [property()],
      key: "searchResults",
      value: void 0
    }, {
      kind: "field",
      decorators: [property()],
      key: "groupedResults",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'initial-search-term',
        reflect: true
      })],
      key: "initialSearchTerm",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'scope-parameters'
      })],
      key: "scopeParameters",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'should-remain-open',
        type: Boolean
      })],
      key: "shouldRemainOpen",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'appid',
        reflect: true
      })],
      key: "appId",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'scope-label',
        reflect: true
      })],
      key: "scopeLabel",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'scope-value',
        reflect: true
      })],
      key: "scopeValue",
      value: void 0
    }, {
      kind: "field",
      decorators: [state()],
      key: "userHasInputSearch",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [query(`.${prefix}--header__search--search`)],
      key: "_searchButtonNode",
      value: void 0
    }, {
      kind: "field",
      decorators: [query(`.${prefix}--header__search--close`)],
      key: "_closeButtonNode",
      value: void 0
    }, {
      kind: "field",
      decorators: [query(`.${prefix}--header__search--input`)],
      key: "_searchInputNode",
      value: void 0
    }, {
      kind: "field",
      decorators: [query(`.react-autosuggest__suggestions-list`)],
      key: "_searchSuggestions",
      value: void 0
    }, {
      kind: "field",
      decorators: [HostListener('shadowRoot:focusin')],
      key: "_handleFocus",
      value() {
        return async ({
          target
        }) => {
          if (!this._searchSuggestions) {
            return;
          }
          if (target === this._searchInputNode) {
            this._searchSuggestions.removeAttribute('hidden');
          } else if (target === (this._searchButtonNode || this._closeButtonNode)) {
            this._searchSuggestions.setAttribute('hidden', '');
          }
          if (target === this._closeButtonNode) {
            this.setAttribute('unfocused', '');
          } else {
            this.removeAttribute('unfocused');
          }
        };
      }
    }, {
      kind: "method",
      key: "_handleClickCloseButton",
      value:
      /**
       * The `<button>` to open the search box.
       */
      /**
       * The `<button>` to open the search box.
       */
      /**
       * The `<input>` of the search box.
       */
      /**
       * The `<ul>` containing the search suggestions.
       */
      /**
       * Handles hiding search suggestions if focusing on other buttons.
       *
       * @param event The event.
       * @param event.target The event target.
       */
      /**
       * Handles `click` event on the close button.
       */
      async function _handleClickCloseButton() {
        if (this.leadspaceSearch) {
          var _this$_closeButtonNod;
          (_this$_closeButtonNod = this._closeButtonNode) === null || _this$_closeButtonNod === void 0 || _this$_closeButtonNod.classList.add(`${prefix}--header__search--hide`);
        }
        this._handleUserInitiatedToggleActiveState(false);
      }

      /**
       * @inheritdoc
       */
    }, {
      kind: "method",
      key: "_handleClickInner",
      value: function _handleClickInner(event) {
        if (event.target.closest('.cds--header__search--input') === event.target) {
          this._handleUserInitiatedToggle();
          if (this.searchQueryString && this.leadspaceSearch) {
            var _this$_closeButtonNod2;
            (_this$_closeButtonNod2 = this._closeButtonNode) === null || _this$_closeButtonNod2 === void 0 || _this$_closeButtonNod2.classList.remove(`${prefix}--header__search--hide`);
          }
        } else {
          const item = event.target.closest(this.constructor.selectorItem);
          if (this.shadowRoot.contains(item) && !item.hasAttribute('groupTitle')) {
            this._handleUserInitiatedSelectItem(item);
          }
        }
      }

      /**
       * Handles `click` event on the search button.
       */
    }, {
      kind: "method",
      key: "_handleClickSearchButton",
      value: async function _handleClickSearchButton() {
        const {
          active
        } = this;
        if (active) {
          if (this.searchQueryString) {
            this._handleUserInitiatedRedirect();
          }
        } else {
          this._handleUserInitiatedToggleActiveState(true);
        }
      }

      /**
       * Handles user-initiated toggling of activated state of the search box.
       *
       * @param active `true` to activate the search box.
       * @param moveFocus
       *   `true` to move focus upon toggling, to the input box when activated, to the trigger button when deactivated.
       */
    }, {
      kind: "method",
      key: "_handleUserInitiatedToggleActiveState",
      value: async function _handleUserInitiatedToggleActiveState(active, moveFocus = true) {
        if (active === this.active) {
          return;
        }
        const {
          _searchInputNode: searchInputNode
        } = this;
        const {
          eventInput,
          eventToggle
        } = this.constructor;
        if (!active && searchInputNode.value) {
          searchInputNode.value = '';
          this.dispatchEvent(new CustomEvent(eventInput, {
            bubbles: true,
            composed: true,
            cancelable: false,
            detail: {
              value: ''
            }
          }));
        }
        this.active = this.shouldRemainOpen ? true : !this.active;
        this.searchResults = [];
        this.groupedResults = [];
        this.dispatchEvent(new CustomEvent(eventToggle, {
          bubbles: true,
          cancelable: true,
          composed: true,
          detail: {
            active
          }
        }));
        await this.updateComplete;
        if (moveFocus) {
          // Does not reuse destructed `searchInputNode` given it's `null` before expanded
          (this.active ? this._searchInputNode : this._searchButtonNode).focus();
        }
      }

      /**
       * Prevents key types in the `<input>` causing other keyboard shortcuts in application UI.
       *
       * @param event The event.
       */
    }, {
      kind: "method",
      key: "_handleKeyInput",
      value: function _handleKeyInput(event) {
        if (this.constructor.getAction(event.key) === DROPDOWN_KEYBOARD_ACTION.NONE) {
          event.stopPropagation();
        }
      }

      /**
       * Builds a redirect href string with appropriate query params. Emulates what
       * would be generated by the form action.
       *
       * @param targetQuery An optional query string value.
       * @returns {string} An href string.
       */
    }, {
      kind: "method",
      key: "_buildRedirect",
      value: function _buildRedirect(targetQuery = this.searchQueryString) {
        const [primary, country] = this.language.split('-');
        const tokens = this.redirectUrl.split('?');
        const base = tokens.shift();
        const searchParams = new URLSearchParams(tokens.join('?'));
        // Setting `this.searchQueryString` as the default value of `targetQuery` seems to cause a Babel bug
        searchParams.append('q', targetQuery);
        searchParams.append('lang', primary);
        searchParams.append('cc', country);
        if (this.appId) {
          searchParams.append('scope-domain', 'scope');
          searchParams.append('scope-value', this.scopeValue);
          searchParams.append('scope-type', this.appId);
          if (this.scopeLabel) {
            var _this$scopeLabel;
            searchParams.append('scope-label', (_this$scopeLabel = this.scopeLabel) !== null && _this$scopeLabel !== void 0 ? _this$scopeLabel : '');
          }
        }
        return `${base}?${searchParams.toString()}`;
      }

      /**
       * Handles user-initiated redirect to the search query page.
       *
       * @param [options] The options.
       * @param [options.targetQuery] The query string the search query page should be of.
       * @param [options.targetHref] The href string to be redirected to.
       */
    }, {
      kind: "method",
      key: "_handleUserInitiatedRedirect",
      value: function _handleUserInitiatedRedirect({
        targetQuery,
        targetHref
      } = {}) {
        const {
          eventBeforeRedirect,
          eventInput
        } = this.constructor;
        this.dispatchEvent(new CustomEvent(eventInput, {
          bubbles: true,
          composed: true,
          cancelable: false,
          detail: {
            value: targetQuery
          }
        }));
        const query = targetQuery !== null && targetQuery !== void 0 ? targetQuery : this.searchQueryString;
        const redirectUrlWithSearch = targetHref || this._buildRedirect(query);
        if (this.dispatchEvent(new CustomEvent(eventBeforeRedirect, {
          bubbles: true,
          cancelable: true,
          composed: true,
          detail: {
            redirectUrl: redirectUrlWithSearch,
            searchQueryString: query
          }
        }))) {
          this._redirect(redirectUrlWithSearch);
        }
      }

      /**
       * @inheritdoc
       */
    }, {
      kind: "method",
      decorators: [HostListener('focusout')],
      key: "_handleFocusOut",
      value: function _handleFocusOut(event) {
        _superPropGet(C4DSearchWithTypeahead, "_handleFocusOut", this, 3)([event]);
      }

      /**
       * Handles search results when using a custom API.
       *
       * @param event The event.
       */
    }, {
      kind: "field",
      decorators: [HostListener('document:eventCustomResults')],
      key: "_handleCustomResults",
      value() {
        return event => {
          if (this.customTypeaheadAPI) {
            [this.searchResults] = event.detail;
            this.groupedResults = event.detail.slice(1);
          }
        };
      }
    }, {
      kind: "field",
      decorators: [HostListener('document:eventSelectScope')],
      key: "_handleScopeSelect",
      value() {
        return event => {
          var _targetScope, _targetScope$label;
          this.appId = event.detail.appId;
          let targetScope;
          this.scopeParameters.forEach(scope => {
            if (scope.appId === this.appId) {
              targetScope = scope;
            }
          });
          this.scopeValue = Array.isArray((_targetScope = targetScope) === null || _targetScope === void 0 ? void 0 : _targetScope.value) ? `[${targetScope.value.toString().split(',').map(word => `"${word.trim()}"`).join(',')}]` : targetScope.value;
          this.scopeLabel = (_targetScope$label = targetScope.label) !== null && _targetScope$label !== void 0 ? _targetScope$label : '';
        };
      }
    }, {
      kind: "method",
      key: "_handleInput",
      value:
      /**
       * Queries scoped search suggestions.
       *
       * @param event The event.
       */
      /**
       * Handles `input` event in the search input.
       */
      function _handleInput(event) {
        const {
          userHasInputSearch
        } = this;
        const {
          target
        } = event;
        const {
          value
        } = target;
        this.removeAttribute('unfocused');
        const items = this.shadowRoot.querySelectorAll(this.constructor.selectorItem);
        items.forEach(e => {
          if (this.leadspaceSearch) {
            e.setAttribute('alternate', '');
          }
          if (e.hasAttribute('highlighted')) {
            this.setAttribute('unfocused', '');
          }
        });
        this.dispatchEvent(new CustomEvent(this.constructor.eventInput, {
          bubbles: true,
          composed: true,
          cancelable: false,
          detail: {
            value
          }
        }));
        this.value = value;
        if (!this.customTypeaheadAPI) {
          this.getResults(value).then(res => {
            this.searchResults = res;
          });
        }
        if (value) {
          this.open = true;
          if (this.leadspaceSearch) {
            var _this$_closeButtonNod3;
            (_this$_closeButtonNod3 = this._closeButtonNode) === null || _this$_closeButtonNod3 === void 0 || _this$_closeButtonNod3.classList.remove(`${prefix}--header__search--hide`);
          }
        }
        if (!userHasInputSearch) {
          this.userHasInputSearch = true;
        }

        // accomodate search results box's width with the scope dropdown
        if (gridBreakpoint < document.body.clientWidth && this._searchSuggestions && this.scopeParameters) {
          var _this$shadowRoot, _this$_searchSuggesti;
          const scopeBarWidth = ((_this$shadowRoot = this.shadowRoot) === null || _this$shadowRoot === void 0 ? void 0 : _this$shadowRoot.querySelector('c4d-scoped-search-dropdown')).offsetWidth;
          (_this$_searchSuggesti = this._searchSuggestions) === null || _this$_searchSuggesti === void 0 || (_this$_searchSuggesti = _this$_searchSuggesti.parentElement) === null || _this$_searchSuggesti === void 0 || _this$_searchSuggesti.setAttribute('style', `left: ${scopeBarWidth}px; width: calc(100% - ${scopeBarWidth}px);`);
        } else {
          var _this$_searchSuggesti2;
          (_this$_searchSuggesti2 = this._searchSuggestions) === null || _this$_searchSuggesti2 === void 0 || (_this$_searchSuggesti2 = _this$_searchSuggesti2.parentElement) === null || _this$_searchSuggesti2 === void 0 || _this$_searchSuggesti2.removeAttribute('style');
        }
      }

      /**
       * Handles search form submission and cancels event execution in circumstances
       * where user action is handled elsewhere.
       *
       * @param event The form submission event.
       */
    }, {
      kind: "method",
      key: "_handleSubmit",
      value: function _handleSubmit(event) {
        const {
          searchQueryString,
          redirectUrl
        } = this;
        const {
          eventBeforeRedirect
        } = this.constructor;
        const {
          selectorItemHighlighted
        } = this.constructor;
        const highlightedItem = this.shadowRoot.querySelector(selectorItemHighlighted);

        // Prevents form submission in certain circumstances. In the case where there
        // is a highlighted item, `._handleUserInitiatedRedirect()` should have navigated
        // the user to the search result page.
        // Otherwise, gives users an opportunity to react to the event before
        // executing the form's action.
        if (highlightedItem || !searchQueryString) {
          event.preventDefault();
        } else if (!this.dispatchEvent(new CustomEvent(eventBeforeRedirect, {
          bubbles: true,
          cancelable: true,
          composed: true,
          detail: {
            redirectUrl,
            searchQueryString
          }
        }))) {
          event.preventDefault();
        }
      }

      /**
       * @inheritdoc
       */
    }, {
      kind: "method",
      key: "_handleUserInitiatedSelectItem",
      value: function _handleUserInitiatedSelectItem(item) {
        if (item && item instanceof C4DSearchWithTypeaheadItem) {
          this._searchInputNode.value = item.text;
          this._handleUserInitiatedRedirect({
            targetQuery: item.text,
            targetHref: item.href
          });
        }
      }

      /**
       * @inheritdoc
       */
    }, {
      kind: "method",
      key: "_handleKeypressInner",
      value: function _handleKeypressInner(event) {
        const {
          key
        } = event;
        const action = this.constructor.getAction(key);
        if (!this.open) {
          switch (action) {
            case DROPDOWN_KEYBOARD_ACTION.TRIGGERING:
              this._handleUserInitiatedToggle(true);
              break;
            default:
              break;
          }
        } else {
          switch (action) {
            case DROPDOWN_KEYBOARD_ACTION.TRIGGERING:
              {
                const {
                  selectorItemHighlighted
                } = this.constructor;
                const highlightedItem = this.shadowRoot.querySelector(selectorItemHighlighted);
                if (highlightedItem) {
                  this._handleUserInitiatedSelectItem(highlightedItem);
                } else {
                  this._handleUserInitiatedToggle(false);
                }
              }
              break;
            default:
              break;
          }
        }
      }

      /**
       * Redirects the page to the given target.
       *
       * @param target The target URL.
       */
    }, {
      kind: "method",
      key: "_redirect",
      value: function _redirect(target) {
        this.ownerDocument.defaultView.location.assign(target);
      }

      /**
       * Navigate through dropdown items.
       *
       * @param direction `-1` to navigate backward, `1` to navigate forward.
       */
    }, {
      kind: "method",
      key: "_navigate",
      value: function _navigate(direction) {
        const constructor = this.constructor;
        const items = this.shadowRoot.querySelectorAll(constructor.selectorItem);
        const highlightedItem = this.shadowRoot.querySelector(constructor.selectorItemHighlighted);
        const highlightedIndex = indexOf(items, highlightedItem);
        let nextIndex = highlightedIndex + direction;
        if (items[nextIndex] && items[nextIndex].hasAttribute('groupTitle')) {
          nextIndex += direction;
        }
        if (nextIndex < 0) {
          nextIndex = items.length - 1;
        }
        if (nextIndex >= items.length) {
          nextIndex = 0;
        }
        forEach(items, (item, i) => {
          item.highlighted = i === nextIndex;
        });
        this.setAttribute('unfocused', '');
        const nextItem = items[nextIndex];
        // Using `{ block: 'nearest' }` to prevent scrolling unless scrolling is absolutely necessary.
        // `scrollIntoViewOptions` seems to work in latest Safari despite of MDN/caniuse table.
        // IE falls back to the old behavior.
        nextItem.scrollIntoView({
          block: 'nearest'
        });
        this.requestUpdate();
      }

      /**
       * @returns The main content of the trigger button.
       */
    }, {
      kind: "method",
      key: "_renderTriggerContent",
      value: function _renderTriggerContent() {
        const {
          initialSearchTerm,
          searchPlaceholder,
          searchLabel,
          userHasInputSearch,
          _handleInput: handleInput,
          _handleKeyInput: handleKeyInput
        } = this;
        return html(_t || (_t = _`
      <input
        type="text"
        part="search-input"
        class="${0}--header__search--input"
        name="q"
        placeholder="${0}"
        value="${0}"
        autocomplete="off"
        aria-controls="result-list"
        aria-autocomplete="list"
        aria-label="${0}"
        @input="${0}"
        @keydown="${0}"
        @keypress="${0}" />
    `), prefix, searchPlaceholder, !userHasInputSearch ? initialSearchTerm : '', ifDefined(searchLabel), handleInput, handleKeyInput, handleKeyInput);
      }

      /**
       * Handles `click` event to redirect based on selected item.
       *
       * @param event The event.
       */
    }, {
      kind: "method",
      key: "_handleClickItem",
      value: function _handleClickItem(event) {
        const {
          selectorItem
        } = this.constructor;
        const item = event.target.closest(selectorItem);
        if (this.shadowRoot.contains(item)) {
          this._handleUserInitiatedSelectItem(item);
        }
      }

      /**
       * @returns The content of the search box.
       */
    }, {
      kind: "method",
      key: "_renderForm",
      value: function _renderForm() {
        const {
          active,
          language,
          open,
          redirectUrl,
          searchLabel,
          _handleClickInner: handleClickInner,
          _handleKeydownInner: handleKeydownInner,
          _handleKeypressInner: handleKeypressInner,
          _handleSubmit: handleSubmit
        } = this;
        if (!active) {
          return undefined;
        }
        const [primary, country] = language.split('-');
        const classes = classMap({
          'react-autosuggest__container': true,
          'react-autosuggest__suggestions-container--open': open
        });
        return html(_t2 || (_t2 = _`
      <form
        role="search"
        part="search-form"
        method="get"
        action="${0}"
        @submit="${0}">
        <input type="hidden" name="lang" value="${0}" />
        <input type="hidden" name="cc" value="${0}" />
        <input type="hidden" name="lnk" value="mhsrch" />
        ${0}
        <div
          role="combobox"
          class="${0}"
          part="container"
          aria-haspopup="listbox"
          aria-owns="result-list"
          aria-expanded="${0}"
          aria-label="${0}"
          @click=${0}
          @keydown="${0}"
          @keypress="${0}">
          ${0}
          ${0}
          ${0}
        </div>
      </form>
    `), redirectUrl, handleSubmit, primary, country, this.scopeParameters ? html(_t3 || (_t3 = _`
              <input type="hidden" name="scope-domain" value="scope" />
              <input type="hidden" name="scope-type" value="${0}" />
              <input
                type="hidden"
                name="scope-value"
                value="${0}" />
              <input
                type="hidden"
                name="scope-label"
                value="${0}" />
            `), this.appId, this.scopeValue, this.scopeLabel) : '', classes, Boolean(this.active), ifDefined(searchLabel), handleClickInner, handleKeydownInner, handleKeypressInner, this.scopeParameters ? html(_t4 || (_t4 = _`
                <c4d-scoped-search-dropdown
                  part="dropdown"
                  value="${0}">
                  ${0}
                </c4d-scoped-search-dropdown>
                <c4d-scoped-search-dropdown-mobile
                  part="dropdown-mobile"
                  value="${0}">
                  ${0}
                </c4d-scoped-search-dropdown-mobile>
              `), this.appId, this.scopeParameters.map(scope => html(_t5 || (_t5 = _`
                      <cds-dropdown-item
                        part="dropdown-item"
                        value="${0}"
                        >${0}</cds-dropdown-item
                      >
                    `), scope.appId, scope.name)), this.appId, this.scopeParameters.map(scope => html(_t6 || (_t6 = _`
                      <cds-select-item
                        part="select-item"
                        label="${0}"
                        value="${0}"
                        >${0}</cds-select-item
                      >
                    `), scope.name, scope.appId, scope.name))) : ``, this._renderTriggerContent(), !this.leadspaceSearch ? html(_t7 || (_t7 = _`
                <div
                  id="result-list"
                  class="react-autosuggest__suggestions-container"
                  part="suggestions-container">
                  <ul
                    role="listbox"
                    class="${0}-ce__search__list react-autosuggest__suggestions-list"
                    part="suggestions-list">
                    ${0}
                    ${0}
                  </ul>
                </div>
              `), c4dPrefix, this.searchResults && this.searchResults.map(item => html(_t8 || (_t8 = _`
                          <c4d-search-with-typeahead-item
                            part="suggestion-item"
                            text="${0}"></c4d-search-with-typeahead-item>
                        `), item)), this.groupedResults && this.groupedResults.map(group => html(_t9 || (_t9 = _`
                          <c4d-search-with-typeahead-item
                            part="suggestion-item"
                            groupTitle
                            text="${0}"></c4d-search-with-typeahead-item>
                          ${0}
                        `), group.title, group.items.map(item => html(_t10 || (_t10 = _`
                                <c4d-search-with-typeahead-item
                                  part="suggestion-item"
                                  text="${0}"
                                  href="${0}"></c4d-search-with-typeahead-item>
                              `), item.name, item.href))))) : ``);
      }

      /**
       * @returns `true` if the selection of this dropdown should change if the given item is selected upon user interaction.
       */
      // eslint-disable-next-line class-methods-use-this
    }, {
      kind: "method",
      key: "_selectionShouldChange",
      value: function _selectionShouldChange() {
        return true;
      }

      /**
       * `true` if this the search box should represent its active state.
       */
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true
      })],
      key: "active",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'close-search-button-assistive-text'
      })],
      key: "closeSearchButtonAssistiveText",
      value() {
        return 'Clear input';
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "language",
      value() {
        return 'en-US';
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'open-search-button-assistive-text'
      })],
      key: "openSearchButtonAssistiveText",
      value() {
        return 'Open IBM search field';
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'perform-search-button-assistive-text'
      })],
      key: "performSearchButtonAssistiveText",
      value() {
        return 'Search all of IBM';
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'placeholder',
        reflect: true
      })],
      key: "searchPlaceholder",
      value() {
        return 'Search all of IBM';
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'redirect-url'
      })],
      key: "redirectUrl",
      value() {
        return 'https://www.ibm.com/search?lnk=mhsrch';
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'search-label'
      })],
      key: "searchLabel",
      value() {
        return 'IBM search field';
      }
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "slot",
      value() {
        return 'search';
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        attribute: 'search-open-on-load'
      })],
      key: "searchOpenOnload",
      value() {
        return false;
      }
    }, {
      kind: "get",
      key: "searchQueryString",
      value:
      /**
       * The assistive text for the button to close the search box.
       */
      /**
       * The language embedded in the inner form.
       */
      /**
       * The assistive text for the button to open the search box.
       */
      /**
       * The assistive text for the button to perform search.
       */
      /**
       * Value to display when the input has an empty `value`.
       */
      /**
       * The redirect URL when a user selects a search suggestion.
       */
      /**
       * The `aria-label` attribute for the search input.
       */
      /**
       * The shadow slot this search UI should be in.
       */
      /**
       * `true` to activate the search box on page load.
       */
      /**
       * The input value.
       */
      function () {
        var _this$_searchInputNod, _this$_searchInputNod2;
        return (_this$_searchInputNod = (_this$_searchInputNod2 = this._searchInputNode) === null || _this$_searchInputNod2 === void 0 ? void 0 : _this$_searchInputNod2.value) !== null && _this$_searchInputNod !== void 0 ? _this$_searchInputNod : '';
      }

      /**
       * Returns query param `q` for search input if exists. Only available when searchOpenOnload is `true`
       */
    }, {
      kind: "method",
      key: "_setSearchParam",
      value: function _setSearchParam() {
        const {
          _searchInputNode: searchInputNode
        } = this;
        const URLParams = new URLSearchParams(this.ownerDocument.defaultView.location.search);
        const searchParam = this.searchOpenOnload ? URLParams.get('q') : '';
        if (searchParam) {
          searchInputNode.value = searchParam;
        }
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        this._setSearchParam();
        if (this.leadspaceSearch) {
          this.setAttribute('should-remain-open', '');
          this.setAttribute('active', '');
        }
        if (!this.appId && this.scopeParameters) {
          this.appId = 'all';
          this.redirectUrl = 'https://www.ibm.com/search/scoped';
        }
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated(changedProperties) {
        if (changedProperties.has('searchResults')) {
          var _this$shadowRoot2;
          const titleElements = (_this$shadowRoot2 = this.shadowRoot) === null || _this$shadowRoot2 === void 0 ? void 0 : _this$shadowRoot2.querySelectorAll('c4d-search-with-typeahead-item[groupTitle]');
          titleElements === null || titleElements === void 0 || titleElements.forEach(e => {
            var _e$previousElementSib;
            (_e$previousElementSib = e.previousElementSibling) === null || _e$previousElementSib === void 0 || _e$previousElementSib.setAttribute('lastBeforeGroup', '');
          });
        }
        if (changedProperties.has('appId')) {
          var _this$scopeParameters;
          if (gridBreakpoint < document.body.clientWidth && this._searchSuggestions && this.scopeParameters) {
            var _this$shadowRoot3, _this$_searchSuggesti3;
            const scopeBarWidth = ((_this$shadowRoot3 = this.shadowRoot) === null || _this$shadowRoot3 === void 0 ? void 0 : _this$shadowRoot3.querySelector('c4d-scoped-search-dropdown')).offsetWidth;
            (_this$_searchSuggesti3 = this._searchSuggestions) === null || _this$_searchSuggesti3 === void 0 || (_this$_searchSuggesti3 = _this$_searchSuggesti3.parentElement) === null || _this$_searchSuggesti3 === void 0 || _this$_searchSuggesti3.setAttribute('style', `left: ${scopeBarWidth}px; width: calc(100% - ${scopeBarWidth}px);`);
          } else {
            var _this$_searchSuggesti4;
            (_this$_searchSuggesti4 = this._searchSuggestions) === null || _this$_searchSuggesti4 === void 0 || (_this$_searchSuggesti4 = _this$_searchSuggesti4.parentElement) === null || _this$_searchSuggesti4 === void 0 || _this$_searchSuggesti4.removeAttribute('style');
          }
          if (!this.customTypeaheadAPI) {
            this.getResults(this.value).then(res => {
              this.searchResults = res;
            });
          }
          const newPlaceholder = this.placeholderFormatter({
            appId: (_this$scopeParameters = this.scopeParameters.filter(e => e.value === `${this.appId}`)[0]) === null || _this$scopeParameters === void 0 ? void 0 : _this$scopeParameters.name
          });
          this.setAttribute('placeholder', newPlaceholder);
          this.performSearchButtonAssistiveText = newPlaceholder;
        }
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          active,
          closeSearchButtonAssistiveText,
          openSearchButtonAssistiveText,
          performSearchButtonAssistiveText,
          _handleClickCloseButton: handleClickCloseButton,
          _handleClickSearchButton: handleClickSearchButton,
          _handleClickItem: handleClickItem
        } = this;
        const searchButtonAssistiveText = !active ? openSearchButtonAssistiveText : performSearchButtonAssistiveText;
        return html(_t11 || (_t11 = _`
      ${0}
    `), !this.leadspaceSearch ? html(_t12 || (_t12 = _`
            ${0}
            <div
              part="header-search-actions"
              class="${0}--header__search--actions">
              <button
                type="button"
                part="open-button"
                class="${0}--header__action ${0}--header__search--search"
                aria-label="${0}"
                @click="${0}">
                ${0}
              </button>
              <button
                type="button"
                part="close-button"
                class="${0}--header__action ${0}--header__search--close"
                aria-label="${0}"
                @click="${0}">
                ${0}
              </button>
            </div>
          `), this._renderForm(), prefix, prefix, prefix, searchButtonAssistiveText, handleClickSearchButton, Search20(), prefix, prefix, closeSearchButtonAssistiveText, handleClickCloseButton, Close20()) : html(_t13 || (_t13 = _`
            <div
              part="header-search-actions"
              class="${0}--header__search--actions">
              ${0}
              ${0}
              <button
                type="button"
                part="close-button"
                class="${0}--header__action ${0}--header__search--close ${0}"
                aria-label="${0}"
                @click="${0}">
                ${0}
              </button>
            </div>
            <div
              id="result-list"
              class="react-autosuggest__suggestions-container"
              part="suggestions-container">
              <ul
                role="listbox"
                class="${0}-ce__search__list react-autosuggest__suggestions-list"
                part="suggestions-list">
                ${0}
              </ul>
            </div>
          `), prefix, Search20({
          part: 'search-icon',
          class: `${prefix}--search-magnifier-icon`,
          role: 'img'
        }), this._renderForm(), prefix, prefix, this.value.length === 0 ? `${prefix}--header__search--hide` : '', closeSearchButtonAssistiveText, handleClickCloseButton, Close20(), c4dPrefix, this.searchResults && this.searchResults.map(item => html(_t14 || (_t14 = _`
                      <c4d-search-with-typeahead-item
                        part="suggestion-item"
                        text="${0}"
                        @click=${0}></c4d-search-with-typeahead-item>
                    `), item, handleClickItem))));
      }

      /**
       * A selector that will return highlighted search result items.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItemHighlighted",
      value: function () {
        return `${c4dPrefix}-search-with-typeahead-item[highlighted]`;
      }

      /**
       * A selector that will return search result items.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItem",
      value: function () {
        return `${c4dPrefix}-search-with-typeahead-item`;
      }

      /**
       * The name of the custom event fired before the page is being redirected to the search result page.
       * Cancellation of this event stops the user-initiated action of redirection.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventBeforeRedirect",
      value: function () {
        return `${c4dPrefix}-search-with-typeahead-beingredirected`;
      }

      /**
       * The name of the custom event fired after the search content is changed upon a user gesture.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventInput",
      value: function () {
        return `${c4dPrefix}-search-with-typeahead-input`;
      }

      /**
       * The name of the custom event captured to retrieve the new search scope.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventSelectScope",
      value: function () {
        return `${prefix}-select-selected`;
      }

      /**
       * The name of the custom event captured to retrieve the custom typeahead API results.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventCustomResults",
      value: function () {
        return `${c4dPrefix}-custom-typeahead-api-results`;
      }

      /**
       * The name of the custom event fired after this search box is toggled upon a user gesture.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventToggle",
      value: function () {
        return `${c4dPrefix}-search-with-typeahead-toggled`;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--search-with-typeahead`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, HostListenerMixin(StableSelectorMixin(CDSDropdown)));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DSearchWithTypeahead;
//# sourceMappingURL=search-with-typeahead.js.map
