import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4,
  _t5,
  _t6;
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { html, LitElement } from 'lit';
import { property } from 'lit/decorators.js';
import '@carbon/web-components/es/components/tooltip/tooltip.js';
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
import Star16 from '@carbon/web-components/es/icons/star/16.js';
import StarHalf16 from '@carbon/web-components/es/icons/star--half/16.js';
import StarFilled16 from '@carbon/web-components/es/icons/star--filled/16.js';
import styles from "././star-rating.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
const {
  stablePrefix: c4dPrefix,
  prefix
} = settings;

/**
 * The Star Rating component.
 * @element c4d-star-rating
 */
let C4DStarRating = _decorate([customElement(`${c4dPrefix}-star-rating`)], function (_initialize, _StableSelectorMixin) {
  class C4DStarRating extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DStarRating,
    d: [{
      kind: "field",
      key: "maxStarCount",
      value() {
        return 10;
      }
    }, {
      kind: "field",
      key: "_rating",
      value() {
        return 0;
      }
    }, {
      kind: "field",
      key: "_starCount",
      value() {
        return 5;
      }
    }, {
      kind: "field",
      key: "_tooltip",
      value() {
        return null;
      }
    }, {
      kind: "set",
      decorators: [property({
        attribute: 'rating',
        reflect: true,
        type: Number
      })],
      key: "rating",
      value:
      /**
       * Maximum number of stars that may be in a rating.
       */

      /**
       * Internal store for rating value.
       */

      /**
       * Internal store for star count value.
       */

      /**
       * Internal store for custom tooltip text.
       */

      /**
       * The rating that will inform the number of stars to display.
       */
      function (value) {
        const oldValue = this._rating;
        // Place boundaries to avoid out-of-memory issues.
        this._rating = Math.min(Math.max(value, 0), this.starCount);
        this.requestUpdate('rating', oldValue);
      }
    }, {
      kind: "get",
      key: "rating",
      value: function () {
        return this._rating;
      }

      /**
       * The text to display beside the rating.
       */
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'label',
        reflect: true
      })],
      key: "label",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'label-href',
        reflect: true
      })],
      key: "labelHref",
      value: void 0
    }, {
      kind: "set",
      decorators: [property({
        attribute: 'star-count',
        reflect: true,
        type: Number
      })],
      key: "starCount",
      value:
      /**
       * An optional href for the label.
       */
      /**
       * The number of stars to display.
       */
      function (value) {
        const oldValue = this._starCount;
        // Place boundaries to avoid out-of-memory issues.
        this._starCount = Math.min(Math.max(value, 0), this.maxStarCount);
        this.requestUpdate('starCount', oldValue);
      }
    }, {
      kind: "get",
      key: "starCount",
      value: function () {
        return this._starCount;
      }

      /**
       * The tooltip text that appears when hovering over the stars. Also used as an
       * accessible label for the stars.
       */
    }, {
      kind: "set",
      decorators: [property({
        attribute: 'tooltip',
        reflect: true
      })],
      key: "tooltip",
      value: function (value) {
        const oldValue = this._tooltip;
        this._tooltip = value;
        this.requestUpdate('tooltip', oldValue);
      }
    }, {
      kind: "get",
      key: "tooltip",
      value: function () {
        return !this._tooltip ? `${this.rating} out of ${this.starCount} stars` : this._tooltip;
      }

      /**
       * Disables the visible tooltip without removing accessibility text.
       */
    }, {
      kind: "field",
      decorators: [property({
        reflect: true,
        type: Boolean
      })],
      key: "disableTooltip",
      value() {
        return false;
      }
    }, {
      kind: "method",
      key: "_renderLabel",
      value:
      /**
       * Renders the label.
       *
       * @returns {TemplateResult} A template fragment representing the label.
       */
      function _renderLabel() {
        const {
          label,
          labelHref
        } = this;
        if (!label) {
          return '';
        }
        return html(_t || (_t = _`
      <div class="${0}-star-rating__label" part="label">
        ${0}
      </div>
    `), prefix, labelHref ? html(_t2 || (_t2 = _` <a href="${0}">${0}</a> `), labelHref, label) : label);
      }

      /**
       * Renders the rating as a series of stars.
       *
       * @returns {TemplateResult} A template fragment representing a series of stars.
       */
    }, {
      kind: "method",
      key: "_renderStars",
      value: function _renderStars() {
        const {
          disableTooltip,
          tooltip,
          rating,
          starCount
        } = this;
        const {
          renderStar
        } = this.constructor;
        const integer = Math.floor(rating);
        const decimal = rating - integer;
        const fillValues = Array(starCount).fill(1, 0, integer).fill(0, integer, starCount);
        if (decimal) {
          fillValues[integer] = decimal;
        }
        return html(_t3 || (_t3 = _`
      <figure
        aria-label="${0}"
        class="${0}-star-rating__stars"
        ?disableTooltip="${0}"
        part="stars">
        ${0}
      </figure>
    `), tooltip, prefix, disableTooltip, fillValues.map(fillValue => renderStar(fillValue)));
      }
    }, {
      kind: "method",
      key: "shouldUpdate",
      value: function shouldUpdate() {
        if (isNaN(this.rating) || isNaN(this.starCount)) {
          return false;
        }
        return true;
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t4 || (_t4 = _`
      <div class="${0}-star-rating" part="wrapper">
        ${0} ${0}
      </div>
    `), prefix, this._renderStars(), this._renderLabel());
      }

      /**
       * Renders an individual star at a given fill value.
       *
       * @param {number} fill The star's fill value.
       * @returns {TemplateResult} A template fragment representing a single star.
       */
    }, {
      kind: "method",
      static: true,
      key: "renderStar",
      value: function renderStar(fill) {
        let markup, classModifier;
        if (fill >= 0.75) {
          markup = StarFilled16();
          classModifier = 'filled';
        } else if (fill >= 0.25) {
          markup = html(_t5 || (_t5 = _` ${0}${0} `), Star16(), StarHalf16());
          classModifier = 'half';
        } else {
          markup = Star16();
          classModifier = 'empty';
        }
        return html(_t6 || (_t6 = _`
      <div
        class="${0}-star-count__star ${0}-star-count__star--${0}"
        part="star">
        ${0}
      </div>
    `), prefix, prefix, classModifier, markup);
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--star-rating`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
export default C4DStarRating;
//# sourceMappingURL=star-rating.js.map
