import _decorate from "@babel/runtime/helpers/esm/decorate";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _get from "@babel/runtime/helpers/esm/get";
let _ = t => t,
  _t,
  _t2;
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import styles from "././structured-list.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * StructuredList
 *
 * @element c4d-structured-list
 * @csspart overflow-indicator - Overflow indicator. Usage `c4d-structured-list::part(overflow-indicator)`
 * @csspart overflow-indicator--left - Overflow indicator left. Usage `c4d-structured-list::part(overflow-indicator--left)`
 * @csspart overflow-indicator--right - Overflow indicator right. Usage `c4d-structured-list::part(overflow-indicator--right)`
 * @csspart section - List section. Usage `c4d-structured-list::part(section)`
 */
let C4DStructuredList = _decorate([customElement(`${c4dPrefix}-structured-list`)], function (_initialize, _StableSelectorMixin) {
  class C4DStructuredList extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DStructuredList,
    d: [{
      kind: "field",
      key: "_listMutationObserver",
      value() {
        return new MutationObserver(this._setColumnSpans.bind(this));
      }
    }, {
      kind: "field",
      key: "_newChildObserver",
      value() {
        return new MutationObserver(this._resetIntersectionObserver.bind(this));
      }
    }, {
      kind: "field",
      key: "_scrollObserver",
      value() {
        return new IntersectionObserver(this._handleScroll.bind(this), {
          root: this,
          rootMargin: '0px',
          threshold: [0, 0.01, 0.02, 0.98, 0.99, 1]
        });
      }
    }, {
      kind: "method",
      key: "_resetIntersectionObserver",
      value: function _resetIntersectionObserver() {
        this._scrollObserver.disconnect();
        const {
          cellSelector
        } = this.constructor;
        this.querySelectorAll(cellSelector).forEach(cell => {
          this._scrollObserver.observe(cell);
        });
      }
    }, {
      kind: "method",
      key: "_handleScroll",
      value: function _handleScroll() {
        const maxScroll = this.scrollWidth - this.offsetWidth;
        const scrollLeft = this.scrollLeft;
        const scrollRight = maxScroll - scrollLeft;
        this.classList.toggle('overflowing-left', scrollLeft > 10);
        this.classList.toggle('overflowing-right', scrollRight > 10);
      }

      /**
       * Handles attribute changes to attributes starting with `col-span`.
       */
    }, {
      kind: "method",
      key: "_setColumnSpans",
      value: function _setColumnSpans(entries) {
        entries.forEach(entry => {
          const attr = entry.attributeName;
          if (attr !== null && attr !== void 0 && attr.startsWith('col-span')) {
            if (this.hasAttribute(attr) && parseInt(this.getAttribute(attr), 10)) {
              this.style.setProperty(`--${attr}`, parseInt(this.getAttribute(attr), 10).toString());
            } else {
              this.style.removeProperty(`--${attr}`);
            }
          }
        });
      }
    }, {
      kind: "method",
      key: "connectedCallback",
      value: function connectedCallback() {
        this._newChildObserver.observe(this, {
          childList: true,
          subtree: true,
          attributes: false
        });
        this._resetIntersectionObserver();
        if (!this.hasAttribute('role')) {
          this.setAttribute('role', 'table');
        }
        _superPropGet(C4DStructuredList, "connectedCallback", this, 3)([]);
        this._listMutationObserver.observe(this, {
          attributes: true,
          attributeOldValue: true
        });
        const colSpanAttributes = Object.values(this.attributes).filter(attr => attr.name.startsWith('col-span'));
        colSpanAttributes.forEach(attr => {
          this.style.setProperty(`--${attr.name}`, attr.value);
        });
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        return html(_t || (_t = _`
      <div
        class="overflow-indicator left"
        part="overflow-indicator overflow-indicator--left"></div>
      ${0}
      <div
        class="overflow-indicator right"
        part="overflow-indicator overflow-indicator--right"></div>
    `), this.renderInner());
      }
    }, {
      kind: "method",
      key: "renderInner",
      value: function renderInner() {
        const {
          wrapperId
        } = this.constructor;
        return html(_t2 || (_t2 = _`
      <section
        id="${0}"
        class="${0}--structured-list"
        part="section">
        <slot></slot>
      </section>
    `), wrapperId, prefix);
      }
    }, {
      kind: "get",
      static: true,
      key: "wrapperId",
      value: function () {
        return 'section';
      }
    }, {
      kind: "get",
      static: true,
      key: "cellSelector",
      value: function () {
        return `${c4dPrefix}-structured-list-cell, ${c4dPrefix}-structured-list-header-cell`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DStructuredList;
//# sourceMappingURL=structured-list.js.map
