import _decorate from "@babel/runtime/helpers/esm/decorate";
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././tabs-extended.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
import CDSTab from '@carbon/web-components/es/components/tabs/tab.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * A tab within a tabbed layout.
 *
 * @element c4d-tab
 */
let C4DTab = _decorate([customElement(`${c4dPrefix}-tab`)], function (_initialize, _StableSelectorMixin) {
  class C4DTab extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DTab,
    d: [{
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--tab`;
      }

      /**
       * An event that fires whenever the tab's selected state changes.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventTabSelected",
      value: function () {
        return `${c4dPrefix}-tab-selected`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(CDSTab));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DTab;
//# sourceMappingURL=tab.js.map
