import _decorate from "@babel/runtime/helpers/esm/decorate";
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import CDSTabs from '@carbon/web-components/es/components/tabs/tabs.js';
import styles from "././tabs-extended.css.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * A component to present content inside a tabbed layout.
 *
 * @element c4d-tabs-extended
 */
let C4DTabsExtended = _decorate([customElement(`${c4dPrefix}-tabs-extended`)], function (_initialize, _StableSelectorMixin) {
  class C4DTabsExtended extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DTabsExtended,
    d: [{
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--tabs-extended`;
      }

      /**
       * A selector that will return tabs.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItem",
      value: function () {
        return `${c4dPrefix}-tab`;
      }

      /**
       * A selector that will return enabled tabs.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItemEnabled",
      value: function () {
        return `${c4dPrefix}-tab:not([disabled])`;
      }

      /**
       * A selector that will return highlighted tabs.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItemHighlighted",
      value: function () {
        return `${c4dPrefix}-tab[highlighted]`;
      }

      /**
       * A selector that will return selected tabs.
       */
    }, {
      kind: "get",
      static: true,
      key: "selectorItemSelected",
      value: function () {
        return `${c4dPrefix}-tab[selected]`;
      }

      /**
       * The name of the custom event fired before a tab is selected upon a user gesture.
       * Cancellation of this event stops changing the user-initiated selection.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventBeforeSelect",
      value: function () {
        return `${c4dPrefix}-tabs-beingselected`;
      }

      /**
       * The name of the custom event fired after a a tab is selected upon a user gesture.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventSelect",
      value: function () {
        return `${c4dPrefix}-tabs-selected`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(CDSTabs));
console.warn('The tabs-extended orientation prop has been deprecated in favor for only horizontal variations. ' + 'See tabs-extended documentation for more information.');

/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DTabsExtended;
//# sourceMappingURL=tabs-extended.js.map
