import _decorate from "@babel/runtime/helpers/esm/decorate";
let _2 = t => t,
  _t;
/**
 * @license
 *
 * Copyright IBM Corp. 2019, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import { ifDefined } from 'lit/directives/if-defined.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././tag-link.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;

/**
 * Tag Link.
 *
 * @element c4d-tag-link
 * @csspart link - The link. Usage: `c4d-tag-link::part(link)`
 */
let C4DTagLink = _decorate([customElement(`${c4dPrefix}-tag-link`)], function (_initialize, _StableSelectorMixin) {
  class C4DTagLink extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DTagLink,
    d: [{
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "href",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "hreflang",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'link-role'
      })],
      key: "linkRole",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "ping",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "rel",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        reflect: true
      })],
      key: "target",
      value: void 0
    }, {
      kind: "method",
      key: "_handleClick",
      value:
      /**
       * Link `href`.
       */

      /**
       * The language of what `href` points to.
       */

      /**
       * The a11y role for `<a>`.
       */

      /**
       * URLs to ping.
       */

      /**
       * The link type.
       */

      /**
       * The link target.
       */

      /**
       * Handles `click` event on the `<a>`.
       */
      // eslint-disable-next-line class-methods-use-this, @typescript-eslint/no-unused-vars
      function _handleClick(_) {}
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          href,
          hreflang,
          linkRole,
          ping,
          rel,
          target,
          _handleClick: handleClick
        } = this;
        return html(_t || (_t = _2`
      <a
        id="link"
        role="${0}"
        class="${0}--link"
        part="link"
        href="${0}"
        hreflang="${0}"
        ping="${0}"
        rel="${0}"
        target="${0}"
        @click="${0}">
        <slot></slot>
      </a>
    `), ifDefined(linkRole), prefix, ifDefined(href), ifDefined(hreflang), ifDefined(ping), ifDefined(rel), ifDefined(target), handleClick);
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--tag-link`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, StableSelectorMixin(LitElement));
console.warn('The tag-link component has been deprecated in favor of using cds-tag components. ' + 'See cds-tag documentation in @carbon/web-components for more information.');

/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DTagLink;
//# sourceMappingURL=tag-link.js.map
