import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t,
  _t2;
/**
 * @license
 *
 * Copyright IBM Corp. 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property, state, query } from 'lit/decorators.js';
import { classMap } from 'lit/directives/class-map.js';
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import { ifDefined } from 'lit/directives/if-defined.js';
import CTAMixin from "../../component-mixins/cta/cta.js";
import VideoCTAMixin from "../../component-mixins/cta/video.js";
import { CTA_TYPE } from "../cta/defs.js";
import styles from "././tile.css.js";
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * The Tile component.
 *
 * @element c4d-tile
 */
let C4DTile = _decorate([customElement(`${c4dPrefix}-tile`)], function (_initialize, _VideoCTAMixin) {
  class C4DTile extends _VideoCTAMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DTile,
    d: [{
      kind: "field",
      decorators: [property({
        attribute: 'label'
      })],
      key: "label",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'cta-type',
        reflect: true
      })],
      key: "ctaType",
      value() {
        return CTA_TYPE['LOCAL'];
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'href'
      })],
      key: "href",
      value: void 0
    }, {
      kind: "field",
      decorators: [state()],
      key: "slottedImages",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "slottedPictogram",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "slotName",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "slotContent",
      value() {
        return [];
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true,
        attribute: 'align-with-content'
      })],
      key: "alignWithContent",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        reflect: true,
        attribute: 'double-tile'
      })],
      key: "doubleTile",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'target',
        reflect: true
      })],
      key: "target",
      value: void 0
    }, {
      kind: "field",
      decorators: [query(`.${c4dPrefix}-tile__action`)],
      key: "_linkNode",
      value: void 0
    }, {
      kind: "method",
      key: "_handleSlotChange",
      value:
      /**
       * The label text.
       */

      function _handleSlotChange(event) {
        const {
          target
        } = event;
        this.slotName = target.name;
        this.slotContent = target.assignedElements();
        if (this.slotName === 'image' && this.slotContent.length === 1) {
          this.slottedImages = true;
        } else if (this.slotName === 'image' && this.slotContent.length === 0) {
          this.slottedImages = false;
        }
        if (this.slotName === 'pictogram' && this.slotContent.length === 1) {
          this.slottedPictogram = true;
        } else if (this.slotName === 'pictogram' && this.slotContent.length === 0) {
          this.slottedPictogram = false;
        }
      }
    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          label,
          href,
          _handleSlotChange: handleSlotChange,
          _handleClick: handleClick,
          slottedPictogram,
          slottedImages,
          alignWithContent,
          doubleTile
        } = this;
        const ctaClasses = classMap({
          [`${c4dPrefix}-tile__footer-placement`]: alignWithContent,
          [`${c4dPrefix}-tile__action`]: true
        });
        const imgClasses = classMap({
          [`${c4dPrefix}-tile__image-double`]: doubleTile,
          [`${c4dPrefix}-tile__image`]: true
        });
        return html(_t || (_t = _`
      <div class="${0}-tile__outer" part="outer">
        <div class="${0}-tile__wrapper" part="wrapper">
          <div class="${0}" part="image" ?hidden=${0}>
            <slot name="image" @slotchange=${0}></slot>
          </div>

          <div class="${0}-tile__content" part="content">
            <div
              class="${0}-tile__pictogram"
              part="pictogram"
              ?hidden=${0}>
              <slot name="pictogram" @slotchange="${0}"></slot>
            </div>

            ${0}

            <div class="${0}-tile__text" part="text">
              <slot></slot>
            </div>

            <a
              href=${0}
              @click="${0}"
              class="${0} cds--link cds--link--lg cds--link-with-icon cds--link-with-icon__icon-right cds--link-with-icon--inline-icon"
              part="cta">
              <slot name="cta"></slot>
              ${0}
            </a>
          </div>
        </div>
      </div>
    `), c4dPrefix, c4dPrefix, imgClasses, !slottedImages, handleSlotChange, c4dPrefix, c4dPrefix, !slottedPictogram, handleSlotChange, label ? html(_t2 || (_t2 = _`
                  <span class="${0}-tile__label" part="label"
                    >${0}</span
                  >
                `), c4dPrefix, label) : '', c4dPrefix, ifDefined(href), handleClick, ctaClasses, this._renderIcon());
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, VideoCTAMixin(CTAMixin(LitElement)));
export default C4DTile;
//# sourceMappingURL=tile.js.map
