import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _decorate from "@babel/runtime/helpers/esm/decorate";
let _ = t => t,
  _t,
  _t2,
  _t3,
  _t4,
  _t5,
  _t6,
  _t7,
  _t8;
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2025
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import { classMap } from 'lit/directives/class-map.js';
import FocusMixin from '@carbon/web-components/es/globals/mixins/focus.js';
import PlayVideo from '../../../es/icons/play-video.js';
import PlayOutline from '@carbon/web-components/es/icons/play--outline/20.js';
import PauseOutline from '@carbon/web-components/es/icons/pause--outline/20.js';
import { formatVideoCaption, formatVideoDuration } from '@carbon/ibmdotcom-utilities/es/utilities/formatVideoCaption/formatVideoCaption.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import KalturaPlayerAPI from '@carbon/ibmdotcom-services/es/services/KalturaPlayer/KalturaPlayer.js';
import { BUTTON_POSITION, VIDEO_PLAYER_CONTENT_STATE, VIDEO_PLAYER_PLAYING_MODE } from "./defs.js";
import "../image/image.js";
import styles from "././video-player.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
import ifNonEmpty from '@carbon/web-components/es/globals/directives/if-non-empty.js';
export { VIDEO_PLAYER_CONTENT_STATE };
export { VIDEO_PLAYER_PLAYING_MODE };
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * Video player.
 *
 * @element c4d-video-player
 * @csspart video - The video. Usage `c4d-video-player::part(video)`
 * @csspart button - The play button. Usage `c4d-video-player::part(button)`
 * @csspart image - The thumbnail image. Usage `c4d-video-player::part(image)`
 * @csspart play-video - The play video icon. Usage `c4d-video-player::part(play-video)`
 * @csspart video-container - The video container. Usage `c4d-video-player::part(video-container)`
 * @csspart caption - The caption. Usage `c4d-video-player::part(caption)`
 */
let C4DVideoPlayer = _decorate([customElement(`${c4dPrefix}-video-player`)], function (_initialize, _FocusMixin) {
  class C4DVideoPlayer extends _FocusMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DVideoPlayer,
    d: [{
      kind: "field",
      decorators: [property({
        reflect: true,
        attribute: 'playing-mode'
      })],
      key: "playingMode",
      value() {
        return VIDEO_PLAYER_PLAYING_MODE.INLINE;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'intersection-mode',
        reflect: true,
        type: Boolean
      })],
      key: "intersectionMode",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "isPlaying",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'button-position',
        reflect: true
      })],
      key: "buttonPosition",
      value() {
        return BUTTON_POSITION.BOTTOM_RIGHT;
      }
    }, {
      kind: "field",
      key: "_handleClickOverlay",
      value() {
        return () => {
          if (this.playingMode === VIDEO_PLAYER_PLAYING_MODE.INLINE) {
            this.contentState = VIDEO_PLAYER_CONTENT_STATE.VIDEO;
          }
          const {
            videoId,
            name,
            customVideoDescription
          } = this;
          const {
            eventContentStateChange
          } = this.constructor;
          this.dispatchEvent(new CustomEvent(eventContentStateChange, {
            bubbles: true,
            composed: true,
            detail: {
              videoId,
              contentState: VIDEO_PLAYER_CONTENT_STATE.VIDEO,
              playingMode: this.playingMode,
              name,
              customVideoDescription
            }
          }));
        };
      }
    }, {
      kind: "field",
      key: "_handleTogglePlayback",
      value() {
        return () => {
          const {
            videoId
          } = this;
          const {
            eventTogglePlayback
          } = this.constructor;
          this.dispatchEvent(new CustomEvent(eventTogglePlayback, {
            bubbles: true,
            composed: true,
            detail: {
              videoId
            }
          }));
        };
      }
    }, {
      kind: "field",
      key: "_renderContent",
      value() {
        return () => {
          const {
            contentState,
            name,
            thumbnailUrl,
            backgroundMode,
            _handleClickOverlay: handleClickOverlay,
            intersectionMode
          } = this;
          if (intersectionMode) {
            return html(_t || (_t = _`
        <div class="${0}--video-player__video">
          ${0}
        </div>
      `), c4dPrefix, contentState === VIDEO_PLAYER_CONTENT_STATE.THUMBNAIL ? html(_t2 || (_t2 = _`
                <c4d-image
                  default-src="${0}"
                  alt="${0}"
                  part="image">
                </c4d-image>
              `), thumbnailUrl, ifNonEmpty(name)) : html(_t3 || (_t3 = _` <slot></slot> `)));
          } else {
            return contentState === VIDEO_PLAYER_CONTENT_STATE.THUMBNAIL && !backgroundMode && !this.autoplay ? html(_t4 || (_t4 = _`
            <div class="${0}--video-player__video" part="video">
              <button
                class="${0}--video-player__image-overlay"
                part="button"
                @click="${0}">
                <c4d-image
                  default-src="${0}"
                  alt="${0}"
                  part="image">
                  ${0}
                </c4d-image>
              </button>
            </div>
          `), c4dPrefix, c4dPrefix, handleClickOverlay, thumbnailUrl, ifNonEmpty(name), PlayVideo({
              slot: 'icon',
              part: 'play-video'
            })) : html(_t5 || (_t5 = _` <slot></slot> `));
          }
        };
      }
    }, {
      kind: "method",
      key: "_updateThumbnailUrl",
      value:
      /**
       * The video player's mode showing Inline or Lightbox.
       */

      /**
       * Triggers playback on intersection with the viewport / carousel.
       */

      /**
       * The current playback state, inherited from the parent.
       */

      /**
       * The position of the toggle playback button.
       */

      /**
       * Handles `click` event on the video thumbnail.
       */

      /**
       * @returns The video content.
       */

      /**
       * Updates video thumbnail url to match video width
       */
      function _updateThumbnailUrl() {
        let thumbnailSrc = false;
        try {
          thumbnailSrc = new URL(this.thumbnailUrl);
        } catch (error) {
          // Do nothing.
        }

        // If current thumbnail is from Kaltura and includes this video's ID we should be able to safely update it.
        if (thumbnailSrc && thumbnailSrc.host.toLowerCase().includes('kaltura') && thumbnailSrc.pathname.includes(this.videoId)) {
          this.thumbnailUrl = KalturaPlayerAPI.getThumbnailUrl({
            mediaId: this.videoId,
            width: String(this.offsetWidth)
          });
        }
      }

      /**
       * userInitiatedTogglePlaybackState
       */
    }, {
      kind: "method",
      key: "userInitiatedTogglePlaybackState",
      value: function userInitiatedTogglePlaybackState() {
        const {
          videoId
        } = this;
        const {
          eventPlaybackStateChange
        } = this.constructor;
        this.dispatchEvent(new CustomEvent(eventPlaybackStateChange, {
          bubbles: true,
          composed: true,
          detail: {
            videoId,
            playingMode: this.playingMode
          }
        }));
      }

      /**
       * The video player's content state.
       */
    }, {
      kind: "field",
      decorators: [property({
        reflect: true,
        attribute: 'content-state'
      })],
      key: "contentState",
      value() {
        return VIDEO_PLAYER_CONTENT_STATE.THUMBNAIL;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Number
      })],
      key: "duration",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "formatCaption",
      value() {
        return formatVideoCaption;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: false
      })],
      key: "formatDuration",
      value() {
        return formatVideoDuration;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean,
        attribute: 'hide-caption'
      })],
      key: "hideCaption",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property()],
      key: "name",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'background-mode',
        reflect: true,
        type: Boolean
      })],
      key: "backgroundMode",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'auto-play',
        reflect: true,
        type: Boolean
      })],
      key: "autoplay",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'video-description'
      })],
      key: "customVideoDescription",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'thumbnail-url'
      })],
      key: "thumbnailUrl",
      value() {
        return '';
      }
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'video-id'
      })],
      key: "videoId",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        attribute: 'aspect-ratio'
      })],
      key: "aspectRatio",
      value: void 0
    }, {
      kind: "method",
      key: "render",
      value:
      /**
       * The video duration.
       */
      /**
       * The formatter for the video caption, composed with the video name and the video duration.
       * Should be changed upon the locale the UI is rendered with.
       */
      /**
       * The formatter for the video duration.
       * Should be changed upon the locale the UI is rendered with.
       */
      /**
       * `true` to hide the caption.
       */
      /**
       * The video name.
       */
      /**
       * `true` to autoplay, mute video, and hide UI
       */
      /**
       * `true` to autoplay
       */
      /**
       * Custom video description. This property should only be set when using `playing-mode="lightbox"`
       */
      /**
       * The thumbnail URL.
       */
      /**
       * The video ID.
       */
      /**
       * Override default aspect ratio of `16x9`.
       * Available aspect ratios:
       *
       * `16x9`, `9x16`, `2x1`, `1x2`, `4x3`, `3x4`, `1x1`
       */
      function render() {
        const {
          aspectRatio,
          duration,
          formatCaption,
          formatDuration,
          hideCaption,
          name,
          buttonPosition,
          intersectionMode,
          _handleTogglePlayback: handleTogglePlayback,
          _renderContent: renderContent
        } = this;
        const aspectRatioClass = classMap({
          [`${c4dPrefix}--video-player__video-container`]: true,
          [`${c4dPrefix}--video-player__aspect-ratio--${aspectRatio}`]: !!aspectRatio
        });
        const togglePlaybackClass = classMap({
          [`${c4dPrefix}--video-player__toggle-playback`]: true,
          [`${c4dPrefix}--video-player__toggle-playback--${buttonPosition}`]: true
        });
        return html(_t6 || (_t6 = _`
      <div class="${0}" part="video-container">
        ${0}
        ${0}
      </div>
      ${0}
    `), aspectRatioClass, intersectionMode ? html(_t7 || (_t7 = _`
              <button
                class="${0}"
                @click="${0}"
                tabindex="0"
                part="button">
                ${0}
              </button>
            `), togglePlaybackClass, handleTogglePlayback, this.isPlaying ? PauseOutline({
          'aria-label': 'Pause'
        }) : PlayOutline({
          'aria-label': 'Play'
        })) : null, renderContent(), hideCaption ? undefined : html(_t8 || (_t8 = _`
            <div
              class="${0}--video-player__video-caption"
              part="caption">
              ${0}
            </div>
          `), c4dPrefix, formatCaption({
          duration: formatDuration({
            duration: !duration ? duration : duration * 1000
          }),
          name
        })));
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated(changedProperties) {
        if (changedProperties.has('duration') || changedProperties.has('formatCaption') || changedProperties.has('name') || changedProperties.has('backgroundMode')) {
          const {
            duration,
            formatCaption,
            formatDuration,
            name
          } = this;
          const caption = formatCaption({
            duration: formatDuration({
              duration: !duration ? duration : duration * 1000
            }),
            name
          });
          if (caption) {
            this.setAttribute('aria-label', caption);
          }
        }

        // Move measurement & API call to callback queue & wait for update to complete.
        setTimeout(async () => {
          await this.updateComplete;
          if (!this.thumbnailUrl.endsWith(`${this.offsetWidth}`)) {
            this._updateThumbnailUrl();
          }
        }, 0);
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        var _this$parentElement, _this$parentElement2, _this$parentElement3;
        this.tabIndex = 0;
        this.backgroundMode = Boolean((_this$parentElement = this.parentElement) === null || _this$parentElement === void 0 ? void 0 : _this$parentElement.backgroundMode);
        this.intersectionMode = Boolean((_this$parentElement2 = this.parentElement) === null || _this$parentElement2 === void 0 ? void 0 : _this$parentElement2.intersectionMode);
        this.autoplay = Boolean((_this$parentElement3 = this.parentElement) === null || _this$parentElement3 === void 0 ? void 0 : _this$parentElement3.autoPlay);
      }

      /**
       * The name of the custom event fired after video content state is changed upon a user gesture.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventContentStateChange",
      value: function () {
        return `${c4dPrefix}-video-player-content-state-changed`;
      }

      /**
       * The name of the custom event fired requesting playback state change.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventPlaybackStateChange",
      value: function () {
        return `${c4dPrefix}-video-player-playback-state-changed`;
      }
    }, {
      kind: "get",
      static: true,
      key: "stableSelector",
      value: function () {
        return `${c4dPrefix}--video-player`;
      }

      /**
       * The name of the custom event fired when a user action toggles playback.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventTogglePlayback",
      value: function () {
        return `${c4dPrefix}-video-player-toggle-playback`;
      }
    }, {
      kind: "field",
      static: true,
      key: "shadowRootOptions",
      value() {
        return _objectSpread(_objectSpread({}, LitElement.shadowRootOptions), {}, {
          delegatesFocus: true
        });
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }]
  };
}, FocusMixin(StableSelectorMixin(LitElement)));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DVideoPlayer;
//# sourceMappingURL=video-player.js.map
