import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2023
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { render } from 'lit';
/**
 * @param Base The base class.
 * @returns A mix-in that allows rendering both Shadow DOM and light DOM.
 */
const HybridRenderMixin = Base => {
  class HybridRenderMixinImpl extends Base {
    constructor(...args) {
      super(...args);
      /**
       * The render target in the light DOM.
       */
      _defineProperty(this, "lightRenderRoot", null);
    }
    /**
     * @returns The template to be render into the light DOM.
     */
    /**
     * @returns The render root of the light DOM.
     */
    createLightRenderRoot() {
      return this;
    }
    update(changedProperties) {
      // TODO: Figure out how to inherit `LitElement` for this mix-in class
      // @ts-ignore
      super.update(changedProperties);
      if (!this.lightRenderRoot) {
        this.lightRenderRoot = this.createLightRenderRoot();
      }
      const {
        lightRenderRoot
      } = this;
      if (lightRenderRoot) {
        render(this.renderLightDOM(), lightRenderRoot);
      }
    }
  }
  return HybridRenderMixinImpl;
};
export default HybridRenderMixin;
//# sourceMappingURL=hybrid-render.js.map
