/**
 * @license
 *
 * Copyright IBM Corp. 2021, 2023
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { ThunkAction } from 'redux-thunk';
import { UserStatus, CLOUD_ACCOUNT_AUTH_API_ACTION, CloudAccountAuthAPIState } from '../types/cloudAccountAuthAPI';
/**
 * @param error An error from the JSONP call for user authentication status.
 * @returns A Redux action to set the state that the JSONP call for user authentication status failed.
 * @private
 */
export declare function setErrorRequestUserStatus(error: Error): {
    type: CLOUD_ACCOUNT_AUTH_API_ACTION;
    error: Error;
};
/**
 * @param request The promise of the REST call for  user status that is in progress.
 * @returns A Redux action to set the state that the REST call for user status is in progress.
 * @private
 */
export declare function setRequestUserStatusInProgress(request: Promise<UserStatus>): {
    type: CLOUD_ACCOUNT_AUTH_API_ACTION;
    request: Promise<UserStatus>;
};
/**
 * @param request The user authentication status from the JSONP call.
 * @returns A Redux action to set the given user authentication status.
 */
export declare function setUserStatus(request: UserStatus): {
    type: CLOUD_ACCOUNT_AUTH_API_ACTION;
    request: UserStatus;
};
export type CloudAccountAuthAPIActions = ReturnType<typeof setErrorRequestUserStatus> | ReturnType<typeof setRequestUserStatusInProgress> | ReturnType<typeof setUserStatus>;
/**
 * @returns A Redux action that sends a REST call for user authentication status.
 */
export declare function loadUserStatus(authMethod: string): ThunkAction<Promise<UserStatus>, {
    cloudAccountAuthAPI: CloudAccountAuthAPIState;
}, void, CloudAccountAuthAPIActions>;

//# sourceMappingURL=cloudAccountAuthAPI.d.ts.map
