/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2022
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { ThunkAction } from 'redux-thunk';
import { MediaData, MEDIA_PLAYER_API_ACTION, MediaPlayerAPIState } from '../types/kalturaPlayerAPI';
/**
 * @param mediaId A language.
 * @param request The promise of the REST call for media data of the given language that is in progress.
 * @returns A Redux action to set the state that the REST call for media data for the given language that is in progress.
 * @private
 */
export declare function setRequestMediaDataInProgress(mediaId: string, request: Promise<MediaData>): {
    type: MEDIA_PLAYER_API_ACTION;
    mediaId: string;
    request: Promise<MediaData>;
};
/**
 * @param mediaId A language.
 * @param error An error from the REST call for media data of the given language.
 * @returns A Redux action to set the state that the REST call for media data for the given language failed.
 * @private
 */
export declare function setErrorRequestMediaData(mediaId: string, error: Error): {
    type: MEDIA_PLAYER_API_ACTION;
    mediaId: string;
    error: Error;
};
/**
 * @param mediaId A language.
 * @param mediaData The media data from the REST call.
 * @returns A Redux action to set the given media data.
 */
export declare function setMediaData(mediaId: string, mediaData: MediaData): {
    type: MEDIA_PLAYER_API_ACTION;
    mediaId: string;
    mediaData: MediaData;
};
/**
 * A Redux action to work with `MediaPlayerAPI`.
 */
export type MediaPlayerAPIActions = ReturnType<typeof setRequestMediaDataInProgress> | ReturnType<typeof setErrorRequestMediaData> | ReturnType<typeof setMediaData>;
/**
 * @returns A Redux action that sends a REST call for media data.
 */
export declare function loadMediaData(mediaId: string): ThunkAction<Promise<MediaData>, {
    mediaPlayerAPI: MediaPlayerAPIState;
}, void, MediaPlayerAPIActions>;

//# sourceMappingURL=kalturaPlayerAPI.d.ts.map
