/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2022
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { ThunkAction } from 'redux-thunk';
import { LocaleList, LOCALE_API_ACTION, LocaleAPIState } from '../types/localeAPI';
/**
 * @param request The promise of the REST call for language data that is in progress.
 * @returns A Redux action to set the state that the REST call for language data is in progress.
 * @private
 */
export declare function setRequestLanguageInProgress(request: Promise<string>): {
    type: LOCALE_API_ACTION;
    request: Promise<string>;
};
/**
 * @param error An error from the REST call for language data.
 * @returns A Redux action to set the state that the REST call for language data failed.
 * @private
 */
export declare function setErrorRequestLanguage(error: Error): {
    type: LOCALE_API_ACTION;
    error: Error;
};
/**
 * @param language The language data from the REST call.
 * @returns A Redux action to set the given language data.
 */
export declare function setLanguage(language: string): {
    type: LOCALE_API_ACTION;
    language: string;
};
/**
 * @param language A language.
 * @param request The promise of the REST call for locale list data of the given language that is in progress.
 * @returns A Redux action to set the state that the REST call for locale list data for the given language that is in progress.
 * @private
 */
export declare function setRequestLocaleListInProgress(language: string, request: Promise<LocaleList>): {
    type: LOCALE_API_ACTION;
    language: string;
    request: Promise<LocaleList>;
};
/**
 * @param language A language.
 * @param error An error from the REST call for locale list data of the given language.
 * @returns A Redux action to set the state that the REST call for locale list data for the given language failed.
 * @private
 */
export declare function setErrorRequestLocaleList(language: string, error: Error): {
    type: LOCALE_API_ACTION;
    language: string;
    error: Error;
};
/**
 * @param language A language.
 * @param localeList The locale list data from the REST call.
 * @returns A Redux action to set the given locale list data.
 */
export declare function setLocaleList(language: string, localeList: LocaleList): {
    type: LOCALE_API_ACTION;
    language: string;
    localeList: LocaleList;
};
/**
 * A Redux action to work with `LocaleAPI`.
 */
export type LocaleAPIActions = ReturnType<typeof setRequestLanguageInProgress> | ReturnType<typeof setErrorRequestLanguage> | ReturnType<typeof setLanguage> | ReturnType<typeof setRequestLocaleListInProgress> | ReturnType<typeof setErrorRequestLocaleList> | ReturnType<typeof setLocaleList>;
/**
 * @returns A Redux action that sends a REST call for language data.
 */
export declare function loadLanguage(): ThunkAction<Promise<string>, {
    localeAPI: LocaleAPIState;
}, void, LocaleAPIActions>;
/**
 * @param language The language. If not given, the default language from DDO is used.
 * @returns A Redux action that sends a REST call for locale list data.
 */
export declare function loadLocaleList(language?: string): ThunkAction<Promise<LocaleList>, {
    localeAPI: LocaleAPIState;
}, void, LocaleAPIActions>;

//# sourceMappingURL=localeAPI.d.ts.map
