/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2022
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { ThunkAction } from 'redux-thunk';
import { SEARCH_API_ACTION, SearchAPIState } from '../types/searchAPI';
/**
 * @param searchQueryString A search query string.
 * @returns A Redux action to set the given search query string as the current one.
 */
export declare function setCurrentSearchQueryString(searchQueryString: string): {
    type: SEARCH_API_ACTION;
    searchQueryString: string;
};
/**
 * @param language A language.
 * @param searchQueryString A search query string.
 * @param request
 *   The promise of the REST call for the search result of the given language and search query string that is in progress.
 * @returns
 *   A Redux action to set the state that the REST call
 *   for search results for the given language and search query that is in progress.
 * @private
 */
export declare function setRequestSearchResultsInProgress(language: string, searchQueryString: string, request: Promise<string[]>): {
    type: SEARCH_API_ACTION;
    language: string;
    searchQueryString: string;
    request: Promise<string[]>;
};
/**
 * @param language The language.
 * @param searchQueryString The search query string.
 * @param error An error from the REST call for search results for the given language and search query.
 * @returns A Redux action to set the state that the REST call for search results for the given language and search query failed.
 * @private
 */
export declare function setErrorRequestSearchResults(language: string, searchQueryString: string, error: Error): {
    type: SEARCH_API_ACTION;
    language: string;
    searchQueryString: string;
    error: Error;
};
/**
 * @param language The language.
 * @param searchQueryString The search query string.
 * @param results The search results.
 * @returns A Redux action to set the given search results for the given language and search query string.
 * @private
 */
export declare function setSearchResults(language: string, searchQueryString: string, results: string[]): {
    type: SEARCH_API_ACTION;
    language: string;
    searchQueryString: string;
    results: string[];
};
export type SearchAPIActions = ReturnType<typeof setCurrentSearchQueryString> | ReturnType<typeof setRequestSearchResultsInProgress> | ReturnType<typeof setErrorRequestSearchResults> | ReturnType<typeof setSearchResults>;
/**
 * @returns A Redux action that monitors user authentication status.
 */
export declare function loadSearchResults(searchQueryString: string): ThunkAction<Promise<string[]>, {
    searchAPI: SearchAPIState;
}, void, SearchAPIActions>;

//# sourceMappingURL=searchAPI.d.ts.map
