/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2022
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */ /**
     * @license
     *
     * Copyright IBM Corp. 2020, 2022
     *
     * This source code is licensed under the Apache-2.0 license found in the
     * LICENSE file in the root directory of this source tree.
     */

import { loadLanguage } from "./localeAPI.js";
import { SEARCH_API_ACTION } from "../types/searchAPI.js";

/**
 * @param language The locale.
 * @param searchQueryString The search query string.
 * @returns The endpoint URL for the given locale and search query string.
 */ /**
     * @param language The locale.
     * @param searchQueryString The search query string.
     * @returns The endpoint URL for the given locale and search query string.
     */
function getSearchEndpoint(language, searchQueryString) {
  const [primary, country] = language.split('-');
  return `${process && process.env.SEARCH_TYPEAHEAD_API || 'https://www-api.ibm.com'}/search/typeahead/v1?lang=${primary}&cc=${country}&query=${searchQueryString}`;
}

/**
 * @param searchQueryString A search query string.
 * @returns A Redux action to set the given search query string as the current one.
 */
export function setCurrentSearchQueryString(searchQueryString) {
  return {
    type: SEARCH_API_ACTION.SET_CURRENT_SEARCH_QUERY_STRING,
    searchQueryString
  };
}

/**
 * @param language A language.
 * @param searchQueryString A search query string.
 * @param request
 *   The promise of the REST call for the search result of the given language and search query string that is in progress.
 * @returns
 *   A Redux action to set the state that the REST call
 *   for search results for the given language and search query that is in progress.
 * @private
 */
export function setRequestSearchResultsInProgress(language, searchQueryString, request) {
  return {
    type: SEARCH_API_ACTION.SET_REQUEST_SEARCH_RESULTS_IN_PROGRESS,
    language,
    searchQueryString,
    request
  };
}

/**
 * @param language The language.
 * @param searchQueryString The search query string.
 * @param error An error from the REST call for search results for the given language and search query.
 * @returns A Redux action to set the state that the REST call for search results for the given language and search query failed.
 * @private
 */
export function setErrorRequestSearchResults(language, searchQueryString, error) {
  return {
    type: SEARCH_API_ACTION.SET_ERROR_REQUEST_SEARCH_RESULTS,
    language,
    searchQueryString,
    error
  };
}

/**
 * @param language The language.
 * @param searchQueryString The search query string.
 * @param results The search results.
 * @returns A Redux action to set the given search results for the given language and search query string.
 * @private
 */
export function setSearchResults(language, searchQueryString, results) {
  return {
    type: SEARCH_API_ACTION.SET_SEARCH_RESULTS,
    language,
    searchQueryString,
    results
  };
}
/**
 * @returns A Redux action that monitors user authentication status.
 */
export function loadSearchResults(searchQueryString) {
  return async (dispatch, getState) => {
    var _getState$searchAPI, _requestsSearchResult;
    dispatch(setCurrentSearchQueryString(searchQueryString));
    // TODO: Can we go without casts without making `LocaleAPI` types a hard-dependency?
    const language = await dispatch(loadLanguage());
    const {
      requestsSearchResults = {}
    } = (_getState$searchAPI = getState().searchAPI) !== null && _getState$searchAPI !== void 0 ? _getState$searchAPI : {};
    const requestSearchResults = requestsSearchResults === null || requestsSearchResults === void 0 || (_requestsSearchResult = requestsSearchResults[searchQueryString]) === null || _requestsSearchResult === void 0 ? void 0 : _requestsSearchResult[language];
    if (requestSearchResults) {
      return requestSearchResults;
    }
    const request = fetch(getSearchEndpoint(language, searchQueryString)).then(response => response.json()).then(({
      response
    }) => response.map(([result]) => result));
    dispatch(setRequestSearchResultsInProgress(language, searchQueryString, request));
    try {
      dispatch(setSearchResults(language, searchQueryString, await request));
    } catch (error) {
      dispatch(setErrorRequestSearchResults(language, searchQueryString, error));
      throw error;
    }
    return request;
  };
}
//# sourceMappingURL=searchAPI.js.map
