/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2023
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { ThunkAction } from 'redux-thunk';
import { Translation, TRANSLATE_API_ACTION, TranslateAPIState } from '../types/translateAPI';
/**
 * @param language A language.
 * @param request The promise of the REST call for translation data of the given language that is in progress.
 * @returns A Redux action to set the state that the REST call for translation data for the given language that is in progress.
 * @private
 */
export declare function setRequestTranslationInProgress(language: string, request: Promise<Translation>, endpoint: any): {
    type: TRANSLATE_API_ACTION;
    language: string;
    request: Promise<Translation>;
    endpoint: any;
};
/**
 * @param language A language.
 * @param error An error from the REST call for translation data of the given language.
 * @returns A Redux action to set the state that the REST call for translation data for the given language failed.
 * @private
 */
export declare function setErrorRequestTranslation(language: string, error: Error): {
    type: TRANSLATE_API_ACTION;
    language: string;
    error: Error;
};
/**
 * @param language A language.
 * @param translation The translation data from the REST call.
 * @returns A Redux action to set the given translation data.
 */
export declare function setTranslation(language: string, translation: Translation, endpoint: any): {
    type: TRANSLATE_API_ACTION;
    language: string;
    translation: Translation;
    endpoint: any;
};
/**
 * A Redux action to work with `TranslateAPI`.
 */
export type TranslateAPIActions = ReturnType<typeof setRequestTranslationInProgress> | ReturnType<typeof setErrorRequestTranslation> | ReturnType<typeof setTranslation>;
/**
 * @param language The language. If not given, the default language from DDO is used.
 * @param dataEndpoint The translation endpoint to fetch from if not using default c4d endpoint
 * @returns A Redux action that sends a REST call for translation data.
 */
export declare function loadTranslation(language?: string, dataEndpoint?: string): ThunkAction<Promise<Translation>, {
    translateAPI: TranslateAPIState;
}, void, TranslateAPIActions>;

//# sourceMappingURL=translateAPI.d.ts.map
