function _slicedToArray(r, e) { return _arrayWithHoles(r) || _iterableToArrayLimit(r, e) || _unsupportedIterableToArray(r, e) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(r) { if (Array.isArray(r)) return r; }
/**
 * Copyright IBM Corp. 2020, 2023
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { on } from '../on';

/**
 * Fires the given event if focus goes out of the given element.
 *
 * @param {Element} element The element to monitor the focus on.
 * @param {Element[]} sentinelNodes
 *   The focus sentinel nodes.
 *   If these nodes gets focus, we see it as focus went out of the `element`.
 * @param {string} [eventRequestFocusWrap=cds-request-focus-wrap] The event name.
 * @returns {Function} The handle to remove the event handler.
 */
function focuswrap(element, sentinelNodes) {
  var eventRequestFocusWrap = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'cds-request-focus-wrap';
  return on(element, 'focusout', function handleFocusout(event) {
    var _event$currentTarget$, _event$currentTarget$2;
    var target = event.target,
      relatedTarget = event.relatedTarget;
    var _sentinelNodes = _slicedToArray(sentinelNodes, 2),
      startSentinelNode = _sentinelNodes[0],
      endSentinelNode = _sentinelNodes[1];
    var oldContains = target && target !== this && (event.currentTarget.contains(target) || ((_event$currentTarget$ = event.currentTarget.host) === null || _event$currentTarget$ === void 0 ? void 0 : _event$currentTarget$.contains(target))) && sentinelNodes.indexOf(target) < 0;
    var currentContains = relatedTarget && relatedTarget !== this && (event.currentTarget.contains(relatedTarget) || ((_event$currentTarget$2 = event.currentTarget.host) === null || _event$currentTarget$2 === void 0 ? void 0 : _event$currentTarget$2.contains(relatedTarget))) && sentinelNodes.indexOf(relatedTarget) < 0;
    // FF fires `focusout` event even if the page itself is losing focus (e.g. upon following outside link).
    // In such case, we do nothing.
    if (oldContains && !currentContains && relatedTarget) {
      var comparisonResult = target.compareDocumentPosition(relatedTarget);
      if (relatedTarget === startSentinelNode) {
        comparisonResult = Node.DOCUMENT_POSITION_PRECEDING;
      } else if (relatedTarget === endSentinelNode) {
        comparisonResult = Node.DOCUMENT_POSITION_FOLLOWING;
      } else {
        comparisonResult = -1;
      }
      element.dispatchEvent(new CustomEvent(eventRequestFocusWrap, {
        bubbles: true,
        cancelable: false,
        composed: true,
        detail: {
          comparisonResult: comparisonResult
        }
      }));
    }
  });
}
export default focuswrap;