"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.loadLanguage = loadLanguage;
exports.loadLocaleList = loadLocaleList;
exports.setErrorRequestLanguage = setErrorRequestLanguage;
exports.setErrorRequestLocaleList = setErrorRequestLocaleList;
exports.setLanguage = setLanguage;
exports.setLocaleList = setLocaleList;
exports.setRequestLanguageInProgress = setRequestLanguageInProgress;
exports.setRequestLocaleListInProgress = setRequestLocaleListInProgress;
var _Locale = _interopRequireDefault(require("@carbon/ibmdotcom-services/lib/services/Locale/Locale.js"));
var _localeAPI = require("../types/localeAPI.js");
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2022
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */ /**
     * @license
     *
     * Copyright IBM Corp. 2020, 2022
     *
     * This source code is licensed under the Apache-2.0 license found in the
     * LICENSE file in the root directory of this source tree.
     */

/**
 * @param request The promise of the REST call for language data that is in progress.
 * @returns A Redux action to set the state that the REST call for language data is in progress.
 * @private
 */ /**
     * @param request The promise of the REST call for language data that is in progress.
     * @returns A Redux action to set the state that the REST call for language data is in progress.
     * @private
     */
function setRequestLanguageInProgress(request) {
  return {
    type: _localeAPI.LOCALE_API_ACTION.SET_REQUEST_LANGUAGE_IN_PROGRESS,
    request
  };
}

/**
 * @param error An error from the REST call for language data.
 * @returns A Redux action to set the state that the REST call for language data failed.
 * @private
 */
function setErrorRequestLanguage(error) {
  return {
    type: _localeAPI.LOCALE_API_ACTION.SET_ERROR_REQUEST_LANGUAGE,
    error
  };
}

/**
 * @param language The language data from the REST call.
 * @returns A Redux action to set the given language data.
 */
function setLanguage(language) {
  return {
    type: _localeAPI.LOCALE_API_ACTION.SET_LANGUAGE,
    language
  };
}

/**
 * @param language A language.
 * @param request The promise of the REST call for locale list data of the given language that is in progress.
 * @returns A Redux action to set the state that the REST call for locale list data for the given language that is in progress.
 * @private
 */
function setRequestLocaleListInProgress(language, request) {
  return {
    type: _localeAPI.LOCALE_API_ACTION.SET_REQUEST_LOCALE_LIST_IN_PROGRESS,
    language,
    request
  };
}

/**
 * @param language A language.
 * @param error An error from the REST call for locale list data of the given language.
 * @returns A Redux action to set the state that the REST call for locale list data for the given language failed.
 * @private
 */
function setErrorRequestLocaleList(language, error) {
  return {
    type: _localeAPI.LOCALE_API_ACTION.SET_ERROR_REQUEST_LOCALE_LIST,
    language,
    error
  };
}

/**
 * @param language A language.
 * @param localeList The locale list data from the REST call.
 * @returns A Redux action to set the given locale list data.
 */
function setLocaleList(language, localeList) {
  return {
    type: _localeAPI.LOCALE_API_ACTION.SET_LOCALE_LIST,
    language,
    localeList
  };
}

/**
 * A Redux action to work with `LocaleAPI`.
 */

/**
 * @returns A Redux action that sends a REST call for language data.
 */
function loadLanguage() {
  return async (dispatch, getState) => {
    var _getState$localeAPI;
    const {
      requestLanguage
    } = (_getState$localeAPI = getState().localeAPI) !== null && _getState$localeAPI !== void 0 ? _getState$localeAPI : {};
    if (requestLanguage) {
      return requestLanguage;
    }
    const promiseLanguage = _Locale.default.getLocale().then(({
      cc: country,
      lc: primary
    }) => `${primary}-${country}`);
    dispatch(setRequestLanguageInProgress(promiseLanguage));
    try {
      dispatch(setLanguage(await promiseLanguage));
    } catch (error) {
      dispatch(setErrorRequestLanguage(error));
      throw error;
    }
    return promiseLanguage;
  };
}

/**
 * @param language The language. If not given, the default language from DDO is used.
 * @returns A Redux action that sends a REST call for locale list data.
 */
function loadLocaleList(language) {
  return async (dispatch, getState) => {
    var _getState$localeAPI2;
    const effectiveLanguage = language !== null && language !== void 0 ? language : await dispatch(loadLanguage());
    const {
      requestsLocaleList = {}
    } = (_getState$localeAPI2 = getState().localeAPI) !== null && _getState$localeAPI2 !== void 0 ? _getState$localeAPI2 : {};
    const {
      [effectiveLanguage]: requestLocaleList
    } = requestsLocaleList;
    if (requestLocaleList) {
      return requestLocaleList;
    }
    const [primary, country] = effectiveLanguage.split('-');
    const promiseLocaleList = _Locale.default.getList({
      cc: country.toLowerCase(),
      lc: primary.toLowerCase()
    });
    dispatch(setRequestLocaleListInProgress(effectiveLanguage, promiseLocaleList));
    try {
      dispatch(setLocaleList(effectiveLanguage, await promiseLocaleList));
    } catch (error) {
      dispatch(setErrorRequestLocaleList(effectiveLanguage, error));
    }
    return promiseLocaleList;
  };
}
//# sourceMappingURL=localeAPI.js.map
