"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.loadUserStatus = loadUserStatus;
exports.setErrorRequestUserStatus = setErrorRequestUserStatus;
exports.setRequestUserStatusInProgress = setRequestUserStatusInProgress;
exports.setUserStatus = setUserStatus;
var _Profile = _interopRequireDefault(require("@carbon/ibmdotcom-services/lib/services/Profile/Profile.js"));
var _profileAPI = require("../types/profileAPI.js");
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2023
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */ /**
     * @license
     *
     * Copyright IBM Corp. 2020, 2023
     *
     * This source code is licensed under the Apache-2.0 license found in the
     * LICENSE file in the root directory of this source tree.
     */

/**
 * @param error An error from the JSONP call for user authentication status.
 * @returns A Redux action to set the state that the JSONP call for user authentication status failed.
 * @private
 */ /**
     * @param error An error from the JSONP call for user authentication status.
     * @returns A Redux action to set the state that the JSONP call for user authentication status failed.
     * @private
     */
function setErrorRequestUserStatus(error) {
  return {
    type: _profileAPI.PROFILE_API_ACTION.SET_ERROR_REQUEST_USER_STATUS,
    error
  };
}

/**
 * @param request The promise of the REST call for  user status that is in progress.
 * @returns A Redux action to set the state that the REST call for user status is in progress.
 * @private
 */
function setRequestUserStatusInProgress(request) {
  return {
    type: _profileAPI.PROFILE_API_ACTION.SET_REQUEST_USER_STATUS_IN_PROGRESS,
    request
  };
}

/**
 * @param request The user authentication status from the JSONP call.
 * @returns A Redux action to set the given user authentication status.
 */
function setUserStatus(request) {
  return {
    type: _profileAPI.PROFILE_API_ACTION.SET_USER_STATUS,
    request
  };
}
/**
 * @returns A Redux action that sends a REST call for user authentication status.
 */
function loadUserStatus(authMethod) {
  return async dispatch => {
    let promiseStatus;
    switch (authMethod) {
      case _profileAPI.MASTHEAD_AUTH_METHOD.COOKIE:
        promiseStatus = _Profile.default.checkCloudCookie();
        break;
      case _profileAPI.MASTHEAD_AUTH_METHOD.DOCS_API:
        promiseStatus = _Profile.default.checkCloudDocsAPI();
        break;
      default:
        promiseStatus = _Profile.default.getUserStatus();
    }
    dispatch(setRequestUserStatusInProgress(promiseStatus));
    try {
      dispatch(setUserStatus(await promiseStatus));
    } catch (error) {
      dispatch(setErrorRequestUserStatus(error));
      throw error;
    }
    return promiseStatus;
  };
}
//# sourceMappingURL=profileAPI.js.map
