"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.loadTranslation = loadTranslation;
exports.setErrorRequestTranslation = setErrorRequestTranslation;
exports.setRequestTranslationInProgress = setRequestTranslationInProgress;
exports.setTranslation = setTranslation;
var _Translation = _interopRequireDefault(require("@carbon/ibmdotcom-services/lib/services/Translation/Translation.js"));
var _localeAPI = require("./localeAPI.js");
var _translateAPI = require("../types/translateAPI.js");
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2023
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */ /**
     * @license
     *
     * Copyright IBM Corp. 2020, 2023
     *
     * This source code is licensed under the Apache-2.0 license found in the
     * LICENSE file in the root directory of this source tree.
     */

/**
 * @param language A language.
 * @param request The promise of the REST call for translation data of the given language that is in progress.
 * @returns A Redux action to set the state that the REST call for translation data for the given language that is in progress.
 * @private
 */ /**
     * @param language A language.
     * @param request The promise of the REST call for translation data of the given language that is in progress.
     * @returns A Redux action to set the state that the REST call for translation data for the given language that is in progress.
     * @private
     */
function setRequestTranslationInProgress(language, request, endpoint) {
  return {
    type: _translateAPI.TRANSLATE_API_ACTION.SET_REQUEST_TRANSLATION_IN_PROGRESS,
    language,
    request,
    endpoint
  };
}

/**
 * @param language A language.
 * @param error An error from the REST call for translation data of the given language.
 * @returns A Redux action to set the state that the REST call for translation data for the given language failed.
 * @private
 */
function setErrorRequestTranslation(language, error) {
  return {
    type: _translateAPI.TRANSLATE_API_ACTION.SET_ERROR_REQUEST_TRANSLATION,
    language,
    error
  };
}

/**
 * @param language A language.
 * @param translation The translation data from the REST call.
 * @returns A Redux action to set the given translation data.
 */
function setTranslation(language, translation, endpoint) {
  return {
    type: _translateAPI.TRANSLATE_API_ACTION.SET_TRANSLATION,
    language,
    translation,
    endpoint
  };
}

/**
 * A Redux action to work with `TranslateAPI`.
 */

/**
 * @param language The language. If not given, the default language from DDO is used.
 * @param dataEndpoint The translation endpoint to fetch from if not using default c4d endpoint
 * @returns A Redux action that sends a REST call for translation data.
 */
function loadTranslation(language, dataEndpoint) {
  return async (dispatch, getState) => {
    var _getState$translateAP;
    // TODO: Can we go without casts without making `LocaleAPI` types a hard-dependency?
    const effectiveLanguage = language !== null && language !== void 0 ? language : await dispatch((0, _localeAPI.loadLanguage)());
    const {
      requestsTranslation = {}
    } = (_getState$translateAP = getState().translateAPI) !== null && _getState$translateAP !== void 0 ? _getState$translateAP : {};
    if (requestsTranslation !== null && requestsTranslation !== void 0 && requestsTranslation[effectiveLanguage]) {
      const requestTranslation = requestsTranslation === null || requestsTranslation === void 0 ? void 0 : requestsTranslation[effectiveLanguage];
      if (requestTranslation && requestTranslation.endpoint === dataEndpoint) {
        return requestTranslation;
      }
    }
    const [primary, country] = effectiveLanguage.split('-');
    const promiseTranslation = _Translation.default.getTranslation({
      cc: country.toLowerCase(),
      lc: primary.toLowerCase()
    }, dataEndpoint);
    dispatch(setRequestTranslationInProgress(effectiveLanguage, promiseTranslation, dataEndpoint));
    try {
      dispatch(setTranslation(effectiveLanguage, await promiseTranslation, dataEndpoint));
    } catch (error) {
      dispatch(setErrorRequestTranslation(effectiveLanguage, error));
    }
    return promiseTranslation;
  };
}
//# sourceMappingURL=translateAPI.js.map
