"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = reducer;
var _translateAPI = require("../types/translateAPI.js");
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2023
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */ /**
     * @license
     *
     * Copyright IBM Corp. 2020, 2023
     *
     * This source code is licensed under the Apache-2.0 license found in the
     * LICENSE file in the root directory of this source tree.
     */

/**
 * @param state The state for translate API.
 * @param action The action.
 * @returns The new state for translate API.
 */
function reducer(state = {}, action) {
  switch (action.type) {
    case _translateAPI.TRANSLATE_API_ACTION.SET_REQUEST_TRANSLATION_IN_PROGRESS:
      {
        const {
          language,
          request,
          endpoint
        } = action;
        return {
          ...state,
          requestsTranslationInProgress: {
            ...(state.requestsTranslationInProgress || {}),
            [language]: true
          },
          requestsTranslation: {
            ...(state.requestsTranslation || {}),
            [language]: request,
            endpoint
          }
        };
      }
    case _translateAPI.TRANSLATE_API_ACTION.SET_ERROR_REQUEST_TRANSLATION:
      {
        const {
          language,
          error
        } = action;
        return {
          ...state,
          requestsTranslationInProgress: {
            ...(state.requestsTranslationInProgress || {}),
            [language]: false
          },
          errorsRequestTranslation: {
            ...(state.errorsRequestTranslation || {}),
            [language]: error
          }
        };
      }
    case _translateAPI.TRANSLATE_API_ACTION.SET_TRANSLATION:
      {
        const {
          language,
          translation,
          endpoint
        } = action;
        return {
          ...state,
          // If application sets language data without making a REST call, mark the request as resolved already
          requestsTranslationInProgress: {
            ...(state.requestsTranslationInProgress || {}),
            [language]: false
          },
          requestsTranslation: {
            ...(state.requestsTranslation || {}),
            [language]: Promise.resolve(translation),
            endpoint
          },
          translations: {
            ...(state.translations || {}),
            [language]: translation
          }
        };
      }
    default:
      return state;
  }
}
//# sourceMappingURL=translateAPI.js.map
